" autoload/characterize.vim
" Maintainer:   Tim Pope <http://tpo.pe/>

unlet! s:digraphs

if exists("g:autoloaded_characterize") || &cp
  finish
endif
let g:autoloaded_characterize = 1

scriptencoding utf-8

function! characterize#digraphs(...) abort
  if !exists('s:digraphs')
    redir => out
    silent digraphs
    redir END
    redraw
    let s:digraphs = {}
    for line in split(out, '\n')
      for entry in split(line, " \\d\\+\\zs\\s*")
        let nr = matchstr(entry, '\d\+$')
        if nr ==# '10' && len(s:digraphs) <= 1
          let nr = 0
        endif
        if !has_key(s:digraphs, nr)
          let s:digraphs[nr] = []
        endif
        let s:digraphs[nr] += [matchstr(entry, '^..')]
      endfor
    endfor
  endif
  return a:0 ? get(s:digraphs, a:1, []) : s:digraphs
endfunction

function! characterize#html_entity(nr) abort
  let char = get(s:html_entities, a:nr, '')
  if !empty(char)
    return '&' . char . ';'
  else
    return ''
  endif
endfunction

let s:html_entities = {
      \  160:    'nbsp',  161:   'iexcl',  162:    'cent',  163:   'pound',
      \  164:  'curren',  165:     'yen',  166:  'brvbar',  167:    'sect',
      \  168:     'uml',  169:    'copy',  170:    'ordf',  171:   'laquo',
      \  172:     'not',  173:     'shy',  174:     'reg',  175:    'macr',
      \  176:     'deg',  177:  'plusmn',  178:    'sup2',  179:    'sup3',
      \  180:   'acute',  181:   'micro',  182:    'para',  183:  'middot',
      \  184:   'cedil',  185:    'sup1',  186:    'ordm',  187:   'raquo',
      \  188:  'frac14',  189:  'frac12',  190:  'frac34',  191:  'iquest',
      \  192:  'Agrave',  193:  'Aacute',  194:   'Acirc',  195:  'Atilde',
      \  196:    'Auml',  197:   'Aring',  198:   'AElig',  199:  'Ccedil',
      \  200:  'Egrave',  201:  'Eacute',  202:   'Ecirc',  203:    'Euml',
      \  204:  'Igrave',  205:  'Iacute',  206:   'Icirc',  207:    'Iuml',
      \  208:     'ETH',  209:  'Ntilde',  210:  'Ograve',  211:  'Oacute',
      \  212:   'Ocirc',  213:  'Otilde',  214:    'Ouml',  215:   'times',
      \  216:  'Oslash',  217:  'Ugrave',  218:  'Uacute',  219:   'Ucirc',
      \  220:    'Uuml',  221:  'Yacute',  222:   'THORN',  223:   'szlig',
      \  224:  'agrave',  225:  'aacute',  226:   'acirc',  227:  'atilde',
      \  228:    'auml',  229:   'aring',  230:   'aelig',  231:  'ccedil',
      \  232:  'egrave',  233:  'eacute',  234:   'ecirc',  235:    'euml',
      \  236:  'igrave',  237:  'iacute',  238:   'icirc',  239:    'iuml',
      \  240:     'eth',  241:  'ntilde',  242:  'ograve',  243:  'oacute',
      \  244:   'ocirc',  245:  'otilde',  246:    'ouml',  247:  'divide',
      \  248:  'oslash',  249:  'ugrave',  250:  'uacute',  251:   'ucirc',
      \  252:    'uuml',  253:  'yacute',  254:   'thorn',  255:    'yuml',
      \  338:   'OElig',  339:   'oelig',  352:  'Scaron',  353:  'scaron',
      \  376:    'Yuml',  710:    'circ',  732:   'tilde', 8194:    'ensp',
      \ 8195:    'emsp', 8201:  'thinsp', 8204:    'zwnj', 8205:     'zwj',
      \ 8206:     'lrm', 8207:     'rlm', 8211:   'ndash', 8212:   'mdash',
      \ 8216:   'lsquo', 8217:   'rsquo', 8218:   'sbquo', 8220:   'ldquo',
      \ 8221:   'rdquo', 8222:   'bdquo', 8224:  'dagger', 8225:  'Dagger',
      \ 8240:  'permil', 8249:  'lsaquo', 8250:  'rsaquo', 8364:    'euro',
      \  402:    'fnof',  913:   'Alpha',  914:    'Beta',  915:   'Gamma',
      \  916:   'Delta',  917: 'Epsilon',  918:    'Zeta',  919:     'Eta',
      \  920:   'Theta',  921:    'Iota',  922:   'Kappa',  923:  'Lambda',
      \  924:      'Mu',  925:      'Nu',  926:      'Xi',  927: 'Omicron',
      \  928:      'Pi',  929:     'Rho',  931:   'Sigma',  932:     'Tau',
      \  933: 'Upsilon',  934:     'Phi',  935:     'Chi',  936:     'Psi',
      \  937:   'Omega',  945:   'alpha',  946:    'beta',  947:   'gamma',
      \  948:   'delta',  949: 'epsilon',  950:    'zeta',  951:     'eta',
      \  952:   'theta',  953:    'iota',  954:   'kappa',  955:  'lambda',
      \  956:      'mu',  957:      'nu',  958:      'xi',  959: 'omicron',
      \  960:      'pi',  961:     'rho',  962:  'sigmaf',  963:   'sigma',
      \  964:     'tau',  965: 'upsilon',  966:     'phi',  967:     'chi',
      \  968:     'psi',  969:   'omega',  977:'thetasym',  978:   'upsih',
      \  982:     'piv', 8226:    'bull', 8230:  'hellip', 8242:   'prime',
      \ 8243:   'Prime', 8254:   'oline', 8260:   'frasl', 8472:  'weierp',
      \ 8465:   'image', 8476:    'real', 8482:   'trade', 8501: 'alefsym',
      \ 8592:    'larr', 8593:    'uarr', 8594:    'rarr', 8595:    'darr',
      \ 8596:    'harr', 8629:   'crarr', 8656:    'lArr', 8657:    'uArr',
      \ 8658:    'rArr', 8659:    'dArr', 8660:    'hArr', 8704:  'forall',
      \ 8706:    'part', 8707:   'exist', 8709:   'empty', 8711:   'nabla',
      \ 8712:    'isin', 8713:   'notin', 8715:      'ni', 8719:    'prod',
      \ 8721:     'sum', 8722:   'minus', 8727:  'lowast', 8730:   'radic',
      \ 8733:    'prop', 8734:   'infin', 8736:     'ang', 8743:     'and',
      \ 8744:      'or', 8745:     'cap', 8746:     'cup', 8747:     'int',
      \ 8756:  'there4', 8764:     'sim', 8773:    'cong', 8776:   'asymp',
      \ 8800:      'ne', 8801:   'equiv', 8804:      'le', 8805:      'ge',
      \ 8834:     'sub', 8835:     'sup', 8836:    'nsub', 8838:    'sube',
      \ 8839:    'supe', 8853:   'oplus', 8855:  'otimes', 8869:    'perp',
      \ 8901:    'sdot', 8968:   'lceil', 8969:   'rceil', 8970:  'lfloor',
      \ 8971:  'rfloor', 9001:    'lang', 9002:    'rang', 9674:     'loz',
      \ 9824:  'spades', 9827:   'clubs', 9829:  'hearts', 9830:   'diams',
      \   38:     'amp',   39:    'apos',   60:      'lt',   62:      'gt'}

function! characterize#emojis(...) abort
  return a:0 ? get(s:emojis, a:1, []) : s:emojis
endfunction

let s:emojis = {
      \ 0x00a9: [':copyright:'],
      \ 0x00ae: [':registered:'],
      \ 0x203c: [':bangbang:'],
      \ 0x2049: [':interrobang:'],
      \ 0x2122: [':tm:'],
      \ 0x2139: [':information_source:'],
      \ 0x2194: [':left_right_arrow:'],
      \ 0x2195: [':arrow_up_down:'],
      \ 0x2196: [':arrow_upper_left:'],
      \ 0x2197: [':arrow_upper_right:'],
      \ 0x2198: [':arrow_lower_right:'],
      \ 0x2199: [':arrow_lower_left:'],
      \ 0x21a9: [':leftwards_arrow_with_hook:'],
      \ 0x21aa: [':arrow_right_hook:'],
      \ 0x231a: [':watch:'],
      \ 0x23e9: [':fast_forward:'],
      \ 0x23ea: [':rewind:'],
      \ 0x23eb: [':arrow_double_up:'],
      \ 0x23ec: [':arrow_double_down:'],
      \ 0x23f0: [':alarm_clock:'],
      \ 0x23f3: [':hourglass:'],
      \ 0x24c2: [':m:'],
      \ 0x25b6: [':arrow_forward:'],
      \ 0x25c0: [':arrow_backward:'],
      \ 0x25fc: [':black_square:'],
      \ 0x2600: [':sunny:'],
      \ 0x2601: [':cloud:'],
      \ 0x260e: [':phone:', ':telephone:'],
      \ 0x2611: [':ballot_box_with_check:'],
      \ 0x2614: [':umbrella:'],
      \ 0x2615: [':coffee:'],
      \ 0x261d: [':point_up:'],
      \ 0x263a: [':relaxed:'],
      \ 0x2648: [':aries:'],
      \ 0x2649: [':taurus:'],
      \ 0x264a: [':gemini:'],
      \ 0x264b: [':cancer:'],
      \ 0x264c: [':leo:'],
      \ 0x264d: [':virgo:'],
      \ 0x264e: [':libra:'],
      \ 0x264f: [':scorpius:'],
      \ 0x2650: [':sagittarius:'],
      \ 0x2651: [':capricorn:'],
      \ 0x2652: [':aquarius:'],
      \ 0x2653: [':pisces:'],
      \ 0x2660: [':spades:'],
      \ 0x2663: [':clubs:'],
      \ 0x2665: [':hearts:'],
      \ 0x2666: [':diamonds:'],
      \ 0x2668: [':hotsprings:'],
      \ 0x267b: [':recycle:'],
      \ 0x267f: [':wheelchair:'],
      \ 0x2693: [':anchor:'],
      \ 0x26a0: [':warning:'],
      \ 0x26a1: [':zap:'],
      \ 0x26aa: [':white_circle:'],
      \ 0x26ab: [':black_circle:'],
      \ 0x26bd: [':soccer:'],
      \ 0x26be: [':baseball:'],
      \ 0x26c4: [':snowman:'],
      \ 0x26c5: [':partly_sunny:'],
      \ 0x26ce: [':ophiuchus:'],
      \ 0x26d4: [':no_entry:'],
      \ 0x26ea: [':church:'],
      \ 0x26f2: [':fountain:'],
      \ 0x26f3: [':golf:'],
      \ 0x26f5: [':boat:', ':sailboat:'],
      \ 0x26fa: [':tent:'],
      \ 0x26fd: [':fuelpump:'],
      \ 0x2702: [':scissors:'],
      \ 0x2705: [':white_check_mark:'],
      \ 0x2708: [':airplane:'],
      \ 0x2709: [':envelope:'],
      \ 0x270a: [':fist:'],
      \ 0x270b: [':hand:'],
      \ 0x270c: [':v:'],
      \ 0x270f: [':pencil2:'],
      \ 0x2712: [':black_nib:'],
      \ 0x2714: [':heavy_check_mark:'],
      \ 0x2716: [':heavy_multiplication_x:'],
      \ 0x2728: [':sparkles:'],
      \ 0x2733: [':eight_spoked_asterisk:'],
      \ 0x2734: [':eight_pointed_black_star:'],
      \ 0x2744: [':snowflake:'],
      \ 0x274c: [':x:'],
      \ 0x274e: [':negative_squared_cross_mark:'],
      \ 0x2754: [':grey_question:', ':question:'],
      \ 0x2755: [':exclamation:', ':grey_exclamation:'],
      \ 0x2757: [':heavy_exclamation_mark:'],
      \ 0x2764: [':heart:'],
      \ 0x2795: [':heavy_plus_sign:'],
      \ 0x2796: [':heavy_minus_sign:'],
      \ 0x2797: [':heavy_division_sign:'],
      \ 0x27a1: [':arrow_right:'],
      \ 0x27b0: [':curly_loop:'],
      \ 0x27bf: [':loop:'],
      \ 0x2934: [':arrow_heading_up:'],
      \ 0x2935: [':arrow_heading_down:'],
      \ 0x2b05: [':arrow_left:'],
      \ 0x2b06: [':arrow_up:'],
      \ 0x2b07: [':arrow_down:'],
      \ 0x2b1c: [':white_square:'],
      \ 0x2b55: [':o:'],
      \ 0x3030: [':wavy_dash:'],
      \ 0x303d: [':part_alternation_mark:'],
      \ 0x3297: [':congratulations:'],
      \ 0x3299: [':secret:'],
      \ 0x1f004: [':mahjong:'],
      \ 0x1f0cf: [':black_joker:'],
      \ 0x1f170: [':a:'],
      \ 0x1f171: [':b:'],
      \ 0x1f17e: [':o2:'],
      \ 0x1f17f: [':parking:'],
      \ 0x1f18e: [':ab:'],
      \ 0x1f191: [':cl:'],
      \ 0x1f192: [':cool:'],
      \ 0x1f193: [':free:'],
      \ 0x1f194: [':id:'],
      \ 0x1f195: [':new:'],
      \ 0x1f196: [':ng:'],
      \ 0x1f197: [':ok:'],
      \ 0x1f198: [':sos:'],
      \ 0x1f199: [':up:'],
      \ 0x1f19a: [':vs:'],
      \ 0x1f201: [':koko:'],
      \ 0x1f202: [':sa:'],
      \ 0x1f21a: [':u7121:'],
      \ 0x1f22f: [':u6307:'],
      \ 0x1f232: [':u7981:'],
      \ 0x1f233: [':u7a7a:'],
      \ 0x1f234: [':u5408:'],
      \ 0x1f235: [':u6e80:'],
      \ 0x1f236: [':u6709:'],
      \ 0x1f237: [':u6708:'],
      \ 0x1f238: [':u7533:'],
      \ 0x1f239: [':u5272:'],
      \ 0x1f23a: [':u55b6:'],
      \ 0x1f250: [':ideograph_advantage:'],
      \ 0x1f251: [':accept:'],
      \ 0x1f300: [':cyclone:'],
      \ 0x1f301: [':foggy:'],
      \ 0x1f302: [':closed_umbrella:'],
      \ 0x1f303: [':stars:'],
      \ 0x1f304: [':sunrise_over_mountains:'],
      \ 0x1f305: [':sunrise:'],
      \ 0x1f306: [':city_sunset:'],
      \ 0x1f307: [':city_sunrise:'],
      \ 0x1f308: [':rainbow:'],
      \ 0x1f309: [':bridge_at_night:'],
      \ 0x1f30a: [':ocean:'],
      \ 0x1f30b: [':volcano:'],
      \ 0x1f30c: [':milky_way:'],
      \ 0x1f30d: [':earth_africa:'],
      \ 0x1f30e: [':earth_americas:'],
      \ 0x1f30f: [':earth_asia:'],
      \ 0x1f310: [':globe_with_meridians:'],
      \ 0x1f311: [':new_moon:'],
      \ 0x1f312: [':waxing_crescent_moon:'],
      \ 0x1f313: [':first_quarter_moon:'],
      \ 0x1f314: [':waxing_gibbous_moon:'],
      \ 0x1f315: [':full_moon:'],
      \ 0x1f316: [':waning_gibbous_moon:'],
      \ 0x1f317: [':last_quarter_moon:'],
      \ 0x1f318: [':waning_crescent_moon:'],
      \ 0x1f319: [':moon:'],
      \ 0x1f31a: [':new_moon_with_face:'],
      \ 0x1f31b: [':first_quarter_moon_with_face:'],
      \ 0x1f31c: [':last_quarter_moon_with_face:'],
      \ 0x1f31d: [':full_moon_with_face:'],
      \ 0x1f31e: [':sun_with_face:'],
      \ 0x1f31f: [':star:', ':star2:'],
      \ 0x1f330: [':chestnut:'],
      \ 0x1f331: [':seedling:'],
      \ 0x1f332: [':evergreen_tree:'],
      \ 0x1f333: [':deciduous_tree:'],
      \ 0x1f334: [':palm_tree:'],
      \ 0x1f335: [':cactus:'],
      \ 0x1f337: [':tulip:'],
      \ 0x1f338: [':cherry_blossom:'],
      \ 0x1f339: [':rose:'],
      \ 0x1f33a: [':hibiscus:'],
      \ 0x1f33b: [':sunflower:'],
      \ 0x1f33c: [':blossom:'],
      \ 0x1f33d: [':corn:'],
      \ 0x1f33e: [':ear_of_rice:'],
      \ 0x1f33f: [':herb:'],
      \ 0x1f340: [':four_leaf_clover:'],
      \ 0x1f341: [':maple_leaf:'],
      \ 0x1f342: [':fallen_leaf:'],
      \ 0x1f343: [':leaves:'],
      \ 0x1f344: [':mushroom:'],
      \ 0x1f345: [':tomato:'],
      \ 0x1f346: [':eggplant:'],
      \ 0x1f347: [':grapes:'],
      \ 0x1f348: [':melon:'],
      \ 0x1f349: [':watermelon:'],
      \ 0x1f34a: [':tangerine:'],
      \ 0x1f34b: [':lemon:'],
      \ 0x1f34c: [':banana:'],
      \ 0x1f34d: [':pineapple:'],
      \ 0x1f34e: [':apple:'],
      \ 0x1f34f: [':green_apple:'],
      \ 0x1f350: [':pear:'],
      \ 0x1f351: [':peach:'],
      \ 0x1f352: [':cherries:'],
      \ 0x1f353: [':strawberry:'],
      \ 0x1f354: [':hamburger:'],
      \ 0x1f355: [':pizza:'],
      \ 0x1f356: [':meat_on_bone:'],
      \ 0x1f357: [':poultry_leg:'],
      \ 0x1f358: [':rice_cracker:'],
      \ 0x1f359: [':rice_ball:'],
      \ 0x1f35a: [':rice:'],
      \ 0x1f35b: [':curry:'],
      \ 0x1f35c: [':ramen:'],
      \ 0x1f35d: [':spaghetti:'],
      \ 0x1f35e: [':bread:'],
      \ 0x1f35f: [':fries:'],
      \ 0x1f360: [':sweet_potato:'],
      \ 0x1f361: [':dango:'],
      \ 0x1f362: [':oden:'],
      \ 0x1f363: [':sushi:'],
      \ 0x1f364: [':fried_shrimp:'],
      \ 0x1f365: [':fish_cake:'],
      \ 0x1f366: [':icecream:'],
      \ 0x1f367: [':shaved_ice:'],
      \ 0x1f368: [':ice_cream:'],
      \ 0x1f369: [':doughnut:'],
      \ 0x1f36a: [':cookie:'],
      \ 0x1f36b: [':chocolate_bar:'],
      \ 0x1f36c: [':candy:'],
      \ 0x1f36d: [':lollipop:'],
      \ 0x1f36e: [':custard:'],
      \ 0x1f36f: [':honey_pot:'],
      \ 0x1f370: [':cake:'],
      \ 0x1f371: [':bento:'],
      \ 0x1f372: [':stew:'],
      \ 0x1f373: [':egg:'],
      \ 0x1f374: [':fork_and_knife:'],
      \ 0x1f375: [':tea:'],
      \ 0x1f376: [':sake:'],
      \ 0x1f377: [':wine_glass:'],
      \ 0x1f378: [':cocktail:'],
      \ 0x1f379: [':tropical_drink:'],
      \ 0x1f37a: [':beer:'],
      \ 0x1f37b: [':beers:'],
      \ 0x1f37c: [':baby_bottle:'],
      \ 0x1f380: [':ribbon:'],
      \ 0x1f381: [':gift:'],
      \ 0x1f382: [':birthday:'],
      \ 0x1f383: [':jack_o_lantern:'],
      \ 0x1f384: [':christmas_tree:'],
      \ 0x1f385: [':santa:'],
      \ 0x1f386: [':fireworks:'],
      \ 0x1f387: [':sparkler:'],
      \ 0x1f388: [':balloon:'],
      \ 0x1f389: [':tada:'],
      \ 0x1f38a: [':confetti_ball:'],
      \ 0x1f38b: [':tanabata_tree:'],
      \ 0x1f38c: [':crossed_flags:'],
      \ 0x1f38d: [':bamboo:'],
      \ 0x1f38e: [':dolls:'],
      \ 0x1f38f: [':flags:'],
      \ 0x1f390: [':wind_chime:'],
      \ 0x1f391: [':rice_scene:'],
      \ 0x1f392: [':school_satchel:'],
      \ 0x1f393: [':mortar_board:'],
      \ 0x1f3a0: [':carousel_horse:'],
      \ 0x1f3a1: [':ferris_wheel:'],
      \ 0x1f3a2: [':roller_coaster:'],
      \ 0x1f3a3: [':fishing_pole_and_fish:'],
      \ 0x1f3a4: [':microphone:'],
      \ 0x1f3a5: [':movie_camera:'],
      \ 0x1f3a6: [':cinema:'],
      \ 0x1f3a7: [':headphones:'],
      \ 0x1f3a8: [':art:'],
      \ 0x1f3a9: [':tophat:'],
      \ 0x1f3aa: [':circus_tent:'],
      \ 0x1f3ab: [':ticket:'],
      \ 0x1f3ac: [':clapper:'],
      \ 0x1f3ad: [':performing_arts:'],
      \ 0x1f3ae: [':video_game:'],
      \ 0x1f3af: [':dart:'],
      \ 0x1f3b0: [':slot_machine:'],
      \ 0x1f3b1: [':8ball:'],
      \ 0x1f3b2: [':game_die:'],
      \ 0x1f3b3: [':bowling:'],
      \ 0x1f3b4: [':flower_playing_cards:'],
      \ 0x1f3b5: [':musical_note:'],
      \ 0x1f3b6: [':notes:'],
      \ 0x1f3b7: [':saxophone:'],
      \ 0x1f3b8: [':guitar:'],
      \ 0x1f3b9: [':musical_keyboard:'],
      \ 0x1f3ba: [':trumpet:'],
      \ 0x1f3bb: [':violin:'],
      \ 0x1f3bc: [':musical_score:'],
      \ 0x1f3bd: [':running_shirt_with_sash:'],
      \ 0x1f3be: [':tennis:'],
      \ 0x1f3bf: [':ski:'],
      \ 0x1f3c0: [':basketball:'],
      \ 0x1f3c1: [':checkered_flag:'],
      \ 0x1f3c2: [':snowboarder:'],
      \ 0x1f3c3: [':runner:', ':running:'],
      \ 0x1f3c4: [':surfer:'],
      \ 0x1f3c6: [':trophy:'],
      \ 0x1f3c7: [':horse_racing:'],
      \ 0x1f3c8: [':football:'],
      \ 0x1f3c9: [':rugby_football:'],
      \ 0x1f3ca: [':swimmer:'],
      \ 0x1f3e0: [':house:'],
      \ 0x1f3e2: [':office:'],
      \ 0x1f3e3: [':post_office:'],
      \ 0x1f3e4: [':european_post_office:'],
      \ 0x1f3e5: [':hospital:'],
      \ 0x1f3e6: [':bank:'],
      \ 0x1f3e7: [':atm:'],
      \ 0x1f3e8: [':hotel:'],
      \ 0x1f3e9: [':love_hotel:'],
      \ 0x1f3ea: [':convenience_store:'],
      \ 0x1f3eb: [':school:'],
      \ 0x1f3ec: [':department_store:'],
      \ 0x1f3ed: [':factory:'],
      \ 0x1f3ee: [':izakaya_lantern:'],
      \ 0x1f3ef: [':japanese_castle:'],
      \ 0x1f3f0: [':european_castle:'],
      \ 0x1f400: [':rat:'],
      \ 0x1f401: [':mouse2:'],
      \ 0x1f402: [':ox:'],
      \ 0x1f403: [':water_buffalo:'],
      \ 0x1f404: [':cow2:'],
      \ 0x1f405: [':tiger2:'],
      \ 0x1f406: [':leopard:'],
      \ 0x1f407: [':rabbit2:'],
      \ 0x1f408: [':cat2:'],
      \ 0x1f409: [':dragon:'],
      \ 0x1f40a: [':crocodile:'],
      \ 0x1f40b: [':whale2:'],
      \ 0x1f40c: [':snail:'],
      \ 0x1f40d: [':snake:'],
      \ 0x1f40e: [':racehorse:'],
      \ 0x1f40f: [':ram:'],
      \ 0x1f410: [':goat:'],
      \ 0x1f411: [':sheep:'],
      \ 0x1f412: [':monkey:'],
      \ 0x1f413: [':rooster:'],
      \ 0x1f414: [':chicken:'],
      \ 0x1f415: [':dog2:'],
      \ 0x1f416: [':pig2:'],
      \ 0x1f417: [':boar:'],
      \ 0x1f418: [':elephant:'],
      \ 0x1f419: [':octopus:'],
      \ 0x1f41a: [':shell:'],
      \ 0x1f41b: [':bug:'],
      \ 0x1f41c: [':ant:'],
      \ 0x1f41d: [':honeybee:'],
      \ 0x1f41e: [':beetle:'],
      \ 0x1f41f: [':fish:'],
      \ 0x1f420: [':tropical_fish:'],
      \ 0x1f421: [':blowfish:'],
      \ 0x1f422: [':turtle:'],
      \ 0x1f423: [':hatching_chick:'],
      \ 0x1f424: [':baby_chick:'],
      \ 0x1f425: [':hatched_chick:'],
      \ 0x1f426: [':bird:'],
      \ 0x1f427: [':penguin:'],
      \ 0x1f428: [':koala:'],
      \ 0x1f429: [':poodle:'],
      \ 0x1f42a: [':dromedary_camel:'],
      \ 0x1f42b: [':camel:'],
      \ 0x1f42c: [':dolphin:'],
      \ 0x1f42d: [':mouse:'],
      \ 0x1f42e: [':cow:'],
      \ 0x1f42f: [':tiger:'],
      \ 0x1f430: [':rabbit:'],
      \ 0x1f431: [':cat:'],
      \ 0x1f432: [':dragon_face:'],
      \ 0x1f433: [':whale:'],
      \ 0x1f434: [':horse:'],
      \ 0x1f435: [':monkey_face:'],
      \ 0x1f436: [':dog:'],
      \ 0x1f437: [':pig:'],
      \ 0x1f438: [':frog:'],
      \ 0x1f439: [':hamster:'],
      \ 0x1f43a: [':wolf:'],
      \ 0x1f43b: [':bear:'],
      \ 0x1f43c: [':panda_face:'],
      \ 0x1f43d: [':pig_nose:'],
      \ 0x1f43e: [':paw_prints:'],
      \ 0x1f440: [':eyes:'],
      \ 0x1f442: [':ear:'],
      \ 0x1f443: [':nose:'],
      \ 0x1f444: [':lips:'],
      \ 0x1f445: [':tongue2:'],
      \ 0x1f446: [':point_up_2:'],
      \ 0x1f447: [':point_down:'],
      \ 0x1f448: [':point_left:'],
      \ 0x1f449: [':point_right:'],
      \ 0x1f44a: [':facepunch:', ':punch:'],
      \ 0x1f44b: [':wave:'],
      \ 0x1f44c: [':ok_hand:'],
      \ 0x1f44d: [':+1:', ':thumbsup:'],
      \ 0x1f44e: [':-1:', ':thumbsdown:'],
      \ 0x1f44f: [':clap:'],
      \ 0x1f450: [':open_hands:'],
      \ 0x1f451: [':crown:'],
      \ 0x1f452: [':womans_hat:'],
      \ 0x1f453: [':eyeglasses:'],
      \ 0x1f454: [':necktie:'],
      \ 0x1f455: [':shirt:', ':tshirt:'],
      \ 0x1f456: [':jeans:'],
      \ 0x1f457: [':dress:'],
      \ 0x1f458: [':kimono:'],
      \ 0x1f459: [':bikini:'],
      \ 0x1f45a: [':womans_clothes:'],
      \ 0x1f45b: [':purse:'],
      \ 0x1f45c: [':handbag:'],
      \ 0x1f45d: [':pouch:'],
      \ 0x1f45e: [':mans_shoe:'],
      \ 0x1f45f: [':shoe:'],
      \ 0x1f460: [':high_heel:'],
      \ 0x1f461: [':sandal:'],
      \ 0x1f462: [':boot:'],
      \ 0x1f463: [':feet:'],
      \ 0x1f464: [':bust_in_silhouette:'],
      \ 0x1f465: [':busts_in_silhouette:'],
      \ 0x1f466: [':boy:'],
      \ 0x1f467: [':girl:'],
      \ 0x1f468: [':man:'],
      \ 0x1f469: [':woman:'],
      \ 0x1f46a: [':family:'],
      \ 0x1f46b: [':couple:'],
      \ 0x1f46c: [':two_men_holding_hands:'],
      \ 0x1f46d: [':two_women_holding_hands:'],
      \ 0x1f46e: [':cop:'],
      \ 0x1f46f: [':dancers:'],
      \ 0x1f470: [':bride_with_veil:'],
      \ 0x1f471: [':person_with_blond_hair:'],
      \ 0x1f472: [':man_with_gua_pi_mao:'],
      \ 0x1f473: [':man_with_turban:'],
      \ 0x1f474: [':older_man:'],
      \ 0x1f475: [':older_woman:'],
      \ 0x1f476: [':baby:'],
      \ 0x1f477: [':construction_worker:'],
      \ 0x1f478: [':princess:'],
      \ 0x1f479: [':japanese_ogre:'],
      \ 0x1f47a: [':japanese_goblin:'],
      \ 0x1f47b: [':ghost:'],
      \ 0x1f47c: [':angel:'],
      \ 0x1f47d: [':alien:'],
      \ 0x1f47e: [':space_invader:'],
      \ 0x1f47f: [':imp:'],
      \ 0x1f480: [':skull:'],
      \ 0x1f481: [':information_desk_person:'],
      \ 0x1f482: [':guardsman:'],
      \ 0x1f483: [':dancer:'],
      \ 0x1f484: [':lipstick:'],
      \ 0x1f485: [':nail_care:'],
      \ 0x1f486: [':massage:'],
      \ 0x1f487: [':haircut:'],
      \ 0x1f488: [':barber:'],
      \ 0x1f489: [':syringe:'],
      \ 0x1f48a: [':pill:'],
      \ 0x1f48b: [':kiss:'],
      \ 0x1f48c: [':love_letter:'],
      \ 0x1f48d: [':ring:'],
      \ 0x1f48e: [':gem:'],
      \ 0x1f48f: [':couplekiss:'],
      \ 0x1f490: [':bouquet:'],
      \ 0x1f491: [':couple_with_heart:'],
      \ 0x1f492: [':wedding:'],
      \ 0x1f493: [':heartbeat:'],
      \ 0x1f494: [':broken_heart:'],
      \ 0x1f495: [':two_hearts:'],
      \ 0x1f497: [':heartpulse:'],
      \ 0x1f498: [':cupid:'],
      \ 0x1f499: [':blue_heart:'],
      \ 0x1f49a: [':green_heart:'],
      \ 0x1f49b: [':yellow_heart:'],
      \ 0x1f49c: [':purple_heart:'],
      \ 0x1f49d: [':gift_heart:'],
      \ 0x1f49e: [':revolving_hearts:'],
      \ 0x1f49f: [':heart_decoration:'],
      \ 0x1f4a0: [':diamond_shape_with_a_dot_inside:'],
      \ 0x1f4a1: [':bulb:'],
      \ 0x1f4a2: [':anger:'],
      \ 0x1f4a3: [':bomb:'],
      \ 0x1f4a4: [':zzz:'],
      \ 0x1f4a5: [':boom:', ':collision:'],
      \ 0x1f4a6: [':sweat_drops:'],
      \ 0x1f4a7: [':droplet:'],
      \ 0x1f4a8: [':dash:'],
      \ 0x1f4a9: [':hankey:', ':poop:', ':shit:'],
      \ 0x1f4aa: [':muscle:'],
      \ 0x1f4ab: [':dizzy:'],
      \ 0x1f4ac: [':speech_balloon:'],
      \ 0x1f4ad: [':thought_balloon:'],
      \ 0x1f4ae: [':white_flower:'],
      \ 0x1f4af: [':100:'],
      \ 0x1f4b0: [':moneybag:'],
      \ 0x1f4b1: [':currency_exchange:'],
      \ 0x1f4b2: [':heavy_dollar_sign:'],
      \ 0x1f4b3: [':credit_card:'],
      \ 0x1f4b4: [':yen:'],
      \ 0x1f4b5: [':dollar:'],
      \ 0x1f4b6: [':euro:'],
      \ 0x1f4b7: [':pound:'],
      \ 0x1f4b8: [':money_with_wings:'],
      \ 0x1f4b9: [':chart:'],
      \ 0x1f4ba: [':seat:'],
      \ 0x1f4bb: [':computer:'],
      \ 0x1f4bc: [':briefcase:'],
      \ 0x1f4bd: [':minidisc:'],
      \ 0x1f4be: [':floppy_disk:'],
      \ 0x1f4bf: [':cd:'],
      \ 0x1f4c0: [':dvd:'],
      \ 0x1f4c1: [':file_folder:'],
      \ 0x1f4c2: [':open_file_folder:'],
      \ 0x1f4c3: [':page_with_curl:'],
      \ 0x1f4c4: [':page_facing_up:'],
      \ 0x1f4c5: [':date:'],
      \ 0x1f4c6: [':calendar:'],
      \ 0x1f4c7: [':card_index:'],
      \ 0x1f4c8: [':chart_with_upwards_trend:'],
      \ 0x1f4c9: [':chart_with_downwards_trend:'],
      \ 0x1f4ca: [':bar_chart:'],
      \ 0x1f4cb: [':clipboard:'],
      \ 0x1f4cc: [':pushpin:'],
      \ 0x1f4cd: [':round_pushpin:'],
      \ 0x1f4ce: [':paperclip:'],
      \ 0x1f4cf: [':straight_ruler:'],
      \ 0x1f4d0: [':triangular_ruler:'],
      \ 0x1f4d1: [':bookmark_tabs:'],
      \ 0x1f4d2: [':ledger:'],
      \ 0x1f4d3: [':notebook:'],
      \ 0x1f4d4: [':notebook_with_decorative_cover:'],
      \ 0x1f4d5: [':closed_book:'],
      \ 0x1f4d6: [':book:'],
      \ 0x1f4d7: [':green_book:'],
      \ 0x1f4d8: [':blue_book:'],
      \ 0x1f4d9: [':orange_book:'],
      \ 0x1f4da: [':books:'],
      \ 0x1f4db: [':name_badge:'],
      \ 0x1f4dc: [':scroll:'],
      \ 0x1f4dd: [':memo:', ':pencil:'],
      \ 0x1f4de: [':telephone_receiver:'],
      \ 0x1f4df: [':pager:'],
      \ 0x1f4e0: [':fax:'],
      \ 0x1f4e1: [':satellite:'],
      \ 0x1f4e2: [':loudspeaker:'],
      \ 0x1f4e3: [':mega:'],
      \ 0x1f4e4: [':outbox_tray:'],
      \ 0x1f4e5: [':inbox_tray:'],
      \ 0x1f4e7: [':e-mail:'],
      \ 0x1f4e8: [':incoming_envelope:'],
      \ 0x1f4e9: [':email:'],
      \ 0x1f4ea: [':mailbox_closed:'],
      \ 0x1f4eb: [':mailbox:'],
      \ 0x1f4ec: [':mailbox_with_mail:'],
      \ 0x1f4ed: [':mailbox_with_no_mail:'],
      \ 0x1f4ee: [':postbox:'],
      \ 0x1f4ef: [':postal_horn:'],
      \ 0x1f4f0: [':newspaper:'],
      \ 0x1f4f1: [':iphone:'],
      \ 0x1f4f2: [':calling:'],
      \ 0x1f4f3: [':vibration_mode:'],
      \ 0x1f4f4: [':mobile_phone_off:'],
      \ 0x1f4f5: [':no_mobile_phones:'],
      \ 0x1f4f6: [':signal_strength:'],
      \ 0x1f4f7: [':camera:'],
      \ 0x1f4f9: [':video_camera:'],
      \ 0x1f4fa: [':tv:'],
      \ 0x1f4fb: [':radio:'],
      \ 0x1f4fc: [':vhs:'],
      \ 0x1f500: [':twisted_rightwards_arrows:'],
      \ 0x1f501: [':repeat:'],
      \ 0x1f502: [':repeat_one:'],
      \ 0x1f503: [':arrows_clockwise:'],
      \ 0x1f504: [':arrows_counterclockwise:'],
      \ 0x1f505: [':low_brightness:'],
      \ 0x1f506: [':high_brightness:'],
      \ 0x1f507: [':mute:'],
      \ 0x1f509: [':sound:'],
      \ 0x1f50a: [':speaker:'],
      \ 0x1f50b: [':battery:'],
      \ 0x1f50c: [':electric_plug:'],
      \ 0x1f50d: [':mag:'],
      \ 0x1f50e: [':mag_right:'],
      \ 0x1f50f: [':lock_with_ink_pen:'],
      \ 0x1f510: [':closed_lock_with_key:'],
      \ 0x1f511: [':key:'],
      \ 0x1f512: [':lock:'],
      \ 0x1f513: [':unlock:'],
      \ 0x1f514: [':bell:'],
      \ 0x1f515: [':no_bell:'],
      \ 0x1f516: [':bookmark:'],
      \ 0x1f517: [':link:'],
      \ 0x1f518: [':radio_button:'],
      \ 0x1f51a: [':end:'],
      \ 0x1f51b: [':on:'],
      \ 0x1f51c: [':soon:'],
      \ 0x1f51d: [':top:'],
      \ 0x1f51e: [':underage:'],
      \ 0x1f51f: [':keycap_ten:'],
      \ 0x1f520: [':capital_abcd:'],
      \ 0x1f521: [':abcd:'],
      \ 0x1f522: [':1234:'],
      \ 0x1f523: [':symbols:'],
      \ 0x1f524: [':abc:'],
      \ 0x1f525: [':fire:'],
      \ 0x1f526: [':flashlight:'],
      \ 0x1f527: [':wrench:'],
      \ 0x1f528: [':hammer:'],
      \ 0x1f529: [':nut_and_bolt:'],
      \ 0x1f52a: [':hocho:'],
      \ 0x1f52b: [':gun:'],
      \ 0x1f52c: [':microscope:'],
      \ 0x1f52d: [':telescope:'],
      \ 0x1f52e: [':crystal_ball:'],
      \ 0x1f52f: [':six_pointed_star:'],
      \ 0x1f530: [':beginner:'],
      \ 0x1f531: [':trident:'],
      \ 0x1f534: [':red_circle:'],
      \ 0x1f535: [':large_blue_circle:'],
      \ 0x1f536: [':large_orange_diamond:'],
      \ 0x1f537: [':large_blue_diamond:'],
      \ 0x1f538: [':small_orange_diamond:'],
      \ 0x1f539: [':small_blue_diamond:'],
      \ 0x1f53a: [':small_red_triangle:'],
      \ 0x1f53b: [':small_red_triangle_down:'],
      \ 0x1f53c: [':arrow_up_small:'],
      \ 0x1f53d: [':arrow_down_small:'],
      \ 0x1f550: [':clock1:'],
      \ 0x1f551: [':clock2:'],
      \ 0x1f552: [':clock3:'],
      \ 0x1f553: [':clock4:'],
      \ 0x1f554: [':clock5:'],
      \ 0x1f555: [':clock6:'],
      \ 0x1f556: [':clock7:'],
      \ 0x1f557: [':clock8:'],
      \ 0x1f558: [':clock9:'],
      \ 0x1f559: [':clock10:'],
      \ 0x1f55a: [':clock11:'],
      \ 0x1f55b: [':clock12:'],
      \ 0x1f55c: [':clock130:'],
      \ 0x1f55d: [':clock230:'],
      \ 0x1f55e: [':clock330:'],
      \ 0x1f55f: [':clock430:'],
      \ 0x1f560: [':clock530:'],
      \ 0x1f561: [':clock630:'],
      \ 0x1f562: [':clock730:'],
      \ 0x1f563: [':clock830:'],
      \ 0x1f564: [':clock930:'],
      \ 0x1f565: [':clock1030:'],
      \ 0x1f566: [':clock1130:'],
      \ 0x1f567: [':clock1230:'],
      \ 0x1f5fb: [':mount_fuji:'],
      \ 0x1f5fc: [':tokyo_tower:'],
      \ 0x1f5fd: [':statue_of_liberty:'],
      \ 0x1f5fe: [':japan:'],
      \ 0x1f5ff: [':moyai:'],
      \ 0x1f601: [':grin:'],
      \ 0x1f602: [':joy:'],
      \ 0x1f603: [':smiley:'],
      \ 0x1f604: [':smile:'],
      \ 0x1f605: [':sweat_smile:'],
      \ 0x1f606: [':laughing:'],
      \ 0x1f607: [':innocent:'],
      \ 0x1f608: [':smiling_imp:'],
      \ 0x1f609: [':wink:'],
      \ 0x1f60a: [':blush:'],
      \ 0x1f60b: [':yum:'],
      \ 0x1f60c: [':satisfied:'],
      \ 0x1f60d: [':heart_eyes:'],
      \ 0x1f60e: [':sunglasses:'],
      \ 0x1f60f: [':smirk:'],
      \ 0x1f610: [':neutral_face:'],
      \ 0x1f612: [':unamused:'],
      \ 0x1f613: [':sweat:'],
      \ 0x1f614: [':pensive:'],
      \ 0x1f616: [':confounded:'],
      \ 0x1f618: [':kissing_heart:'],
      \ 0x1f61a: [':kissing_face:'],
      \ 0x1f61c: [':wink2:'],
      \ 0x1f61d: [':tongue:'],
      \ 0x1f61e: [':disappointed:'],
      \ 0x1f620: [':angry:'],
      \ 0x1f621: [':rage:'],
      \ 0x1f622: [':cry:'],
      \ 0x1f623: [':persevere:'],
      \ 0x1f624: [':triumph:'],
      \ 0x1f625: [':relieved:'],
      \ 0x1f628: [':fearful:'],
      \ 0x1f629: [':weary:'],
      \ 0x1f62a: [':sleepy:'],
      \ 0x1f62b: [':tired_face:'],
      \ 0x1f62d: [':sob:'],
      \ 0x1f630: [':cold_sweat:'],
      \ 0x1f631: [':scream:'],
      \ 0x1f632: [':astonished:'],
      \ 0x1f633: [':flushed:'],
      \ 0x1f635: [':dizzy_face:'],
      \ 0x1f636: [':no_mouth:'],
      \ 0x1f637: [':mask:'],
      \ 0x1f638: [':smile_cat:'],
      \ 0x1f639: [':joy_cat:'],
      \ 0x1f63a: [':smiley_cat:'],
      \ 0x1f63b: [':heart_eyes_cat:'],
      \ 0x1f63c: [':smirk_cat:'],
      \ 0x1f63d: [':kissing_cat:'],
      \ 0x1f63e: [':pouting_cat:'],
      \ 0x1f63f: [':crying_cat_face:'],
      \ 0x1f640: [':scream_cat:'],
      \ 0x1f645: [':no_good:'],
      \ 0x1f646: [':ok_woman:'],
      \ 0x1f647: [':bow:'],
      \ 0x1f648: [':see_no_evil:'],
      \ 0x1f649: [':hear_no_evil:'],
      \ 0x1f64a: [':speak_no_evil:'],
      \ 0x1f64b: [':raised_hand:'],
      \ 0x1f64c: [':raised_hands:'],
      \ 0x1f64d: [':person_frowning:'],
      \ 0x1f64e: [':person_with_pouting_face:'],
      \ 0x1f64f: [':pray:'],
      \ 0x1f680: [':rocket:'],
      \ 0x1f681: [':helicopter:'],
      \ 0x1f682: [':steam_locomotive:'],
      \ 0x1f683: [':railway_car:', ':train:'],
      \ 0x1f684: [':bullettrain_side:'],
      \ 0x1f685: [':bullettrain_front:'],
      \ 0x1f686: [':train2:'],
      \ 0x1f687: [':metro:'],
      \ 0x1f688: [':light_rail:'],
      \ 0x1f689: [':station:'],
      \ 0x1f68a: [':tram:'],
      \ 0x1f68c: [':bus:'],
      \ 0x1f68d: [':oncoming_bus:'],
      \ 0x1f68e: [':trolleybus:'],
      \ 0x1f68f: [':busstop:'],
      \ 0x1f690: [':minibus:'],
      \ 0x1f691: [':ambulance:'],
      \ 0x1f692: [':fire_engine:'],
      \ 0x1f693: [':police_car:'],
      \ 0x1f694: [':oncoming_police_car:'],
      \ 0x1f695: [':taxi:'],
      \ 0x1f696: [':oncoming_taxi:'],
      \ 0x1f697: [':car:', ':red_car:'],
      \ 0x1f698: [':oncoming_automobile:'],
      \ 0x1f699: [':blue_car:'],
      \ 0x1f69a: [':truck:'],
      \ 0x1f69b: [':articulated_lorry:'],
      \ 0x1f69c: [':tractor:'],
      \ 0x1f69d: [':monorail:'],
      \ 0x1f69e: [':mountain_railway:'],
      \ 0x1f69f: [':suspension_railway:'],
      \ 0x1f6a0: [':mountain_cableway:'],
      \ 0x1f6a1: [':aerial_tramway:'],
      \ 0x1f6a2: [':ship:'],
      \ 0x1f6a3: [':rowboat:'],
      \ 0x1f6a4: [':speedboat:'],
      \ 0x1f6a5: [':traffic_light:'],
      \ 0x1f6a6: [':vertical_traffic_light:'],
      \ 0x1f6a7: [':construction:'],
      \ 0x1f6a8: [':rotating_light:'],
      \ 0x1f6a9: [':triangular_flag_on_post:'],
      \ 0x1f6aa: [':door:'],
      \ 0x1f6ab: [':no_entry_sign:'],
      \ 0x1f6ac: [':smoking:'],
      \ 0x1f6ad: [':no_smoking:'],
      \ 0x1f6ae: [':put_litter_in_its_place:'],
      \ 0x1f6af: [':do_not_litter:'],
      \ 0x1f6b0: [':potable_water:'],
      \ 0x1f6b1: [':non-potable_water:'],
      \ 0x1f6b2: [':bike:'],
      \ 0x1f6b3: [':no_bicycles:'],
      \ 0x1f6b4: [':bicyclist:'],
      \ 0x1f6b5: [':mountain_bicyclist:'],
      \ 0x1f6b6: [':walking:'],
      \ 0x1f6b7: [':no_pedestrians:'],
      \ 0x1f6b8: [':children_crossing:'],
      \ 0x1f6b9: [':mens:'],
      \ 0x1f6ba: [':womens:'],
      \ 0x1f6bb: [':restroom:'],
      \ 0x1f6bc: [':baby_symbol:'],
      \ 0x1f6bd: [':toilet:'],
      \ 0x1f6be: [':wc:'],
      \ 0x1f6bf: [':shower:'],
      \ 0x1f6c0: [':bath:'],
      \ 0x1f6c1: [':bathtub:'],
      \ 0x1f6c2: [':passport_control:'],
      \ 0x1f6c3: [':customs:'],
      \ 0x1f6c4: [':baggage_claim:'],
      \ 0x1f6c5: [':left_luggage:'],
      \ }

function! characterize#description(nr, ...) abort
  return get(s:d, a:nr, a:0 ? a:1 : '')
endfunction

let s:d = {}

let s:d[0x0000]='NULL'
let s:d[0x0001]='START OF HEADING'
let s:d[0x0002]='START OF TEXT'
let s:d[0x0003]='END OF TEXT'
let s:d[0x0004]='END OF TRANSMISSION'
let s:d[0x0005]='ENQUIRY'
let s:d[0x0006]='ACKNOWLEDGE'
let s:d[0x0007]='BELL'
let s:d[0x0008]='BACKSPACE'
let s:d[0x0009]='HORIZONTAL TAB'
let s:d[0x000A]='LINE FEED'
let s:d[0x000B]='VERTICAL TAB'
let s:d[0x000C]='FORM FEED'
let s:d[0x000D]='CARRIAGE RETURN'
let s:d[0x000E]='SHIFT OUT'
let s:d[0x000F]='SHIFT IN'
let s:d[0x0010]='DATA LINK ESCAPE'
let s:d[0x0011]='DEVICE CONTROL 1'
let s:d[0x0012]='DEVICE CONTROL 2'
let s:d[0x0013]='DEVICE CONTROL 3'
let s:d[0x0014]='DEVICE CONTROL 4'
let s:d[0x0015]='NEGATIVE ACKNOWLEDGE'
let s:d[0x0016]='SYNCHRONOUS IDLE'
let s:d[0x0017]='END OF TRANSMISSION BLOCK'
let s:d[0x0018]='CANCEL'
let s:d[0x0019]='END OF MEDIUM'
let s:d[0x001A]='SUBSTITUTE'
let s:d[0x001B]='ESCAPE'
let s:d[0x001C]='FILE SEPARATOR'
let s:d[0x001D]='GROUP SEPARATOR'
let s:d[0x001E]='RECORD SEPARATOR'
let s:d[0x001F]='UNIT SEPARATOR'
let s:d[0x0020]='SPACE'
let s:d[0x0021]='EXCLAMATION MARK'
let s:d[0x0022]='QUOTATION MARK'
let s:d[0x0023]='NUMBER SIGN'
let s:d[0x0024]='DOLLAR SIGN'
let s:d[0x0025]='PERCENT SIGN'
let s:d[0x0026]='AMPERSAND'
let s:d[0x0027]='APOSTROPHE'
let s:d[0x0028]='LEFT PARENTHESIS'
let s:d[0x0029]='RIGHT PARENTHESIS'
let s:d[0x002A]='ASTERISK'
let s:d[0x002B]='PLUS SIGN'
let s:d[0x002C]='COMMA'
let s:d[0x002D]='HYPHEN-MINUS'
let s:d[0x002E]='FULL STOP'
let s:d[0x002F]='SOLIDUS'
let s:d[0x0030]='DIGIT ZERO'
let s:d[0x0031]='DIGIT ONE'
let s:d[0x0032]='DIGIT TWO'
let s:d[0x0033]='DIGIT THREE'
let s:d[0x0034]='DIGIT FOUR'
let s:d[0x0035]='DIGIT FIVE'
let s:d[0x0036]='DIGIT SIX'
let s:d[0x0037]='DIGIT SEVEN'
let s:d[0x0038]='DIGIT EIGHT'
let s:d[0x0039]='DIGIT NINE'
let s:d[0x003A]='COLON'
let s:d[0x003B]='SEMICOLON'
let s:d[0x003C]='LESS-THAN SIGN'
let s:d[0x003D]='EQUALS SIGN'
let s:d[0x003E]='GREATER-THAN SIGN'
let s:d[0x003F]='QUESTION MARK'
let s:d[0x0040]='COMMERCIAL AT'
let s:d[0x0041]='LATIN CAPITAL LETTER A'
let s:d[0x0042]='LATIN CAPITAL LETTER B'
let s:d[0x0043]='LATIN CAPITAL LETTER C'
let s:d[0x0044]='LATIN CAPITAL LETTER D'
let s:d[0x0045]='LATIN CAPITAL LETTER E'
let s:d[0x0046]='LATIN CAPITAL LETTER F'
let s:d[0x0047]='LATIN CAPITAL LETTER G'
let s:d[0x0048]='LATIN CAPITAL LETTER H'
let s:d[0x0049]='LATIN CAPITAL LETTER I'
let s:d[0x004A]='LATIN CAPITAL LETTER J'
let s:d[0x004B]='LATIN CAPITAL LETTER K'
let s:d[0x004C]='LATIN CAPITAL LETTER L'
let s:d[0x004D]='LATIN CAPITAL LETTER M'
let s:d[0x004E]='LATIN CAPITAL LETTER N'
let s:d[0x004F]='LATIN CAPITAL LETTER O'
let s:d[0x0050]='LATIN CAPITAL LETTER P'
let s:d[0x0051]='LATIN CAPITAL LETTER Q'
let s:d[0x0052]='LATIN CAPITAL LETTER R'
let s:d[0x0053]='LATIN CAPITAL LETTER S'
let s:d[0x0054]='LATIN CAPITAL LETTER T'
let s:d[0x0055]='LATIN CAPITAL LETTER U'
let s:d[0x0056]='LATIN CAPITAL LETTER V'
let s:d[0x0057]='LATIN CAPITAL LETTER W'
let s:d[0x0058]='LATIN CAPITAL LETTER X'
let s:d[0x0059]='LATIN CAPITAL LETTER Y'
let s:d[0x005A]='LATIN CAPITAL LETTER Z'
let s:d[0x005B]='LEFT SQUARE BRACKET'
let s:d[0x005C]='REVERSE SOLIDUS'
let s:d[0x005D]='RIGHT SQUARE BRACKET'
let s:d[0x005E]='CIRCUMFLEX ACCENT'
let s:d[0x005F]='LOW LINE'
let s:d[0x0060]='GRAVE ACCENT'
let s:d[0x0061]='LATIN SMALL LETTER A'
let s:d[0x0062]='LATIN SMALL LETTER B'
let s:d[0x0063]='LATIN SMALL LETTER C'
let s:d[0x0064]='LATIN SMALL LETTER D'
let s:d[0x0065]='LATIN SMALL LETTER E'
let s:d[0x0066]='LATIN SMALL LETTER F'
let s:d[0x0067]='LATIN SMALL LETTER G'
let s:d[0x0068]='LATIN SMALL LETTER H'
let s:d[0x0069]='LATIN SMALL LETTER I'
let s:d[0x006A]='LATIN SMALL LETTER J'
let s:d[0x006B]='LATIN SMALL LETTER K'
let s:d[0x006C]='LATIN SMALL LETTER L'
let s:d[0x006D]='LATIN SMALL LETTER M'
let s:d[0x006E]='LATIN SMALL LETTER N'
let s:d[0x006F]='LATIN SMALL LETTER O'
let s:d[0x0070]='LATIN SMALL LETTER P'
let s:d[0x0071]='LATIN SMALL LETTER Q'
let s:d[0x0072]='LATIN SMALL LETTER R'
let s:d[0x0073]='LATIN SMALL LETTER S'
let s:d[0x0074]='LATIN SMALL LETTER T'
let s:d[0x0075]='LATIN SMALL LETTER U'
let s:d[0x0076]='LATIN SMALL LETTER V'
let s:d[0x0077]='LATIN SMALL LETTER W'
let s:d[0x0078]='LATIN SMALL LETTER X'
let s:d[0x0079]='LATIN SMALL LETTER Y'
let s:d[0x007A]='LATIN SMALL LETTER Z'
let s:d[0x007B]='LEFT CURLY BRACKET'
let s:d[0x007C]='VERTICAL LINE'
let s:d[0x007D]='RIGHT CURLY BRACKET'
let s:d[0x007E]='TILDE'
let s:d[0x007F]='DELETE'
let s:d[0x0080]='PADDING CHARACTER'
let s:d[0x0081]='HIGH OCTET PRESET'
let s:d[0x0082]='BREAK PERMITTED HERE'
let s:d[0x0083]='NO BREAK HERE'
let s:d[0x0084]='INDEX'
let s:d[0x0085]='NEXT LINE'
let s:d[0x0086]='START OF SELECTED AREA'
let s:d[0x0087]='END OF SELECTED AREA'
let s:d[0x0088]='CHARACTER TABULATION SET'
let s:d[0x0089]='CHARACTER TABULATION WITH JUSTIFICATION'
let s:d[0x008A]='LINE TABULATION SET'
let s:d[0x008B]='PARTIAL LINE FORWARD'
let s:d[0x008C]='PARTIAL LINE BACKWARD'
let s:d[0x008D]='REVERSE LINE FEED'
let s:d[0x008E]='SINGLE-SHIFT TWO'
let s:d[0x008F]='SINGLE-SHIFT THREE'
let s:d[0x0090]='DEVICE CONTROL STRING'
let s:d[0x0091]='PRIVATE USE 1'
let s:d[0x0092]='PRIVATE USE 2'
let s:d[0x0093]='SET TRANSMIT STATE'
let s:d[0x0094]='CANCEL CHARACTER'
let s:d[0x0095]='MESSAGE WAITING'
let s:d[0x0096]='START OF PROTECTED AREA'
let s:d[0x0097]='END OF PROTECTED AREA'
let s:d[0x0098]='START OF STRING'
let s:d[0x0099]='SINGLE GRAPHIC CHARACTER INTRODUCER'
let s:d[0x009A]='SINGLE CHARACTER INTRO INTRODUCER'
let s:d[0x009B]='CONTROL SEQUENCE INTRODUCER'
let s:d[0x009C]='STRING TERMINATOR'
let s:d[0x009D]='OPERATING SYSTEM COMMAND'
let s:d[0x009E]='PRIVATE MESSAGE'
let s:d[0x009F]='APPLICATION PROGRAM COMMAND'
let s:d[0x00A0]='NO-BREAK SPACE'
let s:d[0x00A1]='INVERTED EXCLAMATION MARK'
let s:d[0x00A2]='CENT SIGN'
let s:d[0x00A3]='POUND SIGN'
let s:d[0x00A4]='CURRENCY SIGN'
let s:d[0x00A5]='YEN SIGN'
let s:d[0x00A6]='BROKEN BAR'
let s:d[0x00A7]='SECTION SIGN'
let s:d[0x00A8]='DIAERESIS'
let s:d[0x00A9]='COPYRIGHT SIGN'
let s:d[0x00AA]='FEMININE ORDINAL INDICATOR'
let s:d[0x00AB]='LEFT-POINTING DOUBLE ANGLE QUOTATION MARK'
let s:d[0x00AC]='NOT SIGN'
let s:d[0x00AD]='SOFT HYPHEN'
let s:d[0x00AE]='REGISTERED SIGN'
let s:d[0x00AF]='MACRON'
let s:d[0x00B0]='DEGREE SIGN'
let s:d[0x00B1]='PLUS-MINUS SIGN'
let s:d[0x00B2]='SUPERSCRIPT TWO'
let s:d[0x00B3]='SUPERSCRIPT THREE'
let s:d[0x00B4]='ACUTE ACCENT'
let s:d[0x00B5]='MICRO SIGN'
let s:d[0x00B6]='PILCROW SIGN'
let s:d[0x00B7]='MIDDLE DOT'
let s:d[0x00B8]='CEDILLA'
let s:d[0x00B9]='SUPERSCRIPT ONE'
let s:d[0x00BA]='MASCULINE ORDINAL INDICATOR'
let s:d[0x00BB]='RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK'
let s:d[0x00BC]='VULGAR FRACTION ONE QUARTER'
let s:d[0x00BD]='VULGAR FRACTION ONE HALF'
let s:d[0x00BE]='VULGAR FRACTION THREE QUARTERS'
let s:d[0x00BF]='INVERTED QUESTION MARK'
let s:d[0x00C0]='LATIN CAPITAL LETTER A WITH GRAVE'
let s:d[0x00C1]='LATIN CAPITAL LETTER A WITH ACUTE'
let s:d[0x00C2]='LATIN CAPITAL LETTER A WITH CIRCUMFLEX'
let s:d[0x00C3]='LATIN CAPITAL LETTER A WITH TILDE'
let s:d[0x00C4]='LATIN CAPITAL LETTER A WITH DIAERESIS'
let s:d[0x00C5]='LATIN CAPITAL LETTER A WITH RING ABOVE'
let s:d[0x00C6]='LATIN CAPITAL LETTER AE'
let s:d[0x00C7]='LATIN CAPITAL LETTER C WITH CEDILLA'
let s:d[0x00C8]='LATIN CAPITAL LETTER E WITH GRAVE'
let s:d[0x00C9]='LATIN CAPITAL LETTER E WITH ACUTE'
let s:d[0x00CA]='LATIN CAPITAL LETTER E WITH CIRCUMFLEX'
let s:d[0x00CB]='LATIN CAPITAL LETTER E WITH DIAERESIS'
let s:d[0x00CC]='LATIN CAPITAL LETTER I WITH GRAVE'
let s:d[0x00CD]='LATIN CAPITAL LETTER I WITH ACUTE'
let s:d[0x00CE]='LATIN CAPITAL LETTER I WITH CIRCUMFLEX'
let s:d[0x00CF]='LATIN CAPITAL LETTER I WITH DIAERESIS'
let s:d[0x00D0]='LATIN CAPITAL LETTER ETH'
let s:d[0x00D1]='LATIN CAPITAL LETTER N WITH TILDE'
let s:d[0x00D2]='LATIN CAPITAL LETTER O WITH GRAVE'
let s:d[0x00D3]='LATIN CAPITAL LETTER O WITH ACUTE'
let s:d[0x00D4]='LATIN CAPITAL LETTER O WITH CIRCUMFLEX'
let s:d[0x00D5]='LATIN CAPITAL LETTER O WITH TILDE'
let s:d[0x00D6]='LATIN CAPITAL LETTER O WITH DIAERESIS'
let s:d[0x00D7]='MULTIPLICATION SIGN'
let s:d[0x00D8]='LATIN CAPITAL LETTER O WITH STROKE'
let s:d[0x00D9]='LATIN CAPITAL LETTER U WITH GRAVE'
let s:d[0x00DA]='LATIN CAPITAL LETTER U WITH ACUTE'
let s:d[0x00DB]='LATIN CAPITAL LETTER U WITH CIRCUMFLEX'
let s:d[0x00DC]='LATIN CAPITAL LETTER U WITH DIAERESIS'
let s:d[0x00DD]='LATIN CAPITAL LETTER Y WITH ACUTE'
let s:d[0x00DE]='LATIN CAPITAL LETTER THORN'
let s:d[0x00DF]='LATIN SMALL LETTER SHARP S'
let s:d[0x00E0]='LATIN SMALL LETTER A WITH GRAVE'
let s:d[0x00E1]='LATIN SMALL LETTER A WITH ACUTE'
let s:d[0x00E2]='LATIN SMALL LETTER A WITH CIRCUMFLEX'
let s:d[0x00E3]='LATIN SMALL LETTER A WITH TILDE'
let s:d[0x00E4]='LATIN SMALL LETTER A WITH DIAERESIS'
let s:d[0x00E5]='LATIN SMALL LETTER A WITH RING ABOVE'
let s:d[0x00E6]='LATIN SMALL LETTER AE'
let s:d[0x00E7]='LATIN SMALL LETTER C WITH CEDILLA'
let s:d[0x00E8]='LATIN SMALL LETTER E WITH GRAVE'
let s:d[0x00E9]='LATIN SMALL LETTER E WITH ACUTE'
let s:d[0x00EA]='LATIN SMALL LETTER E WITH CIRCUMFLEX'
let s:d[0x00EB]='LATIN SMALL LETTER E WITH DIAERESIS'
let s:d[0x00EC]='LATIN SMALL LETTER I WITH GRAVE'
let s:d[0x00ED]='LATIN SMALL LETTER I WITH ACUTE'
let s:d[0x00EE]='LATIN SMALL LETTER I WITH CIRCUMFLEX'
let s:d[0x00EF]='LATIN SMALL LETTER I WITH DIAERESIS'
let s:d[0x00F0]='LATIN SMALL LETTER ETH'
let s:d[0x00F1]='LATIN SMALL LETTER N WITH TILDE'
let s:d[0x00F2]='LATIN SMALL LETTER O WITH GRAVE'
let s:d[0x00F3]='LATIN SMALL LETTER O WITH ACUTE'
let s:d[0x00F4]='LATIN SMALL LETTER O WITH CIRCUMFLEX'
let s:d[0x00F5]='LATIN SMALL LETTER O WITH TILDE'
let s:d[0x00F6]='LATIN SMALL LETTER O WITH DIAERESIS'
let s:d[0x00F7]='DIVISION SIGN'
let s:d[0x00F8]='LATIN SMALL LETTER O WITH STROKE'
let s:d[0x00F9]='LATIN SMALL LETTER U WITH GRAVE'
let s:d[0x00FA]='LATIN SMALL LETTER U WITH ACUTE'
let s:d[0x00FB]='LATIN SMALL LETTER U WITH CIRCUMFLEX'
let s:d[0x00FC]='LATIN SMALL LETTER U WITH DIAERESIS'
let s:d[0x00FD]='LATIN SMALL LETTER Y WITH ACUTE'
let s:d[0x00FE]='LATIN SMALL LETTER THORN'
let s:d[0x00FF]='LATIN SMALL LETTER Y WITH DIAERESIS'
let s:d[0x0100]='LATIN CAPITAL LETTER A WITH MACRON'
let s:d[0x0101]='LATIN SMALL LETTER A WITH MACRON'
let s:d[0x0102]='LATIN CAPITAL LETTER A WITH BREVE'
let s:d[0x0103]='LATIN SMALL LETTER A WITH BREVE'
let s:d[0x0104]='LATIN CAPITAL LETTER A WITH OGONEK'
let s:d[0x0105]='LATIN SMALL LETTER A WITH OGONEK'
let s:d[0x0106]='LATIN CAPITAL LETTER C WITH ACUTE'
let s:d[0x0107]='LATIN SMALL LETTER C WITH ACUTE'
let s:d[0x0108]='LATIN CAPITAL LETTER C WITH CIRCUMFLEX'
let s:d[0x0109]='LATIN SMALL LETTER C WITH CIRCUMFLEX'
let s:d[0x010A]='LATIN CAPITAL LETTER C WITH DOT ABOVE'
let s:d[0x010B]='LATIN SMALL LETTER C WITH DOT ABOVE'
let s:d[0x010C]='LATIN CAPITAL LETTER C WITH CARON'
let s:d[0x010D]='LATIN SMALL LETTER C WITH CARON'
let s:d[0x010E]='LATIN CAPITAL LETTER D WITH CARON'
let s:d[0x010F]='LATIN SMALL LETTER D WITH CARON'
let s:d[0x0110]='LATIN CAPITAL LETTER D WITH STROKE'
let s:d[0x0111]='LATIN SMALL LETTER D WITH STROKE'
let s:d[0x0112]='LATIN CAPITAL LETTER E WITH MACRON'
let s:d[0x0113]='LATIN SMALL LETTER E WITH MACRON'
let s:d[0x0114]='LATIN CAPITAL LETTER E WITH BREVE'
let s:d[0x0115]='LATIN SMALL LETTER E WITH BREVE'
let s:d[0x0116]='LATIN CAPITAL LETTER E WITH DOT ABOVE'
let s:d[0x0117]='LATIN SMALL LETTER E WITH DOT ABOVE'
let s:d[0x0118]='LATIN CAPITAL LETTER E WITH OGONEK'
let s:d[0x0119]='LATIN SMALL LETTER E WITH OGONEK'
let s:d[0x011A]='LATIN CAPITAL LETTER E WITH CARON'
let s:d[0x011B]='LATIN SMALL LETTER E WITH CARON'
let s:d[0x011C]='LATIN CAPITAL LETTER G WITH CIRCUMFLEX'
let s:d[0x011D]='LATIN SMALL LETTER G WITH CIRCUMFLEX'
let s:d[0x011E]='LATIN CAPITAL LETTER G WITH BREVE'
let s:d[0x011F]='LATIN SMALL LETTER G WITH BREVE'
let s:d[0x0120]='LATIN CAPITAL LETTER G WITH DOT ABOVE'
let s:d[0x0121]='LATIN SMALL LETTER G WITH DOT ABOVE'
let s:d[0x0122]='LATIN CAPITAL LETTER G WITH CEDILLA'
let s:d[0x0123]='LATIN SMALL LETTER G WITH CEDILLA'
let s:d[0x0124]='LATIN CAPITAL LETTER H WITH CIRCUMFLEX'
let s:d[0x0125]='LATIN SMALL LETTER H WITH CIRCUMFLEX'
let s:d[0x0126]='LATIN CAPITAL LETTER H WITH STROKE'
let s:d[0x0127]='LATIN SMALL LETTER H WITH STROKE'
let s:d[0x0128]='LATIN CAPITAL LETTER I WITH TILDE'
let s:d[0x0129]='LATIN SMALL LETTER I WITH TILDE'
let s:d[0x012A]='LATIN CAPITAL LETTER I WITH MACRON'
let s:d[0x012B]='LATIN SMALL LETTER I WITH MACRON'
let s:d[0x012C]='LATIN CAPITAL LETTER I WITH BREVE'
let s:d[0x012D]='LATIN SMALL LETTER I WITH BREVE'
let s:d[0x012E]='LATIN CAPITAL LETTER I WITH OGONEK'
let s:d[0x012F]='LATIN SMALL LETTER I WITH OGONEK'
let s:d[0x0130]='LATIN CAPITAL LETTER I WITH DOT ABOVE'
let s:d[0x0131]='LATIN SMALL LETTER DOTLESS I'
let s:d[0x0132]='LATIN CAPITAL LIGATURE IJ'
let s:d[0x0133]='LATIN SMALL LIGATURE IJ'
let s:d[0x0134]='LATIN CAPITAL LETTER J WITH CIRCUMFLEX'
let s:d[0x0135]='LATIN SMALL LETTER J WITH CIRCUMFLEX'
let s:d[0x0136]='LATIN CAPITAL LETTER K WITH CEDILLA'
let s:d[0x0137]='LATIN SMALL LETTER K WITH CEDILLA'
let s:d[0x0138]='LATIN SMALL LETTER KRA'
let s:d[0x0139]='LATIN CAPITAL LETTER L WITH ACUTE'
let s:d[0x013A]='LATIN SMALL LETTER L WITH ACUTE'
let s:d[0x013B]='LATIN CAPITAL LETTER L WITH CEDILLA'
let s:d[0x013C]='LATIN SMALL LETTER L WITH CEDILLA'
let s:d[0x013D]='LATIN CAPITAL LETTER L WITH CARON'
let s:d[0x013E]='LATIN SMALL LETTER L WITH CARON'
let s:d[0x013F]='LATIN CAPITAL LETTER L WITH MIDDLE DOT'
let s:d[0x0140]='LATIN SMALL LETTER L WITH MIDDLE DOT'
let s:d[0x0141]='LATIN CAPITAL LETTER L WITH STROKE'
let s:d[0x0142]='LATIN SMALL LETTER L WITH STROKE'
let s:d[0x0143]='LATIN CAPITAL LETTER N WITH ACUTE'
let s:d[0x0144]='LATIN SMALL LETTER N WITH ACUTE'
let s:d[0x0145]='LATIN CAPITAL LETTER N WITH CEDILLA'
let s:d[0x0146]='LATIN SMALL LETTER N WITH CEDILLA'
let s:d[0x0147]='LATIN CAPITAL LETTER N WITH CARON'
let s:d[0x0148]='LATIN SMALL LETTER N WITH CARON'
let s:d[0x0149]='LATIN SMALL LETTER N PRECEDED BY APOSTROPHE'
let s:d[0x014A]='LATIN CAPITAL LETTER ENG'
let s:d[0x014B]='LATIN SMALL LETTER ENG'
let s:d[0x014C]='LATIN CAPITAL LETTER O WITH MACRON'
let s:d[0x014D]='LATIN SMALL LETTER O WITH MACRON'
let s:d[0x014E]='LATIN CAPITAL LETTER O WITH BREVE'
let s:d[0x014F]='LATIN SMALL LETTER O WITH BREVE'
let s:d[0x0150]='LATIN CAPITAL LETTER O WITH DOUBLE ACUTE'
let s:d[0x0151]='LATIN SMALL LETTER O WITH DOUBLE ACUTE'
let s:d[0x0152]='LATIN CAPITAL LIGATURE OE'
let s:d[0x0153]='LATIN SMALL LIGATURE OE'
let s:d[0x0154]='LATIN CAPITAL LETTER R WITH ACUTE'
let s:d[0x0155]='LATIN SMALL LETTER R WITH ACUTE'
let s:d[0x0156]='LATIN CAPITAL LETTER R WITH CEDILLA'
let s:d[0x0157]='LATIN SMALL LETTER R WITH CEDILLA'
let s:d[0x0158]='LATIN CAPITAL LETTER R WITH CARON'
let s:d[0x0159]='LATIN SMALL LETTER R WITH CARON'
let s:d[0x015A]='LATIN CAPITAL LETTER S WITH ACUTE'
let s:d[0x015B]='LATIN SMALL LETTER S WITH ACUTE'
let s:d[0x015C]='LATIN CAPITAL LETTER S WITH CIRCUMFLEX'
let s:d[0x015D]='LATIN SMALL LETTER S WITH CIRCUMFLEX'
let s:d[0x015E]='LATIN CAPITAL LETTER S WITH CEDILLA'
let s:d[0x015F]='LATIN SMALL LETTER S WITH CEDILLA'
let s:d[0x0160]='LATIN CAPITAL LETTER S WITH CARON'
let s:d[0x0161]='LATIN SMALL LETTER S WITH CARON'
let s:d[0x0162]='LATIN CAPITAL LETTER T WITH CEDILLA'
let s:d[0x0163]='LATIN SMALL LETTER T WITH CEDILLA'
let s:d[0x0164]='LATIN CAPITAL LETTER T WITH CARON'
let s:d[0x0165]='LATIN SMALL LETTER T WITH CARON'
let s:d[0x0166]='LATIN CAPITAL LETTER T WITH STROKE'
let s:d[0x0167]='LATIN SMALL LETTER T WITH STROKE'
let s:d[0x0168]='LATIN CAPITAL LETTER U WITH TILDE'
let s:d[0x0169]='LATIN SMALL LETTER U WITH TILDE'
let s:d[0x016A]='LATIN CAPITAL LETTER U WITH MACRON'
let s:d[0x016B]='LATIN SMALL LETTER U WITH MACRON'
let s:d[0x016C]='LATIN CAPITAL LETTER U WITH BREVE'
let s:d[0x016D]='LATIN SMALL LETTER U WITH BREVE'
let s:d[0x016E]='LATIN CAPITAL LETTER U WITH RING ABOVE'
let s:d[0x016F]='LATIN SMALL LETTER U WITH RING ABOVE'
let s:d[0x0170]='LATIN CAPITAL LETTER U WITH DOUBLE ACUTE'
let s:d[0x0171]='LATIN SMALL LETTER U WITH DOUBLE ACUTE'
let s:d[0x0172]='LATIN CAPITAL LETTER U WITH OGONEK'
let s:d[0x0173]='LATIN SMALL LETTER U WITH OGONEK'
let s:d[0x0174]='LATIN CAPITAL LETTER W WITH CIRCUMFLEX'
let s:d[0x0175]='LATIN SMALL LETTER W WITH CIRCUMFLEX'
let s:d[0x0176]='LATIN CAPITAL LETTER Y WITH CIRCUMFLEX'
let s:d[0x0177]='LATIN SMALL LETTER Y WITH CIRCUMFLEX'
let s:d[0x0178]='LATIN CAPITAL LETTER Y WITH DIAERESIS'
let s:d[0x0179]='LATIN CAPITAL LETTER Z WITH ACUTE'
let s:d[0x017A]='LATIN SMALL LETTER Z WITH ACUTE'
let s:d[0x017B]='LATIN CAPITAL LETTER Z WITH DOT ABOVE'
let s:d[0x017C]='LATIN SMALL LETTER Z WITH DOT ABOVE'
let s:d[0x017D]='LATIN CAPITAL LETTER Z WITH CARON'
let s:d[0x017E]='LATIN SMALL LETTER Z WITH CARON'
let s:d[0x017F]='LATIN SMALL LETTER LONG S'
let s:d[0x0180]='LATIN SMALL LETTER B WITH STROKE'
let s:d[0x0181]='LATIN CAPITAL LETTER B WITH HOOK'
let s:d[0x0182]='LATIN CAPITAL LETTER B WITH TOPBAR'
let s:d[0x0183]='LATIN SMALL LETTER B WITH TOPBAR'
let s:d[0x0184]='LATIN CAPITAL LETTER TONE SIX'
let s:d[0x0185]='LATIN SMALL LETTER TONE SIX'
let s:d[0x0186]='LATIN CAPITAL LETTER OPEN O'
let s:d[0x0187]='LATIN CAPITAL LETTER C WITH HOOK'
let s:d[0x0188]='LATIN SMALL LETTER C WITH HOOK'
let s:d[0x0189]='LATIN CAPITAL LETTER AFRICAN D'
let s:d[0x018A]='LATIN CAPITAL LETTER D WITH HOOK'
let s:d[0x018B]='LATIN CAPITAL LETTER D WITH TOPBAR'
let s:d[0x018C]='LATIN SMALL LETTER D WITH TOPBAR'
let s:d[0x018D]='LATIN SMALL LETTER TURNED DELTA'
let s:d[0x018E]='LATIN CAPITAL LETTER REVERSED E'
let s:d[0x018F]='LATIN CAPITAL LETTER SCHWA'
let s:d[0x0190]='LATIN CAPITAL LETTER OPEN E'
let s:d[0x0191]='LATIN CAPITAL LETTER F WITH HOOK'
let s:d[0x0192]='LATIN SMALL LETTER F WITH HOOK'
let s:d[0x0193]='LATIN CAPITAL LETTER G WITH HOOK'
let s:d[0x0194]='LATIN CAPITAL LETTER GAMMA'
let s:d[0x0195]='LATIN SMALL LETTER HV'
let s:d[0x0196]='LATIN CAPITAL LETTER IOTA'
let s:d[0x0197]='LATIN CAPITAL LETTER I WITH STROKE'
let s:d[0x0198]='LATIN CAPITAL LETTER K WITH HOOK'
let s:d[0x0199]='LATIN SMALL LETTER K WITH HOOK'
let s:d[0x019A]='LATIN SMALL LETTER L WITH BAR'
let s:d[0x019B]='LATIN SMALL LETTER LAMBDA WITH STROKE'
let s:d[0x019C]='LATIN CAPITAL LETTER TURNED M'
let s:d[0x019D]='LATIN CAPITAL LETTER N WITH LEFT HOOK'
let s:d[0x019E]='LATIN SMALL LETTER N WITH LONG RIGHT LEG'
let s:d[0x019F]='LATIN CAPITAL LETTER O WITH MIDDLE TILDE'
let s:d[0x01A0]='LATIN CAPITAL LETTER O WITH HORN'
let s:d[0x01A1]='LATIN SMALL LETTER O WITH HORN'
let s:d[0x01A2]='LATIN CAPITAL LETTER OI'
let s:d[0x01A3]='LATIN SMALL LETTER OI'
let s:d[0x01A4]='LATIN CAPITAL LETTER P WITH HOOK'
let s:d[0x01A5]='LATIN SMALL LETTER P WITH HOOK'
let s:d[0x01A6]='LATIN LETTER YR'
let s:d[0x01A7]='LATIN CAPITAL LETTER TONE TWO'
let s:d[0x01A8]='LATIN SMALL LETTER TONE TWO'
let s:d[0x01A9]='LATIN CAPITAL LETTER ESH'
let s:d[0x01AA]='LATIN LETTER REVERSED ESH LOOP'
let s:d[0x01AB]='LATIN SMALL LETTER T WITH PALATAL HOOK'
let s:d[0x01AC]='LATIN CAPITAL LETTER T WITH HOOK'
let s:d[0x01AD]='LATIN SMALL LETTER T WITH HOOK'
let s:d[0x01AE]='LATIN CAPITAL LETTER T WITH RETROFLEX HOOK'
let s:d[0x01AF]='LATIN CAPITAL LETTER U WITH HORN'
let s:d[0x01B0]='LATIN SMALL LETTER U WITH HORN'
let s:d[0x01B1]='LATIN CAPITAL LETTER UPSILON'
let s:d[0x01B2]='LATIN CAPITAL LETTER V WITH HOOK'
let s:d[0x01B3]='LATIN CAPITAL LETTER Y WITH HOOK'
let s:d[0x01B4]='LATIN SMALL LETTER Y WITH HOOK'
let s:d[0x01B5]='LATIN CAPITAL LETTER Z WITH STROKE'
let s:d[0x01B6]='LATIN SMALL LETTER Z WITH STROKE'
let s:d[0x01B7]='LATIN CAPITAL LETTER EZH'
let s:d[0x01B8]='LATIN CAPITAL LETTER EZH REVERSED'
let s:d[0x01B9]='LATIN SMALL LETTER EZH REVERSED'
let s:d[0x01BA]='LATIN SMALL LETTER EZH WITH TAIL'
let s:d[0x01BB]='LATIN LETTER TWO WITH STROKE'
let s:d[0x01BC]='LATIN CAPITAL LETTER TONE FIVE'
let s:d[0x01BD]='LATIN SMALL LETTER TONE FIVE'
let s:d[0x01BE]='LATIN LETTER INVERTED GLOTTAL STOP WITH STROKE'
let s:d[0x01BF]='LATIN LETTER WYNN'
let s:d[0x01C0]='LATIN LETTER DENTAL CLICK'
let s:d[0x01C1]='LATIN LETTER LATERAL CLICK'
let s:d[0x01C2]='LATIN LETTER ALVEOLAR CLICK'
let s:d[0x01C3]='LATIN LETTER RETROFLEX CLICK'
let s:d[0x01C4]='LATIN CAPITAL LETTER DZ WITH CARON'
let s:d[0x01C5]='LATIN CAPITAL LETTER D WITH SMALL LETTER Z WITH CARON'
let s:d[0x01C6]='LATIN SMALL LETTER DZ WITH CARON'
let s:d[0x01C7]='LATIN CAPITAL LETTER LJ'
let s:d[0x01C8]='LATIN CAPITAL LETTER L WITH SMALL LETTER J'
let s:d[0x01C9]='LATIN SMALL LETTER LJ'
let s:d[0x01CA]='LATIN CAPITAL LETTER NJ'
let s:d[0x01CB]='LATIN CAPITAL LETTER N WITH SMALL LETTER J'
let s:d[0x01CC]='LATIN SMALL LETTER NJ'
let s:d[0x01CD]='LATIN CAPITAL LETTER A WITH CARON'
let s:d[0x01CE]='LATIN SMALL LETTER A WITH CARON'
let s:d[0x01CF]='LATIN CAPITAL LETTER I WITH CARON'
let s:d[0x01D0]='LATIN SMALL LETTER I WITH CARON'
let s:d[0x01D1]='LATIN CAPITAL LETTER O WITH CARON'
let s:d[0x01D2]='LATIN SMALL LETTER O WITH CARON'
let s:d[0x01D3]='LATIN CAPITAL LETTER U WITH CARON'
let s:d[0x01D4]='LATIN SMALL LETTER U WITH CARON'
let s:d[0x01D5]='LATIN CAPITAL LETTER U WITH DIAERESIS AND MACRON'
let s:d[0x01D6]='LATIN SMALL LETTER U WITH DIAERESIS AND MACRON'
let s:d[0x01D7]='LATIN CAPITAL LETTER U WITH DIAERESIS AND ACUTE'
let s:d[0x01D8]='LATIN SMALL LETTER U WITH DIAERESIS AND ACUTE'
let s:d[0x01D9]='LATIN CAPITAL LETTER U WITH DIAERESIS AND CARON'
let s:d[0x01DA]='LATIN SMALL LETTER U WITH DIAERESIS AND CARON'
let s:d[0x01DB]='LATIN CAPITAL LETTER U WITH DIAERESIS AND GRAVE'
let s:d[0x01DC]='LATIN SMALL LETTER U WITH DIAERESIS AND GRAVE'
let s:d[0x01DD]='LATIN SMALL LETTER TURNED E'
let s:d[0x01DE]='LATIN CAPITAL LETTER A WITH DIAERESIS AND MACRON'
let s:d[0x01DF]='LATIN SMALL LETTER A WITH DIAERESIS AND MACRON'
let s:d[0x01E0]='LATIN CAPITAL LETTER A WITH DOT ABOVE AND MACRON'
let s:d[0x01E1]='LATIN SMALL LETTER A WITH DOT ABOVE AND MACRON'
let s:d[0x01E2]='LATIN CAPITAL LETTER AE WITH MACRON'
let s:d[0x01E3]='LATIN SMALL LETTER AE WITH MACRON'
let s:d[0x01E4]='LATIN CAPITAL LETTER G WITH STROKE'
let s:d[0x01E5]='LATIN SMALL LETTER G WITH STROKE'
let s:d[0x01E6]='LATIN CAPITAL LETTER G WITH CARON'
let s:d[0x01E7]='LATIN SMALL LETTER G WITH CARON'
let s:d[0x01E8]='LATIN CAPITAL LETTER K WITH CARON'
let s:d[0x01E9]='LATIN SMALL LETTER K WITH CARON'
let s:d[0x01EA]='LATIN CAPITAL LETTER O WITH OGONEK'
let s:d[0x01EB]='LATIN SMALL LETTER O WITH OGONEK'
let s:d[0x01EC]='LATIN CAPITAL LETTER O WITH OGONEK AND MACRON'
let s:d[0x01ED]='LATIN SMALL LETTER O WITH OGONEK AND MACRON'
let s:d[0x01EE]='LATIN CAPITAL LETTER EZH WITH CARON'
let s:d[0x01EF]='LATIN SMALL LETTER EZH WITH CARON'
let s:d[0x01F0]='LATIN SMALL LETTER J WITH CARON'
let s:d[0x01F1]='LATIN CAPITAL LETTER DZ'
let s:d[0x01F2]='LATIN CAPITAL LETTER D WITH SMALL LETTER Z'
let s:d[0x01F3]='LATIN SMALL LETTER DZ'
let s:d[0x01F4]='LATIN CAPITAL LETTER G WITH ACUTE'
let s:d[0x01F5]='LATIN SMALL LETTER G WITH ACUTE'
let s:d[0x01F6]='LATIN CAPITAL LETTER HWAIR'
let s:d[0x01F7]='LATIN CAPITAL LETTER WYNN'
let s:d[0x01F8]='LATIN CAPITAL LETTER N WITH GRAVE'
let s:d[0x01F9]='LATIN SMALL LETTER N WITH GRAVE'
let s:d[0x01FA]='LATIN CAPITAL LETTER A WITH RING ABOVE AND ACUTE'
let s:d[0x01FB]='LATIN SMALL LETTER A WITH RING ABOVE AND ACUTE'
let s:d[0x01FC]='LATIN CAPITAL LETTER AE WITH ACUTE'
let s:d[0x01FD]='LATIN SMALL LETTER AE WITH ACUTE'
let s:d[0x01FE]='LATIN CAPITAL LETTER O WITH STROKE AND ACUTE'
let s:d[0x01FF]='LATIN SMALL LETTER O WITH STROKE AND ACUTE'
let s:d[0x0200]='LATIN CAPITAL LETTER A WITH DOUBLE GRAVE'
let s:d[0x0201]='LATIN SMALL LETTER A WITH DOUBLE GRAVE'
let s:d[0x0202]='LATIN CAPITAL LETTER A WITH INVERTED BREVE'
let s:d[0x0203]='LATIN SMALL LETTER A WITH INVERTED BREVE'
let s:d[0x0204]='LATIN CAPITAL LETTER E WITH DOUBLE GRAVE'
let s:d[0x0205]='LATIN SMALL LETTER E WITH DOUBLE GRAVE'
let s:d[0x0206]='LATIN CAPITAL LETTER E WITH INVERTED BREVE'
let s:d[0x0207]='LATIN SMALL LETTER E WITH INVERTED BREVE'
let s:d[0x0208]='LATIN CAPITAL LETTER I WITH DOUBLE GRAVE'
let s:d[0x0209]='LATIN SMALL LETTER I WITH DOUBLE GRAVE'
let s:d[0x020A]='LATIN CAPITAL LETTER I WITH INVERTED BREVE'
let s:d[0x020B]='LATIN SMALL LETTER I WITH INVERTED BREVE'
let s:d[0x020C]='LATIN CAPITAL LETTER O WITH DOUBLE GRAVE'
let s:d[0x020D]='LATIN SMALL LETTER O WITH DOUBLE GRAVE'
let s:d[0x020E]='LATIN CAPITAL LETTER O WITH INVERTED BREVE'
let s:d[0x020F]='LATIN SMALL LETTER O WITH INVERTED BREVE'
let s:d[0x0210]='LATIN CAPITAL LETTER R WITH DOUBLE GRAVE'
let s:d[0x0211]='LATIN SMALL LETTER R WITH DOUBLE GRAVE'
let s:d[0x0212]='LATIN CAPITAL LETTER R WITH INVERTED BREVE'
let s:d[0x0213]='LATIN SMALL LETTER R WITH INVERTED BREVE'
let s:d[0x0214]='LATIN CAPITAL LETTER U WITH DOUBLE GRAVE'
let s:d[0x0215]='LATIN SMALL LETTER U WITH DOUBLE GRAVE'
let s:d[0x0216]='LATIN CAPITAL LETTER U WITH INVERTED BREVE'
let s:d[0x0217]='LATIN SMALL LETTER U WITH INVERTED BREVE'
let s:d[0x0218]='LATIN CAPITAL LETTER S WITH COMMA BELOW'
let s:d[0x0219]='LATIN SMALL LETTER S WITH COMMA BELOW'
let s:d[0x021A]='LATIN CAPITAL LETTER T WITH COMMA BELOW'
let s:d[0x021B]='LATIN SMALL LETTER T WITH COMMA BELOW'
let s:d[0x021C]='LATIN CAPITAL LETTER YOGH'
let s:d[0x021D]='LATIN SMALL LETTER YOGH'
let s:d[0x021E]='LATIN CAPITAL LETTER H WITH CARON'
let s:d[0x021F]='LATIN SMALL LETTER H WITH CARON'
let s:d[0x0220]='LATIN CAPITAL LETTER N WITH LONG RIGHT LEG'
let s:d[0x0221]='LATIN SMALL LETTER D WITH CURL'
let s:d[0x0222]='LATIN CAPITAL LETTER OU'
let s:d[0x0223]='LATIN SMALL LETTER OU'
let s:d[0x0224]='LATIN CAPITAL LETTER Z WITH HOOK'
let s:d[0x0225]='LATIN SMALL LETTER Z WITH HOOK'
let s:d[0x0226]='LATIN CAPITAL LETTER A WITH DOT ABOVE'
let s:d[0x0227]='LATIN SMALL LETTER A WITH DOT ABOVE'
let s:d[0x0228]='LATIN CAPITAL LETTER E WITH CEDILLA'
let s:d[0x0229]='LATIN SMALL LETTER E WITH CEDILLA'
let s:d[0x022A]='LATIN CAPITAL LETTER O WITH DIAERESIS AND MACRON'
let s:d[0x022B]='LATIN SMALL LETTER O WITH DIAERESIS AND MACRON'
let s:d[0x022C]='LATIN CAPITAL LETTER O WITH TILDE AND MACRON'
let s:d[0x022D]='LATIN SMALL LETTER O WITH TILDE AND MACRON'
let s:d[0x022E]='LATIN CAPITAL LETTER O WITH DOT ABOVE'
let s:d[0x022F]='LATIN SMALL LETTER O WITH DOT ABOVE'
let s:d[0x0230]='LATIN CAPITAL LETTER O WITH DOT ABOVE AND MACRON'
let s:d[0x0231]='LATIN SMALL LETTER O WITH DOT ABOVE AND MACRON'
let s:d[0x0232]='LATIN CAPITAL LETTER Y WITH MACRON'
let s:d[0x0233]='LATIN SMALL LETTER Y WITH MACRON'
let s:d[0x0234]='LATIN SMALL LETTER L WITH CURL'
let s:d[0x0235]='LATIN SMALL LETTER N WITH CURL'
let s:d[0x0236]='LATIN SMALL LETTER T WITH CURL'
let s:d[0x0237]='LATIN SMALL LETTER DOTLESS J'
let s:d[0x0238]='LATIN SMALL LETTER DB DIGRAPH'
let s:d[0x0239]='LATIN SMALL LETTER QP DIGRAPH'
let s:d[0x023A]='LATIN CAPITAL LETTER A WITH STROKE'
let s:d[0x023B]='LATIN CAPITAL LETTER C WITH STROKE'
let s:d[0x023C]='LATIN SMALL LETTER C WITH STROKE'
let s:d[0x023D]='LATIN CAPITAL LETTER L WITH BAR'
let s:d[0x023E]='LATIN CAPITAL LETTER T WITH DIAGONAL STROKE'
let s:d[0x023F]='LATIN SMALL LETTER S WITH SWASH TAIL'
let s:d[0x0240]='LATIN SMALL LETTER Z WITH SWASH TAIL'
let s:d[0x0241]='LATIN CAPITAL LETTER GLOTTAL STOP'
let s:d[0x0242]='LATIN SMALL LETTER GLOTTAL STOP'
let s:d[0x0243]='LATIN CAPITAL LETTER B WITH STROKE'
let s:d[0x0244]='LATIN CAPITAL LETTER U BAR'
let s:d[0x0245]='LATIN CAPITAL LETTER TURNED V'
let s:d[0x0246]='LATIN CAPITAL LETTER E WITH STROKE'
let s:d[0x0247]='LATIN SMALL LETTER E WITH STROKE'
let s:d[0x0248]='LATIN CAPITAL LETTER J WITH STROKE'
let s:d[0x0249]='LATIN SMALL LETTER J WITH STROKE'
let s:d[0x024A]='LATIN CAPITAL LETTER SMALL Q WITH HOOK TAIL'
let s:d[0x024B]='LATIN SMALL LETTER Q WITH HOOK TAIL'
let s:d[0x024C]='LATIN CAPITAL LETTER R WITH STROKE'
let s:d[0x024D]='LATIN SMALL LETTER R WITH STROKE'
let s:d[0x024E]='LATIN CAPITAL LETTER Y WITH STROKE'
let s:d[0x024F]='LATIN SMALL LETTER Y WITH STROKE'
let s:d[0x0250]='LATIN SMALL LETTER TURNED A'
let s:d[0x0251]='LATIN SMALL LETTER ALPHA'
let s:d[0x0252]='LATIN SMALL LETTER TURNED ALPHA'
let s:d[0x0253]='LATIN SMALL LETTER B WITH HOOK'
let s:d[0x0254]='LATIN SMALL LETTER OPEN O'
let s:d[0x0255]='LATIN SMALL LETTER C WITH CURL'
let s:d[0x0256]='LATIN SMALL LETTER D WITH TAIL'
let s:d[0x0257]='LATIN SMALL LETTER D WITH HOOK'
let s:d[0x0258]='LATIN SMALL LETTER REVERSED E'
let s:d[0x0259]='LATIN SMALL LETTER SCHWA'
let s:d[0x025A]='LATIN SMALL LETTER SCHWA WITH HOOK'
let s:d[0x025B]='LATIN SMALL LETTER OPEN E'
let s:d[0x025C]='LATIN SMALL LETTER REVERSED OPEN E'
let s:d[0x025D]='LATIN SMALL LETTER REVERSED OPEN E WITH HOOK'
let s:d[0x025E]='LATIN SMALL LETTER CLOSED REVERSED OPEN E'
let s:d[0x025F]='LATIN SMALL LETTER DOTLESS J WITH STROKE'
let s:d[0x0260]='LATIN SMALL LETTER G WITH HOOK'
let s:d[0x0261]='LATIN SMALL LETTER SCRIPT G'
let s:d[0x0262]='LATIN LETTER SMALL CAPITAL G'
let s:d[0x0263]='LATIN SMALL LETTER GAMMA'
let s:d[0x0264]='LATIN SMALL LETTER RAMS HORN'
let s:d[0x0265]='LATIN SMALL LETTER TURNED H'
let s:d[0x0266]='LATIN SMALL LETTER H WITH HOOK'
let s:d[0x0267]='LATIN SMALL LETTER HENG WITH HOOK'
let s:d[0x0268]='LATIN SMALL LETTER I WITH STROKE'
let s:d[0x0269]='LATIN SMALL LETTER IOTA'
let s:d[0x026A]='LATIN LETTER SMALL CAPITAL I'
let s:d[0x026B]='LATIN SMALL LETTER L WITH MIDDLE TILDE'
let s:d[0x026C]='LATIN SMALL LETTER L WITH BELT'
let s:d[0x026D]='LATIN SMALL LETTER L WITH RETROFLEX HOOK'
let s:d[0x026E]='LATIN SMALL LETTER LEZH'
let s:d[0x026F]='LATIN SMALL LETTER TURNED M'
let s:d[0x0270]='LATIN SMALL LETTER TURNED M WITH LONG LEG'
let s:d[0x0271]='LATIN SMALL LETTER M WITH HOOK'
let s:d[0x0272]='LATIN SMALL LETTER N WITH LEFT HOOK'
let s:d[0x0273]='LATIN SMALL LETTER N WITH RETROFLEX HOOK'
let s:d[0x0274]='LATIN LETTER SMALL CAPITAL N'
let s:d[0x0275]='LATIN SMALL LETTER BARRED O'
let s:d[0x0276]='LATIN LETTER SMALL CAPITAL OE'
let s:d[0x0277]='LATIN SMALL LETTER CLOSED OMEGA'
let s:d[0x0278]='LATIN SMALL LETTER PHI'
let s:d[0x0279]='LATIN SMALL LETTER TURNED R'
let s:d[0x027A]='LATIN SMALL LETTER TURNED R WITH LONG LEG'
let s:d[0x027B]='LATIN SMALL LETTER TURNED R WITH HOOK'
let s:d[0x027C]='LATIN SMALL LETTER R WITH LONG LEG'
let s:d[0x027D]='LATIN SMALL LETTER R WITH TAIL'
let s:d[0x027E]='LATIN SMALL LETTER R WITH FISHHOOK'
let s:d[0x027F]='LATIN SMALL LETTER REVERSED R WITH FISHHOOK'
let s:d[0x0280]='LATIN LETTER SMALL CAPITAL R'
let s:d[0x0281]='LATIN LETTER SMALL CAPITAL INVERTED R'
let s:d[0x0282]='LATIN SMALL LETTER S WITH HOOK'
let s:d[0x0283]='LATIN SMALL LETTER ESH'
let s:d[0x0284]='LATIN SMALL LETTER DOTLESS J WITH STROKE AND HOOK'
let s:d[0x0285]='LATIN SMALL LETTER SQUAT REVERSED ESH'
let s:d[0x0286]='LATIN SMALL LETTER ESH WITH CURL'
let s:d[0x0287]='LATIN SMALL LETTER TURNED T'
let s:d[0x0288]='LATIN SMALL LETTER T WITH RETROFLEX HOOK'
let s:d[0x0289]='LATIN SMALL LETTER U BAR'
let s:d[0x028A]='LATIN SMALL LETTER UPSILON'
let s:d[0x028B]='LATIN SMALL LETTER V WITH HOOK'
let s:d[0x028C]='LATIN SMALL LETTER TURNED V'
let s:d[0x028D]='LATIN SMALL LETTER TURNED W'
let s:d[0x028E]='LATIN SMALL LETTER TURNED Y'
let s:d[0x028F]='LATIN LETTER SMALL CAPITAL Y'
let s:d[0x0290]='LATIN SMALL LETTER Z WITH RETROFLEX HOOK'
let s:d[0x0291]='LATIN SMALL LETTER Z WITH CURL'
let s:d[0x0292]='LATIN SMALL LETTER EZH'
let s:d[0x0293]='LATIN SMALL LETTER EZH WITH CURL'
let s:d[0x0294]='LATIN LETTER GLOTTAL STOP'
let s:d[0x0295]='LATIN LETTER PHARYNGEAL VOICED FRICATIVE'
let s:d[0x0296]='LATIN LETTER INVERTED GLOTTAL STOP'
let s:d[0x0297]='LATIN LETTER STRETCHED C'
let s:d[0x0298]='LATIN LETTER BILABIAL CLICK'
let s:d[0x0299]='LATIN LETTER SMALL CAPITAL B'
let s:d[0x029A]='LATIN SMALL LETTER CLOSED OPEN E'
let s:d[0x029B]='LATIN LETTER SMALL CAPITAL G WITH HOOK'
let s:d[0x029C]='LATIN LETTER SMALL CAPITAL H'
let s:d[0x029D]='LATIN SMALL LETTER J WITH CROSSED-TAIL'
let s:d[0x029E]='LATIN SMALL LETTER TURNED K'
let s:d[0x029F]='LATIN LETTER SMALL CAPITAL L'
let s:d[0x02A0]='LATIN SMALL LETTER Q WITH HOOK'
let s:d[0x02A1]='LATIN LETTER GLOTTAL STOP WITH STROKE'
let s:d[0x02A2]='LATIN LETTER REVERSED GLOTTAL STOP WITH STROKE'
let s:d[0x02A3]='LATIN SMALL LETTER DZ DIGRAPH'
let s:d[0x02A4]='LATIN SMALL LETTER DEZH DIGRAPH'
let s:d[0x02A5]='LATIN SMALL LETTER DZ DIGRAPH WITH CURL'
let s:d[0x02A6]='LATIN SMALL LETTER TS DIGRAPH'
let s:d[0x02A7]='LATIN SMALL LETTER TESH DIGRAPH'
let s:d[0x02A8]='LATIN SMALL LETTER TC DIGRAPH WITH CURL'
let s:d[0x02A9]='LATIN SMALL LETTER FENG DIGRAPH'
let s:d[0x02AA]='LATIN SMALL LETTER LS DIGRAPH'
let s:d[0x02AB]='LATIN SMALL LETTER LZ DIGRAPH'
let s:d[0x02AC]='LATIN LETTER BILABIAL PERCUSSIVE'
let s:d[0x02AD]='LATIN LETTER BIDENTAL PERCUSSIVE'
let s:d[0x02AE]='LATIN SMALL LETTER TURNED H WITH FISHHOOK'
let s:d[0x02AF]='LATIN SMALL LETTER TURNED H WITH FISHHOOK AND TAIL'
let s:d[0x02B0]='MODIFIER LETTER SMALL H'
let s:d[0x02B1]='MODIFIER LETTER SMALL H WITH HOOK'
let s:d[0x02B2]='MODIFIER LETTER SMALL J'
let s:d[0x02B3]='MODIFIER LETTER SMALL R'
let s:d[0x02B4]='MODIFIER LETTER SMALL TURNED R'
let s:d[0x02B5]='MODIFIER LETTER SMALL TURNED R WITH HOOK'
let s:d[0x02B6]='MODIFIER LETTER SMALL CAPITAL INVERTED R'
let s:d[0x02B7]='MODIFIER LETTER SMALL W'
let s:d[0x02B8]='MODIFIER LETTER SMALL Y'
let s:d[0x02B9]='MODIFIER LETTER PRIME'
let s:d[0x02BA]='MODIFIER LETTER DOUBLE PRIME'
let s:d[0x02BB]='MODIFIER LETTER TURNED COMMA'
let s:d[0x02BC]='MODIFIER LETTER APOSTROPHE'
let s:d[0x02BD]='MODIFIER LETTER REVERSED COMMA'
let s:d[0x02BE]='MODIFIER LETTER RIGHT HALF RING'
let s:d[0x02BF]='MODIFIER LETTER LEFT HALF RING'
let s:d[0x02C0]='MODIFIER LETTER GLOTTAL STOP'
let s:d[0x02C1]='MODIFIER LETTER REVERSED GLOTTAL STOP'
let s:d[0x02C2]='MODIFIER LETTER LEFT ARROWHEAD'
let s:d[0x02C3]='MODIFIER LETTER RIGHT ARROWHEAD'
let s:d[0x02C4]='MODIFIER LETTER UP ARROWHEAD'
let s:d[0x02C5]='MODIFIER LETTER DOWN ARROWHEAD'
let s:d[0x02C6]='MODIFIER LETTER CIRCUMFLEX ACCENT'
let s:d[0x02C7]='CARON'
let s:d[0x02C8]='MODIFIER LETTER VERTICAL LINE'
let s:d[0x02C9]='MODIFIER LETTER MACRON'
let s:d[0x02CA]='MODIFIER LETTER ACUTE ACCENT'
let s:d[0x02CB]='MODIFIER LETTER GRAVE ACCENT'
let s:d[0x02CC]='MODIFIER LETTER LOW VERTICAL LINE'
let s:d[0x02CD]='MODIFIER LETTER LOW MACRON'
let s:d[0x02CE]='MODIFIER LETTER LOW GRAVE ACCENT'
let s:d[0x02CF]='MODIFIER LETTER LOW ACUTE ACCENT'
let s:d[0x02D0]='MODIFIER LETTER TRIANGULAR COLON'
let s:d[0x02D1]='MODIFIER LETTER HALF TRIANGULAR COLON'
let s:d[0x02D2]='MODIFIER LETTER CENTRED RIGHT HALF RING'
let s:d[0x02D3]='MODIFIER LETTER CENTRED LEFT HALF RING'
let s:d[0x02D4]='MODIFIER LETTER UP TACK'
let s:d[0x02D5]='MODIFIER LETTER DOWN TACK'
let s:d[0x02D6]='MODIFIER LETTER PLUS SIGN'
let s:d[0x02D7]='MODIFIER LETTER MINUS SIGN'
let s:d[0x02D8]='BREVE'
let s:d[0x02D9]='DOT ABOVE'
let s:d[0x02DA]='RING ABOVE'
let s:d[0x02DB]='OGONEK'
let s:d[0x02DC]='SMALL TILDE'
let s:d[0x02DD]='DOUBLE ACUTE ACCENT'
let s:d[0x02DE]='MODIFIER LETTER RHOTIC HOOK'
let s:d[0x02DF]='MODIFIER LETTER CROSS ACCENT'
let s:d[0x02E0]='MODIFIER LETTER SMALL GAMMA'
let s:d[0x02E1]='MODIFIER LETTER SMALL L'
let s:d[0x02E2]='MODIFIER LETTER SMALL S'
let s:d[0x02E3]='MODIFIER LETTER SMALL X'
let s:d[0x02E4]='MODIFIER LETTER SMALL REVERSED GLOTTAL STOP'
let s:d[0x02E5]='MODIFIER LETTER EXTRA-HIGH TONE BAR'
let s:d[0x02E6]='MODIFIER LETTER HIGH TONE BAR'
let s:d[0x02E7]='MODIFIER LETTER MID TONE BAR'
let s:d[0x02E8]='MODIFIER LETTER LOW TONE BAR'
let s:d[0x02E9]='MODIFIER LETTER EXTRA-LOW TONE BAR'
let s:d[0x02EA]='MODIFIER LETTER YIN DEPARTING TONE MARK'
let s:d[0x02EB]='MODIFIER LETTER YANG DEPARTING TONE MARK'
let s:d[0x02EC]='MODIFIER LETTER VOICING'
let s:d[0x02ED]='MODIFIER LETTER UNASPIRATED'
let s:d[0x02EE]='MODIFIER LETTER DOUBLE APOSTROPHE'
let s:d[0x02EF]='MODIFIER LETTER LOW DOWN ARROWHEAD'
let s:d[0x02F0]='MODIFIER LETTER LOW UP ARROWHEAD'
let s:d[0x02F1]='MODIFIER LETTER LOW LEFT ARROWHEAD'
let s:d[0x02F2]='MODIFIER LETTER LOW RIGHT ARROWHEAD'
let s:d[0x02F3]='MODIFIER LETTER LOW RING'
let s:d[0x02F4]='MODIFIER LETTER MIDDLE GRAVE ACCENT'
let s:d[0x02F5]='MODIFIER LETTER MIDDLE DOUBLE GRAVE ACCENT'
let s:d[0x02F6]='MODIFIER LETTER MIDDLE DOUBLE ACUTE ACCENT'
let s:d[0x02F7]='MODIFIER LETTER LOW TILDE'
let s:d[0x02F8]='MODIFIER LETTER RAISED COLON'
let s:d[0x02F9]='MODIFIER LETTER BEGIN HIGH TONE'
let s:d[0x02FA]='MODIFIER LETTER END HIGH TONE'
let s:d[0x02FB]='MODIFIER LETTER BEGIN LOW TONE'
let s:d[0x02FC]='MODIFIER LETTER END LOW TONE'
let s:d[0x02FD]='MODIFIER LETTER SHELF'
let s:d[0x02FE]='MODIFIER LETTER OPEN SHELF'
let s:d[0x02FF]='MODIFIER LETTER LOW LEFT ARROW'
let s:d[0x0300]='COMBINING GRAVE ACCENT'
let s:d[0x0301]='COMBINING ACUTE ACCENT'
let s:d[0x0302]='COMBINING CIRCUMFLEX ACCENT'
let s:d[0x0303]='COMBINING TILDE'
let s:d[0x0304]='COMBINING MACRON'
let s:d[0x0305]='COMBINING OVERLINE'
let s:d[0x0306]='COMBINING BREVE'
let s:d[0x0307]='COMBINING DOT ABOVE'
let s:d[0x0308]='COMBINING DIAERESIS'
let s:d[0x0309]='COMBINING HOOK ABOVE'
let s:d[0x030A]='COMBINING RING ABOVE'
let s:d[0x030B]='COMBINING DOUBLE ACUTE ACCENT'
let s:d[0x030C]='COMBINING CARON'
let s:d[0x030D]='COMBINING VERTICAL LINE ABOVE'
let s:d[0x030E]='COMBINING DOUBLE VERTICAL LINE ABOVE'
let s:d[0x030F]='COMBINING DOUBLE GRAVE ACCENT'
let s:d[0x0310]='COMBINING CANDRABINDU'
let s:d[0x0311]='COMBINING INVERTED BREVE'
let s:d[0x0312]='COMBINING TURNED COMMA ABOVE'
let s:d[0x0313]='COMBINING COMMA ABOVE'
let s:d[0x0314]='COMBINING REVERSED COMMA ABOVE'
let s:d[0x0315]='COMBINING COMMA ABOVE RIGHT'
let s:d[0x0316]='COMBINING GRAVE ACCENT BELOW'
let s:d[0x0317]='COMBINING ACUTE ACCENT BELOW'
let s:d[0x0318]='COMBINING LEFT TACK BELOW'
let s:d[0x0319]='COMBINING RIGHT TACK BELOW'
let s:d[0x031A]='COMBINING LEFT ANGLE ABOVE'
let s:d[0x031B]='COMBINING HORN'
let s:d[0x031C]='COMBINING LEFT HALF RING BELOW'
let s:d[0x031D]='COMBINING UP TACK BELOW'
let s:d[0x031E]='COMBINING DOWN TACK BELOW'
let s:d[0x031F]='COMBINING PLUS SIGN BELOW'
let s:d[0x0320]='COMBINING MINUS SIGN BELOW'
let s:d[0x0321]='COMBINING PALATALIZED HOOK BELOW'
let s:d[0x0322]='COMBINING RETROFLEX HOOK BELOW'
let s:d[0x0323]='COMBINING DOT BELOW'
let s:d[0x0324]='COMBINING DIAERESIS BELOW'
let s:d[0x0325]='COMBINING RING BELOW'
let s:d[0x0326]='COMBINING COMMA BELOW'
let s:d[0x0327]='COMBINING CEDILLA'
let s:d[0x0328]='COMBINING OGONEK'
let s:d[0x0329]='COMBINING VERTICAL LINE BELOW'
let s:d[0x032A]='COMBINING BRIDGE BELOW'
let s:d[0x032B]='COMBINING INVERTED DOUBLE ARCH BELOW'
let s:d[0x032C]='COMBINING CARON BELOW'
let s:d[0x032D]='COMBINING CIRCUMFLEX ACCENT BELOW'
let s:d[0x032E]='COMBINING BREVE BELOW'
let s:d[0x032F]='COMBINING INVERTED BREVE BELOW'
let s:d[0x0330]='COMBINING TILDE BELOW'
let s:d[0x0331]='COMBINING MACRON BELOW'
let s:d[0x0332]='COMBINING LOW LINE'
let s:d[0x0333]='COMBINING DOUBLE LOW LINE'
let s:d[0x0334]='COMBINING TILDE OVERLAY'
let s:d[0x0335]='COMBINING SHORT STROKE OVERLAY'
let s:d[0x0336]='COMBINING LONG STROKE OVERLAY'
let s:d[0x0337]='COMBINING SHORT SOLIDUS OVERLAY'
let s:d[0x0338]='COMBINING LONG SOLIDUS OVERLAY'
let s:d[0x0339]='COMBINING RIGHT HALF RING BELOW'
let s:d[0x033A]='COMBINING INVERTED BRIDGE BELOW'
let s:d[0x033B]='COMBINING SQUARE BELOW'
let s:d[0x033C]='COMBINING SEAGULL BELOW'
let s:d[0x033D]='COMBINING X ABOVE'
let s:d[0x033E]='COMBINING VERTICAL TILDE'
let s:d[0x033F]='COMBINING DOUBLE OVERLINE'
let s:d[0x0340]='COMBINING GRAVE TONE MARK'
let s:d[0x0341]='COMBINING ACUTE TONE MARK'
let s:d[0x0342]='COMBINING GREEK PERISPOMENI'
let s:d[0x0343]='COMBINING GREEK KORONIS'
let s:d[0x0344]='COMBINING GREEK DIALYTIKA TONOS'
let s:d[0x0345]='COMBINING GREEK YPOGEGRAMMENI'
let s:d[0x0346]='COMBINING BRIDGE ABOVE'
let s:d[0x0347]='COMBINING EQUALS SIGN BELOW'
let s:d[0x0348]='COMBINING DOUBLE VERTICAL LINE BELOW'
let s:d[0x0349]='COMBINING LEFT ANGLE BELOW'
let s:d[0x034A]='COMBINING NOT TILDE ABOVE'
let s:d[0x034B]='COMBINING HOMOTHETIC ABOVE'
let s:d[0x034C]='COMBINING ALMOST EQUAL TO ABOVE'
let s:d[0x034D]='COMBINING LEFT RIGHT ARROW BELOW'
let s:d[0x034E]='COMBINING UPWARDS ARROW BELOW'
let s:d[0x034F]='COMBINING GRAPHEME JOINER'
let s:d[0x0350]='COMBINING RIGHT ARROWHEAD ABOVE'
let s:d[0x0351]='COMBINING LEFT HALF RING ABOVE'
let s:d[0x0352]='COMBINING FERMATA'
let s:d[0x0353]='COMBINING X BELOW'
let s:d[0x0354]='COMBINING LEFT ARROWHEAD BELOW'
let s:d[0x0355]='COMBINING RIGHT ARROWHEAD BELOW'
let s:d[0x0356]='COMBINING RIGHT ARROWHEAD AND UP ARROWHEAD BELOW'
let s:d[0x0357]='COMBINING RIGHT HALF RING ABOVE'
let s:d[0x0358]='COMBINING DOT ABOVE RIGHT'
let s:d[0x0359]='COMBINING ASTERISK BELOW'
let s:d[0x035A]='COMBINING DOUBLE RING BELOW'
let s:d[0x035B]='COMBINING ZIGZAG ABOVE'
let s:d[0x035C]='COMBINING DOUBLE BREVE BELOW'
let s:d[0x035D]='COMBINING DOUBLE BREVE'
let s:d[0x035E]='COMBINING DOUBLE MACRON'
let s:d[0x035F]='COMBINING DOUBLE MACRON BELOW'
let s:d[0x0360]='COMBINING DOUBLE TILDE'
let s:d[0x0361]='COMBINING DOUBLE INVERTED BREVE'
let s:d[0x0362]='COMBINING DOUBLE RIGHTWARDS ARROW BELOW'
let s:d[0x0363]='COMBINING LATIN SMALL LETTER A'
let s:d[0x0364]='COMBINING LATIN SMALL LETTER E'
let s:d[0x0365]='COMBINING LATIN SMALL LETTER I'
let s:d[0x0366]='COMBINING LATIN SMALL LETTER O'
let s:d[0x0367]='COMBINING LATIN SMALL LETTER U'
let s:d[0x0368]='COMBINING LATIN SMALL LETTER C'
let s:d[0x0369]='COMBINING LATIN SMALL LETTER D'
let s:d[0x036A]='COMBINING LATIN SMALL LETTER H'
let s:d[0x036B]='COMBINING LATIN SMALL LETTER M'
let s:d[0x036C]='COMBINING LATIN SMALL LETTER R'
let s:d[0x036D]='COMBINING LATIN SMALL LETTER T'
let s:d[0x036E]='COMBINING LATIN SMALL LETTER V'
let s:d[0x036F]='COMBINING LATIN SMALL LETTER X'
let s:d[0x0370]='GREEK CAPITAL LETTER HETA'
let s:d[0x0371]='GREEK SMALL LETTER HETA'
let s:d[0x0372]='GREEK CAPITAL LETTER ARCHAIC SAMPI'
let s:d[0x0373]='GREEK SMALL LETTER ARCHAIC SAMPI'
let s:d[0x0374]='GREEK NUMERAL SIGN'
let s:d[0x0375]='GREEK LOWER NUMERAL SIGN'
let s:d[0x0376]='GREEK CAPITAL LETTER PAMPHYLIAN DIGAMMA'
let s:d[0x0377]='GREEK SMALL LETTER PAMPHYLIAN DIGAMMA'
let s:d[0x037A]='GREEK YPOGEGRAMMENI'
let s:d[0x037B]='GREEK SMALL REVERSED LUNATE SIGMA SYMBOL'
let s:d[0x037C]='GREEK SMALL DOTTED LUNATE SIGMA SYMBOL'
let s:d[0x037D]='GREEK SMALL REVERSED DOTTED LUNATE SIGMA SYMBOL'
let s:d[0x037E]='GREEK QUESTION MARK'
let s:d[0x0384]='GREEK TONOS'
let s:d[0x0385]='GREEK DIALYTIKA TONOS'
let s:d[0x0386]='GREEK CAPITAL LETTER ALPHA WITH TONOS'
let s:d[0x0387]='GREEK ANO TELEIA'
let s:d[0x0388]='GREEK CAPITAL LETTER EPSILON WITH TONOS'
let s:d[0x0389]='GREEK CAPITAL LETTER ETA WITH TONOS'
let s:d[0x038A]='GREEK CAPITAL LETTER IOTA WITH TONOS'
let s:d[0x038C]='GREEK CAPITAL LETTER OMICRON WITH TONOS'
let s:d[0x038E]='GREEK CAPITAL LETTER UPSILON WITH TONOS'
let s:d[0x038F]='GREEK CAPITAL LETTER OMEGA WITH TONOS'
let s:d[0x0390]='GREEK SMALL LETTER IOTA WITH DIALYTIKA AND TONOS'
let s:d[0x0391]='GREEK CAPITAL LETTER ALPHA'
let s:d[0x0392]='GREEK CAPITAL LETTER BETA'
let s:d[0x0393]='GREEK CAPITAL LETTER GAMMA'
let s:d[0x0394]='GREEK CAPITAL LETTER DELTA'
let s:d[0x0395]='GREEK CAPITAL LETTER EPSILON'
let s:d[0x0396]='GREEK CAPITAL LETTER ZETA'
let s:d[0x0397]='GREEK CAPITAL LETTER ETA'
let s:d[0x0398]='GREEK CAPITAL LETTER THETA'
let s:d[0x0399]='GREEK CAPITAL LETTER IOTA'
let s:d[0x039A]='GREEK CAPITAL LETTER KAPPA'
let s:d[0x039B]='GREEK CAPITAL LETTER LAMDA'
let s:d[0x039C]='GREEK CAPITAL LETTER MU'
let s:d[0x039D]='GREEK CAPITAL LETTER NU'
let s:d[0x039E]='GREEK CAPITAL LETTER XI'
let s:d[0x039F]='GREEK CAPITAL LETTER OMICRON'
let s:d[0x03A0]='GREEK CAPITAL LETTER PI'
let s:d[0x03A1]='GREEK CAPITAL LETTER RHO'
let s:d[0x03A3]='GREEK CAPITAL LETTER SIGMA'
let s:d[0x03A4]='GREEK CAPITAL LETTER TAU'
let s:d[0x03A5]='GREEK CAPITAL LETTER UPSILON'
let s:d[0x03A6]='GREEK CAPITAL LETTER PHI'
let s:d[0x03A7]='GREEK CAPITAL LETTER CHI'
let s:d[0x03A8]='GREEK CAPITAL LETTER PSI'
let s:d[0x03A9]='GREEK CAPITAL LETTER OMEGA'
let s:d[0x03AA]='GREEK CAPITAL LETTER IOTA WITH DIALYTIKA'
let s:d[0x03AB]='GREEK CAPITAL LETTER UPSILON WITH DIALYTIKA'
let s:d[0x03AC]='GREEK SMALL LETTER ALPHA WITH TONOS'
let s:d[0x03AD]='GREEK SMALL LETTER EPSILON WITH TONOS'
let s:d[0x03AE]='GREEK SMALL LETTER ETA WITH TONOS'
let s:d[0x03AF]='GREEK SMALL LETTER IOTA WITH TONOS'
let s:d[0x03B0]='GREEK SMALL LETTER UPSILON WITH DIALYTIKA AND TONOS'
let s:d[0x03B1]='GREEK SMALL LETTER ALPHA'
let s:d[0x03B2]='GREEK SMALL LETTER BETA'
let s:d[0x03B3]='GREEK SMALL LETTER GAMMA'
let s:d[0x03B4]='GREEK SMALL LETTER DELTA'
let s:d[0x03B5]='GREEK SMALL LETTER EPSILON'
let s:d[0x03B6]='GREEK SMALL LETTER ZETA'
let s:d[0x03B7]='GREEK SMALL LETTER ETA'
let s:d[0x03B8]='GREEK SMALL LETTER THETA'
let s:d[0x03B9]='GREEK SMALL LETTER IOTA'
let s:d[0x03BA]='GREEK SMALL LETTER KAPPA'
let s:d[0x03BB]='GREEK SMALL LETTER LAMDA'
let s:d[0x03BC]='GREEK SMALL LETTER MU'
let s:d[0x03BD]='GREEK SMALL LETTER NU'
let s:d[0x03BE]='GREEK SMALL LETTER XI'
let s:d[0x03BF]='GREEK SMALL LETTER OMICRON'
let s:d[0x03C0]='GREEK SMALL LETTER PI'
let s:d[0x03C1]='GREEK SMALL LETTER RHO'
let s:d[0x03C2]='GREEK SMALL LETTER FINAL SIGMA'
let s:d[0x03C3]='GREEK SMALL LETTER SIGMA'
let s:d[0x03C4]='GREEK SMALL LETTER TAU'
let s:d[0x03C5]='GREEK SMALL LETTER UPSILON'
let s:d[0x03C6]='GREEK SMALL LETTER PHI'
let s:d[0x03C7]='GREEK SMALL LETTER CHI'
let s:d[0x03C8]='GREEK SMALL LETTER PSI'
let s:d[0x03C9]='GREEK SMALL LETTER OMEGA'
let s:d[0x03CA]='GREEK SMALL LETTER IOTA WITH DIALYTIKA'
let s:d[0x03CB]='GREEK SMALL LETTER UPSILON WITH DIALYTIKA'
let s:d[0x03CC]='GREEK SMALL LETTER OMICRON WITH TONOS'
let s:d[0x03CD]='GREEK SMALL LETTER UPSILON WITH TONOS'
let s:d[0x03CE]='GREEK SMALL LETTER OMEGA WITH TONOS'
let s:d[0x03CF]='GREEK CAPITAL KAI SYMBOL'
let s:d[0x03D0]='GREEK BETA SYMBOL'
let s:d[0x03D1]='GREEK THETA SYMBOL'
let s:d[0x03D2]='GREEK UPSILON WITH HOOK SYMBOL'
let s:d[0x03D3]='GREEK UPSILON WITH ACUTE AND HOOK SYMBOL'
let s:d[0x03D4]='GREEK UPSILON WITH DIAERESIS AND HOOK SYMBOL'
let s:d[0x03D5]='GREEK PHI SYMBOL'
let s:d[0x03D6]='GREEK PI SYMBOL'
let s:d[0x03D7]='GREEK KAI SYMBOL'
let s:d[0x03D8]='GREEK LETTER ARCHAIC KOPPA'
let s:d[0x03D9]='GREEK SMALL LETTER ARCHAIC KOPPA'
let s:d[0x03DA]='GREEK LETTER STIGMA'
let s:d[0x03DB]='GREEK SMALL LETTER STIGMA'
let s:d[0x03DC]='GREEK LETTER DIGAMMA'
let s:d[0x03DD]='GREEK SMALL LETTER DIGAMMA'
let s:d[0x03DE]='GREEK LETTER KOPPA'
let s:d[0x03DF]='GREEK SMALL LETTER KOPPA'
let s:d[0x03E0]='GREEK LETTER SAMPI'
let s:d[0x03E1]='GREEK SMALL LETTER SAMPI'
let s:d[0x03E2]='COPTIC CAPITAL LETTER SHEI'
let s:d[0x03E3]='COPTIC SMALL LETTER SHEI'
let s:d[0x03E4]='COPTIC CAPITAL LETTER FEI'
let s:d[0x03E5]='COPTIC SMALL LETTER FEI'
let s:d[0x03E6]='COPTIC CAPITAL LETTER KHEI'
let s:d[0x03E7]='COPTIC SMALL LETTER KHEI'
let s:d[0x03E8]='COPTIC CAPITAL LETTER HORI'
let s:d[0x03E9]='COPTIC SMALL LETTER HORI'
let s:d[0x03EA]='COPTIC CAPITAL LETTER GANGIA'
let s:d[0x03EB]='COPTIC SMALL LETTER GANGIA'
let s:d[0x03EC]='COPTIC CAPITAL LETTER SHIMA'
let s:d[0x03ED]='COPTIC SMALL LETTER SHIMA'
let s:d[0x03EE]='COPTIC CAPITAL LETTER DEI'
let s:d[0x03EF]='COPTIC SMALL LETTER DEI'
let s:d[0x03F0]='GREEK KAPPA SYMBOL'
let s:d[0x03F1]='GREEK RHO SYMBOL'
let s:d[0x03F2]='GREEK LUNATE SIGMA SYMBOL'
let s:d[0x03F3]='GREEK LETTER YOT'
let s:d[0x03F4]='GREEK CAPITAL THETA SYMBOL'
let s:d[0x03F5]='GREEK LUNATE EPSILON SYMBOL'
let s:d[0x03F6]='GREEK REVERSED LUNATE EPSILON SYMBOL'
let s:d[0x03F7]='GREEK CAPITAL LETTER SHO'
let s:d[0x03F8]='GREEK SMALL LETTER SHO'
let s:d[0x03F9]='GREEK CAPITAL LUNATE SIGMA SYMBOL'
let s:d[0x03FA]='GREEK CAPITAL LETTER SAN'
let s:d[0x03FB]='GREEK SMALL LETTER SAN'
let s:d[0x03FC]='GREEK RHO WITH STROKE SYMBOL'
let s:d[0x03FD]='GREEK CAPITAL REVERSED LUNATE SIGMA SYMBOL'
let s:d[0x03FE]='GREEK CAPITAL DOTTED LUNATE SIGMA SYMBOL'
let s:d[0x03FF]='GREEK CAPITAL REVERSED DOTTED LUNATE SIGMA SYMBOL'
let s:d[0x0400]='CYRILLIC CAPITAL LETTER IE WITH GRAVE'
let s:d[0x0401]='CYRILLIC CAPITAL LETTER IO'
let s:d[0x0402]='CYRILLIC CAPITAL LETTER DJE'
let s:d[0x0403]='CYRILLIC CAPITAL LETTER GJE'
let s:d[0x0404]='CYRILLIC CAPITAL LETTER UKRAINIAN IE'
let s:d[0x0405]='CYRILLIC CAPITAL LETTER DZE'
let s:d[0x0406]='CYRILLIC CAPITAL LETTER BYELORUSSIAN-UKRAINIAN I'
let s:d[0x0407]='CYRILLIC CAPITAL LETTER YI'
let s:d[0x0408]='CYRILLIC CAPITAL LETTER JE'
let s:d[0x0409]='CYRILLIC CAPITAL LETTER LJE'
let s:d[0x040A]='CYRILLIC CAPITAL LETTER NJE'
let s:d[0x040B]='CYRILLIC CAPITAL LETTER TSHE'
let s:d[0x040C]='CYRILLIC CAPITAL LETTER KJE'
let s:d[0x040D]='CYRILLIC CAPITAL LETTER I WITH GRAVE'
let s:d[0x040E]='CYRILLIC CAPITAL LETTER SHORT U'
let s:d[0x040F]='CYRILLIC CAPITAL LETTER DZHE'
let s:d[0x0410]='CYRILLIC CAPITAL LETTER A'
let s:d[0x0411]='CYRILLIC CAPITAL LETTER BE'
let s:d[0x0412]='CYRILLIC CAPITAL LETTER VE'
let s:d[0x0413]='CYRILLIC CAPITAL LETTER GHE'
let s:d[0x0414]='CYRILLIC CAPITAL LETTER DE'
let s:d[0x0415]='CYRILLIC CAPITAL LETTER IE'
let s:d[0x0416]='CYRILLIC CAPITAL LETTER ZHE'
let s:d[0x0417]='CYRILLIC CAPITAL LETTER ZE'
let s:d[0x0418]='CYRILLIC CAPITAL LETTER I'
let s:d[0x0419]='CYRILLIC CAPITAL LETTER SHORT I'
let s:d[0x041A]='CYRILLIC CAPITAL LETTER KA'
let s:d[0x041B]='CYRILLIC CAPITAL LETTER EL'
let s:d[0x041C]='CYRILLIC CAPITAL LETTER EM'
let s:d[0x041D]='CYRILLIC CAPITAL LETTER EN'
let s:d[0x041E]='CYRILLIC CAPITAL LETTER O'
let s:d[0x041F]='CYRILLIC CAPITAL LETTER PE'
let s:d[0x0420]='CYRILLIC CAPITAL LETTER ER'
let s:d[0x0421]='CYRILLIC CAPITAL LETTER ES'
let s:d[0x0422]='CYRILLIC CAPITAL LETTER TE'
let s:d[0x0423]='CYRILLIC CAPITAL LETTER U'
let s:d[0x0424]='CYRILLIC CAPITAL LETTER EF'
let s:d[0x0425]='CYRILLIC CAPITAL LETTER HA'
let s:d[0x0426]='CYRILLIC CAPITAL LETTER TSE'
let s:d[0x0427]='CYRILLIC CAPITAL LETTER CHE'
let s:d[0x0428]='CYRILLIC CAPITAL LETTER SHA'
let s:d[0x0429]='CYRILLIC CAPITAL LETTER SHCHA'
let s:d[0x042A]='CYRILLIC CAPITAL LETTER HARD SIGN'
let s:d[0x042B]='CYRILLIC CAPITAL LETTER YERU'
let s:d[0x042C]='CYRILLIC CAPITAL LETTER SOFT SIGN'
let s:d[0x042D]='CYRILLIC CAPITAL LETTER E'
let s:d[0x042E]='CYRILLIC CAPITAL LETTER YU'
let s:d[0x042F]='CYRILLIC CAPITAL LETTER YA'
let s:d[0x0430]='CYRILLIC SMALL LETTER A'
let s:d[0x0431]='CYRILLIC SMALL LETTER BE'
let s:d[0x0432]='CYRILLIC SMALL LETTER VE'
let s:d[0x0433]='CYRILLIC SMALL LETTER GHE'
let s:d[0x0434]='CYRILLIC SMALL LETTER DE'
let s:d[0x0435]='CYRILLIC SMALL LETTER IE'
let s:d[0x0436]='CYRILLIC SMALL LETTER ZHE'
let s:d[0x0437]='CYRILLIC SMALL LETTER ZE'
let s:d[0x0438]='CYRILLIC SMALL LETTER I'
let s:d[0x0439]='CYRILLIC SMALL LETTER SHORT I'
let s:d[0x043A]='CYRILLIC SMALL LETTER KA'
let s:d[0x043B]='CYRILLIC SMALL LETTER EL'
let s:d[0x043C]='CYRILLIC SMALL LETTER EM'
let s:d[0x043D]='CYRILLIC SMALL LETTER EN'
let s:d[0x043E]='CYRILLIC SMALL LETTER O'
let s:d[0x043F]='CYRILLIC SMALL LETTER PE'
let s:d[0x0440]='CYRILLIC SMALL LETTER ER'
let s:d[0x0441]='CYRILLIC SMALL LETTER ES'
let s:d[0x0442]='CYRILLIC SMALL LETTER TE'
let s:d[0x0443]='CYRILLIC SMALL LETTER U'
let s:d[0x0444]='CYRILLIC SMALL LETTER EF'
let s:d[0x0445]='CYRILLIC SMALL LETTER HA'
let s:d[0x0446]='CYRILLIC SMALL LETTER TSE'
let s:d[0x0447]='CYRILLIC SMALL LETTER CHE'
let s:d[0x0448]='CYRILLIC SMALL LETTER SHA'
let s:d[0x0449]='CYRILLIC SMALL LETTER SHCHA'
let s:d[0x044A]='CYRILLIC SMALL LETTER HARD SIGN'
let s:d[0x044B]='CYRILLIC SMALL LETTER YERU'
let s:d[0x044C]='CYRILLIC SMALL LETTER SOFT SIGN'
let s:d[0x044D]='CYRILLIC SMALL LETTER E'
let s:d[0x044E]='CYRILLIC SMALL LETTER YU'
let s:d[0x044F]='CYRILLIC SMALL LETTER YA'
let s:d[0x0450]='CYRILLIC SMALL LETTER IE WITH GRAVE'
let s:d[0x0451]='CYRILLIC SMALL LETTER IO'
let s:d[0x0452]='CYRILLIC SMALL LETTER DJE'
let s:d[0x0453]='CYRILLIC SMALL LETTER GJE'
let s:d[0x0454]='CYRILLIC SMALL LETTER UKRAINIAN IE'
let s:d[0x0455]='CYRILLIC SMALL LETTER DZE'
let s:d[0x0456]='CYRILLIC SMALL LETTER BYELORUSSIAN-UKRAINIAN I'
let s:d[0x0457]='CYRILLIC SMALL LETTER YI'
let s:d[0x0458]='CYRILLIC SMALL LETTER JE'
let s:d[0x0459]='CYRILLIC SMALL LETTER LJE'
let s:d[0x045A]='CYRILLIC SMALL LETTER NJE'
let s:d[0x045B]='CYRILLIC SMALL LETTER TSHE'
let s:d[0x045C]='CYRILLIC SMALL LETTER KJE'
let s:d[0x045D]='CYRILLIC SMALL LETTER I WITH GRAVE'
let s:d[0x045E]='CYRILLIC SMALL LETTER SHORT U'
let s:d[0x045F]='CYRILLIC SMALL LETTER DZHE'
let s:d[0x0460]='CYRILLIC CAPITAL LETTER OMEGA'
let s:d[0x0461]='CYRILLIC SMALL LETTER OMEGA'
let s:d[0x0462]='CYRILLIC CAPITAL LETTER YAT'
let s:d[0x0463]='CYRILLIC SMALL LETTER YAT'
let s:d[0x0464]='CYRILLIC CAPITAL LETTER IOTIFIED E'
let s:d[0x0465]='CYRILLIC SMALL LETTER IOTIFIED E'
let s:d[0x0466]='CYRILLIC CAPITAL LETTER LITTLE YUS'
let s:d[0x0467]='CYRILLIC SMALL LETTER LITTLE YUS'
let s:d[0x0468]='CYRILLIC CAPITAL LETTER IOTIFIED LITTLE YUS'
let s:d[0x0469]='CYRILLIC SMALL LETTER IOTIFIED LITTLE YUS'
let s:d[0x046A]='CYRILLIC CAPITAL LETTER BIG YUS'
let s:d[0x046B]='CYRILLIC SMALL LETTER BIG YUS'
let s:d[0x046C]='CYRILLIC CAPITAL LETTER IOTIFIED BIG YUS'
let s:d[0x046D]='CYRILLIC SMALL LETTER IOTIFIED BIG YUS'
let s:d[0x046E]='CYRILLIC CAPITAL LETTER KSI'
let s:d[0x046F]='CYRILLIC SMALL LETTER KSI'
let s:d[0x0470]='CYRILLIC CAPITAL LETTER PSI'
let s:d[0x0471]='CYRILLIC SMALL LETTER PSI'
let s:d[0x0472]='CYRILLIC CAPITAL LETTER FITA'
let s:d[0x0473]='CYRILLIC SMALL LETTER FITA'
let s:d[0x0474]='CYRILLIC CAPITAL LETTER IZHITSA'
let s:d[0x0475]='CYRILLIC SMALL LETTER IZHITSA'
let s:d[0x0476]='CYRILLIC CAPITAL LETTER IZHITSA WITH DOUBLE GRAVE ACCENT'
let s:d[0x0477]='CYRILLIC SMALL LETTER IZHITSA WITH DOUBLE GRAVE ACCENT'
let s:d[0x0478]='CYRILLIC CAPITAL LETTER UK'
let s:d[0x0479]='CYRILLIC SMALL LETTER UK'
let s:d[0x047A]='CYRILLIC CAPITAL LETTER ROUND OMEGA'
let s:d[0x047B]='CYRILLIC SMALL LETTER ROUND OMEGA'
let s:d[0x047C]='CYRILLIC CAPITAL LETTER OMEGA WITH TITLO'
let s:d[0x047D]='CYRILLIC SMALL LETTER OMEGA WITH TITLO'
let s:d[0x047E]='CYRILLIC CAPITAL LETTER OT'
let s:d[0x047F]='CYRILLIC SMALL LETTER OT'
let s:d[0x0480]='CYRILLIC CAPITAL LETTER KOPPA'
let s:d[0x0481]='CYRILLIC SMALL LETTER KOPPA'
let s:d[0x0482]='CYRILLIC THOUSANDS SIGN'
let s:d[0x0483]='COMBINING CYRILLIC TITLO'
let s:d[0x0484]='COMBINING CYRILLIC PALATALIZATION'
let s:d[0x0485]='COMBINING CYRILLIC DASIA PNEUMATA'
let s:d[0x0486]='COMBINING CYRILLIC PSILI PNEUMATA'
let s:d[0x0487]='COMBINING CYRILLIC POKRYTIE'
let s:d[0x0488]='COMBINING CYRILLIC HUNDRED THOUSANDS SIGN'
let s:d[0x0489]='COMBINING CYRILLIC MILLIONS SIGN'
let s:d[0x048A]='CYRILLIC CAPITAL LETTER SHORT I WITH TAIL'
let s:d[0x048B]='CYRILLIC SMALL LETTER SHORT I WITH TAIL'
let s:d[0x048C]='CYRILLIC CAPITAL LETTER SEMISOFT SIGN'
let s:d[0x048D]='CYRILLIC SMALL LETTER SEMISOFT SIGN'
let s:d[0x048E]='CYRILLIC CAPITAL LETTER ER WITH TICK'
let s:d[0x048F]='CYRILLIC SMALL LETTER ER WITH TICK'
let s:d[0x0490]='CYRILLIC CAPITAL LETTER GHE WITH UPTURN'
let s:d[0x0491]='CYRILLIC SMALL LETTER GHE WITH UPTURN'
let s:d[0x0492]='CYRILLIC CAPITAL LETTER GHE WITH STROKE'
let s:d[0x0493]='CYRILLIC SMALL LETTER GHE WITH STROKE'
let s:d[0x0494]='CYRILLIC CAPITAL LETTER GHE WITH MIDDLE HOOK'
let s:d[0x0495]='CYRILLIC SMALL LETTER GHE WITH MIDDLE HOOK'
let s:d[0x0496]='CYRILLIC CAPITAL LETTER ZHE WITH DESCENDER'
let s:d[0x0497]='CYRILLIC SMALL LETTER ZHE WITH DESCENDER'
let s:d[0x0498]='CYRILLIC CAPITAL LETTER ZE WITH DESCENDER'
let s:d[0x0499]='CYRILLIC SMALL LETTER ZE WITH DESCENDER'
let s:d[0x049A]='CYRILLIC CAPITAL LETTER KA WITH DESCENDER'
let s:d[0x049B]='CYRILLIC SMALL LETTER KA WITH DESCENDER'
let s:d[0x049C]='CYRILLIC CAPITAL LETTER KA WITH VERTICAL STROKE'
let s:d[0x049D]='CYRILLIC SMALL LETTER KA WITH VERTICAL STROKE'
let s:d[0x049E]='CYRILLIC CAPITAL LETTER KA WITH STROKE'
let s:d[0x049F]='CYRILLIC SMALL LETTER KA WITH STROKE'
let s:d[0x04A0]='CYRILLIC CAPITAL LETTER BASHKIR KA'
let s:d[0x04A1]='CYRILLIC SMALL LETTER BASHKIR KA'
let s:d[0x04A2]='CYRILLIC CAPITAL LETTER EN WITH DESCENDER'
let s:d[0x04A3]='CYRILLIC SMALL LETTER EN WITH DESCENDER'
let s:d[0x04A4]='CYRILLIC CAPITAL LIGATURE EN GHE'
let s:d[0x04A5]='CYRILLIC SMALL LIGATURE EN GHE'
let s:d[0x04A6]='CYRILLIC CAPITAL LETTER PE WITH MIDDLE HOOK'
let s:d[0x04A7]='CYRILLIC SMALL LETTER PE WITH MIDDLE HOOK'
let s:d[0x04A8]='CYRILLIC CAPITAL LETTER ABKHASIAN HA'
let s:d[0x04A9]='CYRILLIC SMALL LETTER ABKHASIAN HA'
let s:d[0x04AA]='CYRILLIC CAPITAL LETTER ES WITH DESCENDER'
let s:d[0x04AB]='CYRILLIC SMALL LETTER ES WITH DESCENDER'
let s:d[0x04AC]='CYRILLIC CAPITAL LETTER TE WITH DESCENDER'
let s:d[0x04AD]='CYRILLIC SMALL LETTER TE WITH DESCENDER'
let s:d[0x04AE]='CYRILLIC CAPITAL LETTER STRAIGHT U'
let s:d[0x04AF]='CYRILLIC SMALL LETTER STRAIGHT U'
let s:d[0x04B0]='CYRILLIC CAPITAL LETTER STRAIGHT U WITH STROKE'
let s:d[0x04B1]='CYRILLIC SMALL LETTER STRAIGHT U WITH STROKE'
let s:d[0x04B2]='CYRILLIC CAPITAL LETTER HA WITH DESCENDER'
let s:d[0x04B3]='CYRILLIC SMALL LETTER HA WITH DESCENDER'
let s:d[0x04B4]='CYRILLIC CAPITAL LIGATURE TE TSE'
let s:d[0x04B5]='CYRILLIC SMALL LIGATURE TE TSE'
let s:d[0x04B6]='CYRILLIC CAPITAL LETTER CHE WITH DESCENDER'
let s:d[0x04B7]='CYRILLIC SMALL LETTER CHE WITH DESCENDER'
let s:d[0x04B8]='CYRILLIC CAPITAL LETTER CHE WITH VERTICAL STROKE'
let s:d[0x04B9]='CYRILLIC SMALL LETTER CHE WITH VERTICAL STROKE'
let s:d[0x04BA]='CYRILLIC CAPITAL LETTER SHHA'
let s:d[0x04BB]='CYRILLIC SMALL LETTER SHHA'
let s:d[0x04BC]='CYRILLIC CAPITAL LETTER ABKHASIAN CHE'
let s:d[0x04BD]='CYRILLIC SMALL LETTER ABKHASIAN CHE'
let s:d[0x04BE]='CYRILLIC CAPITAL LETTER ABKHASIAN CHE WITH DESCENDER'
let s:d[0x04BF]='CYRILLIC SMALL LETTER ABKHASIAN CHE WITH DESCENDER'
let s:d[0x04C0]='CYRILLIC LETTER PALOCHKA'
let s:d[0x04C1]='CYRILLIC CAPITAL LETTER ZHE WITH BREVE'
let s:d[0x04C2]='CYRILLIC SMALL LETTER ZHE WITH BREVE'
let s:d[0x04C3]='CYRILLIC CAPITAL LETTER KA WITH HOOK'
let s:d[0x04C4]='CYRILLIC SMALL LETTER KA WITH HOOK'
let s:d[0x04C5]='CYRILLIC CAPITAL LETTER EL WITH TAIL'
let s:d[0x04C6]='CYRILLIC SMALL LETTER EL WITH TAIL'
let s:d[0x04C7]='CYRILLIC CAPITAL LETTER EN WITH HOOK'
let s:d[0x04C8]='CYRILLIC SMALL LETTER EN WITH HOOK'
let s:d[0x04C9]='CYRILLIC CAPITAL LETTER EN WITH TAIL'
let s:d[0x04CA]='CYRILLIC SMALL LETTER EN WITH TAIL'
let s:d[0x04CB]='CYRILLIC CAPITAL LETTER KHAKASSIAN CHE'
let s:d[0x04CC]='CYRILLIC SMALL LETTER KHAKASSIAN CHE'
let s:d[0x04CD]='CYRILLIC CAPITAL LETTER EM WITH TAIL'
let s:d[0x04CE]='CYRILLIC SMALL LETTER EM WITH TAIL'
let s:d[0x04CF]='CYRILLIC SMALL LETTER PALOCHKA'
let s:d[0x04D0]='CYRILLIC CAPITAL LETTER A WITH BREVE'
let s:d[0x04D1]='CYRILLIC SMALL LETTER A WITH BREVE'
let s:d[0x04D2]='CYRILLIC CAPITAL LETTER A WITH DIAERESIS'
let s:d[0x04D3]='CYRILLIC SMALL LETTER A WITH DIAERESIS'
let s:d[0x04D4]='CYRILLIC CAPITAL LIGATURE A IE'
let s:d[0x04D5]='CYRILLIC SMALL LIGATURE A IE'
let s:d[0x04D6]='CYRILLIC CAPITAL LETTER IE WITH BREVE'
let s:d[0x04D7]='CYRILLIC SMALL LETTER IE WITH BREVE'
let s:d[0x04D8]='CYRILLIC CAPITAL LETTER SCHWA'
let s:d[0x04D9]='CYRILLIC SMALL LETTER SCHWA'
let s:d[0x04DA]='CYRILLIC CAPITAL LETTER SCHWA WITH DIAERESIS'
let s:d[0x04DB]='CYRILLIC SMALL LETTER SCHWA WITH DIAERESIS'
let s:d[0x04DC]='CYRILLIC CAPITAL LETTER ZHE WITH DIAERESIS'
let s:d[0x04DD]='CYRILLIC SMALL LETTER ZHE WITH DIAERESIS'
let s:d[0x04DE]='CYRILLIC CAPITAL LETTER ZE WITH DIAERESIS'
let s:d[0x04DF]='CYRILLIC SMALL LETTER ZE WITH DIAERESIS'
let s:d[0x04E0]='CYRILLIC CAPITAL LETTER ABKHASIAN DZE'
let s:d[0x04E1]='CYRILLIC SMALL LETTER ABKHASIAN DZE'
let s:d[0x04E2]='CYRILLIC CAPITAL LETTER I WITH MACRON'
let s:d[0x04E3]='CYRILLIC SMALL LETTER I WITH MACRON'
let s:d[0x04E4]='CYRILLIC CAPITAL LETTER I WITH DIAERESIS'
let s:d[0x04E5]='CYRILLIC SMALL LETTER I WITH DIAERESIS'
let s:d[0x04E6]='CYRILLIC CAPITAL LETTER O WITH DIAERESIS'
let s:d[0x04E7]='CYRILLIC SMALL LETTER O WITH DIAERESIS'
let s:d[0x04E8]='CYRILLIC CAPITAL LETTER BARRED O'
let s:d[0x04E9]='CYRILLIC SMALL LETTER BARRED O'
let s:d[0x04EA]='CYRILLIC CAPITAL LETTER BARRED O WITH DIAERESIS'
let s:d[0x04EB]='CYRILLIC SMALL LETTER BARRED O WITH DIAERESIS'
let s:d[0x04EC]='CYRILLIC CAPITAL LETTER E WITH DIAERESIS'
let s:d[0x04ED]='CYRILLIC SMALL LETTER E WITH DIAERESIS'
let s:d[0x04EE]='CYRILLIC CAPITAL LETTER U WITH MACRON'
let s:d[0x04EF]='CYRILLIC SMALL LETTER U WITH MACRON'
let s:d[0x04F0]='CYRILLIC CAPITAL LETTER U WITH DIAERESIS'
let s:d[0x04F1]='CYRILLIC SMALL LETTER U WITH DIAERESIS'
let s:d[0x04F2]='CYRILLIC CAPITAL LETTER U WITH DOUBLE ACUTE'
let s:d[0x04F3]='CYRILLIC SMALL LETTER U WITH DOUBLE ACUTE'
let s:d[0x04F4]='CYRILLIC CAPITAL LETTER CHE WITH DIAERESIS'
let s:d[0x04F5]='CYRILLIC SMALL LETTER CHE WITH DIAERESIS'
let s:d[0x04F6]='CYRILLIC CAPITAL LETTER GHE WITH DESCENDER'
let s:d[0x04F7]='CYRILLIC SMALL LETTER GHE WITH DESCENDER'
let s:d[0x04F8]='CYRILLIC CAPITAL LETTER YERU WITH DIAERESIS'
let s:d[0x04F9]='CYRILLIC SMALL LETTER YERU WITH DIAERESIS'
let s:d[0x04FA]='CYRILLIC CAPITAL LETTER GHE WITH STROKE AND HOOK'
let s:d[0x04FB]='CYRILLIC SMALL LETTER GHE WITH STROKE AND HOOK'
let s:d[0x04FC]='CYRILLIC CAPITAL LETTER HA WITH HOOK'
let s:d[0x04FD]='CYRILLIC SMALL LETTER HA WITH HOOK'
let s:d[0x04FE]='CYRILLIC CAPITAL LETTER HA WITH STROKE'
let s:d[0x04FF]='CYRILLIC SMALL LETTER HA WITH STROKE'
let s:d[0x0500]='CYRILLIC CAPITAL LETTER KOMI DE'
let s:d[0x0501]='CYRILLIC SMALL LETTER KOMI DE'
let s:d[0x0502]='CYRILLIC CAPITAL LETTER KOMI DJE'
let s:d[0x0503]='CYRILLIC SMALL LETTER KOMI DJE'
let s:d[0x0504]='CYRILLIC CAPITAL LETTER KOMI ZJE'
let s:d[0x0505]='CYRILLIC SMALL LETTER KOMI ZJE'
let s:d[0x0506]='CYRILLIC CAPITAL LETTER KOMI DZJE'
let s:d[0x0507]='CYRILLIC SMALL LETTER KOMI DZJE'
let s:d[0x0508]='CYRILLIC CAPITAL LETTER KOMI LJE'
let s:d[0x0509]='CYRILLIC SMALL LETTER KOMI LJE'
let s:d[0x050A]='CYRILLIC CAPITAL LETTER KOMI NJE'
let s:d[0x050B]='CYRILLIC SMALL LETTER KOMI NJE'
let s:d[0x050C]='CYRILLIC CAPITAL LETTER KOMI SJE'
let s:d[0x050D]='CYRILLIC SMALL LETTER KOMI SJE'
let s:d[0x050E]='CYRILLIC CAPITAL LETTER KOMI TJE'
let s:d[0x050F]='CYRILLIC SMALL LETTER KOMI TJE'
let s:d[0x0510]='CYRILLIC CAPITAL LETTER REVERSED ZE'
let s:d[0x0511]='CYRILLIC SMALL LETTER REVERSED ZE'
let s:d[0x0512]='CYRILLIC CAPITAL LETTER EL WITH HOOK'
let s:d[0x0513]='CYRILLIC SMALL LETTER EL WITH HOOK'
let s:d[0x0514]='CYRILLIC CAPITAL LETTER LHA'
let s:d[0x0515]='CYRILLIC SMALL LETTER LHA'
let s:d[0x0516]='CYRILLIC CAPITAL LETTER RHA'
let s:d[0x0517]='CYRILLIC SMALL LETTER RHA'
let s:d[0x0518]='CYRILLIC CAPITAL LETTER YAE'
let s:d[0x0519]='CYRILLIC SMALL LETTER YAE'
let s:d[0x051A]='CYRILLIC CAPITAL LETTER QA'
let s:d[0x051B]='CYRILLIC SMALL LETTER QA'
let s:d[0x051C]='CYRILLIC CAPITAL LETTER WE'
let s:d[0x051D]='CYRILLIC SMALL LETTER WE'
let s:d[0x051E]='CYRILLIC CAPITAL LETTER ALEUT KA'
let s:d[0x051F]='CYRILLIC SMALL LETTER ALEUT KA'
let s:d[0x0520]='CYRILLIC CAPITAL LETTER EL WITH MIDDLE HOOK'
let s:d[0x0521]='CYRILLIC SMALL LETTER EL WITH MIDDLE HOOK'
let s:d[0x0522]='CYRILLIC CAPITAL LETTER EN WITH MIDDLE HOOK'
let s:d[0x0523]='CYRILLIC SMALL LETTER EN WITH MIDDLE HOOK'
let s:d[0x0524]='CYRILLIC CAPITAL LETTER PE WITH DESCENDER'
let s:d[0x0525]='CYRILLIC SMALL LETTER PE WITH DESCENDER'
let s:d[0x0526]='CYRILLIC CAPITAL LETTER SHHA WITH DESCENDER'
let s:d[0x0527]='CYRILLIC SMALL LETTER SHHA WITH DESCENDER'
let s:d[0x0531]='ARMENIAN CAPITAL LETTER AYB'
let s:d[0x0532]='ARMENIAN CAPITAL LETTER BEN'
let s:d[0x0533]='ARMENIAN CAPITAL LETTER GIM'
let s:d[0x0534]='ARMENIAN CAPITAL LETTER DA'
let s:d[0x0535]='ARMENIAN CAPITAL LETTER ECH'
let s:d[0x0536]='ARMENIAN CAPITAL LETTER ZA'
let s:d[0x0537]='ARMENIAN CAPITAL LETTER EH'
let s:d[0x0538]='ARMENIAN CAPITAL LETTER ET'
let s:d[0x0539]='ARMENIAN CAPITAL LETTER TO'
let s:d[0x053A]='ARMENIAN CAPITAL LETTER ZHE'
let s:d[0x053B]='ARMENIAN CAPITAL LETTER INI'
let s:d[0x053C]='ARMENIAN CAPITAL LETTER LIWN'
let s:d[0x053D]='ARMENIAN CAPITAL LETTER XEH'
let s:d[0x053E]='ARMENIAN CAPITAL LETTER CA'
let s:d[0x053F]='ARMENIAN CAPITAL LETTER KEN'
let s:d[0x0540]='ARMENIAN CAPITAL LETTER HO'
let s:d[0x0541]='ARMENIAN CAPITAL LETTER JA'
let s:d[0x0542]='ARMENIAN CAPITAL LETTER GHAD'
let s:d[0x0543]='ARMENIAN CAPITAL LETTER CHEH'
let s:d[0x0544]='ARMENIAN CAPITAL LETTER MEN'
let s:d[0x0545]='ARMENIAN CAPITAL LETTER YI'
let s:d[0x0546]='ARMENIAN CAPITAL LETTER NOW'
let s:d[0x0547]='ARMENIAN CAPITAL LETTER SHA'
let s:d[0x0548]='ARMENIAN CAPITAL LETTER VO'
let s:d[0x0549]='ARMENIAN CAPITAL LETTER CHA'
let s:d[0x054A]='ARMENIAN CAPITAL LETTER PEH'
let s:d[0x054B]='ARMENIAN CAPITAL LETTER JHEH'
let s:d[0x054C]='ARMENIAN CAPITAL LETTER RA'
let s:d[0x054D]='ARMENIAN CAPITAL LETTER SEH'
let s:d[0x054E]='ARMENIAN CAPITAL LETTER VEW'
let s:d[0x054F]='ARMENIAN CAPITAL LETTER TIWN'
let s:d[0x0550]='ARMENIAN CAPITAL LETTER REH'
let s:d[0x0551]='ARMENIAN CAPITAL LETTER CO'
let s:d[0x0552]='ARMENIAN CAPITAL LETTER YIWN'
let s:d[0x0553]='ARMENIAN CAPITAL LETTER PIWR'
let s:d[0x0554]='ARMENIAN CAPITAL LETTER KEH'
let s:d[0x0555]='ARMENIAN CAPITAL LETTER OH'
let s:d[0x0556]='ARMENIAN CAPITAL LETTER FEH'
let s:d[0x0559]='ARMENIAN MODIFIER LETTER LEFT HALF RING'
let s:d[0x055A]='ARMENIAN APOSTROPHE'
let s:d[0x055B]='ARMENIAN EMPHASIS MARK'
let s:d[0x055C]='ARMENIAN EXCLAMATION MARK'
let s:d[0x055D]='ARMENIAN COMMA'
let s:d[0x055E]='ARMENIAN QUESTION MARK'
let s:d[0x055F]='ARMENIAN ABBREVIATION MARK'
let s:d[0x0561]='ARMENIAN SMALL LETTER AYB'
let s:d[0x0562]='ARMENIAN SMALL LETTER BEN'
let s:d[0x0563]='ARMENIAN SMALL LETTER GIM'
let s:d[0x0564]='ARMENIAN SMALL LETTER DA'
let s:d[0x0565]='ARMENIAN SMALL LETTER ECH'
let s:d[0x0566]='ARMENIAN SMALL LETTER ZA'
let s:d[0x0567]='ARMENIAN SMALL LETTER EH'
let s:d[0x0568]='ARMENIAN SMALL LETTER ET'
let s:d[0x0569]='ARMENIAN SMALL LETTER TO'
let s:d[0x056A]='ARMENIAN SMALL LETTER ZHE'
let s:d[0x056B]='ARMENIAN SMALL LETTER INI'
let s:d[0x056C]='ARMENIAN SMALL LETTER LIWN'
let s:d[0x056D]='ARMENIAN SMALL LETTER XEH'
let s:d[0x056E]='ARMENIAN SMALL LETTER CA'
let s:d[0x056F]='ARMENIAN SMALL LETTER KEN'
let s:d[0x0570]='ARMENIAN SMALL LETTER HO'
let s:d[0x0571]='ARMENIAN SMALL LETTER JA'
let s:d[0x0572]='ARMENIAN SMALL LETTER GHAD'
let s:d[0x0573]='ARMENIAN SMALL LETTER CHEH'
let s:d[0x0574]='ARMENIAN SMALL LETTER MEN'
let s:d[0x0575]='ARMENIAN SMALL LETTER YI'
let s:d[0x0576]='ARMENIAN SMALL LETTER NOW'
let s:d[0x0577]='ARMENIAN SMALL LETTER SHA'
let s:d[0x0578]='ARMENIAN SMALL LETTER VO'
let s:d[0x0579]='ARMENIAN SMALL LETTER CHA'
let s:d[0x057A]='ARMENIAN SMALL LETTER PEH'
let s:d[0x057B]='ARMENIAN SMALL LETTER JHEH'
let s:d[0x057C]='ARMENIAN SMALL LETTER RA'
let s:d[0x057D]='ARMENIAN SMALL LETTER SEH'
let s:d[0x057E]='ARMENIAN SMALL LETTER VEW'
let s:d[0x057F]='ARMENIAN SMALL LETTER TIWN'
let s:d[0x0580]='ARMENIAN SMALL LETTER REH'
let s:d[0x0581]='ARMENIAN SMALL LETTER CO'
let s:d[0x0582]='ARMENIAN SMALL LETTER YIWN'
let s:d[0x0583]='ARMENIAN SMALL LETTER PIWR'
let s:d[0x0584]='ARMENIAN SMALL LETTER KEH'
let s:d[0x0585]='ARMENIAN SMALL LETTER OH'
let s:d[0x0586]='ARMENIAN SMALL LETTER FEH'
let s:d[0x0587]='ARMENIAN SMALL LIGATURE ECH YIWN'
let s:d[0x0589]='ARMENIAN FULL STOP'
let s:d[0x058A]='ARMENIAN HYPHEN'
let s:d[0x058F]='ARMENIAN DRAM SIGN'
let s:d[0x0591]='HEBREW ACCENT ETNAHTA'
let s:d[0x0592]='HEBREW ACCENT SEGOL'
let s:d[0x0593]='HEBREW ACCENT SHALSHELET'
let s:d[0x0594]='HEBREW ACCENT ZAQEF QATAN'
let s:d[0x0595]='HEBREW ACCENT ZAQEF GADOL'
let s:d[0x0596]='HEBREW ACCENT TIPEHA'
let s:d[0x0597]='HEBREW ACCENT REVIA'
let s:d[0x0598]='HEBREW ACCENT ZARQA'
let s:d[0x0599]='HEBREW ACCENT PASHTA'
let s:d[0x059A]='HEBREW ACCENT YETIV'
let s:d[0x059B]='HEBREW ACCENT TEVIR'
let s:d[0x059C]='HEBREW ACCENT GERESH'
let s:d[0x059D]='HEBREW ACCENT GERESH MUQDAM'
let s:d[0x059E]='HEBREW ACCENT GERSHAYIM'
let s:d[0x059F]='HEBREW ACCENT QARNEY PARA'
let s:d[0x05A0]='HEBREW ACCENT TELISHA GEDOLA'
let s:d[0x05A1]='HEBREW ACCENT PAZER'
let s:d[0x05A2]='HEBREW ACCENT ATNAH HAFUKH'
let s:d[0x05A3]='HEBREW ACCENT MUNAH'
let s:d[0x05A4]='HEBREW ACCENT MAHAPAKH'
let s:d[0x05A5]='HEBREW ACCENT MERKHA'
let s:d[0x05A6]='HEBREW ACCENT MERKHA KEFULA'
let s:d[0x05A7]='HEBREW ACCENT DARGA'
let s:d[0x05A8]='HEBREW ACCENT QADMA'
let s:d[0x05A9]='HEBREW ACCENT TELISHA QETANA'
let s:d[0x05AA]='HEBREW ACCENT YERAH BEN YOMO'
let s:d[0x05AB]='HEBREW ACCENT OLE'
let s:d[0x05AC]='HEBREW ACCENT ILUY'
let s:d[0x05AD]='HEBREW ACCENT DEHI'
let s:d[0x05AE]='HEBREW ACCENT ZINOR'
let s:d[0x05AF]='HEBREW MARK MASORA CIRCLE'
let s:d[0x05B0]='HEBREW POINT SHEVA'
let s:d[0x05B1]='HEBREW POINT HATAF SEGOL'
let s:d[0x05B2]='HEBREW POINT HATAF PATAH'
let s:d[0x05B3]='HEBREW POINT HATAF QAMATS'
let s:d[0x05B4]='HEBREW POINT HIRIQ'
let s:d[0x05B5]='HEBREW POINT TSERE'
let s:d[0x05B6]='HEBREW POINT SEGOL'
let s:d[0x05B7]='HEBREW POINT PATAH'
let s:d[0x05B8]='HEBREW POINT QAMATS'
let s:d[0x05B9]='HEBREW POINT HOLAM'
let s:d[0x05BA]='HEBREW POINT HOLAM HASER FOR VAV'
let s:d[0x05BB]='HEBREW POINT QUBUTS'
let s:d[0x05BC]='HEBREW POINT DAGESH OR MAPIQ'
let s:d[0x05BD]='HEBREW POINT METEG'
let s:d[0x05BE]='HEBREW PUNCTUATION MAQAF'
let s:d[0x05BF]='HEBREW POINT RAFE'
let s:d[0x05C0]='HEBREW PUNCTUATION PASEQ'
let s:d[0x05C1]='HEBREW POINT SHIN DOT'
let s:d[0x05C2]='HEBREW POINT SIN DOT'
let s:d[0x05C3]='HEBREW PUNCTUATION SOF PASUQ'
let s:d[0x05C4]='HEBREW MARK UPPER DOT'
let s:d[0x05C5]='HEBREW MARK LOWER DOT'
let s:d[0x05C6]='HEBREW PUNCTUATION NUN HAFUKHA'
let s:d[0x05C7]='HEBREW POINT QAMATS QATAN'
let s:d[0x05D0]='HEBREW LETTER ALEF'
let s:d[0x05D1]='HEBREW LETTER BET'
let s:d[0x05D2]='HEBREW LETTER GIMEL'
let s:d[0x05D3]='HEBREW LETTER DALET'
let s:d[0x05D4]='HEBREW LETTER HE'
let s:d[0x05D5]='HEBREW LETTER VAV'
let s:d[0x05D6]='HEBREW LETTER ZAYIN'
let s:d[0x05D7]='HEBREW LETTER HET'
let s:d[0x05D8]='HEBREW LETTER TET'
let s:d[0x05D9]='HEBREW LETTER YOD'
let s:d[0x05DA]='HEBREW LETTER FINAL KAF'
let s:d[0x05DB]='HEBREW LETTER KAF'
let s:d[0x05DC]='HEBREW LETTER LAMED'
let s:d[0x05DD]='HEBREW LETTER FINAL MEM'
let s:d[0x05DE]='HEBREW LETTER MEM'
let s:d[0x05DF]='HEBREW LETTER FINAL NUN'
let s:d[0x05E0]='HEBREW LETTER NUN'
let s:d[0x05E1]='HEBREW LETTER SAMEKH'
let s:d[0x05E2]='HEBREW LETTER AYIN'
let s:d[0x05E3]='HEBREW LETTER FINAL PE'
let s:d[0x05E4]='HEBREW LETTER PE'
let s:d[0x05E5]='HEBREW LETTER FINAL TSADI'
let s:d[0x05E6]='HEBREW LETTER TSADI'
let s:d[0x05E7]='HEBREW LETTER QOF'
let s:d[0x05E8]='HEBREW LETTER RESH'
let s:d[0x05E9]='HEBREW LETTER SHIN'
let s:d[0x05EA]='HEBREW LETTER TAV'
let s:d[0x05F0]='HEBREW LIGATURE YIDDISH DOUBLE VAV'
let s:d[0x05F1]='HEBREW LIGATURE YIDDISH VAV YOD'
let s:d[0x05F2]='HEBREW LIGATURE YIDDISH DOUBLE YOD'
let s:d[0x05F3]='HEBREW PUNCTUATION GERESH'
let s:d[0x05F4]='HEBREW PUNCTUATION GERSHAYIM'
let s:d[0x0600]='ARABIC NUMBER SIGN'
let s:d[0x0601]='ARABIC SIGN SANAH'
let s:d[0x0602]='ARABIC FOOTNOTE MARKER'
let s:d[0x0603]='ARABIC SIGN SAFHA'
let s:d[0x0604]='ARABIC SIGN SAMVAT'
let s:d[0x0606]='ARABIC-INDIC CUBE ROOT'
let s:d[0x0607]='ARABIC-INDIC FOURTH ROOT'
let s:d[0x0608]='ARABIC RAY'
let s:d[0x0609]='ARABIC-INDIC PER MILLE SIGN'
let s:d[0x060A]='ARABIC-INDIC PER TEN THOUSAND SIGN'
let s:d[0x060B]='AFGHANI SIGN'
let s:d[0x060C]='ARABIC COMMA'
let s:d[0x060D]='ARABIC DATE SEPARATOR'
let s:d[0x060E]='ARABIC POETIC VERSE SIGN'
let s:d[0x060F]='ARABIC SIGN MISRA'
let s:d[0x0610]='ARABIC SIGN SALLALLAHOU ALAYHE WASSALLAM'
let s:d[0x0611]='ARABIC SIGN ALAYHE ASSALLAM'
let s:d[0x0612]='ARABIC SIGN RAHMATULLAH ALAYHE'
let s:d[0x0613]='ARABIC SIGN RADI ALLAHOU ANHU'
let s:d[0x0614]='ARABIC SIGN TAKHALLUS'
let s:d[0x0615]='ARABIC SMALL HIGH TAH'
let s:d[0x0616]='ARABIC SMALL HIGH LIGATURE ALEF WITH LAM WITH YEH'
let s:d[0x0617]='ARABIC SMALL HIGH ZAIN'
let s:d[0x0618]='ARABIC SMALL FATHA'
let s:d[0x0619]='ARABIC SMALL DAMMA'
let s:d[0x061A]='ARABIC SMALL KASRA'
let s:d[0x061B]='ARABIC SEMICOLON'
let s:d[0x061E]='ARABIC TRIPLE DOT PUNCTUATION MARK'
let s:d[0x061F]='ARABIC QUESTION MARK'
let s:d[0x0620]='ARABIC LETTER KASHMIRI YEH'
let s:d[0x0621]='ARABIC LETTER HAMZA'
let s:d[0x0622]='ARABIC LETTER ALEF WITH MADDA ABOVE'
let s:d[0x0623]='ARABIC LETTER ALEF WITH HAMZA ABOVE'
let s:d[0x0624]='ARABIC LETTER WAW WITH HAMZA ABOVE'
let s:d[0x0625]='ARABIC LETTER ALEF WITH HAMZA BELOW'
let s:d[0x0626]='ARABIC LETTER YEH WITH HAMZA ABOVE'
let s:d[0x0627]='ARABIC LETTER ALEF'
let s:d[0x0628]='ARABIC LETTER BEH'
let s:d[0x0629]='ARABIC LETTER TEH MARBUTA'
let s:d[0x062A]='ARABIC LETTER TEH'
let s:d[0x062B]='ARABIC LETTER THEH'
let s:d[0x062C]='ARABIC LETTER JEEM'
let s:d[0x062D]='ARABIC LETTER HAH'
let s:d[0x062E]='ARABIC LETTER KHAH'
let s:d[0x062F]='ARABIC LETTER DAL'
let s:d[0x0630]='ARABIC LETTER THAL'
let s:d[0x0631]='ARABIC LETTER REH'
let s:d[0x0632]='ARABIC LETTER ZAIN'
let s:d[0x0633]='ARABIC LETTER SEEN'
let s:d[0x0634]='ARABIC LETTER SHEEN'
let s:d[0x0635]='ARABIC LETTER SAD'
let s:d[0x0636]='ARABIC LETTER DAD'
let s:d[0x0637]='ARABIC LETTER TAH'
let s:d[0x0638]='ARABIC LETTER ZAH'
let s:d[0x0639]='ARABIC LETTER AIN'
let s:d[0x063A]='ARABIC LETTER GHAIN'
let s:d[0x063B]='ARABIC LETTER KEHEH WITH TWO DOTS ABOVE'
let s:d[0x063C]='ARABIC LETTER KEHEH WITH THREE DOTS BELOW'
let s:d[0x063D]='ARABIC LETTER FARSI YEH WITH INVERTED V'
let s:d[0x063E]='ARABIC LETTER FARSI YEH WITH TWO DOTS ABOVE'
let s:d[0x063F]='ARABIC LETTER FARSI YEH WITH THREE DOTS ABOVE'
let s:d[0x0640]='ARABIC TATWEEL'
let s:d[0x0641]='ARABIC LETTER FEH'
let s:d[0x0642]='ARABIC LETTER QAF'
let s:d[0x0643]='ARABIC LETTER KAF'
let s:d[0x0644]='ARABIC LETTER LAM'
let s:d[0x0645]='ARABIC LETTER MEEM'
let s:d[0x0646]='ARABIC LETTER NOON'
let s:d[0x0647]='ARABIC LETTER HEH'
let s:d[0x0648]='ARABIC LETTER WAW'
let s:d[0x0649]='ARABIC LETTER ALEF MAKSURA'
let s:d[0x064A]='ARABIC LETTER YEH'
let s:d[0x064B]='ARABIC FATHATAN'
let s:d[0x064C]='ARABIC DAMMATAN'
let s:d[0x064D]='ARABIC KASRATAN'
let s:d[0x064E]='ARABIC FATHA'
let s:d[0x064F]='ARABIC DAMMA'
let s:d[0x0650]='ARABIC KASRA'
let s:d[0x0651]='ARABIC SHADDA'
let s:d[0x0652]='ARABIC SUKUN'
let s:d[0x0653]='ARABIC MADDAH ABOVE'
let s:d[0x0654]='ARABIC HAMZA ABOVE'
let s:d[0x0655]='ARABIC HAMZA BELOW'
let s:d[0x0656]='ARABIC SUBSCRIPT ALEF'
let s:d[0x0657]='ARABIC INVERTED DAMMA'
let s:d[0x0658]='ARABIC MARK NOON GHUNNA'
let s:d[0x0659]='ARABIC ZWARAKAY'
let s:d[0x065A]='ARABIC VOWEL SIGN SMALL V ABOVE'
let s:d[0x065B]='ARABIC VOWEL SIGN INVERTED SMALL V ABOVE'
let s:d[0x065C]='ARABIC VOWEL SIGN DOT BELOW'
let s:d[0x065D]='ARABIC REVERSED DAMMA'
let s:d[0x065E]='ARABIC FATHA WITH TWO DOTS'
let s:d[0x065F]='ARABIC WAVY HAMZA BELOW'
let s:d[0x0660]='ARABIC-INDIC DIGIT ZERO'
let s:d[0x0661]='ARABIC-INDIC DIGIT ONE'
let s:d[0x0662]='ARABIC-INDIC DIGIT TWO'
let s:d[0x0663]='ARABIC-INDIC DIGIT THREE'
let s:d[0x0664]='ARABIC-INDIC DIGIT FOUR'
let s:d[0x0665]='ARABIC-INDIC DIGIT FIVE'
let s:d[0x0666]='ARABIC-INDIC DIGIT SIX'
let s:d[0x0667]='ARABIC-INDIC DIGIT SEVEN'
let s:d[0x0668]='ARABIC-INDIC DIGIT EIGHT'
let s:d[0x0669]='ARABIC-INDIC DIGIT NINE'
let s:d[0x066A]='ARABIC PERCENT SIGN'
let s:d[0x066B]='ARABIC DECIMAL SEPARATOR'
let s:d[0x066C]='ARABIC THOUSANDS SEPARATOR'
let s:d[0x066D]='ARABIC FIVE POINTED STAR'
let s:d[0x066E]='ARABIC LETTER DOTLESS BEH'
let s:d[0x066F]='ARABIC LETTER DOTLESS QAF'
let s:d[0x0670]='ARABIC LETTER SUPERSCRIPT ALEF'
let s:d[0x0671]='ARABIC LETTER ALEF WASLA'
let s:d[0x0672]='ARABIC LETTER ALEF WITH WAVY HAMZA ABOVE'
let s:d[0x0673]='ARABIC LETTER ALEF WITH WAVY HAMZA BELOW'
let s:d[0x0674]='ARABIC LETTER HIGH HAMZA'
let s:d[0x0675]='ARABIC LETTER HIGH HAMZA ALEF'
let s:d[0x0676]='ARABIC LETTER HIGH HAMZA WAW'
let s:d[0x0677]='ARABIC LETTER U WITH HAMZA ABOVE'
let s:d[0x0678]='ARABIC LETTER HIGH HAMZA YEH'
let s:d[0x0679]='ARABIC LETTER TTEH'
let s:d[0x067A]='ARABIC LETTER TTEHEH'
let s:d[0x067B]='ARABIC LETTER BEEH'
let s:d[0x067C]='ARABIC LETTER TEH WITH RING'
let s:d[0x067D]='ARABIC LETTER TEH WITH THREE DOTS ABOVE DOWNWARDS'
let s:d[0x067E]='ARABIC LETTER PEH'
let s:d[0x067F]='ARABIC LETTER TEHEH'
let s:d[0x0680]='ARABIC LETTER BEHEH'
let s:d[0x0681]='ARABIC LETTER HAH WITH HAMZA ABOVE'
let s:d[0x0682]='ARABIC LETTER HAH WITH TWO DOTS VERTICAL ABOVE'
let s:d[0x0683]='ARABIC LETTER NYEH'
let s:d[0x0684]='ARABIC LETTER DYEH'
let s:d[0x0685]='ARABIC LETTER HAH WITH THREE DOTS ABOVE'
let s:d[0x0686]='ARABIC LETTER TCHEH'
let s:d[0x0687]='ARABIC LETTER TCHEHEH'
let s:d[0x0688]='ARABIC LETTER DDAL'
let s:d[0x0689]='ARABIC LETTER DAL WITH RING'
let s:d[0x068A]='ARABIC LETTER DAL WITH DOT BELOW'
let s:d[0x068B]='ARABIC LETTER DAL WITH DOT BELOW AND SMALL TAH'
let s:d[0x068C]='ARABIC LETTER DAHAL'
let s:d[0x068D]='ARABIC LETTER DDAHAL'
let s:d[0x068E]='ARABIC LETTER DUL'
let s:d[0x068F]='ARABIC LETTER DAL WITH THREE DOTS ABOVE DOWNWARDS'
let s:d[0x0690]='ARABIC LETTER DAL WITH FOUR DOTS ABOVE'
let s:d[0x0691]='ARABIC LETTER RREH'
let s:d[0x0692]='ARABIC LETTER REH WITH SMALL V'
let s:d[0x0693]='ARABIC LETTER REH WITH RING'
let s:d[0x0694]='ARABIC LETTER REH WITH DOT BELOW'
let s:d[0x0695]='ARABIC LETTER REH WITH SMALL V BELOW'
let s:d[0x0696]='ARABIC LETTER REH WITH DOT BELOW AND DOT ABOVE'
let s:d[0x0697]='ARABIC LETTER REH WITH TWO DOTS ABOVE'
let s:d[0x0698]='ARABIC LETTER JEH'
let s:d[0x0699]='ARABIC LETTER REH WITH FOUR DOTS ABOVE'
let s:d[0x069A]='ARABIC LETTER SEEN WITH DOT BELOW AND DOT ABOVE'
let s:d[0x069B]='ARABIC LETTER SEEN WITH THREE DOTS BELOW'
let s:d[0x069C]='ARABIC LETTER SEEN WITH THREE DOTS BELOW AND THREE DOTS ABOVE'
let s:d[0x069D]='ARABIC LETTER SAD WITH TWO DOTS BELOW'
let s:d[0x069E]='ARABIC LETTER SAD WITH THREE DOTS ABOVE'
let s:d[0x069F]='ARABIC LETTER TAH WITH THREE DOTS ABOVE'
let s:d[0x06A0]='ARABIC LETTER AIN WITH THREE DOTS ABOVE'
let s:d[0x06A1]='ARABIC LETTER DOTLESS FEH'
let s:d[0x06A2]='ARABIC LETTER FEH WITH DOT MOVED BELOW'
let s:d[0x06A3]='ARABIC LETTER FEH WITH DOT BELOW'
let s:d[0x06A4]='ARABIC LETTER VEH'
let s:d[0x06A5]='ARABIC LETTER FEH WITH THREE DOTS BELOW'
let s:d[0x06A6]='ARABIC LETTER PEHEH'
let s:d[0x06A7]='ARABIC LETTER QAF WITH DOT ABOVE'
let s:d[0x06A8]='ARABIC LETTER QAF WITH THREE DOTS ABOVE'
let s:d[0x06A9]='ARABIC LETTER KEHEH'
let s:d[0x06AA]='ARABIC LETTER SWASH KAF'
let s:d[0x06AB]='ARABIC LETTER KAF WITH RING'
let s:d[0x06AC]='ARABIC LETTER KAF WITH DOT ABOVE'
let s:d[0x06AD]='ARABIC LETTER NG'
let s:d[0x06AE]='ARABIC LETTER KAF WITH THREE DOTS BELOW'
let s:d[0x06AF]='ARABIC LETTER GAF'
let s:d[0x06B0]='ARABIC LETTER GAF WITH RING'
let s:d[0x06B1]='ARABIC LETTER NGOEH'
let s:d[0x06B2]='ARABIC LETTER GAF WITH TWO DOTS BELOW'
let s:d[0x06B3]='ARABIC LETTER GUEH'
let s:d[0x06B4]='ARABIC LETTER GAF WITH THREE DOTS ABOVE'
let s:d[0x06B5]='ARABIC LETTER LAM WITH SMALL V'
let s:d[0x06B6]='ARABIC LETTER LAM WITH DOT ABOVE'
let s:d[0x06B7]='ARABIC LETTER LAM WITH THREE DOTS ABOVE'
let s:d[0x06B8]='ARABIC LETTER LAM WITH THREE DOTS BELOW'
let s:d[0x06B9]='ARABIC LETTER NOON WITH DOT BELOW'
let s:d[0x06BA]='ARABIC LETTER NOON GHUNNA'
let s:d[0x06BB]='ARABIC LETTER RNOON'
let s:d[0x06BC]='ARABIC LETTER NOON WITH RING'
let s:d[0x06BD]='ARABIC LETTER NOON WITH THREE DOTS ABOVE'
let s:d[0x06BE]='ARABIC LETTER HEH DOACHASHMEE'
let s:d[0x06BF]='ARABIC LETTER TCHEH WITH DOT ABOVE'
let s:d[0x06C0]='ARABIC LETTER HEH WITH YEH ABOVE'
let s:d[0x06C1]='ARABIC LETTER HEH GOAL'
let s:d[0x06C2]='ARABIC LETTER HEH GOAL WITH HAMZA ABOVE'
let s:d[0x06C3]='ARABIC LETTER TEH MARBUTA GOAL'
let s:d[0x06C4]='ARABIC LETTER WAW WITH RING'
let s:d[0x06C5]='ARABIC LETTER KIRGHIZ OE'
let s:d[0x06C6]='ARABIC LETTER OE'
let s:d[0x06C7]='ARABIC LETTER U'
let s:d[0x06C8]='ARABIC LETTER YU'
let s:d[0x06C9]='ARABIC LETTER KIRGHIZ YU'
let s:d[0x06CA]='ARABIC LETTER WAW WITH TWO DOTS ABOVE'
let s:d[0x06CB]='ARABIC LETTER VE'
let s:d[0x06CC]='ARABIC LETTER FARSI YEH'
let s:d[0x06CD]='ARABIC LETTER YEH WITH TAIL'
let s:d[0x06CE]='ARABIC LETTER YEH WITH SMALL V'
let s:d[0x06CF]='ARABIC LETTER WAW WITH DOT ABOVE'
let s:d[0x06D0]='ARABIC LETTER E'
let s:d[0x06D1]='ARABIC LETTER YEH WITH THREE DOTS BELOW'
let s:d[0x06D2]='ARABIC LETTER YEH BARREE'
let s:d[0x06D3]='ARABIC LETTER YEH BARREE WITH HAMZA ABOVE'
let s:d[0x06D4]='ARABIC FULL STOP'
let s:d[0x06D5]='ARABIC LETTER AE'
let s:d[0x06D6]='ARABIC SMALL HIGH LIGATURE SAD WITH LAM WITH ALEF MAKSURA'
let s:d[0x06D7]='ARABIC SMALL HIGH LIGATURE QAF WITH LAM WITH ALEF MAKSURA'
let s:d[0x06D8]='ARABIC SMALL HIGH MEEM INITIAL FORM'
let s:d[0x06D9]='ARABIC SMALL HIGH LAM ALEF'
let s:d[0x06DA]='ARABIC SMALL HIGH JEEM'
let s:d[0x06DB]='ARABIC SMALL HIGH THREE DOTS'
let s:d[0x06DC]='ARABIC SMALL HIGH SEEN'
let s:d[0x06DD]='ARABIC END OF AYAH'
let s:d[0x06DE]='ARABIC START OF RUB EL HIZB'
let s:d[0x06DF]='ARABIC SMALL HIGH ROUNDED ZERO'
let s:d[0x06E0]='ARABIC SMALL HIGH UPRIGHT RECTANGULAR ZERO'
let s:d[0x06E1]='ARABIC SMALL HIGH DOTLESS HEAD OF KHAH'
let s:d[0x06E2]='ARABIC SMALL HIGH MEEM ISOLATED FORM'
let s:d[0x06E3]='ARABIC SMALL LOW SEEN'
let s:d[0x06E4]='ARABIC SMALL HIGH MADDA'
let s:d[0x06E5]='ARABIC SMALL WAW'
let s:d[0x06E6]='ARABIC SMALL YEH'
let s:d[0x06E7]='ARABIC SMALL HIGH YEH'
let s:d[0x06E8]='ARABIC SMALL HIGH NOON'
let s:d[0x06E9]='ARABIC PLACE OF SAJDAH'
let s:d[0x06EA]='ARABIC EMPTY CENTRE LOW STOP'
let s:d[0x06EB]='ARABIC EMPTY CENTRE HIGH STOP'
let s:d[0x06EC]='ARABIC ROUNDED HIGH STOP WITH FILLED CENTRE'
let s:d[0x06ED]='ARABIC SMALL LOW MEEM'
let s:d[0x06EE]='ARABIC LETTER DAL WITH INVERTED V'
let s:d[0x06EF]='ARABIC LETTER REH WITH INVERTED V'
let s:d[0x06F0]='EXTENDED ARABIC-INDIC DIGIT ZERO'
let s:d[0x06F1]='EXTENDED ARABIC-INDIC DIGIT ONE'
let s:d[0x06F2]='EXTENDED ARABIC-INDIC DIGIT TWO'
let s:d[0x06F3]='EXTENDED ARABIC-INDIC DIGIT THREE'
let s:d[0x06F4]='EXTENDED ARABIC-INDIC DIGIT FOUR'
let s:d[0x06F5]='EXTENDED ARABIC-INDIC DIGIT FIVE'
let s:d[0x06F6]='EXTENDED ARABIC-INDIC DIGIT SIX'
let s:d[0x06F7]='EXTENDED ARABIC-INDIC DIGIT SEVEN'
let s:d[0x06F8]='EXTENDED ARABIC-INDIC DIGIT EIGHT'
let s:d[0x06F9]='EXTENDED ARABIC-INDIC DIGIT NINE'
let s:d[0x06FA]='ARABIC LETTER SHEEN WITH DOT BELOW'
let s:d[0x06FB]='ARABIC LETTER DAD WITH DOT BELOW'
let s:d[0x06FC]='ARABIC LETTER GHAIN WITH DOT BELOW'
let s:d[0x06FD]='ARABIC SIGN SINDHI AMPERSAND'
let s:d[0x06FE]='ARABIC SIGN SINDHI POSTPOSITION MEN'
let s:d[0x06FF]='ARABIC LETTER HEH WITH INVERTED V'
let s:d[0x0700]='SYRIAC END OF PARAGRAPH'
let s:d[0x0701]='SYRIAC SUPRALINEAR FULL STOP'
let s:d[0x0702]='SYRIAC SUBLINEAR FULL STOP'
let s:d[0x0703]='SYRIAC SUPRALINEAR COLON'
let s:d[0x0704]='SYRIAC SUBLINEAR COLON'
let s:d[0x0705]='SYRIAC HORIZONTAL COLON'
let s:d[0x0706]='SYRIAC COLON SKEWED LEFT'
let s:d[0x0707]='SYRIAC COLON SKEWED RIGHT'
let s:d[0x0708]='SYRIAC SUPRALINEAR COLON SKEWED LEFT'
let s:d[0x0709]='SYRIAC SUBLINEAR COLON SKEWED RIGHT'
let s:d[0x070A]='SYRIAC CONTRACTION'
let s:d[0x070B]='SYRIAC HARKLEAN OBELUS'
let s:d[0x070C]='SYRIAC HARKLEAN METOBELUS'
let s:d[0x070D]='SYRIAC HARKLEAN ASTERISCUS'
let s:d[0x070F]='SYRIAC ABBREVIATION MARK'
let s:d[0x0710]='SYRIAC LETTER ALAPH'
let s:d[0x0711]='SYRIAC LETTER SUPERSCRIPT ALAPH'
let s:d[0x0712]='SYRIAC LETTER BETH'
let s:d[0x0713]='SYRIAC LETTER GAMAL'
let s:d[0x0714]='SYRIAC LETTER GAMAL GARSHUNI'
let s:d[0x0715]='SYRIAC LETTER DALATH'
let s:d[0x0716]='SYRIAC LETTER DOTLESS DALATH RISH'
let s:d[0x0717]='SYRIAC LETTER HE'
let s:d[0x0718]='SYRIAC LETTER WAW'
let s:d[0x0719]='SYRIAC LETTER ZAIN'
let s:d[0x071A]='SYRIAC LETTER HETH'
let s:d[0x071B]='SYRIAC LETTER TETH'
let s:d[0x071C]='SYRIAC LETTER TETH GARSHUNI'
let s:d[0x071D]='SYRIAC LETTER YUDH'
let s:d[0x071E]='SYRIAC LETTER YUDH HE'
let s:d[0x071F]='SYRIAC LETTER KAPH'
let s:d[0x0720]='SYRIAC LETTER LAMADH'
let s:d[0x0721]='SYRIAC LETTER MIM'
let s:d[0x0722]='SYRIAC LETTER NUN'
let s:d[0x0723]='SYRIAC LETTER SEMKATH'
let s:d[0x0724]='SYRIAC LETTER FINAL SEMKATH'
let s:d[0x0725]='SYRIAC LETTER E'
let s:d[0x0726]='SYRIAC LETTER PE'
let s:d[0x0727]='SYRIAC LETTER REVERSED PE'
let s:d[0x0728]='SYRIAC LETTER SADHE'
let s:d[0x0729]='SYRIAC LETTER QAPH'
let s:d[0x072A]='SYRIAC LETTER RISH'
let s:d[0x072B]='SYRIAC LETTER SHIN'
let s:d[0x072C]='SYRIAC LETTER TAW'
let s:d[0x072D]='SYRIAC LETTER PERSIAN BHETH'
let s:d[0x072E]='SYRIAC LETTER PERSIAN GHAMAL'
let s:d[0x072F]='SYRIAC LETTER PERSIAN DHALATH'
let s:d[0x0730]='SYRIAC PTHAHA ABOVE'
let s:d[0x0731]='SYRIAC PTHAHA BELOW'
let s:d[0x0732]='SYRIAC PTHAHA DOTTED'
let s:d[0x0733]='SYRIAC ZQAPHA ABOVE'
let s:d[0x0734]='SYRIAC ZQAPHA BELOW'
let s:d[0x0735]='SYRIAC ZQAPHA DOTTED'
let s:d[0x0736]='SYRIAC RBASA ABOVE'
let s:d[0x0737]='SYRIAC RBASA BELOW'
let s:d[0x0738]='SYRIAC DOTTED ZLAMA HORIZONTAL'
let s:d[0x0739]='SYRIAC DOTTED ZLAMA ANGULAR'
let s:d[0x073A]='SYRIAC HBASA ABOVE'
let s:d[0x073B]='SYRIAC HBASA BELOW'
let s:d[0x073C]='SYRIAC HBASA-ESASA DOTTED'
let s:d[0x073D]='SYRIAC ESASA ABOVE'
let s:d[0x073E]='SYRIAC ESASA BELOW'
let s:d[0x073F]='SYRIAC RWAHA'
let s:d[0x0740]='SYRIAC FEMININE DOT'
let s:d[0x0741]='SYRIAC QUSHSHAYA'
let s:d[0x0742]='SYRIAC RUKKAKHA'
let s:d[0x0743]='SYRIAC TWO VERTICAL DOTS ABOVE'
let s:d[0x0744]='SYRIAC TWO VERTICAL DOTS BELOW'
let s:d[0x0745]='SYRIAC THREE DOTS ABOVE'
let s:d[0x0746]='SYRIAC THREE DOTS BELOW'
let s:d[0x0747]='SYRIAC OBLIQUE LINE ABOVE'
let s:d[0x0748]='SYRIAC OBLIQUE LINE BELOW'
let s:d[0x0749]='SYRIAC MUSIC'
let s:d[0x074A]='SYRIAC BARREKH'
let s:d[0x074D]='SYRIAC LETTER SOGDIAN ZHAIN'
let s:d[0x074E]='SYRIAC LETTER SOGDIAN KHAPH'
let s:d[0x074F]='SYRIAC LETTER SOGDIAN FE'
let s:d[0x0750]='ARABIC LETTER BEH WITH THREE DOTS HORIZONTALLY BELOW'
let s:d[0x0751]='ARABIC LETTER BEH WITH DOT BELOW AND THREE DOTS ABOVE'
let s:d[0x0752]='ARABIC LETTER BEH WITH THREE DOTS POINTING UPWARDS BELOW'
let s:d[0x0753]='ARABIC LETTER BEH WITH THREE DOTS POINTING UPWARDS BELOW AND TWO DOTS ABOVE'
let s:d[0x0754]='ARABIC LETTER BEH WITH TWO DOTS BELOW AND DOT ABOVE'
let s:d[0x0755]='ARABIC LETTER BEH WITH INVERTED SMALL V BELOW'
let s:d[0x0756]='ARABIC LETTER BEH WITH SMALL V'
let s:d[0x0757]='ARABIC LETTER HAH WITH TWO DOTS ABOVE'
let s:d[0x0758]='ARABIC LETTER HAH WITH THREE DOTS POINTING UPWARDS BELOW'
let s:d[0x0759]='ARABIC LETTER DAL WITH TWO DOTS VERTICALLY BELOW AND SMALL TAH'
let s:d[0x075A]='ARABIC LETTER DAL WITH INVERTED SMALL V BELOW'
let s:d[0x075B]='ARABIC LETTER REH WITH STROKE'
let s:d[0x075C]='ARABIC LETTER SEEN WITH FOUR DOTS ABOVE'
let s:d[0x075D]='ARABIC LETTER AIN WITH TWO DOTS ABOVE'
let s:d[0x075E]='ARABIC LETTER AIN WITH THREE DOTS POINTING DOWNWARDS ABOVE'
let s:d[0x075F]='ARABIC LETTER AIN WITH TWO DOTS VERTICALLY ABOVE'
let s:d[0x0760]='ARABIC LETTER FEH WITH TWO DOTS BELOW'
let s:d[0x0761]='ARABIC LETTER FEH WITH THREE DOTS POINTING UPWARDS BELOW'
let s:d[0x0762]='ARABIC LETTER KEHEH WITH DOT ABOVE'
let s:d[0x0763]='ARABIC LETTER KEHEH WITH THREE DOTS ABOVE'
let s:d[0x0764]='ARABIC LETTER KEHEH WITH THREE DOTS POINTING UPWARDS BELOW'
let s:d[0x0765]='ARABIC LETTER MEEM WITH DOT ABOVE'
let s:d[0x0766]='ARABIC LETTER MEEM WITH DOT BELOW'
let s:d[0x0767]='ARABIC LETTER NOON WITH TWO DOTS BELOW'
let s:d[0x0768]='ARABIC LETTER NOON WITH SMALL TAH'
let s:d[0x0769]='ARABIC LETTER NOON WITH SMALL V'
let s:d[0x076A]='ARABIC LETTER LAM WITH BAR'
let s:d[0x076B]='ARABIC LETTER REH WITH TWO DOTS VERTICALLY ABOVE'
let s:d[0x076C]='ARABIC LETTER REH WITH HAMZA ABOVE'
let s:d[0x076D]='ARABIC LETTER SEEN WITH TWO DOTS VERTICALLY ABOVE'
let s:d[0x076E]='ARABIC LETTER HAH WITH SMALL ARABIC LETTER TAH BELOW'
let s:d[0x076F]='ARABIC LETTER HAH WITH SMALL ARABIC LETTER TAH AND TWO DOTS'
let s:d[0x0770]='ARABIC LETTER SEEN WITH SMALL ARABIC LETTER TAH AND TWO DOTS'
let s:d[0x0771]='ARABIC LETTER REH WITH SMALL ARABIC LETTER TAH AND TWO DOTS'
let s:d[0x0772]='ARABIC LETTER HAH WITH SMALL ARABIC LETTER TAH ABOVE'
let s:d[0x0773]='ARABIC LETTER ALEF WITH EXTENDED ARABIC-INDIC DIGIT TWO ABOVE'
let s:d[0x0774]='ARABIC LETTER ALEF WITH EXTENDED ARABIC-INDIC DIGIT THREE ABOVE'
let s:d[0x0775]='ARABIC LETTER FARSI YEH WITH EXTENDED ARABIC-INDIC DIGIT TWO ABOVE'
let s:d[0x0776]='ARABIC LETTER FARSI YEH WITH EXTENDED ARABIC-INDIC DIGIT THREE ABOVE'
let s:d[0x0777]='ARABIC LETTER FARSI YEH WITH EXTENDED ARABIC-INDIC DIGIT FOUR BELOW'
let s:d[0x0778]='ARABIC LETTER WAW WITH EXTENDED ARABIC-INDIC DIGIT TWO ABOVE'
let s:d[0x0779]='ARABIC LETTER WAW WITH EXTENDED ARABIC-INDIC DIGIT THREE ABOVE'
let s:d[0x077A]='ARABIC LETTER YEH BARREE WITH EXTENDED ARABIC-INDIC DIGIT TWO ABOVE'
let s:d[0x077B]='ARABIC LETTER YEH BARREE WITH EXTENDED ARABIC-INDIC DIGIT THREE ABOVE'
let s:d[0x077C]='ARABIC LETTER HAH WITH EXTENDED ARABIC-INDIC DIGIT FOUR BELOW'
let s:d[0x077D]='ARABIC LETTER SEEN WITH EXTENDED ARABIC-INDIC DIGIT FOUR ABOVE'
let s:d[0x077E]='ARABIC LETTER SEEN WITH INVERTED V'
let s:d[0x077F]='ARABIC LETTER KAF WITH TWO DOTS ABOVE'
let s:d[0x0780]='THAANA LETTER HAA'
let s:d[0x0781]='THAANA LETTER SHAVIYANI'
let s:d[0x0782]='THAANA LETTER NOONU'
let s:d[0x0783]='THAANA LETTER RAA'
let s:d[0x0784]='THAANA LETTER BAA'
let s:d[0x0785]='THAANA LETTER LHAVIYANI'
let s:d[0x0786]='THAANA LETTER KAAFU'
let s:d[0x0787]='THAANA LETTER ALIFU'
let s:d[0x0788]='THAANA LETTER VAAVU'
let s:d[0x0789]='THAANA LETTER MEEMU'
let s:d[0x078A]='THAANA LETTER FAAFU'
let s:d[0x078B]='THAANA LETTER DHAALU'
let s:d[0x078C]='THAANA LETTER THAA'
let s:d[0x078D]='THAANA LETTER LAAMU'
let s:d[0x078E]='THAANA LETTER GAAFU'
let s:d[0x078F]='THAANA LETTER GNAVIYANI'
let s:d[0x0790]='THAANA LETTER SEENU'
let s:d[0x0791]='THAANA LETTER DAVIYANI'
let s:d[0x0792]='THAANA LETTER ZAVIYANI'
let s:d[0x0793]='THAANA LETTER TAVIYANI'
let s:d[0x0794]='THAANA LETTER YAA'
let s:d[0x0795]='THAANA LETTER PAVIYANI'
let s:d[0x0796]='THAANA LETTER JAVIYANI'
let s:d[0x0797]='THAANA LETTER CHAVIYANI'
let s:d[0x0798]='THAANA LETTER TTAA'
let s:d[0x0799]='THAANA LETTER HHAA'
let s:d[0x079A]='THAANA LETTER KHAA'
let s:d[0x079B]='THAANA LETTER THAALU'
let s:d[0x079C]='THAANA LETTER ZAA'
let s:d[0x079D]='THAANA LETTER SHEENU'
let s:d[0x079E]='THAANA LETTER SAADHU'
let s:d[0x079F]='THAANA LETTER DAADHU'
let s:d[0x07A0]='THAANA LETTER TO'
let s:d[0x07A1]='THAANA LETTER ZO'
let s:d[0x07A2]='THAANA LETTER AINU'
let s:d[0x07A3]='THAANA LETTER GHAINU'
let s:d[0x07A4]='THAANA LETTER QAAFU'
let s:d[0x07A5]='THAANA LETTER WAAVU'
let s:d[0x07A6]='THAANA ABAFILI'
let s:d[0x07A7]='THAANA AABAAFILI'
let s:d[0x07A8]='THAANA IBIFILI'
let s:d[0x07A9]='THAANA EEBEEFILI'
let s:d[0x07AA]='THAANA UBUFILI'
let s:d[0x07AB]='THAANA OOBOOFILI'
let s:d[0x07AC]='THAANA EBEFILI'
let s:d[0x07AD]='THAANA EYBEYFILI'
let s:d[0x07AE]='THAANA OBOFILI'
let s:d[0x07AF]='THAANA OABOAFILI'
let s:d[0x07B0]='THAANA SUKUN'
let s:d[0x07B1]='THAANA LETTER NAA'
let s:d[0x07C0]='NKO DIGIT ZERO'
let s:d[0x07C1]='NKO DIGIT ONE'
let s:d[0x07C2]='NKO DIGIT TWO'
let s:d[0x07C3]='NKO DIGIT THREE'
let s:d[0x07C4]='NKO DIGIT FOUR'
let s:d[0x07C5]='NKO DIGIT FIVE'
let s:d[0x07C6]='NKO DIGIT SIX'
let s:d[0x07C7]='NKO DIGIT SEVEN'
let s:d[0x07C8]='NKO DIGIT EIGHT'
let s:d[0x07C9]='NKO DIGIT NINE'
let s:d[0x07CA]='NKO LETTER A'
let s:d[0x07CB]='NKO LETTER EE'
let s:d[0x07CC]='NKO LETTER I'
let s:d[0x07CD]='NKO LETTER E'
let s:d[0x07CE]='NKO LETTER U'
let s:d[0x07CF]='NKO LETTER OO'
let s:d[0x07D0]='NKO LETTER O'
let s:d[0x07D1]='NKO LETTER DAGBASINNA'
let s:d[0x07D2]='NKO LETTER N'
let s:d[0x07D3]='NKO LETTER BA'
let s:d[0x07D4]='NKO LETTER PA'
let s:d[0x07D5]='NKO LETTER TA'
let s:d[0x07D6]='NKO LETTER JA'
let s:d[0x07D7]='NKO LETTER CHA'
let s:d[0x07D8]='NKO LETTER DA'
let s:d[0x07D9]='NKO LETTER RA'
let s:d[0x07DA]='NKO LETTER RRA'
let s:d[0x07DB]='NKO LETTER SA'
let s:d[0x07DC]='NKO LETTER GBA'
let s:d[0x07DD]='NKO LETTER FA'
let s:d[0x07DE]='NKO LETTER KA'
let s:d[0x07DF]='NKO LETTER LA'
let s:d[0x07E0]='NKO LETTER NA WOLOSO'
let s:d[0x07E1]='NKO LETTER MA'
let s:d[0x07E2]='NKO LETTER NYA'
let s:d[0x07E3]='NKO LETTER NA'
let s:d[0x07E4]='NKO LETTER HA'
let s:d[0x07E5]='NKO LETTER WA'
let s:d[0x07E6]='NKO LETTER YA'
let s:d[0x07E7]='NKO LETTER NYA WOLOSO'
let s:d[0x07E8]='NKO LETTER JONA JA'
let s:d[0x07E9]='NKO LETTER JONA CHA'
let s:d[0x07EA]='NKO LETTER JONA RA'
let s:d[0x07EB]='NKO COMBINING SHORT HIGH TONE'
let s:d[0x07EC]='NKO COMBINING SHORT LOW TONE'
let s:d[0x07ED]='NKO COMBINING SHORT RISING TONE'
let s:d[0x07EE]='NKO COMBINING LONG DESCENDING TONE'
let s:d[0x07EF]='NKO COMBINING LONG HIGH TONE'
let s:d[0x07F0]='NKO COMBINING LONG LOW TONE'
let s:d[0x07F1]='NKO COMBINING LONG RISING TONE'
let s:d[0x07F2]='NKO COMBINING NASALIZATION MARK'
let s:d[0x07F3]='NKO COMBINING DOUBLE DOT ABOVE'
let s:d[0x07F4]='NKO HIGH TONE APOSTROPHE'
let s:d[0x07F5]='NKO LOW TONE APOSTROPHE'
let s:d[0x07F6]='NKO SYMBOL OO DENNEN'
let s:d[0x07F7]='NKO SYMBOL GBAKURUNEN'
let s:d[0x07F8]='NKO COMMA'
let s:d[0x07F9]='NKO EXCLAMATION MARK'
let s:d[0x07FA]='NKO LAJANYALAN'
let s:d[0x0800]='SAMARITAN LETTER ALAF'
let s:d[0x0801]='SAMARITAN LETTER BIT'
let s:d[0x0802]='SAMARITAN LETTER GAMAN'
let s:d[0x0803]='SAMARITAN LETTER DALAT'
let s:d[0x0804]='SAMARITAN LETTER IY'
let s:d[0x0805]='SAMARITAN LETTER BAA'
let s:d[0x0806]='SAMARITAN LETTER ZEN'
let s:d[0x0807]='SAMARITAN LETTER IT'
let s:d[0x0808]='SAMARITAN LETTER TIT'
let s:d[0x0809]='SAMARITAN LETTER YUT'
let s:d[0x080A]='SAMARITAN LETTER KAAF'
let s:d[0x080B]='SAMARITAN LETTER LABAT'
let s:d[0x080C]='SAMARITAN LETTER MIM'
let s:d[0x080D]='SAMARITAN LETTER NUN'
let s:d[0x080E]='SAMARITAN LETTER SINGAAT'
let s:d[0x080F]='SAMARITAN LETTER IN'
let s:d[0x0810]='SAMARITAN LETTER FI'
let s:d[0x0811]='SAMARITAN LETTER TSAADIY'
let s:d[0x0812]='SAMARITAN LETTER QUF'
let s:d[0x0813]='SAMARITAN LETTER RISH'
let s:d[0x0814]='SAMARITAN LETTER SHAN'
let s:d[0x0815]='SAMARITAN LETTER TAAF'
let s:d[0x0816]='SAMARITAN MARK IN'
let s:d[0x0817]='SAMARITAN MARK IN-ALAF'
let s:d[0x0818]='SAMARITAN MARK OCCLUSION'
let s:d[0x0819]='SAMARITAN MARK DAGESH'
let s:d[0x081A]='SAMARITAN MODIFIER LETTER EPENTHETIC YUT'
let s:d[0x081B]='SAMARITAN MARK EPENTHETIC YUT'
let s:d[0x081C]='SAMARITAN VOWEL SIGN LONG E'
let s:d[0x081D]='SAMARITAN VOWEL SIGN E'
let s:d[0x081E]='SAMARITAN VOWEL SIGN OVERLONG AA'
let s:d[0x081F]='SAMARITAN VOWEL SIGN LONG AA'
let s:d[0x0820]='SAMARITAN VOWEL SIGN AA'
let s:d[0x0821]='SAMARITAN VOWEL SIGN OVERLONG A'
let s:d[0x0822]='SAMARITAN VOWEL SIGN LONG A'
let s:d[0x0823]='SAMARITAN VOWEL SIGN A'
let s:d[0x0824]='SAMARITAN MODIFIER LETTER SHORT A'
let s:d[0x0825]='SAMARITAN VOWEL SIGN SHORT A'
let s:d[0x0826]='SAMARITAN VOWEL SIGN LONG U'
let s:d[0x0827]='SAMARITAN VOWEL SIGN U'
let s:d[0x0828]='SAMARITAN MODIFIER LETTER I'
let s:d[0x0829]='SAMARITAN VOWEL SIGN LONG I'
let s:d[0x082A]='SAMARITAN VOWEL SIGN I'
let s:d[0x082B]='SAMARITAN VOWEL SIGN O'
let s:d[0x082C]='SAMARITAN VOWEL SIGN SUKUN'
let s:d[0x082D]='SAMARITAN MARK NEQUDAA'
let s:d[0x0830]='SAMARITAN PUNCTUATION NEQUDAA'
let s:d[0x0831]='SAMARITAN PUNCTUATION AFSAAQ'
let s:d[0x0832]='SAMARITAN PUNCTUATION ANGED'
let s:d[0x0833]='SAMARITAN PUNCTUATION BAU'
let s:d[0x0834]='SAMARITAN PUNCTUATION ATMAAU'
let s:d[0x0835]='SAMARITAN PUNCTUATION SHIYYAALAA'
let s:d[0x0836]='SAMARITAN ABBREVIATION MARK'
let s:d[0x0837]='SAMARITAN PUNCTUATION MELODIC QITSA'
let s:d[0x0838]='SAMARITAN PUNCTUATION ZIQAA'
let s:d[0x0839]='SAMARITAN PUNCTUATION QITSA'
let s:d[0x083A]='SAMARITAN PUNCTUATION ZAEF'
let s:d[0x083B]='SAMARITAN PUNCTUATION TURU'
let s:d[0x083C]='SAMARITAN PUNCTUATION ARKAANU'
let s:d[0x083D]='SAMARITAN PUNCTUATION SOF MASHFAAT'
let s:d[0x083E]='SAMARITAN PUNCTUATION ANNAAU'
let s:d[0x0840]='MANDAIC LETTER HALQA'
let s:d[0x0841]='MANDAIC LETTER AB'
let s:d[0x0842]='MANDAIC LETTER AG'
let s:d[0x0843]='MANDAIC LETTER AD'
let s:d[0x0844]='MANDAIC LETTER AH'
let s:d[0x0845]='MANDAIC LETTER USHENNA'
let s:d[0x0846]='MANDAIC LETTER AZ'
let s:d[0x0847]='MANDAIC LETTER IT'
let s:d[0x0848]='MANDAIC LETTER ATT'
let s:d[0x0849]='MANDAIC LETTER AKSA'
let s:d[0x084A]='MANDAIC LETTER AK'
let s:d[0x084B]='MANDAIC LETTER AL'
let s:d[0x084C]='MANDAIC LETTER AM'
let s:d[0x084D]='MANDAIC LETTER AN'
let s:d[0x084E]='MANDAIC LETTER AS'
let s:d[0x084F]='MANDAIC LETTER IN'
let s:d[0x0850]='MANDAIC LETTER AP'
let s:d[0x0851]='MANDAIC LETTER ASZ'
let s:d[0x0852]='MANDAIC LETTER AQ'
let s:d[0x0853]='MANDAIC LETTER AR'
let s:d[0x0854]='MANDAIC LETTER ASH'
let s:d[0x0855]='MANDAIC LETTER AT'
let s:d[0x0856]='MANDAIC LETTER DUSHENNA'
let s:d[0x0857]='MANDAIC LETTER KAD'
let s:d[0x0858]='MANDAIC LETTER AIN'
let s:d[0x0859]='MANDAIC AFFRICATION MARK'
let s:d[0x085A]='MANDAIC VOCALIZATION MARK'
let s:d[0x085B]='MANDAIC GEMINATION MARK'
let s:d[0x085E]='MANDAIC PUNCTUATION'
let s:d[0x08A0]='ARABIC LETTER BEH WITH SMALL V BELOW'
let s:d[0x08A2]='ARABIC LETTER JEEM WITH TWO DOTS ABOVE'
let s:d[0x08A3]='ARABIC LETTER TAH WITH TWO DOTS ABOVE'
let s:d[0x08A4]='ARABIC LETTER FEH WITH DOT BELOW AND THREE DOTS ABOVE'
let s:d[0x08A5]='ARABIC LETTER QAF WITH DOT BELOW'
let s:d[0x08A6]='ARABIC LETTER LAM WITH DOUBLE BAR'
let s:d[0x08A7]='ARABIC LETTER MEEM WITH THREE DOTS ABOVE'
let s:d[0x08A8]='ARABIC LETTER YEH WITH TWO DOTS BELOW AND HAMZA ABOVE'
let s:d[0x08A9]='ARABIC LETTER YEH WITH TWO DOTS BELOW AND DOT ABOVE'
let s:d[0x08AA]='ARABIC LETTER REH WITH LOOP'
let s:d[0x08AB]='ARABIC LETTER WAW WITH DOT WITHIN'
let s:d[0x08AC]='ARABIC LETTER ROHINGYA YEH'
let s:d[0x08E4]='ARABIC CURLY FATHA'
let s:d[0x08E5]='ARABIC CURLY DAMMA'
let s:d[0x08E6]='ARABIC CURLY KASRA'
let s:d[0x08E7]='ARABIC CURLY FATHATAN'
let s:d[0x08E8]='ARABIC CURLY DAMMATAN'
let s:d[0x08E9]='ARABIC CURLY KASRATAN'
let s:d[0x08EA]='ARABIC TONE ONE DOT ABOVE'
let s:d[0x08EB]='ARABIC TONE TWO DOTS ABOVE'
let s:d[0x08EC]='ARABIC TONE LOOP ABOVE'
let s:d[0x08ED]='ARABIC TONE ONE DOT BELOW'
let s:d[0x08EE]='ARABIC TONE TWO DOTS BELOW'
let s:d[0x08EF]='ARABIC TONE LOOP BELOW'
let s:d[0x08F0]='ARABIC OPEN FATHATAN'
let s:d[0x08F1]='ARABIC OPEN DAMMATAN'
let s:d[0x08F2]='ARABIC OPEN KASRATAN'
let s:d[0x08F3]='ARABIC SMALL HIGH WAW'
let s:d[0x08F4]='ARABIC FATHA WITH RING'
let s:d[0x08F5]='ARABIC FATHA WITH DOT ABOVE'
let s:d[0x08F6]='ARABIC KASRA WITH DOT BELOW'
let s:d[0x08F7]='ARABIC LEFT ARROWHEAD ABOVE'
let s:d[0x08F8]='ARABIC RIGHT ARROWHEAD ABOVE'
let s:d[0x08F9]='ARABIC LEFT ARROWHEAD BELOW'
let s:d[0x08FA]='ARABIC RIGHT ARROWHEAD BELOW'
let s:d[0x08FB]='ARABIC DOUBLE RIGHT ARROWHEAD ABOVE'
let s:d[0x08FC]='ARABIC DOUBLE RIGHT ARROWHEAD ABOVE WITH DOT'
let s:d[0x08FD]='ARABIC RIGHT ARROWHEAD ABOVE WITH DOT'
let s:d[0x08FE]='ARABIC DAMMA WITH DOT'
let s:d[0x0900]='DEVANAGARI SIGN INVERTED CANDRABINDU'
let s:d[0x0901]='DEVANAGARI SIGN CANDRABINDU'
let s:d[0x0902]='DEVANAGARI SIGN ANUSVARA'
let s:d[0x0903]='DEVANAGARI SIGN VISARGA'
let s:d[0x0904]='DEVANAGARI LETTER SHORT A'
let s:d[0x0905]='DEVANAGARI LETTER A'
let s:d[0x0906]='DEVANAGARI LETTER AA'
let s:d[0x0907]='DEVANAGARI LETTER I'
let s:d[0x0908]='DEVANAGARI LETTER II'
let s:d[0x0909]='DEVANAGARI LETTER U'
let s:d[0x090A]='DEVANAGARI LETTER UU'
let s:d[0x090B]='DEVANAGARI LETTER VOCALIC R'
let s:d[0x090C]='DEVANAGARI LETTER VOCALIC L'
let s:d[0x090D]='DEVANAGARI LETTER CANDRA E'
let s:d[0x090E]='DEVANAGARI LETTER SHORT E'
let s:d[0x090F]='DEVANAGARI LETTER E'
let s:d[0x0910]='DEVANAGARI LETTER AI'
let s:d[0x0911]='DEVANAGARI LETTER CANDRA O'
let s:d[0x0912]='DEVANAGARI LETTER SHORT O'
let s:d[0x0913]='DEVANAGARI LETTER O'
let s:d[0x0914]='DEVANAGARI LETTER AU'
let s:d[0x0915]='DEVANAGARI LETTER KA'
let s:d[0x0916]='DEVANAGARI LETTER KHA'
let s:d[0x0917]='DEVANAGARI LETTER GA'
let s:d[0x0918]='DEVANAGARI LETTER GHA'
let s:d[0x0919]='DEVANAGARI LETTER NGA'
let s:d[0x091A]='DEVANAGARI LETTER CA'
let s:d[0x091B]='DEVANAGARI LETTER CHA'
let s:d[0x091C]='DEVANAGARI LETTER JA'
let s:d[0x091D]='DEVANAGARI LETTER JHA'
let s:d[0x091E]='DEVANAGARI LETTER NYA'
let s:d[0x091F]='DEVANAGARI LETTER TTA'
let s:d[0x0920]='DEVANAGARI LETTER TTHA'
let s:d[0x0921]='DEVANAGARI LETTER DDA'
let s:d[0x0922]='DEVANAGARI LETTER DDHA'
let s:d[0x0923]='DEVANAGARI LETTER NNA'
let s:d[0x0924]='DEVANAGARI LETTER TA'
let s:d[0x0925]='DEVANAGARI LETTER THA'
let s:d[0x0926]='DEVANAGARI LETTER DA'
let s:d[0x0927]='DEVANAGARI LETTER DHA'
let s:d[0x0928]='DEVANAGARI LETTER NA'
let s:d[0x0929]='DEVANAGARI LETTER NNNA'
let s:d[0x092A]='DEVANAGARI LETTER PA'
let s:d[0x092B]='DEVANAGARI LETTER PHA'
let s:d[0x092C]='DEVANAGARI LETTER BA'
let s:d[0x092D]='DEVANAGARI LETTER BHA'
let s:d[0x092E]='DEVANAGARI LETTER MA'
let s:d[0x092F]='DEVANAGARI LETTER YA'
let s:d[0x0930]='DEVANAGARI LETTER RA'
let s:d[0x0931]='DEVANAGARI LETTER RRA'
let s:d[0x0932]='DEVANAGARI LETTER LA'
let s:d[0x0933]='DEVANAGARI LETTER LLA'
let s:d[0x0934]='DEVANAGARI LETTER LLLA'
let s:d[0x0935]='DEVANAGARI LETTER VA'
let s:d[0x0936]='DEVANAGARI LETTER SHA'
let s:d[0x0937]='DEVANAGARI LETTER SSA'
let s:d[0x0938]='DEVANAGARI LETTER SA'
let s:d[0x0939]='DEVANAGARI LETTER HA'
let s:d[0x093A]='DEVANAGARI VOWEL SIGN OE'
let s:d[0x093B]='DEVANAGARI VOWEL SIGN OOE'
let s:d[0x093C]='DEVANAGARI SIGN NUKTA'
let s:d[0x093D]='DEVANAGARI SIGN AVAGRAHA'
let s:d[0x093E]='DEVANAGARI VOWEL SIGN AA'
let s:d[0x093F]='DEVANAGARI VOWEL SIGN I'
let s:d[0x0940]='DEVANAGARI VOWEL SIGN II'
let s:d[0x0941]='DEVANAGARI VOWEL SIGN U'
let s:d[0x0942]='DEVANAGARI VOWEL SIGN UU'
let s:d[0x0943]='DEVANAGARI VOWEL SIGN VOCALIC R'
let s:d[0x0944]='DEVANAGARI VOWEL SIGN VOCALIC RR'
let s:d[0x0945]='DEVANAGARI VOWEL SIGN CANDRA E'
let s:d[0x0946]='DEVANAGARI VOWEL SIGN SHORT E'
let s:d[0x0947]='DEVANAGARI VOWEL SIGN E'
let s:d[0x0948]='DEVANAGARI VOWEL SIGN AI'
let s:d[0x0949]='DEVANAGARI VOWEL SIGN CANDRA O'
let s:d[0x094A]='DEVANAGARI VOWEL SIGN SHORT O'
let s:d[0x094B]='DEVANAGARI VOWEL SIGN O'
let s:d[0x094C]='DEVANAGARI VOWEL SIGN AU'
let s:d[0x094D]='DEVANAGARI SIGN VIRAMA'
let s:d[0x094E]='DEVANAGARI VOWEL SIGN PRISHTHAMATRA E'
let s:d[0x094F]='DEVANAGARI VOWEL SIGN AW'
let s:d[0x0950]='DEVANAGARI OM'
let s:d[0x0951]='DEVANAGARI STRESS SIGN UDATTA'
let s:d[0x0952]='DEVANAGARI STRESS SIGN ANUDATTA'
let s:d[0x0953]='DEVANAGARI GRAVE ACCENT'
let s:d[0x0954]='DEVANAGARI ACUTE ACCENT'
let s:d[0x0955]='DEVANAGARI VOWEL SIGN CANDRA LONG E'
let s:d[0x0956]='DEVANAGARI VOWEL SIGN UE'
let s:d[0x0957]='DEVANAGARI VOWEL SIGN UUE'
let s:d[0x0958]='DEVANAGARI LETTER QA'
let s:d[0x0959]='DEVANAGARI LETTER KHHA'
let s:d[0x095A]='DEVANAGARI LETTER GHHA'
let s:d[0x095B]='DEVANAGARI LETTER ZA'
let s:d[0x095C]='DEVANAGARI LETTER DDDHA'
let s:d[0x095D]='DEVANAGARI LETTER RHA'
let s:d[0x095E]='DEVANAGARI LETTER FA'
let s:d[0x095F]='DEVANAGARI LETTER YYA'
let s:d[0x0960]='DEVANAGARI LETTER VOCALIC RR'
let s:d[0x0961]='DEVANAGARI LETTER VOCALIC LL'
let s:d[0x0962]='DEVANAGARI VOWEL SIGN VOCALIC L'
let s:d[0x0963]='DEVANAGARI VOWEL SIGN VOCALIC LL'
let s:d[0x0964]='DEVANAGARI DANDA'
let s:d[0x0965]='DEVANAGARI DOUBLE DANDA'
let s:d[0x0966]='DEVANAGARI DIGIT ZERO'
let s:d[0x0967]='DEVANAGARI DIGIT ONE'
let s:d[0x0968]='DEVANAGARI DIGIT TWO'
let s:d[0x0969]='DEVANAGARI DIGIT THREE'
let s:d[0x096A]='DEVANAGARI DIGIT FOUR'
let s:d[0x096B]='DEVANAGARI DIGIT FIVE'
let s:d[0x096C]='DEVANAGARI DIGIT SIX'
let s:d[0x096D]='DEVANAGARI DIGIT SEVEN'
let s:d[0x096E]='DEVANAGARI DIGIT EIGHT'
let s:d[0x096F]='DEVANAGARI DIGIT NINE'
let s:d[0x0970]='DEVANAGARI ABBREVIATION SIGN'
let s:d[0x0971]='DEVANAGARI SIGN HIGH SPACING DOT'
let s:d[0x0972]='DEVANAGARI LETTER CANDRA A'
let s:d[0x0973]='DEVANAGARI LETTER OE'
let s:d[0x0974]='DEVANAGARI LETTER OOE'
let s:d[0x0975]='DEVANAGARI LETTER AW'
let s:d[0x0976]='DEVANAGARI LETTER UE'
let s:d[0x0977]='DEVANAGARI LETTER UUE'
let s:d[0x0979]='DEVANAGARI LETTER ZHA'
let s:d[0x097A]='DEVANAGARI LETTER HEAVY YA'
let s:d[0x097B]='DEVANAGARI LETTER GGA'
let s:d[0x097C]='DEVANAGARI LETTER JJA'
let s:d[0x097D]='DEVANAGARI LETTER GLOTTAL STOP'
let s:d[0x097E]='DEVANAGARI LETTER DDDA'
let s:d[0x097F]='DEVANAGARI LETTER BBA'
let s:d[0x0981]='BENGALI SIGN CANDRABINDU'
let s:d[0x0982]='BENGALI SIGN ANUSVARA'
let s:d[0x0983]='BENGALI SIGN VISARGA'
let s:d[0x0985]='BENGALI LETTER A'
let s:d[0x0986]='BENGALI LETTER AA'
let s:d[0x0987]='BENGALI LETTER I'
let s:d[0x0988]='BENGALI LETTER II'
let s:d[0x0989]='BENGALI LETTER U'
let s:d[0x098A]='BENGALI LETTER UU'
let s:d[0x098B]='BENGALI LETTER VOCALIC R'
let s:d[0x098C]='BENGALI LETTER VOCALIC L'
let s:d[0x098F]='BENGALI LETTER E'
let s:d[0x0990]='BENGALI LETTER AI'
let s:d[0x0993]='BENGALI LETTER O'
let s:d[0x0994]='BENGALI LETTER AU'
let s:d[0x0995]='BENGALI LETTER KA'
let s:d[0x0996]='BENGALI LETTER KHA'
let s:d[0x0997]='BENGALI LETTER GA'
let s:d[0x0998]='BENGALI LETTER GHA'
let s:d[0x0999]='BENGALI LETTER NGA'
let s:d[0x099A]='BENGALI LETTER CA'
let s:d[0x099B]='BENGALI LETTER CHA'
let s:d[0x099C]='BENGALI LETTER JA'
let s:d[0x099D]='BENGALI LETTER JHA'
let s:d[0x099E]='BENGALI LETTER NYA'
let s:d[0x099F]='BENGALI LETTER TTA'
let s:d[0x09A0]='BENGALI LETTER TTHA'
let s:d[0x09A1]='BENGALI LETTER DDA'
let s:d[0x09A2]='BENGALI LETTER DDHA'
let s:d[0x09A3]='BENGALI LETTER NNA'
let s:d[0x09A4]='BENGALI LETTER TA'
let s:d[0x09A5]='BENGALI LETTER THA'
let s:d[0x09A6]='BENGALI LETTER DA'
let s:d[0x09A7]='BENGALI LETTER DHA'
let s:d[0x09A8]='BENGALI LETTER NA'
let s:d[0x09AA]='BENGALI LETTER PA'
let s:d[0x09AB]='BENGALI LETTER PHA'
let s:d[0x09AC]='BENGALI LETTER BA'
let s:d[0x09AD]='BENGALI LETTER BHA'
let s:d[0x09AE]='BENGALI LETTER MA'
let s:d[0x09AF]='BENGALI LETTER YA'
let s:d[0x09B0]='BENGALI LETTER RA'
let s:d[0x09B2]='BENGALI LETTER LA'
let s:d[0x09B6]='BENGALI LETTER SHA'
let s:d[0x09B7]='BENGALI LETTER SSA'
let s:d[0x09B8]='BENGALI LETTER SA'
let s:d[0x09B9]='BENGALI LETTER HA'
let s:d[0x09BC]='BENGALI SIGN NUKTA'
let s:d[0x09BD]='BENGALI SIGN AVAGRAHA'
let s:d[0x09BE]='BENGALI VOWEL SIGN AA'
let s:d[0x09BF]='BENGALI VOWEL SIGN I'
let s:d[0x09C0]='BENGALI VOWEL SIGN II'
let s:d[0x09C1]='BENGALI VOWEL SIGN U'
let s:d[0x09C2]='BENGALI VOWEL SIGN UU'
let s:d[0x09C3]='BENGALI VOWEL SIGN VOCALIC R'
let s:d[0x09C4]='BENGALI VOWEL SIGN VOCALIC RR'
let s:d[0x09C7]='BENGALI VOWEL SIGN E'
let s:d[0x09C8]='BENGALI VOWEL SIGN AI'
let s:d[0x09CB]='BENGALI VOWEL SIGN O'
let s:d[0x09CC]='BENGALI VOWEL SIGN AU'
let s:d[0x09CD]='BENGALI SIGN VIRAMA'
let s:d[0x09CE]='BENGALI LETTER KHANDA TA'
let s:d[0x09D7]='BENGALI AU LENGTH MARK'
let s:d[0x09DC]='BENGALI LETTER RRA'
let s:d[0x09DD]='BENGALI LETTER RHA'
let s:d[0x09DF]='BENGALI LETTER YYA'
let s:d[0x09E0]='BENGALI LETTER VOCALIC RR'
let s:d[0x09E1]='BENGALI LETTER VOCALIC LL'
let s:d[0x09E2]='BENGALI VOWEL SIGN VOCALIC L'
let s:d[0x09E3]='BENGALI VOWEL SIGN VOCALIC LL'
let s:d[0x09E4]='<reserved>'
let s:d[0x09E5]='<reserved>'
let s:d[0x09E6]='BENGALI DIGIT ZERO'
let s:d[0x09E7]='BENGALI DIGIT ONE'
let s:d[0x09E8]='BENGALI DIGIT TWO'
let s:d[0x09E9]='BENGALI DIGIT THREE'
let s:d[0x09EA]='BENGALI DIGIT FOUR'
let s:d[0x09EB]='BENGALI DIGIT FIVE'
let s:d[0x09EC]='BENGALI DIGIT SIX'
let s:d[0x09ED]='BENGALI DIGIT SEVEN'
let s:d[0x09EE]='BENGALI DIGIT EIGHT'
let s:d[0x09EF]='BENGALI DIGIT NINE'
let s:d[0x09F0]='BENGALI LETTER RA WITH MIDDLE DIAGONAL'
let s:d[0x09F1]='BENGALI LETTER RA WITH LOWER DIAGONAL'
let s:d[0x09F2]='BENGALI RUPEE MARK'
let s:d[0x09F3]='BENGALI RUPEE SIGN'
let s:d[0x09F4]='BENGALI CURRENCY NUMERATOR ONE'
let s:d[0x09F5]='BENGALI CURRENCY NUMERATOR TWO'
let s:d[0x09F6]='BENGALI CURRENCY NUMERATOR THREE'
let s:d[0x09F7]='BENGALI CURRENCY NUMERATOR FOUR'
let s:d[0x09F8]='BENGALI CURRENCY NUMERATOR ONE LESS THAN THE DENOMINATOR'
let s:d[0x09F9]='BENGALI CURRENCY DENOMINATOR SIXTEEN'
let s:d[0x09FA]='BENGALI ISSHAR'
let s:d[0x09FB]='BENGALI GANDA MARK'
let s:d[0x0A01]='GURMUKHI SIGN ADAK BINDI'
let s:d[0x0A02]='GURMUKHI SIGN BINDI'
let s:d[0x0A03]='GURMUKHI SIGN VISARGA'
let s:d[0x0A05]='GURMUKHI LETTER A'
let s:d[0x0A06]='GURMUKHI LETTER AA'
let s:d[0x0A07]='GURMUKHI LETTER I'
let s:d[0x0A08]='GURMUKHI LETTER II'
let s:d[0x0A09]='GURMUKHI LETTER U'
let s:d[0x0A0A]='GURMUKHI LETTER UU'
let s:d[0x0A0F]='GURMUKHI LETTER EE'
let s:d[0x0A10]='GURMUKHI LETTER AI'
let s:d[0x0A13]='GURMUKHI LETTER OO'
let s:d[0x0A14]='GURMUKHI LETTER AU'
let s:d[0x0A15]='GURMUKHI LETTER KA'
let s:d[0x0A16]='GURMUKHI LETTER KHA'
let s:d[0x0A17]='GURMUKHI LETTER GA'
let s:d[0x0A18]='GURMUKHI LETTER GHA'
let s:d[0x0A19]='GURMUKHI LETTER NGA'
let s:d[0x0A1A]='GURMUKHI LETTER CA'
let s:d[0x0A1B]='GURMUKHI LETTER CHA'
let s:d[0x0A1C]='GURMUKHI LETTER JA'
let s:d[0x0A1D]='GURMUKHI LETTER JHA'
let s:d[0x0A1E]='GURMUKHI LETTER NYA'
let s:d[0x0A1F]='GURMUKHI LETTER TTA'
let s:d[0x0A20]='GURMUKHI LETTER TTHA'
let s:d[0x0A21]='GURMUKHI LETTER DDA'
let s:d[0x0A22]='GURMUKHI LETTER DDHA'
let s:d[0x0A23]='GURMUKHI LETTER NNA'
let s:d[0x0A24]='GURMUKHI LETTER TA'
let s:d[0x0A25]='GURMUKHI LETTER THA'
let s:d[0x0A26]='GURMUKHI LETTER DA'
let s:d[0x0A27]='GURMUKHI LETTER DHA'
let s:d[0x0A28]='GURMUKHI LETTER NA'
let s:d[0x0A2A]='GURMUKHI LETTER PA'
let s:d[0x0A2B]='GURMUKHI LETTER PHA'
let s:d[0x0A2C]='GURMUKHI LETTER BA'
let s:d[0x0A2D]='GURMUKHI LETTER BHA'
let s:d[0x0A2E]='GURMUKHI LETTER MA'
let s:d[0x0A2F]='GURMUKHI LETTER YA'
let s:d[0x0A30]='GURMUKHI LETTER RA'
let s:d[0x0A32]='GURMUKHI LETTER LA'
let s:d[0x0A33]='GURMUKHI LETTER LLA'
let s:d[0x0A35]='GURMUKHI LETTER VA'
let s:d[0x0A36]='GURMUKHI LETTER SHA'
let s:d[0x0A38]='GURMUKHI LETTER SA'
let s:d[0x0A39]='GURMUKHI LETTER HA'
let s:d[0x0A3C]='GURMUKHI SIGN NUKTA'
let s:d[0x0A3E]='GURMUKHI VOWEL SIGN AA'
let s:d[0x0A3F]='GURMUKHI VOWEL SIGN I'
let s:d[0x0A40]='GURMUKHI VOWEL SIGN II'
let s:d[0x0A41]='GURMUKHI VOWEL SIGN U'
let s:d[0x0A42]='GURMUKHI VOWEL SIGN UU'
let s:d[0x0A47]='GURMUKHI VOWEL SIGN EE'
let s:d[0x0A48]='GURMUKHI VOWEL SIGN AI'
let s:d[0x0A4B]='GURMUKHI VOWEL SIGN OO'
let s:d[0x0A4C]='GURMUKHI VOWEL SIGN AU'
let s:d[0x0A4D]='GURMUKHI SIGN VIRAMA'
let s:d[0x0A51]='GURMUKHI SIGN UDAAT'
let s:d[0x0A59]='GURMUKHI LETTER KHHA'
let s:d[0x0A5A]='GURMUKHI LETTER GHHA'
let s:d[0x0A5B]='GURMUKHI LETTER ZA'
let s:d[0x0A5C]='GURMUKHI LETTER RRA'
let s:d[0x0A5E]='GURMUKHI LETTER FA'
let s:d[0x0A64]='<reserved>'
let s:d[0x0A65]='<reserved>'
let s:d[0x0A66]='GURMUKHI DIGIT ZERO'
let s:d[0x0A67]='GURMUKHI DIGIT ONE'
let s:d[0x0A68]='GURMUKHI DIGIT TWO'
let s:d[0x0A69]='GURMUKHI DIGIT THREE'
let s:d[0x0A6A]='GURMUKHI DIGIT FOUR'
let s:d[0x0A6B]='GURMUKHI DIGIT FIVE'
let s:d[0x0A6C]='GURMUKHI DIGIT SIX'
let s:d[0x0A6D]='GURMUKHI DIGIT SEVEN'
let s:d[0x0A6E]='GURMUKHI DIGIT EIGHT'
let s:d[0x0A6F]='GURMUKHI DIGIT NINE'
let s:d[0x0A70]='GURMUKHI TIPPI'
let s:d[0x0A71]='GURMUKHI ADDAK'
let s:d[0x0A72]='GURMUKHI IRI'
let s:d[0x0A73]='GURMUKHI URA'
let s:d[0x0A74]='GURMUKHI EK ONKAR'
let s:d[0x0A75]='GURMUKHI SIGN YAKASH'
let s:d[0x0A81]='GUJARATI SIGN CANDRABINDU'
let s:d[0x0A82]='GUJARATI SIGN ANUSVARA'
let s:d[0x0A83]='GUJARATI SIGN VISARGA'
let s:d[0x0A85]='GUJARATI LETTER A'
let s:d[0x0A86]='GUJARATI LETTER AA'
let s:d[0x0A87]='GUJARATI LETTER I'
let s:d[0x0A88]='GUJARATI LETTER II'
let s:d[0x0A89]='GUJARATI LETTER U'
let s:d[0x0A8A]='GUJARATI LETTER UU'
let s:d[0x0A8B]='GUJARATI LETTER VOCALIC R'
let s:d[0x0A8C]='GUJARATI LETTER VOCALIC L'
let s:d[0x0A8D]='GUJARATI VOWEL CANDRA E'
let s:d[0x0A8F]='GUJARATI LETTER E'
let s:d[0x0A90]='GUJARATI LETTER AI'
let s:d[0x0A91]='GUJARATI VOWEL CANDRA O'
let s:d[0x0A93]='GUJARATI LETTER O'
let s:d[0x0A94]='GUJARATI LETTER AU'
let s:d[0x0A95]='GUJARATI LETTER KA'
let s:d[0x0A96]='GUJARATI LETTER KHA'
let s:d[0x0A97]='GUJARATI LETTER GA'
let s:d[0x0A98]='GUJARATI LETTER GHA'
let s:d[0x0A99]='GUJARATI LETTER NGA'
let s:d[0x0A9A]='GUJARATI LETTER CA'
let s:d[0x0A9B]='GUJARATI LETTER CHA'
let s:d[0x0A9C]='GUJARATI LETTER JA'
let s:d[0x0A9D]='GUJARATI LETTER JHA'
let s:d[0x0A9E]='GUJARATI LETTER NYA'
let s:d[0x0A9F]='GUJARATI LETTER TTA'
let s:d[0x0AA0]='GUJARATI LETTER TTHA'
let s:d[0x0AA1]='GUJARATI LETTER DDA'
let s:d[0x0AA2]='GUJARATI LETTER DDHA'
let s:d[0x0AA3]='GUJARATI LETTER NNA'
let s:d[0x0AA4]='GUJARATI LETTER TA'
let s:d[0x0AA5]='GUJARATI LETTER THA'
let s:d[0x0AA6]='GUJARATI LETTER DA'
let s:d[0x0AA7]='GUJARATI LETTER DHA'
let s:d[0x0AA8]='GUJARATI LETTER NA'
let s:d[0x0AAA]='GUJARATI LETTER PA'
let s:d[0x0AAB]='GUJARATI LETTER PHA'
let s:d[0x0AAC]='GUJARATI LETTER BA'
let s:d[0x0AAD]='GUJARATI LETTER BHA'
let s:d[0x0AAE]='GUJARATI LETTER MA'
let s:d[0x0AAF]='GUJARATI LETTER YA'
let s:d[0x0AB0]='GUJARATI LETTER RA'
let s:d[0x0AB2]='GUJARATI LETTER LA'
let s:d[0x0AB3]='GUJARATI LETTER LLA'
let s:d[0x0AB5]='GUJARATI LETTER VA'
let s:d[0x0AB6]='GUJARATI LETTER SHA'
let s:d[0x0AB7]='GUJARATI LETTER SSA'
let s:d[0x0AB8]='GUJARATI LETTER SA'
let s:d[0x0AB9]='GUJARATI LETTER HA'
let s:d[0x0ABC]='GUJARATI SIGN NUKTA'
let s:d[0x0ABD]='GUJARATI SIGN AVAGRAHA'
let s:d[0x0ABE]='GUJARATI VOWEL SIGN AA'
let s:d[0x0ABF]='GUJARATI VOWEL SIGN I'
let s:d[0x0AC0]='GUJARATI VOWEL SIGN II'
let s:d[0x0AC1]='GUJARATI VOWEL SIGN U'
let s:d[0x0AC2]='GUJARATI VOWEL SIGN UU'
let s:d[0x0AC3]='GUJARATI VOWEL SIGN VOCALIC R'
let s:d[0x0AC4]='GUJARATI VOWEL SIGN VOCALIC RR'
let s:d[0x0AC5]='GUJARATI VOWEL SIGN CANDRA E'
let s:d[0x0AC7]='GUJARATI VOWEL SIGN E'
let s:d[0x0AC8]='GUJARATI VOWEL SIGN AI'
let s:d[0x0AC9]='GUJARATI VOWEL SIGN CANDRA O'
let s:d[0x0ACB]='GUJARATI VOWEL SIGN O'
let s:d[0x0ACC]='GUJARATI VOWEL SIGN AU'
let s:d[0x0ACD]='GUJARATI SIGN VIRAMA'
let s:d[0x0AD0]='GUJARATI OM'
let s:d[0x0AE0]='GUJARATI LETTER VOCALIC RR'
let s:d[0x0AE1]='GUJARATI LETTER VOCALIC LL'
let s:d[0x0AE2]='GUJARATI VOWEL SIGN VOCALIC L'
let s:d[0x0AE3]='GUJARATI VOWEL SIGN VOCALIC LL'
let s:d[0x0AE4]='<reserved>'
let s:d[0x0AE5]='<reserved>'
let s:d[0x0AE6]='GUJARATI DIGIT ZERO'
let s:d[0x0AE7]='GUJARATI DIGIT ONE'
let s:d[0x0AE8]='GUJARATI DIGIT TWO'
let s:d[0x0AE9]='GUJARATI DIGIT THREE'
let s:d[0x0AEA]='GUJARATI DIGIT FOUR'
let s:d[0x0AEB]='GUJARATI DIGIT FIVE'
let s:d[0x0AEC]='GUJARATI DIGIT SIX'
let s:d[0x0AED]='GUJARATI DIGIT SEVEN'
let s:d[0x0AEE]='GUJARATI DIGIT EIGHT'
let s:d[0x0AEF]='GUJARATI DIGIT NINE'
let s:d[0x0AF0]='GUJARATI ABBREVIATION SIGN'
let s:d[0x0AF1]='GUJARATI RUPEE SIGN'
let s:d[0x0B01]='ORIYA SIGN CANDRABINDU'
let s:d[0x0B02]='ORIYA SIGN ANUSVARA'
let s:d[0x0B03]='ORIYA SIGN VISARGA'
let s:d[0x0B05]='ORIYA LETTER A'
let s:d[0x0B06]='ORIYA LETTER AA'
let s:d[0x0B07]='ORIYA LETTER I'
let s:d[0x0B08]='ORIYA LETTER II'
let s:d[0x0B09]='ORIYA LETTER U'
let s:d[0x0B0A]='ORIYA LETTER UU'
let s:d[0x0B0B]='ORIYA LETTER VOCALIC R'
let s:d[0x0B0C]='ORIYA LETTER VOCALIC L'
let s:d[0x0B0F]='ORIYA LETTER E'
let s:d[0x0B10]='ORIYA LETTER AI'
let s:d[0x0B13]='ORIYA LETTER O'
let s:d[0x0B14]='ORIYA LETTER AU'
let s:d[0x0B15]='ORIYA LETTER KA'
let s:d[0x0B16]='ORIYA LETTER KHA'
let s:d[0x0B17]='ORIYA LETTER GA'
let s:d[0x0B18]='ORIYA LETTER GHA'
let s:d[0x0B19]='ORIYA LETTER NGA'
let s:d[0x0B1A]='ORIYA LETTER CA'
let s:d[0x0B1B]='ORIYA LETTER CHA'
let s:d[0x0B1C]='ORIYA LETTER JA'
let s:d[0x0B1D]='ORIYA LETTER JHA'
let s:d[0x0B1E]='ORIYA LETTER NYA'
let s:d[0x0B1F]='ORIYA LETTER TTA'
let s:d[0x0B20]='ORIYA LETTER TTHA'
let s:d[0x0B21]='ORIYA LETTER DDA'
let s:d[0x0B22]='ORIYA LETTER DDHA'
let s:d[0x0B23]='ORIYA LETTER NNA'
let s:d[0x0B24]='ORIYA LETTER TA'
let s:d[0x0B25]='ORIYA LETTER THA'
let s:d[0x0B26]='ORIYA LETTER DA'
let s:d[0x0B27]='ORIYA LETTER DHA'
let s:d[0x0B28]='ORIYA LETTER NA'
let s:d[0x0B2A]='ORIYA LETTER PA'
let s:d[0x0B2B]='ORIYA LETTER PHA'
let s:d[0x0B2C]='ORIYA LETTER BA'
let s:d[0x0B2D]='ORIYA LETTER BHA'
let s:d[0x0B2E]='ORIYA LETTER MA'
let s:d[0x0B2F]='ORIYA LETTER YA'
let s:d[0x0B30]='ORIYA LETTER RA'
let s:d[0x0B32]='ORIYA LETTER LA'
let s:d[0x0B33]='ORIYA LETTER LLA'
let s:d[0x0B35]='ORIYA LETTER VA'
let s:d[0x0B36]='ORIYA LETTER SHA'
let s:d[0x0B37]='ORIYA LETTER SSA'
let s:d[0x0B38]='ORIYA LETTER SA'
let s:d[0x0B39]='ORIYA LETTER HA'
let s:d[0x0B3C]='ORIYA SIGN NUKTA'
let s:d[0x0B3D]='ORIYA SIGN AVAGRAHA'
let s:d[0x0B3E]='ORIYA VOWEL SIGN AA'
let s:d[0x0B3F]='ORIYA VOWEL SIGN I'
let s:d[0x0B40]='ORIYA VOWEL SIGN II'
let s:d[0x0B41]='ORIYA VOWEL SIGN U'
let s:d[0x0B42]='ORIYA VOWEL SIGN UU'
let s:d[0x0B43]='ORIYA VOWEL SIGN VOCALIC R'
let s:d[0x0B44]='ORIYA VOWEL SIGN VOCALIC RR'
let s:d[0x0B47]='ORIYA VOWEL SIGN E'
let s:d[0x0B48]='ORIYA VOWEL SIGN AI'
let s:d[0x0B4B]='ORIYA VOWEL SIGN O'
let s:d[0x0B4C]='ORIYA VOWEL SIGN AU'
let s:d[0x0B4D]='ORIYA SIGN VIRAMA'
let s:d[0x0B56]='ORIYA AI LENGTH MARK'
let s:d[0x0B57]='ORIYA AU LENGTH MARK'
let s:d[0x0B5C]='ORIYA LETTER RRA'
let s:d[0x0B5D]='ORIYA LETTER RHA'
let s:d[0x0B5F]='ORIYA LETTER YYA'
let s:d[0x0B60]='ORIYA LETTER VOCALIC RR'
let s:d[0x0B61]='ORIYA LETTER VOCALIC LL'
let s:d[0x0B62]='ORIYA VOWEL SIGN VOCALIC L'
let s:d[0x0B63]='ORIYA VOWEL SIGN VOCALIC LL'
let s:d[0x0B64]='<reserved>'
let s:d[0x0B65]='<reserved>'
let s:d[0x0B66]='ORIYA DIGIT ZERO'
let s:d[0x0B67]='ORIYA DIGIT ONE'
let s:d[0x0B68]='ORIYA DIGIT TWO'
let s:d[0x0B69]='ORIYA DIGIT THREE'
let s:d[0x0B6A]='ORIYA DIGIT FOUR'
let s:d[0x0B6B]='ORIYA DIGIT FIVE'
let s:d[0x0B6C]='ORIYA DIGIT SIX'
let s:d[0x0B6D]='ORIYA DIGIT SEVEN'
let s:d[0x0B6E]='ORIYA DIGIT EIGHT'
let s:d[0x0B6F]='ORIYA DIGIT NINE'
let s:d[0x0B70]='ORIYA ISSHAR'
let s:d[0x0B71]='ORIYA LETTER WA'
let s:d[0x0B72]='ORIYA FRACTION ONE QUARTER'
let s:d[0x0B73]='ORIYA FRACTION ONE HALF'
let s:d[0x0B74]='ORIYA FRACTION THREE QUARTERS'
let s:d[0x0B75]='ORIYA FRACTION ONE SIXTEENTH'
let s:d[0x0B76]='ORIYA FRACTION ONE EIGHTH'
let s:d[0x0B77]='ORIYA FRACTION THREE SIXTEENTHS'
let s:d[0x0B82]='TAMIL SIGN ANUSVARA'
let s:d[0x0B83]='TAMIL SIGN VISARGA'
let s:d[0x0B85]='TAMIL LETTER A'
let s:d[0x0B86]='TAMIL LETTER AA'
let s:d[0x0B87]='TAMIL LETTER I'
let s:d[0x0B88]='TAMIL LETTER II'
let s:d[0x0B89]='TAMIL LETTER U'
let s:d[0x0B8A]='TAMIL LETTER UU'
let s:d[0x0B8E]='TAMIL LETTER E'
let s:d[0x0B8F]='TAMIL LETTER EE'
let s:d[0x0B90]='TAMIL LETTER AI'
let s:d[0x0B92]='TAMIL LETTER O'
let s:d[0x0B93]='TAMIL LETTER OO'
let s:d[0x0B94]='TAMIL LETTER AU'
let s:d[0x0B95]='TAMIL LETTER KA'
let s:d[0x0B99]='TAMIL LETTER NGA'
let s:d[0x0B9A]='TAMIL LETTER CA'
let s:d[0x0B9C]='TAMIL LETTER JA'
let s:d[0x0B9E]='TAMIL LETTER NYA'
let s:d[0x0B9F]='TAMIL LETTER TTA'
let s:d[0x0BA3]='TAMIL LETTER NNA'
let s:d[0x0BA4]='TAMIL LETTER TA'
let s:d[0x0BA8]='TAMIL LETTER NA'
let s:d[0x0BA9]='TAMIL LETTER NNNA'
let s:d[0x0BAA]='TAMIL LETTER PA'
let s:d[0x0BAE]='TAMIL LETTER MA'
let s:d[0x0BAF]='TAMIL LETTER YA'
let s:d[0x0BB0]='TAMIL LETTER RA'
let s:d[0x0BB1]='TAMIL LETTER RRA'
let s:d[0x0BB2]='TAMIL LETTER LA'
let s:d[0x0BB3]='TAMIL LETTER LLA'
let s:d[0x0BB4]='TAMIL LETTER LLLA'
let s:d[0x0BB5]='TAMIL LETTER VA'
let s:d[0x0BB6]='TAMIL LETTER SHA'
let s:d[0x0BB7]='TAMIL LETTER SSA'
let s:d[0x0BB8]='TAMIL LETTER SA'
let s:d[0x0BB9]='TAMIL LETTER HA'
let s:d[0x0BBE]='TAMIL VOWEL SIGN AA'
let s:d[0x0BBF]='TAMIL VOWEL SIGN I'
let s:d[0x0BC0]='TAMIL VOWEL SIGN II'
let s:d[0x0BC1]='TAMIL VOWEL SIGN U'
let s:d[0x0BC2]='TAMIL VOWEL SIGN UU'
let s:d[0x0BC6]='TAMIL VOWEL SIGN E'
let s:d[0x0BC7]='TAMIL VOWEL SIGN EE'
let s:d[0x0BC8]='TAMIL VOWEL SIGN AI'
let s:d[0x0BCA]='TAMIL VOWEL SIGN O'
let s:d[0x0BCB]='TAMIL VOWEL SIGN OO'
let s:d[0x0BCC]='TAMIL VOWEL SIGN AU'
let s:d[0x0BCD]='TAMIL SIGN VIRAMA'
let s:d[0x0BD0]='TAMIL OM'
let s:d[0x0BD7]='TAMIL AU LENGTH MARK'
let s:d[0x0BE4]='<reserved>'
let s:d[0x0BE5]='<reserved>'
let s:d[0x0BE6]='TAMIL DIGIT ZERO'
let s:d[0x0BE7]='TAMIL DIGIT ONE'
let s:d[0x0BE8]='TAMIL DIGIT TWO'
let s:d[0x0BE9]='TAMIL DIGIT THREE'
let s:d[0x0BEA]='TAMIL DIGIT FOUR'
let s:d[0x0BEB]='TAMIL DIGIT FIVE'
let s:d[0x0BEC]='TAMIL DIGIT SIX'
let s:d[0x0BED]='TAMIL DIGIT SEVEN'
let s:d[0x0BEE]='TAMIL DIGIT EIGHT'
let s:d[0x0BEF]='TAMIL DIGIT NINE'
let s:d[0x0BF0]='TAMIL NUMBER TEN'
let s:d[0x0BF1]='TAMIL NUMBER ONE HUNDRED'
let s:d[0x0BF2]='TAMIL NUMBER ONE THOUSAND'
let s:d[0x0BF3]='TAMIL DAY SIGN'
let s:d[0x0BF4]='TAMIL MONTH SIGN'
let s:d[0x0BF5]='TAMIL YEAR SIGN'
let s:d[0x0BF6]='TAMIL DEBIT SIGN'
let s:d[0x0BF7]='TAMIL CREDIT SIGN'
let s:d[0x0BF8]='TAMIL AS ABOVE SIGN'
let s:d[0x0BF9]='TAMIL RUPEE SIGN'
let s:d[0x0BFA]='TAMIL NUMBER SIGN'
let s:d[0x0C01]='TELUGU SIGN CANDRABINDU'
let s:d[0x0C02]='TELUGU SIGN ANUSVARA'
let s:d[0x0C03]='TELUGU SIGN VISARGA'
let s:d[0x0C05]='TELUGU LETTER A'
let s:d[0x0C06]='TELUGU LETTER AA'
let s:d[0x0C07]='TELUGU LETTER I'
let s:d[0x0C08]='TELUGU LETTER II'
let s:d[0x0C09]='TELUGU LETTER U'
let s:d[0x0C0A]='TELUGU LETTER UU'
let s:d[0x0C0B]='TELUGU LETTER VOCALIC R'
let s:d[0x0C0C]='TELUGU LETTER VOCALIC L'
let s:d[0x0C0E]='TELUGU LETTER E'
let s:d[0x0C0F]='TELUGU LETTER EE'
let s:d[0x0C10]='TELUGU LETTER AI'
let s:d[0x0C12]='TELUGU LETTER O'
let s:d[0x0C13]='TELUGU LETTER OO'
let s:d[0x0C14]='TELUGU LETTER AU'
let s:d[0x0C15]='TELUGU LETTER KA'
let s:d[0x0C16]='TELUGU LETTER KHA'
let s:d[0x0C17]='TELUGU LETTER GA'
let s:d[0x0C18]='TELUGU LETTER GHA'
let s:d[0x0C19]='TELUGU LETTER NGA'
let s:d[0x0C1A]='TELUGU LETTER CA'
let s:d[0x0C1B]='TELUGU LETTER CHA'
let s:d[0x0C1C]='TELUGU LETTER JA'
let s:d[0x0C1D]='TELUGU LETTER JHA'
let s:d[0x0C1E]='TELUGU LETTER NYA'
let s:d[0x0C1F]='TELUGU LETTER TTA'
let s:d[0x0C20]='TELUGU LETTER TTHA'
let s:d[0x0C21]='TELUGU LETTER DDA'
let s:d[0x0C22]='TELUGU LETTER DDHA'
let s:d[0x0C23]='TELUGU LETTER NNA'
let s:d[0x0C24]='TELUGU LETTER TA'
let s:d[0x0C25]='TELUGU LETTER THA'
let s:d[0x0C26]='TELUGU LETTER DA'
let s:d[0x0C27]='TELUGU LETTER DHA'
let s:d[0x0C28]='TELUGU LETTER NA'
let s:d[0x0C2A]='TELUGU LETTER PA'
let s:d[0x0C2B]='TELUGU LETTER PHA'
let s:d[0x0C2C]='TELUGU LETTER BA'
let s:d[0x0C2D]='TELUGU LETTER BHA'
let s:d[0x0C2E]='TELUGU LETTER MA'
let s:d[0x0C2F]='TELUGU LETTER YA'
let s:d[0x0C30]='TELUGU LETTER RA'
let s:d[0x0C31]='TELUGU LETTER RRA'
let s:d[0x0C32]='TELUGU LETTER LA'
let s:d[0x0C33]='TELUGU LETTER LLA'
let s:d[0x0C35]='TELUGU LETTER VA'
let s:d[0x0C36]='TELUGU LETTER SHA'
let s:d[0x0C37]='TELUGU LETTER SSA'
let s:d[0x0C38]='TELUGU LETTER SA'
let s:d[0x0C39]='TELUGU LETTER HA'
let s:d[0x0C3D]='TELUGU SIGN AVAGRAHA'
let s:d[0x0C3E]='TELUGU VOWEL SIGN AA'
let s:d[0x0C3F]='TELUGU VOWEL SIGN I'
let s:d[0x0C40]='TELUGU VOWEL SIGN II'
let s:d[0x0C41]='TELUGU VOWEL SIGN U'
let s:d[0x0C42]='TELUGU VOWEL SIGN UU'
let s:d[0x0C43]='TELUGU VOWEL SIGN VOCALIC R'
let s:d[0x0C44]='TELUGU VOWEL SIGN VOCALIC RR'
let s:d[0x0C46]='TELUGU VOWEL SIGN E'
let s:d[0x0C47]='TELUGU VOWEL SIGN EE'
let s:d[0x0C48]='TELUGU VOWEL SIGN AI'
let s:d[0x0C4A]='TELUGU VOWEL SIGN O'
let s:d[0x0C4B]='TELUGU VOWEL SIGN OO'
let s:d[0x0C4C]='TELUGU VOWEL SIGN AU'
let s:d[0x0C4D]='TELUGU SIGN VIRAMA'
let s:d[0x0C55]='TELUGU LENGTH MARK'
let s:d[0x0C56]='TELUGU AI LENGTH MARK'
let s:d[0x0C58]='TELUGU LETTER TSA'
let s:d[0x0C59]='TELUGU LETTER DZA'
let s:d[0x0C60]='TELUGU LETTER VOCALIC RR'
let s:d[0x0C61]='TELUGU LETTER VOCALIC LL'
let s:d[0x0C62]='TELUGU VOWEL SIGN VOCALIC L'
let s:d[0x0C63]='TELUGU VOWEL SIGN VOCALIC LL'
let s:d[0x0C64]='<reserved>'
let s:d[0x0C65]='<reserved>'
let s:d[0x0C66]='TELUGU DIGIT ZERO'
let s:d[0x0C67]='TELUGU DIGIT ONE'
let s:d[0x0C68]='TELUGU DIGIT TWO'
let s:d[0x0C69]='TELUGU DIGIT THREE'
let s:d[0x0C6A]='TELUGU DIGIT FOUR'
let s:d[0x0C6B]='TELUGU DIGIT FIVE'
let s:d[0x0C6C]='TELUGU DIGIT SIX'
let s:d[0x0C6D]='TELUGU DIGIT SEVEN'
let s:d[0x0C6E]='TELUGU DIGIT EIGHT'
let s:d[0x0C6F]='TELUGU DIGIT NINE'
let s:d[0x0C78]='TELUGU FRACTION DIGIT ZERO FOR ODD POWERS OF FOUR'
let s:d[0x0C79]='TELUGU FRACTION DIGIT ONE FOR ODD POWERS OF FOUR'
let s:d[0x0C7A]='TELUGU FRACTION DIGIT TWO FOR ODD POWERS OF FOUR'
let s:d[0x0C7B]='TELUGU FRACTION DIGIT THREE FOR ODD POWERS OF FOUR'
let s:d[0x0C7C]='TELUGU FRACTION DIGIT ONE FOR EVEN POWERS OF FOUR'
let s:d[0x0C7D]='TELUGU FRACTION DIGIT TWO FOR EVEN POWERS OF FOUR'
let s:d[0x0C7E]='TELUGU FRACTION DIGIT THREE FOR EVEN POWERS OF FOUR'
let s:d[0x0C7F]='TELUGU SIGN TUUMU'
let s:d[0x0C82]='KANNADA SIGN ANUSVARA'
let s:d[0x0C83]='KANNADA SIGN VISARGA'
let s:d[0x0C85]='KANNADA LETTER A'
let s:d[0x0C86]='KANNADA LETTER AA'
let s:d[0x0C87]='KANNADA LETTER I'
let s:d[0x0C88]='KANNADA LETTER II'
let s:d[0x0C89]='KANNADA LETTER U'
let s:d[0x0C8A]='KANNADA LETTER UU'
let s:d[0x0C8B]='KANNADA LETTER VOCALIC R'
let s:d[0x0C8C]='KANNADA LETTER VOCALIC L'
let s:d[0x0C8E]='KANNADA LETTER E'
let s:d[0x0C8F]='KANNADA LETTER EE'
let s:d[0x0C90]='KANNADA LETTER AI'
let s:d[0x0C92]='KANNADA LETTER O'
let s:d[0x0C93]='KANNADA LETTER OO'
let s:d[0x0C94]='KANNADA LETTER AU'
let s:d[0x0C95]='KANNADA LETTER KA'
let s:d[0x0C96]='KANNADA LETTER KHA'
let s:d[0x0C97]='KANNADA LETTER GA'
let s:d[0x0C98]='KANNADA LETTER GHA'
let s:d[0x0C99]='KANNADA LETTER NGA'
let s:d[0x0C9A]='KANNADA LETTER CA'
let s:d[0x0C9B]='KANNADA LETTER CHA'
let s:d[0x0C9C]='KANNADA LETTER JA'
let s:d[0x0C9D]='KANNADA LETTER JHA'
let s:d[0x0C9E]='KANNADA LETTER NYA'
let s:d[0x0C9F]='KANNADA LETTER TTA'
let s:d[0x0CA0]='KANNADA LETTER TTHA'
let s:d[0x0CA1]='KANNADA LETTER DDA'
let s:d[0x0CA2]='KANNADA LETTER DDHA'
let s:d[0x0CA3]='KANNADA LETTER NNA'
let s:d[0x0CA4]='KANNADA LETTER TA'
let s:d[0x0CA5]='KANNADA LETTER THA'
let s:d[0x0CA6]='KANNADA LETTER DA'
let s:d[0x0CA7]='KANNADA LETTER DHA'
let s:d[0x0CA8]='KANNADA LETTER NA'
let s:d[0x0CAA]='KANNADA LETTER PA'
let s:d[0x0CAB]='KANNADA LETTER PHA'
let s:d[0x0CAC]='KANNADA LETTER BA'
let s:d[0x0CAD]='KANNADA LETTER BHA'
let s:d[0x0CAE]='KANNADA LETTER MA'
let s:d[0x0CAF]='KANNADA LETTER YA'
let s:d[0x0CB0]='KANNADA LETTER RA'
let s:d[0x0CB1]='KANNADA LETTER RRA'
let s:d[0x0CB2]='KANNADA LETTER LA'
let s:d[0x0CB3]='KANNADA LETTER LLA'
let s:d[0x0CB5]='KANNADA LETTER VA'
let s:d[0x0CB6]='KANNADA LETTER SHA'
let s:d[0x0CB7]='KANNADA LETTER SSA'
let s:d[0x0CB8]='KANNADA LETTER SA'
let s:d[0x0CB9]='KANNADA LETTER HA'
let s:d[0x0CBC]='KANNADA SIGN NUKTA'
let s:d[0x0CBD]='KANNADA SIGN AVAGRAHA'
let s:d[0x0CBE]='KANNADA VOWEL SIGN AA'
let s:d[0x0CBF]='KANNADA VOWEL SIGN I'
let s:d[0x0CC0]='KANNADA VOWEL SIGN II'
let s:d[0x0CC1]='KANNADA VOWEL SIGN U'
let s:d[0x0CC2]='KANNADA VOWEL SIGN UU'
let s:d[0x0CC3]='KANNADA VOWEL SIGN VOCALIC R'
let s:d[0x0CC4]='KANNADA VOWEL SIGN VOCALIC RR'
let s:d[0x0CC6]='KANNADA VOWEL SIGN E'
let s:d[0x0CC7]='KANNADA VOWEL SIGN EE'
let s:d[0x0CC8]='KANNADA VOWEL SIGN AI'
let s:d[0x0CCA]='KANNADA VOWEL SIGN O'
let s:d[0x0CCB]='KANNADA VOWEL SIGN OO'
let s:d[0x0CCC]='KANNADA VOWEL SIGN AU'
let s:d[0x0CCD]='KANNADA SIGN VIRAMA'
let s:d[0x0CD5]='KANNADA LENGTH MARK'
let s:d[0x0CD6]='KANNADA AI LENGTH MARK'
let s:d[0x0CDE]='KANNADA LETTER FA'
let s:d[0x0CE0]='KANNADA LETTER VOCALIC RR'
let s:d[0x0CE1]='KANNADA LETTER VOCALIC LL'
let s:d[0x0CE2]='KANNADA VOWEL SIGN VOCALIC L'
let s:d[0x0CE3]='KANNADA VOWEL SIGN VOCALIC LL'
let s:d[0x0CE4]='<reserved>'
let s:d[0x0CE5]='<reserved>'
let s:d[0x0CE6]='KANNADA DIGIT ZERO'
let s:d[0x0CE7]='KANNADA DIGIT ONE'
let s:d[0x0CE8]='KANNADA DIGIT TWO'
let s:d[0x0CE9]='KANNADA DIGIT THREE'
let s:d[0x0CEA]='KANNADA DIGIT FOUR'
let s:d[0x0CEB]='KANNADA DIGIT FIVE'
let s:d[0x0CEC]='KANNADA DIGIT SIX'
let s:d[0x0CED]='KANNADA DIGIT SEVEN'
let s:d[0x0CEE]='KANNADA DIGIT EIGHT'
let s:d[0x0CEF]='KANNADA DIGIT NINE'
let s:d[0x0CF1]='KANNADA SIGN JIHVAMULIYA'
let s:d[0x0CF2]='KANNADA SIGN UPADHMANIYA'
let s:d[0x0D02]='MALAYALAM SIGN ANUSVARA'
let s:d[0x0D03]='MALAYALAM SIGN VISARGA'
let s:d[0x0D05]='MALAYALAM LETTER A'
let s:d[0x0D06]='MALAYALAM LETTER AA'
let s:d[0x0D07]='MALAYALAM LETTER I'
let s:d[0x0D08]='MALAYALAM LETTER II'
let s:d[0x0D09]='MALAYALAM LETTER U'
let s:d[0x0D0A]='MALAYALAM LETTER UU'
let s:d[0x0D0B]='MALAYALAM LETTER VOCALIC R'
let s:d[0x0D0C]='MALAYALAM LETTER VOCALIC L'
let s:d[0x0D0E]='MALAYALAM LETTER E'
let s:d[0x0D0F]='MALAYALAM LETTER EE'
let s:d[0x0D10]='MALAYALAM LETTER AI'
let s:d[0x0D12]='MALAYALAM LETTER O'
let s:d[0x0D13]='MALAYALAM LETTER OO'
let s:d[0x0D14]='MALAYALAM LETTER AU'
let s:d[0x0D15]='MALAYALAM LETTER KA'
let s:d[0x0D16]='MALAYALAM LETTER KHA'
let s:d[0x0D17]='MALAYALAM LETTER GA'
let s:d[0x0D18]='MALAYALAM LETTER GHA'
let s:d[0x0D19]='MALAYALAM LETTER NGA'
let s:d[0x0D1A]='MALAYALAM LETTER CA'
let s:d[0x0D1B]='MALAYALAM LETTER CHA'
let s:d[0x0D1C]='MALAYALAM LETTER JA'
let s:d[0x0D1D]='MALAYALAM LETTER JHA'
let s:d[0x0D1E]='MALAYALAM LETTER NYA'
let s:d[0x0D1F]='MALAYALAM LETTER TTA'
let s:d[0x0D20]='MALAYALAM LETTER TTHA'
let s:d[0x0D21]='MALAYALAM LETTER DDA'
let s:d[0x0D22]='MALAYALAM LETTER DDHA'
let s:d[0x0D23]='MALAYALAM LETTER NNA'
let s:d[0x0D24]='MALAYALAM LETTER TA'
let s:d[0x0D25]='MALAYALAM LETTER THA'
let s:d[0x0D26]='MALAYALAM LETTER DA'
let s:d[0x0D27]='MALAYALAM LETTER DHA'
let s:d[0x0D28]='MALAYALAM LETTER NA'
let s:d[0x0D29]='MALAYALAM LETTER NNNA'
let s:d[0x0D2A]='MALAYALAM LETTER PA'
let s:d[0x0D2B]='MALAYALAM LETTER PHA'
let s:d[0x0D2C]='MALAYALAM LETTER BA'
let s:d[0x0D2D]='MALAYALAM LETTER BHA'
let s:d[0x0D2E]='MALAYALAM LETTER MA'
let s:d[0x0D2F]='MALAYALAM LETTER YA'
let s:d[0x0D30]='MALAYALAM LETTER RA'
let s:d[0x0D31]='MALAYALAM LETTER RRA'
let s:d[0x0D32]='MALAYALAM LETTER LA'
let s:d[0x0D33]='MALAYALAM LETTER LLA'
let s:d[0x0D34]='MALAYALAM LETTER LLLA'
let s:d[0x0D35]='MALAYALAM LETTER VA'
let s:d[0x0D36]='MALAYALAM LETTER SHA'
let s:d[0x0D37]='MALAYALAM LETTER SSA'
let s:d[0x0D38]='MALAYALAM LETTER SA'
let s:d[0x0D39]='MALAYALAM LETTER HA'
let s:d[0x0D3A]='MALAYALAM LETTER TTTA'
let s:d[0x0D3D]='MALAYALAM SIGN AVAGRAHA'
let s:d[0x0D3E]='MALAYALAM VOWEL SIGN AA'
let s:d[0x0D3F]='MALAYALAM VOWEL SIGN I'
let s:d[0x0D40]='MALAYALAM VOWEL SIGN II'
let s:d[0x0D41]='MALAYALAM VOWEL SIGN U'
let s:d[0x0D42]='MALAYALAM VOWEL SIGN UU'
let s:d[0x0D43]='MALAYALAM VOWEL SIGN VOCALIC R'
let s:d[0x0D44]='MALAYALAM VOWEL SIGN VOCALIC RR'
let s:d[0x0D46]='MALAYALAM VOWEL SIGN E'
let s:d[0x0D47]='MALAYALAM VOWEL SIGN EE'
let s:d[0x0D48]='MALAYALAM VOWEL SIGN AI'
let s:d[0x0D4A]='MALAYALAM VOWEL SIGN O'
let s:d[0x0D4B]='MALAYALAM VOWEL SIGN OO'
let s:d[0x0D4C]='MALAYALAM VOWEL SIGN AU'
let s:d[0x0D4D]='MALAYALAM SIGN VIRAMA'
let s:d[0x0D4E]='MALAYALAM LETTER DOT REPH'
let s:d[0x0D57]='MALAYALAM AU LENGTH MARK'
let s:d[0x0D60]='MALAYALAM LETTER VOCALIC RR'
let s:d[0x0D61]='MALAYALAM LETTER VOCALIC LL'
let s:d[0x0D62]='MALAYALAM VOWEL SIGN VOCALIC L'
let s:d[0x0D63]='MALAYALAM VOWEL SIGN VOCALIC LL'
let s:d[0x0D64]='<reserved>'
let s:d[0x0D65]='<reserved>'
let s:d[0x0D66]='MALAYALAM DIGIT ZERO'
let s:d[0x0D67]='MALAYALAM DIGIT ONE'
let s:d[0x0D68]='MALAYALAM DIGIT TWO'
let s:d[0x0D69]='MALAYALAM DIGIT THREE'
let s:d[0x0D6A]='MALAYALAM DIGIT FOUR'
let s:d[0x0D6B]='MALAYALAM DIGIT FIVE'
let s:d[0x0D6C]='MALAYALAM DIGIT SIX'
let s:d[0x0D6D]='MALAYALAM DIGIT SEVEN'
let s:d[0x0D6E]='MALAYALAM DIGIT EIGHT'
let s:d[0x0D6F]='MALAYALAM DIGIT NINE'
let s:d[0x0D70]='MALAYALAM NUMBER TEN'
let s:d[0x0D71]='MALAYALAM NUMBER ONE HUNDRED'
let s:d[0x0D72]='MALAYALAM NUMBER ONE THOUSAND'
let s:d[0x0D73]='MALAYALAM FRACTION ONE QUARTER'
let s:d[0x0D74]='MALAYALAM FRACTION ONE HALF'
let s:d[0x0D75]='MALAYALAM FRACTION THREE QUARTERS'
let s:d[0x0D79]='MALAYALAM DATE MARK'
let s:d[0x0D7A]='MALAYALAM LETTER CHILLU NN'
let s:d[0x0D7B]='MALAYALAM LETTER CHILLU N'
let s:d[0x0D7C]='MALAYALAM LETTER CHILLU RR'
let s:d[0x0D7D]='MALAYALAM LETTER CHILLU L'
let s:d[0x0D7E]='MALAYALAM LETTER CHILLU LL'
let s:d[0x0D7F]='MALAYALAM LETTER CHILLU K'
let s:d[0x0D82]='SINHALA SIGN ANUSVARAYA'
let s:d[0x0D83]='SINHALA SIGN VISARGAYA'
let s:d[0x0D85]='SINHALA LETTER AYANNA'
let s:d[0x0D86]='SINHALA LETTER AAYANNA'
let s:d[0x0D87]='SINHALA LETTER AEYANNA'
let s:d[0x0D88]='SINHALA LETTER AEEYANNA'
let s:d[0x0D89]='SINHALA LETTER IYANNA'
let s:d[0x0D8A]='SINHALA LETTER IIYANNA'
let s:d[0x0D8B]='SINHALA LETTER UYANNA'
let s:d[0x0D8C]='SINHALA LETTER UUYANNA'
let s:d[0x0D8D]='SINHALA LETTER IRUYANNA'
let s:d[0x0D8E]='SINHALA LETTER IRUUYANNA'
let s:d[0x0D8F]='SINHALA LETTER ILUYANNA'
let s:d[0x0D90]='SINHALA LETTER ILUUYANNA'
let s:d[0x0D91]='SINHALA LETTER EYANNA'
let s:d[0x0D92]='SINHALA LETTER EEYANNA'
let s:d[0x0D93]='SINHALA LETTER AIYANNA'
let s:d[0x0D94]='SINHALA LETTER OYANNA'
let s:d[0x0D95]='SINHALA LETTER OOYANNA'
let s:d[0x0D96]='SINHALA LETTER AUYANNA'
let s:d[0x0D9A]='SINHALA LETTER ALPAPRAANA KAYANNA'
let s:d[0x0D9B]='SINHALA LETTER MAHAAPRAANA KAYANNA'
let s:d[0x0D9C]='SINHALA LETTER ALPAPRAANA GAYANNA'
let s:d[0x0D9D]='SINHALA LETTER MAHAAPRAANA GAYANNA'
let s:d[0x0D9E]='SINHALA LETTER KANTAJA NAASIKYAYA'
let s:d[0x0D9F]='SINHALA LETTER SANYAKA GAYANNA'
let s:d[0x0DA0]='SINHALA LETTER ALPAPRAANA CAYANNA'
let s:d[0x0DA1]='SINHALA LETTER MAHAAPRAANA CAYANNA'
let s:d[0x0DA2]='SINHALA LETTER ALPAPRAANA JAYANNA'
let s:d[0x0DA3]='SINHALA LETTER MAHAAPRAANA JAYANNA'
let s:d[0x0DA4]='SINHALA LETTER TAALUJA NAASIKYAYA'
let s:d[0x0DA5]='SINHALA LETTER TAALUJA SANYOOGA NAAKSIKYAYA'
let s:d[0x0DA6]='SINHALA LETTER SANYAKA JAYANNA'
let s:d[0x0DA7]='SINHALA LETTER ALPAPRAANA TTAYANNA'
let s:d[0x0DA8]='SINHALA LETTER MAHAAPRAANA TTAYANNA'
let s:d[0x0DA9]='SINHALA LETTER ALPAPRAANA DDAYANNA'
let s:d[0x0DAA]='SINHALA LETTER MAHAAPRAANA DDAYANNA'
let s:d[0x0DAB]='SINHALA LETTER MUURDHAJA NAYANNA'
let s:d[0x0DAC]='SINHALA LETTER SANYAKA DDAYANNA'
let s:d[0x0DAD]='SINHALA LETTER ALPAPRAANA TAYANNA'
let s:d[0x0DAE]='SINHALA LETTER MAHAAPRAANA TAYANNA'
let s:d[0x0DAF]='SINHALA LETTER ALPAPRAANA DAYANNA'
let s:d[0x0DB0]='SINHALA LETTER MAHAAPRAANA DAYANNA'
let s:d[0x0DB1]='SINHALA LETTER DANTAJA NAYANNA'
let s:d[0x0DB3]='SINHALA LETTER SANYAKA DAYANNA'
let s:d[0x0DB4]='SINHALA LETTER ALPAPRAANA PAYANNA'
let s:d[0x0DB5]='SINHALA LETTER MAHAAPRAANA PAYANNA'
let s:d[0x0DB6]='SINHALA LETTER ALPAPRAANA BAYANNA'
let s:d[0x0DB7]='SINHALA LETTER MAHAAPRAANA BAYANNA'
let s:d[0x0DB8]='SINHALA LETTER MAYANNA'
let s:d[0x0DB9]='SINHALA LETTER AMBA BAYANNA'
let s:d[0x0DBA]='SINHALA LETTER YAYANNA'
let s:d[0x0DBB]='SINHALA LETTER RAYANNA'
let s:d[0x0DBD]='SINHALA LETTER DANTAJA LAYANNA'
let s:d[0x0DC0]='SINHALA LETTER VAYANNA'
let s:d[0x0DC1]='SINHALA LETTER TAALUJA SAYANNA'
let s:d[0x0DC2]='SINHALA LETTER MUURDHAJA SAYANNA'
let s:d[0x0DC3]='SINHALA LETTER DANTAJA SAYANNA'
let s:d[0x0DC4]='SINHALA LETTER HAYANNA'
let s:d[0x0DC5]='SINHALA LETTER MUURDHAJA LAYANNA'
let s:d[0x0DC6]='SINHALA LETTER FAYANNA'
let s:d[0x0DCA]='SINHALA SIGN AL-LAKUNA'
let s:d[0x0DCF]='SINHALA VOWEL SIGN AELA-PILLA'
let s:d[0x0DD0]='SINHALA VOWEL SIGN KETTI AEDA-PILLA'
let s:d[0x0DD1]='SINHALA VOWEL SIGN DIGA AEDA-PILLA'
let s:d[0x0DD2]='SINHALA VOWEL SIGN KETTI IS-PILLA'
let s:d[0x0DD3]='SINHALA VOWEL SIGN DIGA IS-PILLA'
let s:d[0x0DD4]='SINHALA VOWEL SIGN KETTI PAA-PILLA'
let s:d[0x0DD6]='SINHALA VOWEL SIGN DIGA PAA-PILLA'
let s:d[0x0DD8]='SINHALA VOWEL SIGN GAETTA-PILLA'
let s:d[0x0DD9]='SINHALA VOWEL SIGN KOMBUVA'
let s:d[0x0DDA]='SINHALA VOWEL SIGN DIGA KOMBUVA'
let s:d[0x0DDB]='SINHALA VOWEL SIGN KOMBU DEKA'
let s:d[0x0DDC]='SINHALA VOWEL SIGN KOMBUVA HAA AELA-PILLA'
let s:d[0x0DDD]='SINHALA VOWEL SIGN KOMBUVA HAA DIGA AELA-PILLA'
let s:d[0x0DDE]='SINHALA VOWEL SIGN KOMBUVA HAA GAYANUKITTA'
let s:d[0x0DDF]='SINHALA VOWEL SIGN GAYANUKITTA'
let s:d[0x0DF2]='SINHALA VOWEL SIGN DIGA GAETTA-PILLA'
let s:d[0x0DF3]='SINHALA VOWEL SIGN DIGA GAYANUKITTA'
let s:d[0x0DF4]='SINHALA PUNCTUATION KUNDDALIYA'
let s:d[0x0E01]='THAI CHARACTER KO KAI'
let s:d[0x0E02]='THAI CHARACTER KHO KHAI'
let s:d[0x0E03]='THAI CHARACTER KHO KHUAT'
let s:d[0x0E04]='THAI CHARACTER KHO KHWAI'
let s:d[0x0E05]='THAI CHARACTER KHO KHON'
let s:d[0x0E06]='THAI CHARACTER KHO RAKHANG'
let s:d[0x0E07]='THAI CHARACTER NGO NGU'
let s:d[0x0E08]='THAI CHARACTER CHO CHAN'
let s:d[0x0E09]='THAI CHARACTER CHO CHING'
let s:d[0x0E0A]='THAI CHARACTER CHO CHANG'
let s:d[0x0E0B]='THAI CHARACTER SO SO'
let s:d[0x0E0C]='THAI CHARACTER CHO CHOE'
let s:d[0x0E0D]='THAI CHARACTER YO YING'
let s:d[0x0E0E]='THAI CHARACTER DO CHADA'
let s:d[0x0E0F]='THAI CHARACTER TO PATAK'
let s:d[0x0E10]='THAI CHARACTER THO THAN'
let s:d[0x0E11]='THAI CHARACTER THO NANGMONTHO'
let s:d[0x0E12]='THAI CHARACTER THO PHUTHAO'
let s:d[0x0E13]='THAI CHARACTER NO NEN'
let s:d[0x0E14]='THAI CHARACTER DO DEK'
let s:d[0x0E15]='THAI CHARACTER TO TAO'
let s:d[0x0E16]='THAI CHARACTER THO THUNG'
let s:d[0x0E17]='THAI CHARACTER THO THAHAN'
let s:d[0x0E18]='THAI CHARACTER THO THONG'
let s:d[0x0E19]='THAI CHARACTER NO NU'
let s:d[0x0E1A]='THAI CHARACTER BO BAIMAI'
let s:d[0x0E1B]='THAI CHARACTER PO PLA'
let s:d[0x0E1C]='THAI CHARACTER PHO PHUNG'
let s:d[0x0E1D]='THAI CHARACTER FO FA'
let s:d[0x0E1E]='THAI CHARACTER PHO PHAN'
let s:d[0x0E1F]='THAI CHARACTER FO FAN'
let s:d[0x0E20]='THAI CHARACTER PHO SAMPHAO'
let s:d[0x0E21]='THAI CHARACTER MO MA'
let s:d[0x0E22]='THAI CHARACTER YO YAK'
let s:d[0x0E23]='THAI CHARACTER RO RUA'
let s:d[0x0E24]='THAI CHARACTER RU'
let s:d[0x0E25]='THAI CHARACTER LO LING'
let s:d[0x0E26]='THAI CHARACTER LU'
let s:d[0x0E27]='THAI CHARACTER WO WAEN'
let s:d[0x0E28]='THAI CHARACTER SO SALA'
let s:d[0x0E29]='THAI CHARACTER SO RUSI'
let s:d[0x0E2A]='THAI CHARACTER SO SUA'
let s:d[0x0E2B]='THAI CHARACTER HO HIP'
let s:d[0x0E2C]='THAI CHARACTER LO CHULA'
let s:d[0x0E2D]='THAI CHARACTER O ANG'
let s:d[0x0E2E]='THAI CHARACTER HO NOKHUK'
let s:d[0x0E2F]='THAI CHARACTER PAIYANNOI'
let s:d[0x0E30]='THAI CHARACTER SARA A'
let s:d[0x0E31]='THAI CHARACTER MAI HAN-AKAT'
let s:d[0x0E32]='THAI CHARACTER SARA AA'
let s:d[0x0E33]='THAI CHARACTER SARA AM'
let s:d[0x0E34]='THAI CHARACTER SARA I'
let s:d[0x0E35]='THAI CHARACTER SARA II'
let s:d[0x0E36]='THAI CHARACTER SARA UE'
let s:d[0x0E37]='THAI CHARACTER SARA UEE'
let s:d[0x0E38]='THAI CHARACTER SARA U'
let s:d[0x0E39]='THAI CHARACTER SARA UU'
let s:d[0x0E3A]='THAI CHARACTER PHINTHU'
let s:d[0x0E3F]='THAI CURRENCY SYMBOL BAHT'
let s:d[0x0E40]='THAI CHARACTER SARA E'
let s:d[0x0E41]='THAI CHARACTER SARA AE'
let s:d[0x0E42]='THAI CHARACTER SARA O'
let s:d[0x0E43]='THAI CHARACTER SARA AI MAIMUAN'
let s:d[0x0E44]='THAI CHARACTER SARA AI MAIMALAI'
let s:d[0x0E45]='THAI CHARACTER LAKKHANGYAO'
let s:d[0x0E46]='THAI CHARACTER MAIYAMOK'
let s:d[0x0E47]='THAI CHARACTER MAITAIKHU'
let s:d[0x0E48]='THAI CHARACTER MAI EK'
let s:d[0x0E49]='THAI CHARACTER MAI THO'
let s:d[0x0E4A]='THAI CHARACTER MAI TRI'
let s:d[0x0E4B]='THAI CHARACTER MAI CHATTAWA'
let s:d[0x0E4C]='THAI CHARACTER THANTHAKHAT'
let s:d[0x0E4D]='THAI CHARACTER NIKHAHIT'
let s:d[0x0E4E]='THAI CHARACTER YAMAKKAN'
let s:d[0x0E4F]='THAI CHARACTER FONGMAN'
let s:d[0x0E50]='THAI DIGIT ZERO'
let s:d[0x0E51]='THAI DIGIT ONE'
let s:d[0x0E52]='THAI DIGIT TWO'
let s:d[0x0E53]='THAI DIGIT THREE'
let s:d[0x0E54]='THAI DIGIT FOUR'
let s:d[0x0E55]='THAI DIGIT FIVE'
let s:d[0x0E56]='THAI DIGIT SIX'
let s:d[0x0E57]='THAI DIGIT SEVEN'
let s:d[0x0E58]='THAI DIGIT EIGHT'
let s:d[0x0E59]='THAI DIGIT NINE'
let s:d[0x0E5A]='THAI CHARACTER ANGKHANKHU'
let s:d[0x0E5B]='THAI CHARACTER KHOMUT'
let s:d[0x0E81]='LAO LETTER KO'
let s:d[0x0E82]='LAO LETTER KHO SUNG'
let s:d[0x0E84]='LAO LETTER KHO TAM'
let s:d[0x0E87]='LAO LETTER NGO'
let s:d[0x0E88]='LAO LETTER CO'
let s:d[0x0E8A]='LAO LETTER SO TAM'
let s:d[0x0E8D]='LAO LETTER NYO'
let s:d[0x0E94]='LAO LETTER DO'
let s:d[0x0E95]='LAO LETTER TO'
let s:d[0x0E96]='LAO LETTER THO SUNG'
let s:d[0x0E97]='LAO LETTER THO TAM'
let s:d[0x0E99]='LAO LETTER NO'
let s:d[0x0E9A]='LAO LETTER BO'
let s:d[0x0E9B]='LAO LETTER PO'
let s:d[0x0E9C]='LAO LETTER PHO SUNG'
let s:d[0x0E9D]='LAO LETTER FO TAM'
let s:d[0x0E9E]='LAO LETTER PHO TAM'
let s:d[0x0E9F]='LAO LETTER FO SUNG'
let s:d[0x0EA1]='LAO LETTER MO'
let s:d[0x0EA2]='LAO LETTER YO'
let s:d[0x0EA3]='LAO LETTER LO LING'
let s:d[0x0EA5]='LAO LETTER LO LOOT'
let s:d[0x0EA7]='LAO LETTER WO'
let s:d[0x0EAA]='LAO LETTER SO SUNG'
let s:d[0x0EAB]='LAO LETTER HO SUNG'
let s:d[0x0EAD]='LAO LETTER O'
let s:d[0x0EAE]='LAO LETTER HO TAM'
let s:d[0x0EAF]='LAO ELLIPSIS'
let s:d[0x0EB0]='LAO VOWEL SIGN A'
let s:d[0x0EB1]='LAO VOWEL SIGN MAI KAN'
let s:d[0x0EB2]='LAO VOWEL SIGN AA'
let s:d[0x0EB3]='LAO VOWEL SIGN AM'
let s:d[0x0EB4]='LAO VOWEL SIGN I'
let s:d[0x0EB5]='LAO VOWEL SIGN II'
let s:d[0x0EB6]='LAO VOWEL SIGN Y'
let s:d[0x0EB7]='LAO VOWEL SIGN YY'
let s:d[0x0EB8]='LAO VOWEL SIGN U'
let s:d[0x0EB9]='LAO VOWEL SIGN UU'
let s:d[0x0EBB]='LAO VOWEL SIGN MAI KON'
let s:d[0x0EBC]='LAO SEMIVOWEL SIGN LO'
let s:d[0x0EBD]='LAO SEMIVOWEL SIGN NYO'
let s:d[0x0EC0]='LAO VOWEL SIGN E'
let s:d[0x0EC1]='LAO VOWEL SIGN EI'
let s:d[0x0EC2]='LAO VOWEL SIGN O'
let s:d[0x0EC3]='LAO VOWEL SIGN AY'
let s:d[0x0EC4]='LAO VOWEL SIGN AI'
let s:d[0x0EC6]='LAO KO LA'
let s:d[0x0EC8]='LAO TONE MAI EK'
let s:d[0x0EC9]='LAO TONE MAI THO'
let s:d[0x0ECA]='LAO TONE MAI TI'
let s:d[0x0ECB]='LAO TONE MAI CATAWA'
let s:d[0x0ECC]='LAO CANCELLATION MARK'
let s:d[0x0ECD]='LAO NIGGAHITA'
let s:d[0x0ED0]='LAO DIGIT ZERO'
let s:d[0x0ED1]='LAO DIGIT ONE'
let s:d[0x0ED2]='LAO DIGIT TWO'
let s:d[0x0ED3]='LAO DIGIT THREE'
let s:d[0x0ED4]='LAO DIGIT FOUR'
let s:d[0x0ED5]='LAO DIGIT FIVE'
let s:d[0x0ED6]='LAO DIGIT SIX'
let s:d[0x0ED7]='LAO DIGIT SEVEN'
let s:d[0x0ED8]='LAO DIGIT EIGHT'
let s:d[0x0ED9]='LAO DIGIT NINE'
let s:d[0x0EDC]='LAO HO NO'
let s:d[0x0EDD]='LAO HO MO'
let s:d[0x0EDE]='LAO LETTER KHMU GO'
let s:d[0x0EDF]='LAO LETTER KHMU NYO'
let s:d[0x0F00]='TIBETAN SYLLABLE OM'
let s:d[0x0F01]='TIBETAN MARK GTER YIG MGO TRUNCATED A'
let s:d[0x0F02]='TIBETAN MARK GTER YIG MGO -UM RNAM BCAD MA'
let s:d[0x0F03]='TIBETAN MARK GTER YIG MGO -UM GTER TSHEG MA'
let s:d[0x0F04]='TIBETAN MARK INITIAL YIG MGO MDUN MA'
let s:d[0x0F05]='TIBETAN MARK CLOSING YIG MGO SGAB MA'
let s:d[0x0F06]='TIBETAN MARK CARET YIG MGO PHUR SHAD MA'
let s:d[0x0F07]='TIBETAN MARK YIG MGO TSHEG SHAD MA'
let s:d[0x0F08]='TIBETAN MARK SBRUL SHAD'
let s:d[0x0F09]='TIBETAN MARK BSKUR YIG MGO'
let s:d[0x0F0A]='TIBETAN MARK BKA- SHOG YIG MGO'
let s:d[0x0F0B]='TIBETAN MARK INTERSYLLABIC TSHEG'
let s:d[0x0F0C]='TIBETAN MARK DELIMITER TSHEG BSTAR'
let s:d[0x0F0D]='TIBETAN MARK SHAD'
let s:d[0x0F0E]='TIBETAN MARK NYIS SHAD'
let s:d[0x0F0F]='TIBETAN MARK TSHEG SHAD'
let s:d[0x0F10]='TIBETAN MARK NYIS TSHEG SHAD'
let s:d[0x0F11]='TIBETAN MARK RIN CHEN SPUNGS SHAD'
let s:d[0x0F12]='TIBETAN MARK RGYA GRAM SHAD'
let s:d[0x0F13]='TIBETAN MARK CARET -DZUD RTAGS ME LONG CAN'
let s:d[0x0F14]='TIBETAN MARK GTER TSHEG'
let s:d[0x0F15]='TIBETAN LOGOTYPE SIGN CHAD RTAGS'
let s:d[0x0F16]='TIBETAN LOGOTYPE SIGN LHAG RTAGS'
let s:d[0x0F17]='TIBETAN ASTROLOGICAL SIGN SGRA GCAN -CHAR RTAGS'
let s:d[0x0F18]='TIBETAN ASTROLOGICAL SIGN -KHYUD PA'
let s:d[0x0F19]='TIBETAN ASTROLOGICAL SIGN SDONG TSHUGS'
let s:d[0x0F1A]='TIBETAN SIGN RDEL DKAR GCIG'
let s:d[0x0F1B]='TIBETAN SIGN RDEL DKAR GNYIS'
let s:d[0x0F1C]='TIBETAN SIGN RDEL DKAR GSUM'
let s:d[0x0F1D]='TIBETAN SIGN RDEL NAG GCIG'
let s:d[0x0F1E]='TIBETAN SIGN RDEL NAG GNYIS'
let s:d[0x0F1F]='TIBETAN SIGN RDEL DKAR RDEL NAG'
let s:d[0x0F20]='TIBETAN DIGIT ZERO'
let s:d[0x0F21]='TIBETAN DIGIT ONE'
let s:d[0x0F22]='TIBETAN DIGIT TWO'
let s:d[0x0F23]='TIBETAN DIGIT THREE'
let s:d[0x0F24]='TIBETAN DIGIT FOUR'
let s:d[0x0F25]='TIBETAN DIGIT FIVE'
let s:d[0x0F26]='TIBETAN DIGIT SIX'
let s:d[0x0F27]='TIBETAN DIGIT SEVEN'
let s:d[0x0F28]='TIBETAN DIGIT EIGHT'
let s:d[0x0F29]='TIBETAN DIGIT NINE'
let s:d[0x0F2A]='TIBETAN DIGIT HALF ONE'
let s:d[0x0F2B]='TIBETAN DIGIT HALF TWO'
let s:d[0x0F2C]='TIBETAN DIGIT HALF THREE'
let s:d[0x0F2D]='TIBETAN DIGIT HALF FOUR'
let s:d[0x0F2E]='TIBETAN DIGIT HALF FIVE'
let s:d[0x0F2F]='TIBETAN DIGIT HALF SIX'
let s:d[0x0F30]='TIBETAN DIGIT HALF SEVEN'
let s:d[0x0F31]='TIBETAN DIGIT HALF EIGHT'
let s:d[0x0F32]='TIBETAN DIGIT HALF NINE'
let s:d[0x0F33]='TIBETAN DIGIT HALF ZERO'
let s:d[0x0F34]='TIBETAN MARK BSDUS RTAGS'
let s:d[0x0F35]='TIBETAN MARK NGAS BZUNG NYI ZLA'
let s:d[0x0F36]='TIBETAN MARK CARET -DZUD RTAGS BZHI MIG CAN'
let s:d[0x0F37]='TIBETAN MARK NGAS BZUNG SGOR RTAGS'
let s:d[0x0F38]='TIBETAN MARK CHE MGO'
let s:d[0x0F39]='TIBETAN MARK TSA -PHRU'
let s:d[0x0F3A]='TIBETAN MARK GUG RTAGS GYON'
let s:d[0x0F3B]='TIBETAN MARK GUG RTAGS GYAS'
let s:d[0x0F3C]='TIBETAN MARK ANG KHANG GYON'
let s:d[0x0F3D]='TIBETAN MARK ANG KHANG GYAS'
let s:d[0x0F3E]='TIBETAN SIGN YAR TSHES'
let s:d[0x0F3F]='TIBETAN SIGN MAR TSHES'
let s:d[0x0F40]='TIBETAN LETTER KA'
let s:d[0x0F41]='TIBETAN LETTER KHA'
let s:d[0x0F42]='TIBETAN LETTER GA'
let s:d[0x0F43]='TIBETAN LETTER GHA'
let s:d[0x0F44]='TIBETAN LETTER NGA'
let s:d[0x0F45]='TIBETAN LETTER CA'
let s:d[0x0F46]='TIBETAN LETTER CHA'
let s:d[0x0F47]='TIBETAN LETTER JA'
let s:d[0x0F49]='TIBETAN LETTER NYA'
let s:d[0x0F4A]='TIBETAN LETTER TTA'
let s:d[0x0F4B]='TIBETAN LETTER TTHA'
let s:d[0x0F4C]='TIBETAN LETTER DDA'
let s:d[0x0F4D]='TIBETAN LETTER DDHA'
let s:d[0x0F4E]='TIBETAN LETTER NNA'
let s:d[0x0F4F]='TIBETAN LETTER TA'
let s:d[0x0F50]='TIBETAN LETTER THA'
let s:d[0x0F51]='TIBETAN LETTER DA'
let s:d[0x0F52]='TIBETAN LETTER DHA'
let s:d[0x0F53]='TIBETAN LETTER NA'
let s:d[0x0F54]='TIBETAN LETTER PA'
let s:d[0x0F55]='TIBETAN LETTER PHA'
let s:d[0x0F56]='TIBETAN LETTER BA'
let s:d[0x0F57]='TIBETAN LETTER BHA'
let s:d[0x0F58]='TIBETAN LETTER MA'
let s:d[0x0F59]='TIBETAN LETTER TSA'
let s:d[0x0F5A]='TIBETAN LETTER TSHA'
let s:d[0x0F5B]='TIBETAN LETTER DZA'
let s:d[0x0F5C]='TIBETAN LETTER DZHA'
let s:d[0x0F5D]='TIBETAN LETTER WA'
let s:d[0x0F5E]='TIBETAN LETTER ZHA'
let s:d[0x0F5F]='TIBETAN LETTER ZA'
let s:d[0x0F60]='TIBETAN LETTER -A'
let s:d[0x0F61]='TIBETAN LETTER YA'
let s:d[0x0F62]='TIBETAN LETTER RA'
let s:d[0x0F63]='TIBETAN LETTER LA'
let s:d[0x0F64]='TIBETAN LETTER SHA'
let s:d[0x0F65]='TIBETAN LETTER SSA'
let s:d[0x0F66]='TIBETAN LETTER SA'
let s:d[0x0F67]='TIBETAN LETTER HA'
let s:d[0x0F68]='TIBETAN LETTER A'
let s:d[0x0F69]='TIBETAN LETTER KSSA'
let s:d[0x0F6A]='TIBETAN LETTER FIXED-FORM RA'
let s:d[0x0F6B]='TIBETAN LETTER KKA'
let s:d[0x0F6C]='TIBETAN LETTER RRA'
let s:d[0x0F71]='TIBETAN VOWEL SIGN AA'
let s:d[0x0F72]='TIBETAN VOWEL SIGN I'
let s:d[0x0F73]='TIBETAN VOWEL SIGN II'
let s:d[0x0F74]='TIBETAN VOWEL SIGN U'
let s:d[0x0F75]='TIBETAN VOWEL SIGN UU'
let s:d[0x0F76]='TIBETAN VOWEL SIGN VOCALIC R'
let s:d[0x0F77]='TIBETAN VOWEL SIGN VOCALIC RR'
let s:d[0x0F78]='TIBETAN VOWEL SIGN VOCALIC L'
let s:d[0x0F79]='TIBETAN VOWEL SIGN VOCALIC LL'
let s:d[0x0F7A]='TIBETAN VOWEL SIGN E'
let s:d[0x0F7B]='TIBETAN VOWEL SIGN EE'
let s:d[0x0F7C]='TIBETAN VOWEL SIGN O'
let s:d[0x0F7D]='TIBETAN VOWEL SIGN OO'
let s:d[0x0F7E]='TIBETAN SIGN RJES SU NGA RO'
let s:d[0x0F7F]='TIBETAN SIGN RNAM BCAD'
let s:d[0x0F80]='TIBETAN VOWEL SIGN REVERSED I'
let s:d[0x0F81]='TIBETAN VOWEL SIGN REVERSED II'
let s:d[0x0F82]='TIBETAN SIGN NYI ZLA NAA DA'
let s:d[0x0F83]='TIBETAN SIGN SNA LDAN'
let s:d[0x0F84]='TIBETAN MARK HALANTA'
let s:d[0x0F85]='TIBETAN MARK PALUTA'
let s:d[0x0F86]='TIBETAN SIGN LCI RTAGS'
let s:d[0x0F87]='TIBETAN SIGN YANG RTAGS'
let s:d[0x0F88]='TIBETAN SIGN LCE TSA CAN'
let s:d[0x0F89]='TIBETAN SIGN MCHU CAN'
let s:d[0x0F8A]='TIBETAN SIGN GRU CAN RGYINGS'
let s:d[0x0F8B]='TIBETAN SIGN GRU MED RGYINGS'
let s:d[0x0F8C]='TIBETAN SIGN INVERTED MCHU CAN'
let s:d[0x0F8D]='TIBETAN SUBJOINED SIGN LCE TSA CAN'
let s:d[0x0F8E]='TIBETAN SUBJOINED SIGN MCHU CAN'
let s:d[0x0F8F]='TIBETAN SUBJOINED SIGN INVERTED MCHU CAN'
let s:d[0x0F90]='TIBETAN SUBJOINED LETTER KA'
let s:d[0x0F91]='TIBETAN SUBJOINED LETTER KHA'
let s:d[0x0F92]='TIBETAN SUBJOINED LETTER GA'
let s:d[0x0F93]='TIBETAN SUBJOINED LETTER GHA'
let s:d[0x0F94]='TIBETAN SUBJOINED LETTER NGA'
let s:d[0x0F95]='TIBETAN SUBJOINED LETTER CA'
let s:d[0x0F96]='TIBETAN SUBJOINED LETTER CHA'
let s:d[0x0F97]='TIBETAN SUBJOINED LETTER JA'
let s:d[0x0F99]='TIBETAN SUBJOINED LETTER NYA'
let s:d[0x0F9A]='TIBETAN SUBJOINED LETTER TTA'
let s:d[0x0F9B]='TIBETAN SUBJOINED LETTER TTHA'
let s:d[0x0F9C]='TIBETAN SUBJOINED LETTER DDA'
let s:d[0x0F9D]='TIBETAN SUBJOINED LETTER DDHA'
let s:d[0x0F9E]='TIBETAN SUBJOINED LETTER NNA'
let s:d[0x0F9F]='TIBETAN SUBJOINED LETTER TA'
let s:d[0x0FA0]='TIBETAN SUBJOINED LETTER THA'
let s:d[0x0FA1]='TIBETAN SUBJOINED LETTER DA'
let s:d[0x0FA2]='TIBETAN SUBJOINED LETTER DHA'
let s:d[0x0FA3]='TIBETAN SUBJOINED LETTER NA'
let s:d[0x0FA4]='TIBETAN SUBJOINED LETTER PA'
let s:d[0x0FA5]='TIBETAN SUBJOINED LETTER PHA'
let s:d[0x0FA6]='TIBETAN SUBJOINED LETTER BA'
let s:d[0x0FA7]='TIBETAN SUBJOINED LETTER BHA'
let s:d[0x0FA8]='TIBETAN SUBJOINED LETTER MA'
let s:d[0x0FA9]='TIBETAN SUBJOINED LETTER TSA'
let s:d[0x0FAA]='TIBETAN SUBJOINED LETTER TSHA'
let s:d[0x0FAB]='TIBETAN SUBJOINED LETTER DZA'
let s:d[0x0FAC]='TIBETAN SUBJOINED LETTER DZHA'
let s:d[0x0FAD]='TIBETAN SUBJOINED LETTER WA'
let s:d[0x0FAE]='TIBETAN SUBJOINED LETTER ZHA'
let s:d[0x0FAF]='TIBETAN SUBJOINED LETTER ZA'
let s:d[0x0FB0]='TIBETAN SUBJOINED LETTER -A'
let s:d[0x0FB1]='TIBETAN SUBJOINED LETTER YA'
let s:d[0x0FB2]='TIBETAN SUBJOINED LETTER RA'
let s:d[0x0FB3]='TIBETAN SUBJOINED LETTER LA'
let s:d[0x0FB4]='TIBETAN SUBJOINED LETTER SHA'
let s:d[0x0FB5]='TIBETAN SUBJOINED LETTER SSA'
let s:d[0x0FB6]='TIBETAN SUBJOINED LETTER SA'
let s:d[0x0FB7]='TIBETAN SUBJOINED LETTER HA'
let s:d[0x0FB8]='TIBETAN SUBJOINED LETTER A'
let s:d[0x0FB9]='TIBETAN SUBJOINED LETTER KSSA'
let s:d[0x0FBA]='TIBETAN SUBJOINED LETTER FIXED-FORM WA'
let s:d[0x0FBB]='TIBETAN SUBJOINED LETTER FIXED-FORM YA'
let s:d[0x0FBC]='TIBETAN SUBJOINED LETTER FIXED-FORM RA'
let s:d[0x0FBE]='TIBETAN KU RU KHA'
let s:d[0x0FBF]='TIBETAN KU RU KHA BZHI MIG CAN'
let s:d[0x0FC0]='TIBETAN CANTILLATION SIGN HEAVY BEAT'
let s:d[0x0FC1]='TIBETAN CANTILLATION SIGN LIGHT BEAT'
let s:d[0x0FC2]='TIBETAN CANTILLATION SIGN CANG TE-U'
let s:d[0x0FC3]='TIBETAN CANTILLATION SIGN SBUB -CHAL'
let s:d[0x0FC4]='TIBETAN SYMBOL DRIL BU'
let s:d[0x0FC5]='TIBETAN SYMBOL RDO RJE'
let s:d[0x0FC6]='TIBETAN SYMBOL PADMA GDAN'
let s:d[0x0FC7]='TIBETAN SYMBOL RDO RJE RGYA GRAM'
let s:d[0x0FC8]='TIBETAN SYMBOL PHUR PA'
let s:d[0x0FC9]='TIBETAN SYMBOL NOR BU'
let s:d[0x0FCA]='TIBETAN SYMBOL NOR BU NYIS -KHYIL'
let s:d[0x0FCB]='TIBETAN SYMBOL NOR BU GSUM -KHYIL'
let s:d[0x0FCC]='TIBETAN SYMBOL NOR BU BZHI -KHYIL'
let s:d[0x0FCE]='TIBETAN SIGN RDEL NAG RDEL DKAR'
let s:d[0x0FCF]='TIBETAN SIGN RDEL NAG GSUM'
let s:d[0x0FD0]='TIBETAN MARK BSKA- SHOG GI MGO RGYAN'
let s:d[0x0FD1]='TIBETAN MARK MNYAM YIG GI MGO RGYAN'
let s:d[0x0FD2]='TIBETAN MARK NYIS TSHEG'
let s:d[0x0FD3]='TIBETAN MARK INITIAL BRDA RNYING YIG MGO MDUN MA'
let s:d[0x0FD4]='TIBETAN MARK CLOSING BRDA RNYING YIG MGO SGAB MA'
let s:d[0x0FD5]='RIGHT-FACING SVASTI SIGN'
let s:d[0x0FD6]='LEFT-FACING SVASTI SIGN'
let s:d[0x0FD7]='RIGHT-FACING SVASTI SIGN WITH DOTS'
let s:d[0x0FD8]='LEFT-FACING SVASTI SIGN WITH DOTS'
let s:d[0x0FD9]='TIBETAN MARK LEADING MCHAN RTAGS'
let s:d[0x0FDA]='TIBETAN MARK TRAILING MCHAN RTAGS'
let s:d[0x1000]='MYANMAR LETTER KA'
let s:d[0x1001]='MYANMAR LETTER KHA'
let s:d[0x1002]='MYANMAR LETTER GA'
let s:d[0x1003]='MYANMAR LETTER GHA'
let s:d[0x1004]='MYANMAR LETTER NGA'
let s:d[0x1005]='MYANMAR LETTER CA'
let s:d[0x1006]='MYANMAR LETTER CHA'
let s:d[0x1007]='MYANMAR LETTER JA'
let s:d[0x1008]='MYANMAR LETTER JHA'
let s:d[0x1009]='MYANMAR LETTER NYA'
let s:d[0x100A]='MYANMAR LETTER NNYA'
let s:d[0x100B]='MYANMAR LETTER TTA'
let s:d[0x100C]='MYANMAR LETTER TTHA'
let s:d[0x100D]='MYANMAR LETTER DDA'
let s:d[0x100E]='MYANMAR LETTER DDHA'
let s:d[0x100F]='MYANMAR LETTER NNA'
let s:d[0x1010]='MYANMAR LETTER TA'
let s:d[0x1011]='MYANMAR LETTER THA'
let s:d[0x1012]='MYANMAR LETTER DA'
let s:d[0x1013]='MYANMAR LETTER DHA'
let s:d[0x1014]='MYANMAR LETTER NA'
let s:d[0x1015]='MYANMAR LETTER PA'
let s:d[0x1016]='MYANMAR LETTER PHA'
let s:d[0x1017]='MYANMAR LETTER BA'
let s:d[0x1018]='MYANMAR LETTER BHA'
let s:d[0x1019]='MYANMAR LETTER MA'
let s:d[0x101A]='MYANMAR LETTER YA'
let s:d[0x101B]='MYANMAR LETTER RA'
let s:d[0x101C]='MYANMAR LETTER LA'
let s:d[0x101D]='MYANMAR LETTER WA'
let s:d[0x101E]='MYANMAR LETTER SA'
let s:d[0x101F]='MYANMAR LETTER HA'
let s:d[0x1020]='MYANMAR LETTER LLA'
let s:d[0x1021]='MYANMAR LETTER A'
let s:d[0x1022]='MYANMAR LETTER SHAN A'
let s:d[0x1023]='MYANMAR LETTER I'
let s:d[0x1024]='MYANMAR LETTER II'
let s:d[0x1025]='MYANMAR LETTER U'
let s:d[0x1026]='MYANMAR LETTER UU'
let s:d[0x1027]='MYANMAR LETTER E'
let s:d[0x1028]='MYANMAR LETTER MON E'
let s:d[0x1029]='MYANMAR LETTER O'
let s:d[0x102A]='MYANMAR LETTER AU'
let s:d[0x102B]='MYANMAR VOWEL SIGN TALL AA'
let s:d[0x102C]='MYANMAR VOWEL SIGN AA'
let s:d[0x102D]='MYANMAR VOWEL SIGN I'
let s:d[0x102E]='MYANMAR VOWEL SIGN II'
let s:d[0x102F]='MYANMAR VOWEL SIGN U'
let s:d[0x1030]='MYANMAR VOWEL SIGN UU'
let s:d[0x1031]='MYANMAR VOWEL SIGN E'
let s:d[0x1032]='MYANMAR VOWEL SIGN AI'
let s:d[0x1033]='MYANMAR VOWEL SIGN MON II'
let s:d[0x1034]='MYANMAR VOWEL SIGN MON O'
let s:d[0x1035]='MYANMAR VOWEL SIGN E ABOVE'
let s:d[0x1036]='MYANMAR SIGN ANUSVARA'
let s:d[0x1037]='MYANMAR SIGN DOT BELOW'
let s:d[0x1038]='MYANMAR SIGN VISARGA'
let s:d[0x1039]='MYANMAR SIGN VIRAMA'
let s:d[0x103A]='MYANMAR SIGN ASAT'
let s:d[0x103B]='MYANMAR CONSONANT SIGN MEDIAL YA'
let s:d[0x103C]='MYANMAR CONSONANT SIGN MEDIAL RA'
let s:d[0x103D]='MYANMAR CONSONANT SIGN MEDIAL WA'
let s:d[0x103E]='MYANMAR CONSONANT SIGN MEDIAL HA'
let s:d[0x103F]='MYANMAR LETTER GREAT SA'
let s:d[0x1040]='MYANMAR DIGIT ZERO'
let s:d[0x1041]='MYANMAR DIGIT ONE'
let s:d[0x1042]='MYANMAR DIGIT TWO'
let s:d[0x1043]='MYANMAR DIGIT THREE'
let s:d[0x1044]='MYANMAR DIGIT FOUR'
let s:d[0x1045]='MYANMAR DIGIT FIVE'
let s:d[0x1046]='MYANMAR DIGIT SIX'
let s:d[0x1047]='MYANMAR DIGIT SEVEN'
let s:d[0x1048]='MYANMAR DIGIT EIGHT'
let s:d[0x1049]='MYANMAR DIGIT NINE'
let s:d[0x104A]='MYANMAR SIGN LITTLE SECTION'
let s:d[0x104B]='MYANMAR SIGN SECTION'
let s:d[0x104C]='MYANMAR SYMBOL LOCATIVE'
let s:d[0x104D]='MYANMAR SYMBOL COMPLETED'
let s:d[0x104E]='MYANMAR SYMBOL AFOREMENTIONED'
let s:d[0x104F]='MYANMAR SYMBOL GENITIVE'
let s:d[0x1050]='MYANMAR LETTER SHA'
let s:d[0x1051]='MYANMAR LETTER SSA'
let s:d[0x1052]='MYANMAR LETTER VOCALIC R'
let s:d[0x1053]='MYANMAR LETTER VOCALIC RR'
let s:d[0x1054]='MYANMAR LETTER VOCALIC L'
let s:d[0x1055]='MYANMAR LETTER VOCALIC LL'
let s:d[0x1056]='MYANMAR VOWEL SIGN VOCALIC R'
let s:d[0x1057]='MYANMAR VOWEL SIGN VOCALIC RR'
let s:d[0x1058]='MYANMAR VOWEL SIGN VOCALIC L'
let s:d[0x1059]='MYANMAR VOWEL SIGN VOCALIC LL'
let s:d[0x105A]='MYANMAR LETTER MON NGA'
let s:d[0x105B]='MYANMAR LETTER MON JHA'
let s:d[0x105C]='MYANMAR LETTER MON BBA'
let s:d[0x105D]='MYANMAR LETTER MON BBE'
let s:d[0x105E]='MYANMAR CONSONANT SIGN MON MEDIAL NA'
let s:d[0x105F]='MYANMAR CONSONANT SIGN MON MEDIAL MA'
let s:d[0x1060]='MYANMAR CONSONANT SIGN MON MEDIAL LA'
let s:d[0x1061]='MYANMAR LETTER SGAW KAREN SHA'
let s:d[0x1062]='MYANMAR VOWEL SIGN SGAW KAREN EU'
let s:d[0x1063]='MYANMAR TONE MARK SGAW KAREN HATHI'
let s:d[0x1064]='MYANMAR TONE MARK SGAW KAREN KE PHO'
let s:d[0x1065]='MYANMAR LETTER WESTERN PWO KAREN THA'
let s:d[0x1066]='MYANMAR LETTER WESTERN PWO KAREN PWA'
let s:d[0x1067]='MYANMAR VOWEL SIGN WESTERN PWO KAREN EU'
let s:d[0x1068]='MYANMAR VOWEL SIGN WESTERN PWO KAREN UE'
let s:d[0x1069]='MYANMAR SIGN WESTERN PWO KAREN TONE-1'
let s:d[0x106A]='MYANMAR SIGN WESTERN PWO KAREN TONE-2'
let s:d[0x106B]='MYANMAR SIGN WESTERN PWO KAREN TONE-3'
let s:d[0x106C]='MYANMAR SIGN WESTERN PWO KAREN TONE-4'
let s:d[0x106D]='MYANMAR SIGN WESTERN PWO KAREN TONE-5'
let s:d[0x106E]='MYANMAR LETTER EASTERN PWO KAREN NNA'
let s:d[0x106F]='MYANMAR LETTER EASTERN PWO KAREN YWA'
let s:d[0x1070]='MYANMAR LETTER EASTERN PWO KAREN GHWA'
let s:d[0x1071]='MYANMAR VOWEL SIGN GEBA KAREN I'
let s:d[0x1072]='MYANMAR VOWEL SIGN KAYAH OE'
let s:d[0x1073]='MYANMAR VOWEL SIGN KAYAH U'
let s:d[0x1074]='MYANMAR VOWEL SIGN KAYAH EE'
let s:d[0x1075]='MYANMAR LETTER SHAN KA'
let s:d[0x1076]='MYANMAR LETTER SHAN KHA'
let s:d[0x1077]='MYANMAR LETTER SHAN GA'
let s:d[0x1078]='MYANMAR LETTER SHAN CA'
let s:d[0x1079]='MYANMAR LETTER SHAN ZA'
let s:d[0x107A]='MYANMAR LETTER SHAN NYA'
let s:d[0x107B]='MYANMAR LETTER SHAN DA'
let s:d[0x107C]='MYANMAR LETTER SHAN NA'
let s:d[0x107D]='MYANMAR LETTER SHAN PHA'
let s:d[0x107E]='MYANMAR LETTER SHAN FA'
let s:d[0x107F]='MYANMAR LETTER SHAN BA'
let s:d[0x1080]='MYANMAR LETTER SHAN THA'
let s:d[0x1081]='MYANMAR LETTER SHAN HA'
let s:d[0x1082]='MYANMAR CONSONANT SIGN SHAN MEDIAL WA'
let s:d[0x1083]='MYANMAR VOWEL SIGN SHAN AA'
let s:d[0x1084]='MYANMAR VOWEL SIGN SHAN E'
let s:d[0x1085]='MYANMAR VOWEL SIGN SHAN E ABOVE'
let s:d[0x1086]='MYANMAR VOWEL SIGN SHAN FINAL Y'
let s:d[0x1087]='MYANMAR SIGN SHAN TONE-2'
let s:d[0x1088]='MYANMAR SIGN SHAN TONE-3'
let s:d[0x1089]='MYANMAR SIGN SHAN TONE-5'
let s:d[0x108A]='MYANMAR SIGN SHAN TONE-6'
let s:d[0x108B]='MYANMAR SIGN SHAN COUNCIL TONE-2'
let s:d[0x108C]='MYANMAR SIGN SHAN COUNCIL TONE-3'
let s:d[0x108D]='MYANMAR SIGN SHAN COUNCIL EMPHATIC TONE'
let s:d[0x108E]='MYANMAR LETTER RUMAI PALAUNG FA'
let s:d[0x108F]='MYANMAR SIGN RUMAI PALAUNG TONE-5'
let s:d[0x1090]='MYANMAR SHAN DIGIT ZERO'
let s:d[0x1091]='MYANMAR SHAN DIGIT ONE'
let s:d[0x1092]='MYANMAR SHAN DIGIT TWO'
let s:d[0x1093]='MYANMAR SHAN DIGIT THREE'
let s:d[0x1094]='MYANMAR SHAN DIGIT FOUR'
let s:d[0x1095]='MYANMAR SHAN DIGIT FIVE'
let s:d[0x1096]='MYANMAR SHAN DIGIT SIX'
let s:d[0x1097]='MYANMAR SHAN DIGIT SEVEN'
let s:d[0x1098]='MYANMAR SHAN DIGIT EIGHT'
let s:d[0x1099]='MYANMAR SHAN DIGIT NINE'
let s:d[0x109A]='MYANMAR SIGN KHAMTI TONE-1'
let s:d[0x109B]='MYANMAR SIGN KHAMTI TONE-3'
let s:d[0x109C]='MYANMAR VOWEL SIGN AITON A'
let s:d[0x109D]='MYANMAR VOWEL SIGN AITON AI'
let s:d[0x109E]='MYANMAR SYMBOL SHAN ONE'
let s:d[0x109F]='MYANMAR SYMBOL SHAN EXCLAMATION'
let s:d[0x10A0]='GEORGIAN CAPITAL LETTER AN'
let s:d[0x10A1]='GEORGIAN CAPITAL LETTER BAN'
let s:d[0x10A2]='GEORGIAN CAPITAL LETTER GAN'
let s:d[0x10A3]='GEORGIAN CAPITAL LETTER DON'
let s:d[0x10A4]='GEORGIAN CAPITAL LETTER EN'
let s:d[0x10A5]='GEORGIAN CAPITAL LETTER VIN'
let s:d[0x10A6]='GEORGIAN CAPITAL LETTER ZEN'
let s:d[0x10A7]='GEORGIAN CAPITAL LETTER TAN'
let s:d[0x10A8]='GEORGIAN CAPITAL LETTER IN'
let s:d[0x10A9]='GEORGIAN CAPITAL LETTER KAN'
let s:d[0x10AA]='GEORGIAN CAPITAL LETTER LAS'
let s:d[0x10AB]='GEORGIAN CAPITAL LETTER MAN'
let s:d[0x10AC]='GEORGIAN CAPITAL LETTER NAR'
let s:d[0x10AD]='GEORGIAN CAPITAL LETTER ON'
let s:d[0x10AE]='GEORGIAN CAPITAL LETTER PAR'
let s:d[0x10AF]='GEORGIAN CAPITAL LETTER ZHAR'
let s:d[0x10B0]='GEORGIAN CAPITAL LETTER RAE'
let s:d[0x10B1]='GEORGIAN CAPITAL LETTER SAN'
let s:d[0x10B2]='GEORGIAN CAPITAL LETTER TAR'
let s:d[0x10B3]='GEORGIAN CAPITAL LETTER UN'
let s:d[0x10B4]='GEORGIAN CAPITAL LETTER PHAR'
let s:d[0x10B5]='GEORGIAN CAPITAL LETTER KHAR'
let s:d[0x10B6]='GEORGIAN CAPITAL LETTER GHAN'
let s:d[0x10B7]='GEORGIAN CAPITAL LETTER QAR'
let s:d[0x10B8]='GEORGIAN CAPITAL LETTER SHIN'
let s:d[0x10B9]='GEORGIAN CAPITAL LETTER CHIN'
let s:d[0x10BA]='GEORGIAN CAPITAL LETTER CAN'
let s:d[0x10BB]='GEORGIAN CAPITAL LETTER JIL'
let s:d[0x10BC]='GEORGIAN CAPITAL LETTER CIL'
let s:d[0x10BD]='GEORGIAN CAPITAL LETTER CHAR'
let s:d[0x10BE]='GEORGIAN CAPITAL LETTER XAN'
let s:d[0x10BF]='GEORGIAN CAPITAL LETTER JHAN'
let s:d[0x10C0]='GEORGIAN CAPITAL LETTER HAE'
let s:d[0x10C1]='GEORGIAN CAPITAL LETTER HE'
let s:d[0x10C2]='GEORGIAN CAPITAL LETTER HIE'
let s:d[0x10C3]='GEORGIAN CAPITAL LETTER WE'
let s:d[0x10C4]='GEORGIAN CAPITAL LETTER HAR'
let s:d[0x10C5]='GEORGIAN CAPITAL LETTER HOE'
let s:d[0x10C7]='GEORGIAN CAPITAL LETTER YN'
let s:d[0x10CD]='GEORGIAN CAPITAL LETTER AEN'
let s:d[0x10D0]='GEORGIAN LETTER AN'
let s:d[0x10D1]='GEORGIAN LETTER BAN'
let s:d[0x10D2]='GEORGIAN LETTER GAN'
let s:d[0x10D3]='GEORGIAN LETTER DON'
let s:d[0x10D4]='GEORGIAN LETTER EN'
let s:d[0x10D5]='GEORGIAN LETTER VIN'
let s:d[0x10D6]='GEORGIAN LETTER ZEN'
let s:d[0x10D7]='GEORGIAN LETTER TAN'
let s:d[0x10D8]='GEORGIAN LETTER IN'
let s:d[0x10D9]='GEORGIAN LETTER KAN'
let s:d[0x10DA]='GEORGIAN LETTER LAS'
let s:d[0x10DB]='GEORGIAN LETTER MAN'
let s:d[0x10DC]='GEORGIAN LETTER NAR'
let s:d[0x10DD]='GEORGIAN LETTER ON'
let s:d[0x10DE]='GEORGIAN LETTER PAR'
let s:d[0x10DF]='GEORGIAN LETTER ZHAR'
let s:d[0x10E0]='GEORGIAN LETTER RAE'
let s:d[0x10E1]='GEORGIAN LETTER SAN'
let s:d[0x10E2]='GEORGIAN LETTER TAR'
let s:d[0x10E3]='GEORGIAN LETTER UN'
let s:d[0x10E4]='GEORGIAN LETTER PHAR'
let s:d[0x10E5]='GEORGIAN LETTER KHAR'
let s:d[0x10E6]='GEORGIAN LETTER GHAN'
let s:d[0x10E7]='GEORGIAN LETTER QAR'
let s:d[0x10E8]='GEORGIAN LETTER SHIN'
let s:d[0x10E9]='GEORGIAN LETTER CHIN'
let s:d[0x10EA]='GEORGIAN LETTER CAN'
let s:d[0x10EB]='GEORGIAN LETTER JIL'
let s:d[0x10EC]='GEORGIAN LETTER CIL'
let s:d[0x10ED]='GEORGIAN LETTER CHAR'
let s:d[0x10EE]='GEORGIAN LETTER XAN'
let s:d[0x10EF]='GEORGIAN LETTER JHAN'
let s:d[0x10F0]='GEORGIAN LETTER HAE'
let s:d[0x10F1]='GEORGIAN LETTER HE'
let s:d[0x10F2]='GEORGIAN LETTER HIE'
let s:d[0x10F3]='GEORGIAN LETTER WE'
let s:d[0x10F4]='GEORGIAN LETTER HAR'
let s:d[0x10F5]='GEORGIAN LETTER HOE'
let s:d[0x10F6]='GEORGIAN LETTER FI'
let s:d[0x10F7]='GEORGIAN LETTER YN'
let s:d[0x10F8]='GEORGIAN LETTER ELIFI'
let s:d[0x10F9]='GEORGIAN LETTER TURNED GAN'
let s:d[0x10FA]='GEORGIAN LETTER AIN'
let s:d[0x10FB]='GEORGIAN PARAGRAPH SEPARATOR'
let s:d[0x10FC]='MODIFIER LETTER GEORGIAN NAR'
let s:d[0x10FD]='GEORGIAN LETTER AEN'
let s:d[0x10FE]='GEORGIAN LETTER HARD SIGN'
let s:d[0x10FF]='GEORGIAN LETTER LABIAL SIGN'
let s:d[0x1100]='HANGUL CHOSEONG KIYEOK'
let s:d[0x1101]='HANGUL CHOSEONG SSANGKIYEOK'
let s:d[0x1102]='HANGUL CHOSEONG NIEUN'
let s:d[0x1103]='HANGUL CHOSEONG TIKEUT'
let s:d[0x1104]='HANGUL CHOSEONG SSANGTIKEUT'
let s:d[0x1105]='HANGUL CHOSEONG RIEUL'
let s:d[0x1106]='HANGUL CHOSEONG MIEUM'
let s:d[0x1107]='HANGUL CHOSEONG PIEUP'
let s:d[0x1108]='HANGUL CHOSEONG SSANGPIEUP'
let s:d[0x1109]='HANGUL CHOSEONG SIOS'
let s:d[0x110A]='HANGUL CHOSEONG SSANGSIOS'
let s:d[0x110B]='HANGUL CHOSEONG IEUNG'
let s:d[0x110C]='HANGUL CHOSEONG CIEUC'
let s:d[0x110D]='HANGUL CHOSEONG SSANGCIEUC'
let s:d[0x110E]='HANGUL CHOSEONG CHIEUCH'
let s:d[0x110F]='HANGUL CHOSEONG KHIEUKH'
let s:d[0x1110]='HANGUL CHOSEONG THIEUTH'
let s:d[0x1111]='HANGUL CHOSEONG PHIEUPH'
let s:d[0x1112]='HANGUL CHOSEONG HIEUH'
let s:d[0x1113]='HANGUL CHOSEONG NIEUN-KIYEOK'
let s:d[0x1114]='HANGUL CHOSEONG SSANGNIEUN'
let s:d[0x1115]='HANGUL CHOSEONG NIEUN-TIKEUT'
let s:d[0x1116]='HANGUL CHOSEONG NIEUN-PIEUP'
let s:d[0x1117]='HANGUL CHOSEONG TIKEUT-KIYEOK'
let s:d[0x1118]='HANGUL CHOSEONG RIEUL-NIEUN'
let s:d[0x1119]='HANGUL CHOSEONG SSANGRIEUL'
let s:d[0x111A]='HANGUL CHOSEONG RIEUL-HIEUH'
let s:d[0x111B]='HANGUL CHOSEONG KAPYEOUNRIEUL'
let s:d[0x111C]='HANGUL CHOSEONG MIEUM-PIEUP'
let s:d[0x111D]='HANGUL CHOSEONG KAPYEOUNMIEUM'
let s:d[0x111E]='HANGUL CHOSEONG PIEUP-KIYEOK'
let s:d[0x111F]='HANGUL CHOSEONG PIEUP-NIEUN'
let s:d[0x1120]='HANGUL CHOSEONG PIEUP-TIKEUT'
let s:d[0x1121]='HANGUL CHOSEONG PIEUP-SIOS'
let s:d[0x1122]='HANGUL CHOSEONG PIEUP-SIOS-KIYEOK'
let s:d[0x1123]='HANGUL CHOSEONG PIEUP-SIOS-TIKEUT'
let s:d[0x1124]='HANGUL CHOSEONG PIEUP-SIOS-PIEUP'
let s:d[0x1125]='HANGUL CHOSEONG PIEUP-SSANGSIOS'
let s:d[0x1126]='HANGUL CHOSEONG PIEUP-SIOS-CIEUC'
let s:d[0x1127]='HANGUL CHOSEONG PIEUP-CIEUC'
let s:d[0x1128]='HANGUL CHOSEONG PIEUP-CHIEUCH'
let s:d[0x1129]='HANGUL CHOSEONG PIEUP-THIEUTH'
let s:d[0x112A]='HANGUL CHOSEONG PIEUP-PHIEUPH'
let s:d[0x112B]='HANGUL CHOSEONG KAPYEOUNPIEUP'
let s:d[0x112C]='HANGUL CHOSEONG KAPYEOUNSSANGPIEUP'
let s:d[0x112D]='HANGUL CHOSEONG SIOS-KIYEOK'
let s:d[0x112E]='HANGUL CHOSEONG SIOS-NIEUN'
let s:d[0x112F]='HANGUL CHOSEONG SIOS-TIKEUT'
let s:d[0x1130]='HANGUL CHOSEONG SIOS-RIEUL'
let s:d[0x1131]='HANGUL CHOSEONG SIOS-MIEUM'
let s:d[0x1132]='HANGUL CHOSEONG SIOS-PIEUP'
let s:d[0x1133]='HANGUL CHOSEONG SIOS-PIEUP-KIYEOK'
let s:d[0x1134]='HANGUL CHOSEONG SIOS-SSANGSIOS'
let s:d[0x1135]='HANGUL CHOSEONG SIOS-IEUNG'
let s:d[0x1136]='HANGUL CHOSEONG SIOS-CIEUC'
let s:d[0x1137]='HANGUL CHOSEONG SIOS-CHIEUCH'
let s:d[0x1138]='HANGUL CHOSEONG SIOS-KHIEUKH'
let s:d[0x1139]='HANGUL CHOSEONG SIOS-THIEUTH'
let s:d[0x113A]='HANGUL CHOSEONG SIOS-PHIEUPH'
let s:d[0x113B]='HANGUL CHOSEONG SIOS-HIEUH'
let s:d[0x113C]='HANGUL CHOSEONG CHITUEUMSIOS'
let s:d[0x113D]='HANGUL CHOSEONG CHITUEUMSSANGSIOS'
let s:d[0x113E]='HANGUL CHOSEONG CEONGCHIEUMSIOS'
let s:d[0x113F]='HANGUL CHOSEONG CEONGCHIEUMSSANGSIOS'
let s:d[0x1140]='HANGUL CHOSEONG PANSIOS'
let s:d[0x1141]='HANGUL CHOSEONG IEUNG-KIYEOK'
let s:d[0x1142]='HANGUL CHOSEONG IEUNG-TIKEUT'
let s:d[0x1143]='HANGUL CHOSEONG IEUNG-MIEUM'
let s:d[0x1144]='HANGUL CHOSEONG IEUNG-PIEUP'
let s:d[0x1145]='HANGUL CHOSEONG IEUNG-SIOS'
let s:d[0x1146]='HANGUL CHOSEONG IEUNG-PANSIOS'
let s:d[0x1147]='HANGUL CHOSEONG SSANGIEUNG'
let s:d[0x1148]='HANGUL CHOSEONG IEUNG-CIEUC'
let s:d[0x1149]='HANGUL CHOSEONG IEUNG-CHIEUCH'
let s:d[0x114A]='HANGUL CHOSEONG IEUNG-THIEUTH'
let s:d[0x114B]='HANGUL CHOSEONG IEUNG-PHIEUPH'
let s:d[0x114C]='HANGUL CHOSEONG YESIEUNG'
let s:d[0x114D]='HANGUL CHOSEONG CIEUC-IEUNG'
let s:d[0x114E]='HANGUL CHOSEONG CHITUEUMCIEUC'
let s:d[0x114F]='HANGUL CHOSEONG CHITUEUMSSANGCIEUC'
let s:d[0x1150]='HANGUL CHOSEONG CEONGCHIEUMCIEUC'
let s:d[0x1151]='HANGUL CHOSEONG CEONGCHIEUMSSANGCIEUC'
let s:d[0x1152]='HANGUL CHOSEONG CHIEUCH-KHIEUKH'
let s:d[0x1153]='HANGUL CHOSEONG CHIEUCH-HIEUH'
let s:d[0x1154]='HANGUL CHOSEONG CHITUEUMCHIEUCH'
let s:d[0x1155]='HANGUL CHOSEONG CEONGCHIEUMCHIEUCH'
let s:d[0x1156]='HANGUL CHOSEONG PHIEUPH-PIEUP'
let s:d[0x1157]='HANGUL CHOSEONG KAPYEOUNPHIEUPH'
let s:d[0x1158]='HANGUL CHOSEONG SSANGHIEUH'
let s:d[0x1159]='HANGUL CHOSEONG YEORINHIEUH'
let s:d[0x115A]='HANGUL CHOSEONG KIYEOK-TIKEUT'
let s:d[0x115B]='HANGUL CHOSEONG NIEUN-SIOS'
let s:d[0x115C]='HANGUL CHOSEONG NIEUN-CIEUC'
let s:d[0x115D]='HANGUL CHOSEONG NIEUN-HIEUH'
let s:d[0x115E]='HANGUL CHOSEONG TIKEUT-RIEUL'
let s:d[0x115F]='HANGUL CHOSEONG FILLER'
let s:d[0x1160]='HANGUL JUNGSEONG FILLER'
let s:d[0x1161]='HANGUL JUNGSEONG A'
let s:d[0x1162]='HANGUL JUNGSEONG AE'
let s:d[0x1163]='HANGUL JUNGSEONG YA'
let s:d[0x1164]='HANGUL JUNGSEONG YAE'
let s:d[0x1165]='HANGUL JUNGSEONG EO'
let s:d[0x1166]='HANGUL JUNGSEONG E'
let s:d[0x1167]='HANGUL JUNGSEONG YEO'
let s:d[0x1168]='HANGUL JUNGSEONG YE'
let s:d[0x1169]='HANGUL JUNGSEONG O'
let s:d[0x116A]='HANGUL JUNGSEONG WA'
let s:d[0x116B]='HANGUL JUNGSEONG WAE'
let s:d[0x116C]='HANGUL JUNGSEONG OE'
let s:d[0x116D]='HANGUL JUNGSEONG YO'
let s:d[0x116E]='HANGUL JUNGSEONG U'
let s:d[0x116F]='HANGUL JUNGSEONG WEO'
let s:d[0x1170]='HANGUL JUNGSEONG WE'
let s:d[0x1171]='HANGUL JUNGSEONG WI'
let s:d[0x1172]='HANGUL JUNGSEONG YU'
let s:d[0x1173]='HANGUL JUNGSEONG EU'
let s:d[0x1174]='HANGUL JUNGSEONG YI'
let s:d[0x1175]='HANGUL JUNGSEONG I'
let s:d[0x1176]='HANGUL JUNGSEONG A-O'
let s:d[0x1177]='HANGUL JUNGSEONG A-U'
let s:d[0x1178]='HANGUL JUNGSEONG YA-O'
let s:d[0x1179]='HANGUL JUNGSEONG YA-YO'
let s:d[0x117A]='HANGUL JUNGSEONG EO-O'
let s:d[0x117B]='HANGUL JUNGSEONG EO-U'
let s:d[0x117C]='HANGUL JUNGSEONG EO-EU'
let s:d[0x117D]='HANGUL JUNGSEONG YEO-O'
let s:d[0x117E]='HANGUL JUNGSEONG YEO-U'
let s:d[0x117F]='HANGUL JUNGSEONG O-EO'
let s:d[0x1180]='HANGUL JUNGSEONG O-E'
let s:d[0x1181]='HANGUL JUNGSEONG O-YE'
let s:d[0x1182]='HANGUL JUNGSEONG O-O'
let s:d[0x1183]='HANGUL JUNGSEONG O-U'
let s:d[0x1184]='HANGUL JUNGSEONG YO-YA'
let s:d[0x1185]='HANGUL JUNGSEONG YO-YAE'
let s:d[0x1186]='HANGUL JUNGSEONG YO-YEO'
let s:d[0x1187]='HANGUL JUNGSEONG YO-O'
let s:d[0x1188]='HANGUL JUNGSEONG YO-I'
let s:d[0x1189]='HANGUL JUNGSEONG U-A'
let s:d[0x118A]='HANGUL JUNGSEONG U-AE'
let s:d[0x118B]='HANGUL JUNGSEONG U-EO-EU'
let s:d[0x118C]='HANGUL JUNGSEONG U-YE'
let s:d[0x118D]='HANGUL JUNGSEONG U-U'
let s:d[0x118E]='HANGUL JUNGSEONG YU-A'
let s:d[0x118F]='HANGUL JUNGSEONG YU-EO'
let s:d[0x1190]='HANGUL JUNGSEONG YU-E'
let s:d[0x1191]='HANGUL JUNGSEONG YU-YEO'
let s:d[0x1192]='HANGUL JUNGSEONG YU-YE'
let s:d[0x1193]='HANGUL JUNGSEONG YU-U'
let s:d[0x1194]='HANGUL JUNGSEONG YU-I'
let s:d[0x1195]='HANGUL JUNGSEONG EU-U'
let s:d[0x1196]='HANGUL JUNGSEONG EU-EU'
let s:d[0x1197]='HANGUL JUNGSEONG YI-U'
let s:d[0x1198]='HANGUL JUNGSEONG I-A'
let s:d[0x1199]='HANGUL JUNGSEONG I-YA'
let s:d[0x119A]='HANGUL JUNGSEONG I-O'
let s:d[0x119B]='HANGUL JUNGSEONG I-U'
let s:d[0x119C]='HANGUL JUNGSEONG I-EU'
let s:d[0x119D]='HANGUL JUNGSEONG I-ARAEA'
let s:d[0x119E]='HANGUL JUNGSEONG ARAEA'
let s:d[0x119F]='HANGUL JUNGSEONG ARAEA-EO'
let s:d[0x11A0]='HANGUL JUNGSEONG ARAEA-U'
let s:d[0x11A1]='HANGUL JUNGSEONG ARAEA-I'
let s:d[0x11A2]='HANGUL JUNGSEONG SSANGARAEA'
let s:d[0x11A3]='HANGUL JUNGSEONG A-EU'
let s:d[0x11A4]='HANGUL JUNGSEONG YA-U'
let s:d[0x11A5]='HANGUL JUNGSEONG YEO-YA'
let s:d[0x11A6]='HANGUL JUNGSEONG O-YA'
let s:d[0x11A7]='HANGUL JUNGSEONG O-YAE'
let s:d[0x11A8]='HANGUL JONGSEONG KIYEOK'
let s:d[0x11A9]='HANGUL JONGSEONG SSANGKIYEOK'
let s:d[0x11AA]='HANGUL JONGSEONG KIYEOK-SIOS'
let s:d[0x11AB]='HANGUL JONGSEONG NIEUN'
let s:d[0x11AC]='HANGUL JONGSEONG NIEUN-CIEUC'
let s:d[0x11AD]='HANGUL JONGSEONG NIEUN-HIEUH'
let s:d[0x11AE]='HANGUL JONGSEONG TIKEUT'
let s:d[0x11AF]='HANGUL JONGSEONG RIEUL'
let s:d[0x11B0]='HANGUL JONGSEONG RIEUL-KIYEOK'
let s:d[0x11B1]='HANGUL JONGSEONG RIEUL-MIEUM'
let s:d[0x11B2]='HANGUL JONGSEONG RIEUL-PIEUP'
let s:d[0x11B3]='HANGUL JONGSEONG RIEUL-SIOS'
let s:d[0x11B4]='HANGUL JONGSEONG RIEUL-THIEUTH'
let s:d[0x11B5]='HANGUL JONGSEONG RIEUL-PHIEUPH'
let s:d[0x11B6]='HANGUL JONGSEONG RIEUL-HIEUH'
let s:d[0x11B7]='HANGUL JONGSEONG MIEUM'
let s:d[0x11B8]='HANGUL JONGSEONG PIEUP'
let s:d[0x11B9]='HANGUL JONGSEONG PIEUP-SIOS'
let s:d[0x11BA]='HANGUL JONGSEONG SIOS'
let s:d[0x11BB]='HANGUL JONGSEONG SSANGSIOS'
let s:d[0x11BC]='HANGUL JONGSEONG IEUNG'
let s:d[0x11BD]='HANGUL JONGSEONG CIEUC'
let s:d[0x11BE]='HANGUL JONGSEONG CHIEUCH'
let s:d[0x11BF]='HANGUL JONGSEONG KHIEUKH'
let s:d[0x11C0]='HANGUL JONGSEONG THIEUTH'
let s:d[0x11C1]='HANGUL JONGSEONG PHIEUPH'
let s:d[0x11C2]='HANGUL JONGSEONG HIEUH'
let s:d[0x11C3]='HANGUL JONGSEONG KIYEOK-RIEUL'
let s:d[0x11C4]='HANGUL JONGSEONG KIYEOK-SIOS-KIYEOK'
let s:d[0x11C5]='HANGUL JONGSEONG NIEUN-KIYEOK'
let s:d[0x11C6]='HANGUL JONGSEONG NIEUN-TIKEUT'
let s:d[0x11C7]='HANGUL JONGSEONG NIEUN-SIOS'
let s:d[0x11C8]='HANGUL JONGSEONG NIEUN-PANSIOS'
let s:d[0x11C9]='HANGUL JONGSEONG NIEUN-THIEUTH'
let s:d[0x11CA]='HANGUL JONGSEONG TIKEUT-KIYEOK'
let s:d[0x11CB]='HANGUL JONGSEONG TIKEUT-RIEUL'
let s:d[0x11CC]='HANGUL JONGSEONG RIEUL-KIYEOK-SIOS'
let s:d[0x11CD]='HANGUL JONGSEONG RIEUL-NIEUN'
let s:d[0x11CE]='HANGUL JONGSEONG RIEUL-TIKEUT'
let s:d[0x11CF]='HANGUL JONGSEONG RIEUL-TIKEUT-HIEUH'
let s:d[0x11D0]='HANGUL JONGSEONG SSANGRIEUL'
let s:d[0x11D1]='HANGUL JONGSEONG RIEUL-MIEUM-KIYEOK'
let s:d[0x11D2]='HANGUL JONGSEONG RIEUL-MIEUM-SIOS'
let s:d[0x11D3]='HANGUL JONGSEONG RIEUL-PIEUP-SIOS'
let s:d[0x11D4]='HANGUL JONGSEONG RIEUL-PIEUP-HIEUH'
let s:d[0x11D5]='HANGUL JONGSEONG RIEUL-KAPYEOUNPIEUP'
let s:d[0x11D6]='HANGUL JONGSEONG RIEUL-SSANGSIOS'
let s:d[0x11D7]='HANGUL JONGSEONG RIEUL-PANSIOS'
let s:d[0x11D8]='HANGUL JONGSEONG RIEUL-KHIEUKH'
let s:d[0x11D9]='HANGUL JONGSEONG RIEUL-YEORINHIEUH'
let s:d[0x11DA]='HANGUL JONGSEONG MIEUM-KIYEOK'
let s:d[0x11DB]='HANGUL JONGSEONG MIEUM-RIEUL'
let s:d[0x11DC]='HANGUL JONGSEONG MIEUM-PIEUP'
let s:d[0x11DD]='HANGUL JONGSEONG MIEUM-SIOS'
let s:d[0x11DE]='HANGUL JONGSEONG MIEUM-SSANGSIOS'
let s:d[0x11DF]='HANGUL JONGSEONG MIEUM-PANSIOS'
let s:d[0x11E0]='HANGUL JONGSEONG MIEUM-CHIEUCH'
let s:d[0x11E1]='HANGUL JONGSEONG MIEUM-HIEUH'
let s:d[0x11E2]='HANGUL JONGSEONG KAPYEOUNMIEUM'
let s:d[0x11E3]='HANGUL JONGSEONG PIEUP-RIEUL'
let s:d[0x11E4]='HANGUL JONGSEONG PIEUP-PHIEUPH'
let s:d[0x11E5]='HANGUL JONGSEONG PIEUP-HIEUH'
let s:d[0x11E6]='HANGUL JONGSEONG KAPYEOUNPIEUP'
let s:d[0x11E7]='HANGUL JONGSEONG SIOS-KIYEOK'
let s:d[0x11E8]='HANGUL JONGSEONG SIOS-TIKEUT'
let s:d[0x11E9]='HANGUL JONGSEONG SIOS-RIEUL'
let s:d[0x11EA]='HANGUL JONGSEONG SIOS-PIEUP'
let s:d[0x11EB]='HANGUL JONGSEONG PANSIOS'
let s:d[0x11EC]='HANGUL JONGSEONG IEUNG-KIYEOK'
let s:d[0x11ED]='HANGUL JONGSEONG IEUNG-SSANGKIYEOK'
let s:d[0x11EE]='HANGUL JONGSEONG SSANGIEUNG'
let s:d[0x11EF]='HANGUL JONGSEONG IEUNG-KHIEUKH'
let s:d[0x11F0]='HANGUL JONGSEONG YESIEUNG'
let s:d[0x11F1]='HANGUL JONGSEONG YESIEUNG-SIOS'
let s:d[0x11F2]='HANGUL JONGSEONG YESIEUNG-PANSIOS'
let s:d[0x11F3]='HANGUL JONGSEONG PHIEUPH-PIEUP'
let s:d[0x11F4]='HANGUL JONGSEONG KAPYEOUNPHIEUPH'
let s:d[0x11F5]='HANGUL JONGSEONG HIEUH-NIEUN'
let s:d[0x11F6]='HANGUL JONGSEONG HIEUH-RIEUL'
let s:d[0x11F7]='HANGUL JONGSEONG HIEUH-MIEUM'
let s:d[0x11F8]='HANGUL JONGSEONG HIEUH-PIEUP'
let s:d[0x11F9]='HANGUL JONGSEONG YEORINHIEUH'
let s:d[0x11FA]='HANGUL JONGSEONG KIYEOK-NIEUN'
let s:d[0x11FB]='HANGUL JONGSEONG KIYEOK-PIEUP'
let s:d[0x11FC]='HANGUL JONGSEONG KIYEOK-CHIEUCH'
let s:d[0x11FD]='HANGUL JONGSEONG KIYEOK-KHIEUKH'
let s:d[0x11FE]='HANGUL JONGSEONG KIYEOK-HIEUH'
let s:d[0x11FF]='HANGUL JONGSEONG SSANGNIEUN'
let s:d[0x1200]='ETHIOPIC SYLLABLE HA'
let s:d[0x1201]='ETHIOPIC SYLLABLE HU'
let s:d[0x1202]='ETHIOPIC SYLLABLE HI'
let s:d[0x1203]='ETHIOPIC SYLLABLE HAA'
let s:d[0x1204]='ETHIOPIC SYLLABLE HEE'
let s:d[0x1205]='ETHIOPIC SYLLABLE HE'
let s:d[0x1206]='ETHIOPIC SYLLABLE HO'
let s:d[0x1207]='ETHIOPIC SYLLABLE HOA'
let s:d[0x1208]='ETHIOPIC SYLLABLE LA'
let s:d[0x1209]='ETHIOPIC SYLLABLE LU'
let s:d[0x120A]='ETHIOPIC SYLLABLE LI'
let s:d[0x120B]='ETHIOPIC SYLLABLE LAA'
let s:d[0x120C]='ETHIOPIC SYLLABLE LEE'
let s:d[0x120D]='ETHIOPIC SYLLABLE LE'
let s:d[0x120E]='ETHIOPIC SYLLABLE LO'
let s:d[0x120F]='ETHIOPIC SYLLABLE LWA'
let s:d[0x1210]='ETHIOPIC SYLLABLE HHA'
let s:d[0x1211]='ETHIOPIC SYLLABLE HHU'
let s:d[0x1212]='ETHIOPIC SYLLABLE HHI'
let s:d[0x1213]='ETHIOPIC SYLLABLE HHAA'
let s:d[0x1214]='ETHIOPIC SYLLABLE HHEE'
let s:d[0x1215]='ETHIOPIC SYLLABLE HHE'
let s:d[0x1216]='ETHIOPIC SYLLABLE HHO'
let s:d[0x1217]='ETHIOPIC SYLLABLE HHWA'
let s:d[0x1218]='ETHIOPIC SYLLABLE MA'
let s:d[0x1219]='ETHIOPIC SYLLABLE MU'
let s:d[0x121A]='ETHIOPIC SYLLABLE MI'
let s:d[0x121B]='ETHIOPIC SYLLABLE MAA'
let s:d[0x121C]='ETHIOPIC SYLLABLE MEE'
let s:d[0x121D]='ETHIOPIC SYLLABLE ME'
let s:d[0x121E]='ETHIOPIC SYLLABLE MO'
let s:d[0x121F]='ETHIOPIC SYLLABLE MWA'
let s:d[0x1220]='ETHIOPIC SYLLABLE SZA'
let s:d[0x1221]='ETHIOPIC SYLLABLE SZU'
let s:d[0x1222]='ETHIOPIC SYLLABLE SZI'
let s:d[0x1223]='ETHIOPIC SYLLABLE SZAA'
let s:d[0x1224]='ETHIOPIC SYLLABLE SZEE'
let s:d[0x1225]='ETHIOPIC SYLLABLE SZE'
let s:d[0x1226]='ETHIOPIC SYLLABLE SZO'
let s:d[0x1227]='ETHIOPIC SYLLABLE SZWA'
let s:d[0x1228]='ETHIOPIC SYLLABLE RA'
let s:d[0x1229]='ETHIOPIC SYLLABLE RU'
let s:d[0x122A]='ETHIOPIC SYLLABLE RI'
let s:d[0x122B]='ETHIOPIC SYLLABLE RAA'
let s:d[0x122C]='ETHIOPIC SYLLABLE REE'
let s:d[0x122D]='ETHIOPIC SYLLABLE RE'
let s:d[0x122E]='ETHIOPIC SYLLABLE RO'
let s:d[0x122F]='ETHIOPIC SYLLABLE RWA'
let s:d[0x1230]='ETHIOPIC SYLLABLE SA'
let s:d[0x1231]='ETHIOPIC SYLLABLE SU'
let s:d[0x1232]='ETHIOPIC SYLLABLE SI'
let s:d[0x1233]='ETHIOPIC SYLLABLE SAA'
let s:d[0x1234]='ETHIOPIC SYLLABLE SEE'
let s:d[0x1235]='ETHIOPIC SYLLABLE SE'
let s:d[0x1236]='ETHIOPIC SYLLABLE SO'
let s:d[0x1237]='ETHIOPIC SYLLABLE SWA'
let s:d[0x1238]='ETHIOPIC SYLLABLE SHA'
let s:d[0x1239]='ETHIOPIC SYLLABLE SHU'
let s:d[0x123A]='ETHIOPIC SYLLABLE SHI'
let s:d[0x123B]='ETHIOPIC SYLLABLE SHAA'
let s:d[0x123C]='ETHIOPIC SYLLABLE SHEE'
let s:d[0x123D]='ETHIOPIC SYLLABLE SHE'
let s:d[0x123E]='ETHIOPIC SYLLABLE SHO'
let s:d[0x123F]='ETHIOPIC SYLLABLE SHWA'
let s:d[0x1240]='ETHIOPIC SYLLABLE QA'
let s:d[0x1241]='ETHIOPIC SYLLABLE QU'
let s:d[0x1242]='ETHIOPIC SYLLABLE QI'
let s:d[0x1243]='ETHIOPIC SYLLABLE QAA'
let s:d[0x1244]='ETHIOPIC SYLLABLE QEE'
let s:d[0x1245]='ETHIOPIC SYLLABLE QE'
let s:d[0x1246]='ETHIOPIC SYLLABLE QO'
let s:d[0x1247]='ETHIOPIC SYLLABLE QOA'
let s:d[0x1248]='ETHIOPIC SYLLABLE QWA'
let s:d[0x124A]='ETHIOPIC SYLLABLE QWI'
let s:d[0x124B]='ETHIOPIC SYLLABLE QWAA'
let s:d[0x124C]='ETHIOPIC SYLLABLE QWEE'
let s:d[0x124D]='ETHIOPIC SYLLABLE QWE'
let s:d[0x1250]='ETHIOPIC SYLLABLE QHA'
let s:d[0x1251]='ETHIOPIC SYLLABLE QHU'
let s:d[0x1252]='ETHIOPIC SYLLABLE QHI'
let s:d[0x1253]='ETHIOPIC SYLLABLE QHAA'
let s:d[0x1254]='ETHIOPIC SYLLABLE QHEE'
let s:d[0x1255]='ETHIOPIC SYLLABLE QHE'
let s:d[0x1256]='ETHIOPIC SYLLABLE QHO'
let s:d[0x1258]='ETHIOPIC SYLLABLE QHWA'
let s:d[0x125A]='ETHIOPIC SYLLABLE QHWI'
let s:d[0x125B]='ETHIOPIC SYLLABLE QHWAA'
let s:d[0x125C]='ETHIOPIC SYLLABLE QHWEE'
let s:d[0x125D]='ETHIOPIC SYLLABLE QHWE'
let s:d[0x1260]='ETHIOPIC SYLLABLE BA'
let s:d[0x1261]='ETHIOPIC SYLLABLE BU'
let s:d[0x1262]='ETHIOPIC SYLLABLE BI'
let s:d[0x1263]='ETHIOPIC SYLLABLE BAA'
let s:d[0x1264]='ETHIOPIC SYLLABLE BEE'
let s:d[0x1265]='ETHIOPIC SYLLABLE BE'
let s:d[0x1266]='ETHIOPIC SYLLABLE BO'
let s:d[0x1267]='ETHIOPIC SYLLABLE BWA'
let s:d[0x1268]='ETHIOPIC SYLLABLE VA'
let s:d[0x1269]='ETHIOPIC SYLLABLE VU'
let s:d[0x126A]='ETHIOPIC SYLLABLE VI'
let s:d[0x126B]='ETHIOPIC SYLLABLE VAA'
let s:d[0x126C]='ETHIOPIC SYLLABLE VEE'
let s:d[0x126D]='ETHIOPIC SYLLABLE VE'
let s:d[0x126E]='ETHIOPIC SYLLABLE VO'
let s:d[0x126F]='ETHIOPIC SYLLABLE VWA'
let s:d[0x1270]='ETHIOPIC SYLLABLE TA'
let s:d[0x1271]='ETHIOPIC SYLLABLE TU'
let s:d[0x1272]='ETHIOPIC SYLLABLE TI'
let s:d[0x1273]='ETHIOPIC SYLLABLE TAA'
let s:d[0x1274]='ETHIOPIC SYLLABLE TEE'
let s:d[0x1275]='ETHIOPIC SYLLABLE TE'
let s:d[0x1276]='ETHIOPIC SYLLABLE TO'
let s:d[0x1277]='ETHIOPIC SYLLABLE TWA'
let s:d[0x1278]='ETHIOPIC SYLLABLE CA'
let s:d[0x1279]='ETHIOPIC SYLLABLE CU'
let s:d[0x127A]='ETHIOPIC SYLLABLE CI'
let s:d[0x127B]='ETHIOPIC SYLLABLE CAA'
let s:d[0x127C]='ETHIOPIC SYLLABLE CEE'
let s:d[0x127D]='ETHIOPIC SYLLABLE CE'
let s:d[0x127E]='ETHIOPIC SYLLABLE CO'
let s:d[0x127F]='ETHIOPIC SYLLABLE CWA'
let s:d[0x1280]='ETHIOPIC SYLLABLE XA'
let s:d[0x1281]='ETHIOPIC SYLLABLE XU'
let s:d[0x1282]='ETHIOPIC SYLLABLE XI'
let s:d[0x1283]='ETHIOPIC SYLLABLE XAA'
let s:d[0x1284]='ETHIOPIC SYLLABLE XEE'
let s:d[0x1285]='ETHIOPIC SYLLABLE XE'
let s:d[0x1286]='ETHIOPIC SYLLABLE XO'
let s:d[0x1287]='ETHIOPIC SYLLABLE XOA'
let s:d[0x1288]='ETHIOPIC SYLLABLE XWA'
let s:d[0x128A]='ETHIOPIC SYLLABLE XWI'
let s:d[0x128B]='ETHIOPIC SYLLABLE XWAA'
let s:d[0x128C]='ETHIOPIC SYLLABLE XWEE'
let s:d[0x128D]='ETHIOPIC SYLLABLE XWE'
let s:d[0x1290]='ETHIOPIC SYLLABLE NA'
let s:d[0x1291]='ETHIOPIC SYLLABLE NU'
let s:d[0x1292]='ETHIOPIC SYLLABLE NI'
let s:d[0x1293]='ETHIOPIC SYLLABLE NAA'
let s:d[0x1294]='ETHIOPIC SYLLABLE NEE'
let s:d[0x1295]='ETHIOPIC SYLLABLE NE'
let s:d[0x1296]='ETHIOPIC SYLLABLE NO'
let s:d[0x1297]='ETHIOPIC SYLLABLE NWA'
let s:d[0x1298]='ETHIOPIC SYLLABLE NYA'
let s:d[0x1299]='ETHIOPIC SYLLABLE NYU'
let s:d[0x129A]='ETHIOPIC SYLLABLE NYI'
let s:d[0x129B]='ETHIOPIC SYLLABLE NYAA'
let s:d[0x129C]='ETHIOPIC SYLLABLE NYEE'
let s:d[0x129D]='ETHIOPIC SYLLABLE NYE'
let s:d[0x129E]='ETHIOPIC SYLLABLE NYO'
let s:d[0x129F]='ETHIOPIC SYLLABLE NYWA'
let s:d[0x12A0]='ETHIOPIC SYLLABLE GLOTTAL A'
let s:d[0x12A1]='ETHIOPIC SYLLABLE GLOTTAL U'
let s:d[0x12A2]='ETHIOPIC SYLLABLE GLOTTAL I'
let s:d[0x12A3]='ETHIOPIC SYLLABLE GLOTTAL AA'
let s:d[0x12A4]='ETHIOPIC SYLLABLE GLOTTAL EE'
let s:d[0x12A5]='ETHIOPIC SYLLABLE GLOTTAL E'
let s:d[0x12A6]='ETHIOPIC SYLLABLE GLOTTAL O'
let s:d[0x12A7]='ETHIOPIC SYLLABLE GLOTTAL WA'
let s:d[0x12A8]='ETHIOPIC SYLLABLE KA'
let s:d[0x12A9]='ETHIOPIC SYLLABLE KU'
let s:d[0x12AA]='ETHIOPIC SYLLABLE KI'
let s:d[0x12AB]='ETHIOPIC SYLLABLE KAA'
let s:d[0x12AC]='ETHIOPIC SYLLABLE KEE'
let s:d[0x12AD]='ETHIOPIC SYLLABLE KE'
let s:d[0x12AE]='ETHIOPIC SYLLABLE KO'
let s:d[0x12AF]='ETHIOPIC SYLLABLE KOA'
let s:d[0x12B0]='ETHIOPIC SYLLABLE KWA'
let s:d[0x12B2]='ETHIOPIC SYLLABLE KWI'
let s:d[0x12B3]='ETHIOPIC SYLLABLE KWAA'
let s:d[0x12B4]='ETHIOPIC SYLLABLE KWEE'
let s:d[0x12B5]='ETHIOPIC SYLLABLE KWE'
let s:d[0x12B8]='ETHIOPIC SYLLABLE KXA'
let s:d[0x12B9]='ETHIOPIC SYLLABLE KXU'
let s:d[0x12BA]='ETHIOPIC SYLLABLE KXI'
let s:d[0x12BB]='ETHIOPIC SYLLABLE KXAA'
let s:d[0x12BC]='ETHIOPIC SYLLABLE KXEE'
let s:d[0x12BD]='ETHIOPIC SYLLABLE KXE'
let s:d[0x12BE]='ETHIOPIC SYLLABLE KXO'
let s:d[0x12C0]='ETHIOPIC SYLLABLE KXWA'
let s:d[0x12C2]='ETHIOPIC SYLLABLE KXWI'
let s:d[0x12C3]='ETHIOPIC SYLLABLE KXWAA'
let s:d[0x12C4]='ETHIOPIC SYLLABLE KXWEE'
let s:d[0x12C5]='ETHIOPIC SYLLABLE KXWE'
let s:d[0x12C8]='ETHIOPIC SYLLABLE WA'
let s:d[0x12C9]='ETHIOPIC SYLLABLE WU'
let s:d[0x12CA]='ETHIOPIC SYLLABLE WI'
let s:d[0x12CB]='ETHIOPIC SYLLABLE WAA'
let s:d[0x12CC]='ETHIOPIC SYLLABLE WEE'
let s:d[0x12CD]='ETHIOPIC SYLLABLE WE'
let s:d[0x12CE]='ETHIOPIC SYLLABLE WO'
let s:d[0x12CF]='ETHIOPIC SYLLABLE WOA'
let s:d[0x12D0]='ETHIOPIC SYLLABLE PHARYNGEAL A'
let s:d[0x12D1]='ETHIOPIC SYLLABLE PHARYNGEAL U'
let s:d[0x12D2]='ETHIOPIC SYLLABLE PHARYNGEAL I'
let s:d[0x12D3]='ETHIOPIC SYLLABLE PHARYNGEAL AA'
let s:d[0x12D4]='ETHIOPIC SYLLABLE PHARYNGEAL EE'
let s:d[0x12D5]='ETHIOPIC SYLLABLE PHARYNGEAL E'
let s:d[0x12D6]='ETHIOPIC SYLLABLE PHARYNGEAL O'
let s:d[0x12D8]='ETHIOPIC SYLLABLE ZA'
let s:d[0x12D9]='ETHIOPIC SYLLABLE ZU'
let s:d[0x12DA]='ETHIOPIC SYLLABLE ZI'
let s:d[0x12DB]='ETHIOPIC SYLLABLE ZAA'
let s:d[0x12DC]='ETHIOPIC SYLLABLE ZEE'
let s:d[0x12DD]='ETHIOPIC SYLLABLE ZE'
let s:d[0x12DE]='ETHIOPIC SYLLABLE ZO'
let s:d[0x12DF]='ETHIOPIC SYLLABLE ZWA'
let s:d[0x12E0]='ETHIOPIC SYLLABLE ZHA'
let s:d[0x12E1]='ETHIOPIC SYLLABLE ZHU'
let s:d[0x12E2]='ETHIOPIC SYLLABLE ZHI'
let s:d[0x12E3]='ETHIOPIC SYLLABLE ZHAA'
let s:d[0x12E4]='ETHIOPIC SYLLABLE ZHEE'
let s:d[0x12E5]='ETHIOPIC SYLLABLE ZHE'
let s:d[0x12E6]='ETHIOPIC SYLLABLE ZHO'
let s:d[0x12E7]='ETHIOPIC SYLLABLE ZHWA'
let s:d[0x12E8]='ETHIOPIC SYLLABLE YA'
let s:d[0x12E9]='ETHIOPIC SYLLABLE YU'
let s:d[0x12EA]='ETHIOPIC SYLLABLE YI'
let s:d[0x12EB]='ETHIOPIC SYLLABLE YAA'
let s:d[0x12EC]='ETHIOPIC SYLLABLE YEE'
let s:d[0x12ED]='ETHIOPIC SYLLABLE YE'
let s:d[0x12EE]='ETHIOPIC SYLLABLE YO'
let s:d[0x12EF]='ETHIOPIC SYLLABLE YOA'
let s:d[0x12F0]='ETHIOPIC SYLLABLE DA'
let s:d[0x12F1]='ETHIOPIC SYLLABLE DU'
let s:d[0x12F2]='ETHIOPIC SYLLABLE DI'
let s:d[0x12F3]='ETHIOPIC SYLLABLE DAA'
let s:d[0x12F4]='ETHIOPIC SYLLABLE DEE'
let s:d[0x12F5]='ETHIOPIC SYLLABLE DE'
let s:d[0x12F6]='ETHIOPIC SYLLABLE DO'
let s:d[0x12F7]='ETHIOPIC SYLLABLE DWA'
let s:d[0x12F8]='ETHIOPIC SYLLABLE DDA'
let s:d[0x12F9]='ETHIOPIC SYLLABLE DDU'
let s:d[0x12FA]='ETHIOPIC SYLLABLE DDI'
let s:d[0x12FB]='ETHIOPIC SYLLABLE DDAA'
let s:d[0x12FC]='ETHIOPIC SYLLABLE DDEE'
let s:d[0x12FD]='ETHIOPIC SYLLABLE DDE'
let s:d[0x12FE]='ETHIOPIC SYLLABLE DDO'
let s:d[0x12FF]='ETHIOPIC SYLLABLE DDWA'
let s:d[0x1300]='ETHIOPIC SYLLABLE JA'
let s:d[0x1301]='ETHIOPIC SYLLABLE JU'
let s:d[0x1302]='ETHIOPIC SYLLABLE JI'
let s:d[0x1303]='ETHIOPIC SYLLABLE JAA'
let s:d[0x1304]='ETHIOPIC SYLLABLE JEE'
let s:d[0x1305]='ETHIOPIC SYLLABLE JE'
let s:d[0x1306]='ETHIOPIC SYLLABLE JO'
let s:d[0x1307]='ETHIOPIC SYLLABLE JWA'
let s:d[0x1308]='ETHIOPIC SYLLABLE GA'
let s:d[0x1309]='ETHIOPIC SYLLABLE GU'
let s:d[0x130A]='ETHIOPIC SYLLABLE GI'
let s:d[0x130B]='ETHIOPIC SYLLABLE GAA'
let s:d[0x130C]='ETHIOPIC SYLLABLE GEE'
let s:d[0x130D]='ETHIOPIC SYLLABLE GE'
let s:d[0x130E]='ETHIOPIC SYLLABLE GO'
let s:d[0x130F]='ETHIOPIC SYLLABLE GOA'
let s:d[0x1310]='ETHIOPIC SYLLABLE GWA'
let s:d[0x1312]='ETHIOPIC SYLLABLE GWI'
let s:d[0x1313]='ETHIOPIC SYLLABLE GWAA'
let s:d[0x1314]='ETHIOPIC SYLLABLE GWEE'
let s:d[0x1315]='ETHIOPIC SYLLABLE GWE'
let s:d[0x1318]='ETHIOPIC SYLLABLE GGA'
let s:d[0x1319]='ETHIOPIC SYLLABLE GGU'
let s:d[0x131A]='ETHIOPIC SYLLABLE GGI'
let s:d[0x131B]='ETHIOPIC SYLLABLE GGAA'
let s:d[0x131C]='ETHIOPIC SYLLABLE GGEE'
let s:d[0x131D]='ETHIOPIC SYLLABLE GGE'
let s:d[0x131E]='ETHIOPIC SYLLABLE GGO'
let s:d[0x131F]='ETHIOPIC SYLLABLE GGWAA'
let s:d[0x1320]='ETHIOPIC SYLLABLE THA'
let s:d[0x1321]='ETHIOPIC SYLLABLE THU'
let s:d[0x1322]='ETHIOPIC SYLLABLE THI'
let s:d[0x1323]='ETHIOPIC SYLLABLE THAA'
let s:d[0x1324]='ETHIOPIC SYLLABLE THEE'
let s:d[0x1325]='ETHIOPIC SYLLABLE THE'
let s:d[0x1326]='ETHIOPIC SYLLABLE THO'
let s:d[0x1327]='ETHIOPIC SYLLABLE THWA'
let s:d[0x1328]='ETHIOPIC SYLLABLE CHA'
let s:d[0x1329]='ETHIOPIC SYLLABLE CHU'
let s:d[0x132A]='ETHIOPIC SYLLABLE CHI'
let s:d[0x132B]='ETHIOPIC SYLLABLE CHAA'
let s:d[0x132C]='ETHIOPIC SYLLABLE CHEE'
let s:d[0x132D]='ETHIOPIC SYLLABLE CHE'
let s:d[0x132E]='ETHIOPIC SYLLABLE CHO'
let s:d[0x132F]='ETHIOPIC SYLLABLE CHWA'
let s:d[0x1330]='ETHIOPIC SYLLABLE PHA'
let s:d[0x1331]='ETHIOPIC SYLLABLE PHU'
let s:d[0x1332]='ETHIOPIC SYLLABLE PHI'
let s:d[0x1333]='ETHIOPIC SYLLABLE PHAA'
let s:d[0x1334]='ETHIOPIC SYLLABLE PHEE'
let s:d[0x1335]='ETHIOPIC SYLLABLE PHE'
let s:d[0x1336]='ETHIOPIC SYLLABLE PHO'
let s:d[0x1337]='ETHIOPIC SYLLABLE PHWA'
let s:d[0x1338]='ETHIOPIC SYLLABLE TSA'
let s:d[0x1339]='ETHIOPIC SYLLABLE TSU'
let s:d[0x133A]='ETHIOPIC SYLLABLE TSI'
let s:d[0x133B]='ETHIOPIC SYLLABLE TSAA'
let s:d[0x133C]='ETHIOPIC SYLLABLE TSEE'
let s:d[0x133D]='ETHIOPIC SYLLABLE TSE'
let s:d[0x133E]='ETHIOPIC SYLLABLE TSO'
let s:d[0x133F]='ETHIOPIC SYLLABLE TSWA'
let s:d[0x1340]='ETHIOPIC SYLLABLE TZA'
let s:d[0x1341]='ETHIOPIC SYLLABLE TZU'
let s:d[0x1342]='ETHIOPIC SYLLABLE TZI'
let s:d[0x1343]='ETHIOPIC SYLLABLE TZAA'
let s:d[0x1344]='ETHIOPIC SYLLABLE TZEE'
let s:d[0x1345]='ETHIOPIC SYLLABLE TZE'
let s:d[0x1346]='ETHIOPIC SYLLABLE TZO'
let s:d[0x1347]='ETHIOPIC SYLLABLE TZOA'
let s:d[0x1348]='ETHIOPIC SYLLABLE FA'
let s:d[0x1349]='ETHIOPIC SYLLABLE FU'
let s:d[0x134A]='ETHIOPIC SYLLABLE FI'
let s:d[0x134B]='ETHIOPIC SYLLABLE FAA'
let s:d[0x134C]='ETHIOPIC SYLLABLE FEE'
let s:d[0x134D]='ETHIOPIC SYLLABLE FE'
let s:d[0x134E]='ETHIOPIC SYLLABLE FO'
let s:d[0x134F]='ETHIOPIC SYLLABLE FWA'
let s:d[0x1350]='ETHIOPIC SYLLABLE PA'
let s:d[0x1351]='ETHIOPIC SYLLABLE PU'
let s:d[0x1352]='ETHIOPIC SYLLABLE PI'
let s:d[0x1353]='ETHIOPIC SYLLABLE PAA'
let s:d[0x1354]='ETHIOPIC SYLLABLE PEE'
let s:d[0x1355]='ETHIOPIC SYLLABLE PE'
let s:d[0x1356]='ETHIOPIC SYLLABLE PO'
let s:d[0x1357]='ETHIOPIC SYLLABLE PWA'
let s:d[0x1358]='ETHIOPIC SYLLABLE RYA'
let s:d[0x1359]='ETHIOPIC SYLLABLE MYA'
let s:d[0x135A]='ETHIOPIC SYLLABLE FYA'
let s:d[0x135D]='ETHIOPIC COMBINING GEMINATION AND VOWEL LENGTH MARK'
let s:d[0x135E]='ETHIOPIC COMBINING VOWEL LENGTH MARK'
let s:d[0x135F]='ETHIOPIC COMBINING GEMINATION MARK'
let s:d[0x1360]='ETHIOPIC SECTION MARK'
let s:d[0x1361]='ETHIOPIC WORDSPACE'
let s:d[0x1362]='ETHIOPIC FULL STOP'
let s:d[0x1363]='ETHIOPIC COMMA'
let s:d[0x1364]='ETHIOPIC SEMICOLON'
let s:d[0x1365]='ETHIOPIC COLON'
let s:d[0x1366]='ETHIOPIC PREFACE COLON'
let s:d[0x1367]='ETHIOPIC QUESTION MARK'
let s:d[0x1368]='ETHIOPIC PARAGRAPH SEPARATOR'
let s:d[0x1369]='ETHIOPIC DIGIT ONE'
let s:d[0x136A]='ETHIOPIC DIGIT TWO'
let s:d[0x136B]='ETHIOPIC DIGIT THREE'
let s:d[0x136C]='ETHIOPIC DIGIT FOUR'
let s:d[0x136D]='ETHIOPIC DIGIT FIVE'
let s:d[0x136E]='ETHIOPIC DIGIT SIX'
let s:d[0x136F]='ETHIOPIC DIGIT SEVEN'
let s:d[0x1370]='ETHIOPIC DIGIT EIGHT'
let s:d[0x1371]='ETHIOPIC DIGIT NINE'
let s:d[0x1372]='ETHIOPIC NUMBER TEN'
let s:d[0x1373]='ETHIOPIC NUMBER TWENTY'
let s:d[0x1374]='ETHIOPIC NUMBER THIRTY'
let s:d[0x1375]='ETHIOPIC NUMBER FORTY'
let s:d[0x1376]='ETHIOPIC NUMBER FIFTY'
let s:d[0x1377]='ETHIOPIC NUMBER SIXTY'
let s:d[0x1378]='ETHIOPIC NUMBER SEVENTY'
let s:d[0x1379]='ETHIOPIC NUMBER EIGHTY'
let s:d[0x137A]='ETHIOPIC NUMBER NINETY'
let s:d[0x137B]='ETHIOPIC NUMBER HUNDRED'
let s:d[0x137C]='ETHIOPIC NUMBER TEN THOUSAND'
let s:d[0x1380]='ETHIOPIC SYLLABLE SEBATBEIT MWA'
let s:d[0x1381]='ETHIOPIC SYLLABLE MWI'
let s:d[0x1382]='ETHIOPIC SYLLABLE MWEE'
let s:d[0x1383]='ETHIOPIC SYLLABLE MWE'
let s:d[0x1384]='ETHIOPIC SYLLABLE SEBATBEIT BWA'
let s:d[0x1385]='ETHIOPIC SYLLABLE BWI'
let s:d[0x1386]='ETHIOPIC SYLLABLE BWEE'
let s:d[0x1387]='ETHIOPIC SYLLABLE BWE'
let s:d[0x1388]='ETHIOPIC SYLLABLE SEBATBEIT FWA'
let s:d[0x1389]='ETHIOPIC SYLLABLE FWI'
let s:d[0x138A]='ETHIOPIC SYLLABLE FWEE'
let s:d[0x138B]='ETHIOPIC SYLLABLE FWE'
let s:d[0x138C]='ETHIOPIC SYLLABLE SEBATBEIT PWA'
let s:d[0x138D]='ETHIOPIC SYLLABLE PWI'
let s:d[0x138E]='ETHIOPIC SYLLABLE PWEE'
let s:d[0x138F]='ETHIOPIC SYLLABLE PWE'
let s:d[0x1390]='ETHIOPIC TONAL MARK YIZET'
let s:d[0x1391]='ETHIOPIC TONAL MARK DERET'
let s:d[0x1392]='ETHIOPIC TONAL MARK RIKRIK'
let s:d[0x1393]='ETHIOPIC TONAL MARK SHORT RIKRIK'
let s:d[0x1394]='ETHIOPIC TONAL MARK DIFAT'
let s:d[0x1395]='ETHIOPIC TONAL MARK KENAT'
let s:d[0x1396]='ETHIOPIC TONAL MARK CHIRET'
let s:d[0x1397]='ETHIOPIC TONAL MARK HIDET'
let s:d[0x1398]='ETHIOPIC TONAL MARK DERET-HIDET'
let s:d[0x1399]='ETHIOPIC TONAL MARK KURT'
let s:d[0x13A0]='CHEROKEE LETTER A'
let s:d[0x13A1]='CHEROKEE LETTER E'
let s:d[0x13A2]='CHEROKEE LETTER I'
let s:d[0x13A3]='CHEROKEE LETTER O'
let s:d[0x13A4]='CHEROKEE LETTER U'
let s:d[0x13A5]='CHEROKEE LETTER V'
let s:d[0x13A6]='CHEROKEE LETTER GA'
let s:d[0x13A7]='CHEROKEE LETTER KA'
let s:d[0x13A8]='CHEROKEE LETTER GE'
let s:d[0x13A9]='CHEROKEE LETTER GI'
let s:d[0x13AA]='CHEROKEE LETTER GO'
let s:d[0x13AB]='CHEROKEE LETTER GU'
let s:d[0x13AC]='CHEROKEE LETTER GV'
let s:d[0x13AD]='CHEROKEE LETTER HA'
let s:d[0x13AE]='CHEROKEE LETTER HE'
let s:d[0x13AF]='CHEROKEE LETTER HI'
let s:d[0x13B0]='CHEROKEE LETTER HO'
let s:d[0x13B1]='CHEROKEE LETTER HU'
let s:d[0x13B2]='CHEROKEE LETTER HV'
let s:d[0x13B3]='CHEROKEE LETTER LA'
let s:d[0x13B4]='CHEROKEE LETTER LE'
let s:d[0x13B5]='CHEROKEE LETTER LI'
let s:d[0x13B6]='CHEROKEE LETTER LO'
let s:d[0x13B7]='CHEROKEE LETTER LU'
let s:d[0x13B8]='CHEROKEE LETTER LV'
let s:d[0x13B9]='CHEROKEE LETTER MA'
let s:d[0x13BA]='CHEROKEE LETTER ME'
let s:d[0x13BB]='CHEROKEE LETTER MI'
let s:d[0x13BC]='CHEROKEE LETTER MO'
let s:d[0x13BD]='CHEROKEE LETTER MU'
let s:d[0x13BE]='CHEROKEE LETTER NA'
let s:d[0x13BF]='CHEROKEE LETTER HNA'
let s:d[0x13C0]='CHEROKEE LETTER NAH'
let s:d[0x13C1]='CHEROKEE LETTER NE'
let s:d[0x13C2]='CHEROKEE LETTER NI'
let s:d[0x13C3]='CHEROKEE LETTER NO'
let s:d[0x13C4]='CHEROKEE LETTER NU'
let s:d[0x13C5]='CHEROKEE LETTER NV'
let s:d[0x13C6]='CHEROKEE LETTER QUA'
let s:d[0x13C7]='CHEROKEE LETTER QUE'
let s:d[0x13C8]='CHEROKEE LETTER QUI'
let s:d[0x13C9]='CHEROKEE LETTER QUO'
let s:d[0x13CA]='CHEROKEE LETTER QUU'
let s:d[0x13CB]='CHEROKEE LETTER QUV'
let s:d[0x13CC]='CHEROKEE LETTER SA'
let s:d[0x13CD]='CHEROKEE LETTER S'
let s:d[0x13CE]='CHEROKEE LETTER SE'
let s:d[0x13CF]='CHEROKEE LETTER SI'
let s:d[0x13D0]='CHEROKEE LETTER SO'
let s:d[0x13D1]='CHEROKEE LETTER SU'
let s:d[0x13D2]='CHEROKEE LETTER SV'
let s:d[0x13D3]='CHEROKEE LETTER DA'
let s:d[0x13D4]='CHEROKEE LETTER TA'
let s:d[0x13D5]='CHEROKEE LETTER DE'
let s:d[0x13D6]='CHEROKEE LETTER TE'
let s:d[0x13D7]='CHEROKEE LETTER DI'
let s:d[0x13D8]='CHEROKEE LETTER TI'
let s:d[0x13D9]='CHEROKEE LETTER DO'
let s:d[0x13DA]='CHEROKEE LETTER DU'
let s:d[0x13DB]='CHEROKEE LETTER DV'
let s:d[0x13DC]='CHEROKEE LETTER DLA'
let s:d[0x13DD]='CHEROKEE LETTER TLA'
let s:d[0x13DE]='CHEROKEE LETTER TLE'
let s:d[0x13DF]='CHEROKEE LETTER TLI'
let s:d[0x13E0]='CHEROKEE LETTER TLO'
let s:d[0x13E1]='CHEROKEE LETTER TLU'
let s:d[0x13E2]='CHEROKEE LETTER TLV'
let s:d[0x13E3]='CHEROKEE LETTER TSA'
let s:d[0x13E4]='CHEROKEE LETTER TSE'
let s:d[0x13E5]='CHEROKEE LETTER TSI'
let s:d[0x13E6]='CHEROKEE LETTER TSO'
let s:d[0x13E7]='CHEROKEE LETTER TSU'
let s:d[0x13E8]='CHEROKEE LETTER TSV'
let s:d[0x13E9]='CHEROKEE LETTER WA'
let s:d[0x13EA]='CHEROKEE LETTER WE'
let s:d[0x13EB]='CHEROKEE LETTER WI'
let s:d[0x13EC]='CHEROKEE LETTER WO'
let s:d[0x13ED]='CHEROKEE LETTER WU'
let s:d[0x13EE]='CHEROKEE LETTER WV'
let s:d[0x13EF]='CHEROKEE LETTER YA'
let s:d[0x13F0]='CHEROKEE LETTER YE'
let s:d[0x13F1]='CHEROKEE LETTER YI'
let s:d[0x13F2]='CHEROKEE LETTER YO'
let s:d[0x13F3]='CHEROKEE LETTER YU'
let s:d[0x13F4]='CHEROKEE LETTER YV'
let s:d[0x1400]='CANADIAN SYLLABICS HYPHEN'
let s:d[0x1401]='CANADIAN SYLLABICS E'
let s:d[0x1402]='CANADIAN SYLLABICS AAI'
let s:d[0x1403]='CANADIAN SYLLABICS I'
let s:d[0x1404]='CANADIAN SYLLABICS II'
let s:d[0x1405]='CANADIAN SYLLABICS O'
let s:d[0x1406]='CANADIAN SYLLABICS OO'
let s:d[0x1407]='CANADIAN SYLLABICS Y-CREE OO'
let s:d[0x1408]='CANADIAN SYLLABICS CARRIER EE'
let s:d[0x1409]='CANADIAN SYLLABICS CARRIER I'
let s:d[0x140A]='CANADIAN SYLLABICS A'
let s:d[0x140B]='CANADIAN SYLLABICS AA'
let s:d[0x140C]='CANADIAN SYLLABICS WE'
let s:d[0x140D]='CANADIAN SYLLABICS WEST-CREE WE'
let s:d[0x140E]='CANADIAN SYLLABICS WI'
let s:d[0x140F]='CANADIAN SYLLABICS WEST-CREE WI'
let s:d[0x1410]='CANADIAN SYLLABICS WII'
let s:d[0x1411]='CANADIAN SYLLABICS WEST-CREE WII'
let s:d[0x1412]='CANADIAN SYLLABICS WO'
let s:d[0x1413]='CANADIAN SYLLABICS WEST-CREE WO'
let s:d[0x1414]='CANADIAN SYLLABICS WOO'
let s:d[0x1415]='CANADIAN SYLLABICS WEST-CREE WOO'
let s:d[0x1416]='CANADIAN SYLLABICS NASKAPI WOO'
let s:d[0x1417]='CANADIAN SYLLABICS WA'
let s:d[0x1418]='CANADIAN SYLLABICS WEST-CREE WA'
let s:d[0x1419]='CANADIAN SYLLABICS WAA'
let s:d[0x141A]='CANADIAN SYLLABICS WEST-CREE WAA'
let s:d[0x141B]='CANADIAN SYLLABICS NASKAPI WAA'
let s:d[0x141C]='CANADIAN SYLLABICS AI'
let s:d[0x141D]='CANADIAN SYLLABICS Y-CREE W'
let s:d[0x141E]='CANADIAN SYLLABICS GLOTTAL STOP'
let s:d[0x141F]='CANADIAN SYLLABICS FINAL ACUTE'
let s:d[0x1420]='CANADIAN SYLLABICS FINAL GRAVE'
let s:d[0x1421]='CANADIAN SYLLABICS FINAL BOTTOM HALF RING'
let s:d[0x1422]='CANADIAN SYLLABICS FINAL TOP HALF RING'
let s:d[0x1423]='CANADIAN SYLLABICS FINAL RIGHT HALF RING'
let s:d[0x1424]='CANADIAN SYLLABICS FINAL RING'
let s:d[0x1425]='CANADIAN SYLLABICS FINAL DOUBLE ACUTE'
let s:d[0x1426]='CANADIAN SYLLABICS FINAL DOUBLE SHORT VERTICAL STROKES'
let s:d[0x1427]='CANADIAN SYLLABICS FINAL MIDDLE DOT'
let s:d[0x1428]='CANADIAN SYLLABICS FINAL SHORT HORIZONTAL STROKE'
let s:d[0x1429]='CANADIAN SYLLABICS FINAL PLUS'
let s:d[0x142A]='CANADIAN SYLLABICS FINAL DOWN TACK'
let s:d[0x142B]='CANADIAN SYLLABICS EN'
let s:d[0x142C]='CANADIAN SYLLABICS IN'
let s:d[0x142D]='CANADIAN SYLLABICS ON'
let s:d[0x142E]='CANADIAN SYLLABICS AN'
let s:d[0x142F]='CANADIAN SYLLABICS PE'
let s:d[0x1430]='CANADIAN SYLLABICS PAAI'
let s:d[0x1431]='CANADIAN SYLLABICS PI'
let s:d[0x1432]='CANADIAN SYLLABICS PII'
let s:d[0x1433]='CANADIAN SYLLABICS PO'
let s:d[0x1434]='CANADIAN SYLLABICS POO'
let s:d[0x1435]='CANADIAN SYLLABICS Y-CREE POO'
let s:d[0x1436]='CANADIAN SYLLABICS CARRIER HEE'
let s:d[0x1437]='CANADIAN SYLLABICS CARRIER HI'
let s:d[0x1438]='CANADIAN SYLLABICS PA'
let s:d[0x1439]='CANADIAN SYLLABICS PAA'
let s:d[0x143A]='CANADIAN SYLLABICS PWE'
let s:d[0x143B]='CANADIAN SYLLABICS WEST-CREE PWE'
let s:d[0x143C]='CANADIAN SYLLABICS PWI'
let s:d[0x143D]='CANADIAN SYLLABICS WEST-CREE PWI'
let s:d[0x143E]='CANADIAN SYLLABICS PWII'
let s:d[0x143F]='CANADIAN SYLLABICS WEST-CREE PWII'
let s:d[0x1440]='CANADIAN SYLLABICS PWO'
let s:d[0x1441]='CANADIAN SYLLABICS WEST-CREE PWO'
let s:d[0x1442]='CANADIAN SYLLABICS PWOO'
let s:d[0x1443]='CANADIAN SYLLABICS WEST-CREE PWOO'
let s:d[0x1444]='CANADIAN SYLLABICS PWA'
let s:d[0x1445]='CANADIAN SYLLABICS WEST-CREE PWA'
let s:d[0x1446]='CANADIAN SYLLABICS PWAA'
let s:d[0x1447]='CANADIAN SYLLABICS WEST-CREE PWAA'
let s:d[0x1448]='CANADIAN SYLLABICS Y-CREE PWAA'
let s:d[0x1449]='CANADIAN SYLLABICS P'
let s:d[0x144A]='CANADIAN SYLLABICS WEST-CREE P'
let s:d[0x144B]='CANADIAN SYLLABICS CARRIER H'
let s:d[0x144C]='CANADIAN SYLLABICS TE'
let s:d[0x144D]='CANADIAN SYLLABICS TAAI'
let s:d[0x144E]='CANADIAN SYLLABICS TI'
let s:d[0x144F]='CANADIAN SYLLABICS TII'
let s:d[0x1450]='CANADIAN SYLLABICS TO'
let s:d[0x1451]='CANADIAN SYLLABICS TOO'
let s:d[0x1452]='CANADIAN SYLLABICS Y-CREE TOO'
let s:d[0x1453]='CANADIAN SYLLABICS CARRIER DEE'
let s:d[0x1454]='CANADIAN SYLLABICS CARRIER DI'
let s:d[0x1455]='CANADIAN SYLLABICS TA'
let s:d[0x1456]='CANADIAN SYLLABICS TAA'
let s:d[0x1457]='CANADIAN SYLLABICS TWE'
let s:d[0x1458]='CANADIAN SYLLABICS WEST-CREE TWE'
let s:d[0x1459]='CANADIAN SYLLABICS TWI'
let s:d[0x145A]='CANADIAN SYLLABICS WEST-CREE TWI'
let s:d[0x145B]='CANADIAN SYLLABICS TWII'
let s:d[0x145C]='CANADIAN SYLLABICS WEST-CREE TWII'
let s:d[0x145D]='CANADIAN SYLLABICS TWO'
let s:d[0x145E]='CANADIAN SYLLABICS WEST-CREE TWO'
let s:d[0x145F]='CANADIAN SYLLABICS TWOO'
let s:d[0x1460]='CANADIAN SYLLABICS WEST-CREE TWOO'
let s:d[0x1461]='CANADIAN SYLLABICS TWA'
let s:d[0x1462]='CANADIAN SYLLABICS WEST-CREE TWA'
let s:d[0x1463]='CANADIAN SYLLABICS TWAA'
let s:d[0x1464]='CANADIAN SYLLABICS WEST-CREE TWAA'
let s:d[0x1465]='CANADIAN SYLLABICS NASKAPI TWAA'
let s:d[0x1466]='CANADIAN SYLLABICS T'
let s:d[0x1467]='CANADIAN SYLLABICS TTE'
let s:d[0x1468]='CANADIAN SYLLABICS TTI'
let s:d[0x1469]='CANADIAN SYLLABICS TTO'
let s:d[0x146A]='CANADIAN SYLLABICS TTA'
let s:d[0x146B]='CANADIAN SYLLABICS KE'
let s:d[0x146C]='CANADIAN SYLLABICS KAAI'
let s:d[0x146D]='CANADIAN SYLLABICS KI'
let s:d[0x146E]='CANADIAN SYLLABICS KII'
let s:d[0x146F]='CANADIAN SYLLABICS KO'
let s:d[0x1470]='CANADIAN SYLLABICS KOO'
let s:d[0x1471]='CANADIAN SYLLABICS Y-CREE KOO'
let s:d[0x1472]='CANADIAN SYLLABICS KA'
let s:d[0x1473]='CANADIAN SYLLABICS KAA'
let s:d[0x1474]='CANADIAN SYLLABICS KWE'
let s:d[0x1475]='CANADIAN SYLLABICS WEST-CREE KWE'
let s:d[0x1476]='CANADIAN SYLLABICS KWI'
let s:d[0x1477]='CANADIAN SYLLABICS WEST-CREE KWI'
let s:d[0x1478]='CANADIAN SYLLABICS KWII'
let s:d[0x1479]='CANADIAN SYLLABICS WEST-CREE KWII'
let s:d[0x147A]='CANADIAN SYLLABICS KWO'
let s:d[0x147B]='CANADIAN SYLLABICS WEST-CREE KWO'
let s:d[0x147C]='CANADIAN SYLLABICS KWOO'
let s:d[0x147D]='CANADIAN SYLLABICS WEST-CREE KWOO'
let s:d[0x147E]='CANADIAN SYLLABICS KWA'
let s:d[0x147F]='CANADIAN SYLLABICS WEST-CREE KWA'
let s:d[0x1480]='CANADIAN SYLLABICS KWAA'
let s:d[0x1481]='CANADIAN SYLLABICS WEST-CREE KWAA'
let s:d[0x1482]='CANADIAN SYLLABICS NASKAPI KWAA'
let s:d[0x1483]='CANADIAN SYLLABICS K'
let s:d[0x1484]='CANADIAN SYLLABICS KW'
let s:d[0x1485]='CANADIAN SYLLABICS SOUTH-SLAVEY KEH'
let s:d[0x1486]='CANADIAN SYLLABICS SOUTH-SLAVEY KIH'
let s:d[0x1487]='CANADIAN SYLLABICS SOUTH-SLAVEY KOH'
let s:d[0x1488]='CANADIAN SYLLABICS SOUTH-SLAVEY KAH'
let s:d[0x1489]='CANADIAN SYLLABICS CE'
let s:d[0x148A]='CANADIAN SYLLABICS CAAI'
let s:d[0x148B]='CANADIAN SYLLABICS CI'
let s:d[0x148C]='CANADIAN SYLLABICS CII'
let s:d[0x148D]='CANADIAN SYLLABICS CO'
let s:d[0x148E]='CANADIAN SYLLABICS COO'
let s:d[0x148F]='CANADIAN SYLLABICS Y-CREE COO'
let s:d[0x1490]='CANADIAN SYLLABICS CA'
let s:d[0x1491]='CANADIAN SYLLABICS CAA'
let s:d[0x1492]='CANADIAN SYLLABICS CWE'
let s:d[0x1493]='CANADIAN SYLLABICS WEST-CREE CWE'
let s:d[0x1494]='CANADIAN SYLLABICS CWI'
let s:d[0x1495]='CANADIAN SYLLABICS WEST-CREE CWI'
let s:d[0x1496]='CANADIAN SYLLABICS CWII'
let s:d[0x1497]='CANADIAN SYLLABICS WEST-CREE CWII'
let s:d[0x1498]='CANADIAN SYLLABICS CWO'
let s:d[0x1499]='CANADIAN SYLLABICS WEST-CREE CWO'
let s:d[0x149A]='CANADIAN SYLLABICS CWOO'
let s:d[0x149B]='CANADIAN SYLLABICS WEST-CREE CWOO'
let s:d[0x149C]='CANADIAN SYLLABICS CWA'
let s:d[0x149D]='CANADIAN SYLLABICS WEST-CREE CWA'
let s:d[0x149E]='CANADIAN SYLLABICS CWAA'
let s:d[0x149F]='CANADIAN SYLLABICS WEST-CREE CWAA'
let s:d[0x14A0]='CANADIAN SYLLABICS NASKAPI CWAA'
let s:d[0x14A1]='CANADIAN SYLLABICS C'
let s:d[0x14A2]='CANADIAN SYLLABICS SAYISI TH'
let s:d[0x14A3]='CANADIAN SYLLABICS ME'
let s:d[0x14A4]='CANADIAN SYLLABICS MAAI'
let s:d[0x14A5]='CANADIAN SYLLABICS MI'
let s:d[0x14A6]='CANADIAN SYLLABICS MII'
let s:d[0x14A7]='CANADIAN SYLLABICS MO'
let s:d[0x14A8]='CANADIAN SYLLABICS MOO'
let s:d[0x14A9]='CANADIAN SYLLABICS Y-CREE MOO'
let s:d[0x14AA]='CANADIAN SYLLABICS MA'
let s:d[0x14AB]='CANADIAN SYLLABICS MAA'
let s:d[0x14AC]='CANADIAN SYLLABICS MWE'
let s:d[0x14AD]='CANADIAN SYLLABICS WEST-CREE MWE'
let s:d[0x14AE]='CANADIAN SYLLABICS MWI'
let s:d[0x14AF]='CANADIAN SYLLABICS WEST-CREE MWI'
let s:d[0x14B0]='CANADIAN SYLLABICS MWII'
let s:d[0x14B1]='CANADIAN SYLLABICS WEST-CREE MWII'
let s:d[0x14B2]='CANADIAN SYLLABICS MWO'
let s:d[0x14B3]='CANADIAN SYLLABICS WEST-CREE MWO'
let s:d[0x14B4]='CANADIAN SYLLABICS MWOO'
let s:d[0x14B5]='CANADIAN SYLLABICS WEST-CREE MWOO'
let s:d[0x14B6]='CANADIAN SYLLABICS MWA'
let s:d[0x14B7]='CANADIAN SYLLABICS WEST-CREE MWA'
let s:d[0x14B8]='CANADIAN SYLLABICS MWAA'
let s:d[0x14B9]='CANADIAN SYLLABICS WEST-CREE MWAA'
let s:d[0x14BA]='CANADIAN SYLLABICS NASKAPI MWAA'
let s:d[0x14BB]='CANADIAN SYLLABICS M'
let s:d[0x14BC]='CANADIAN SYLLABICS WEST-CREE M'
let s:d[0x14BD]='CANADIAN SYLLABICS MH'
let s:d[0x14BE]='CANADIAN SYLLABICS ATHAPASCAN M'
let s:d[0x14BF]='CANADIAN SYLLABICS SAYISI M'
let s:d[0x14C0]='CANADIAN SYLLABICS NE'
let s:d[0x14C1]='CANADIAN SYLLABICS NAAI'
let s:d[0x14C2]='CANADIAN SYLLABICS NI'
let s:d[0x14C3]='CANADIAN SYLLABICS NII'
let s:d[0x14C4]='CANADIAN SYLLABICS NO'
let s:d[0x14C5]='CANADIAN SYLLABICS NOO'
let s:d[0x14C6]='CANADIAN SYLLABICS Y-CREE NOO'
let s:d[0x14C7]='CANADIAN SYLLABICS NA'
let s:d[0x14C8]='CANADIAN SYLLABICS NAA'
let s:d[0x14C9]='CANADIAN SYLLABICS NWE'
let s:d[0x14CA]='CANADIAN SYLLABICS WEST-CREE NWE'
let s:d[0x14CB]='CANADIAN SYLLABICS NWA'
let s:d[0x14CC]='CANADIAN SYLLABICS WEST-CREE NWA'
let s:d[0x14CD]='CANADIAN SYLLABICS NWAA'
let s:d[0x14CE]='CANADIAN SYLLABICS WEST-CREE NWAA'
let s:d[0x14CF]='CANADIAN SYLLABICS NASKAPI NWAA'
let s:d[0x14D0]='CANADIAN SYLLABICS N'
let s:d[0x14D1]='CANADIAN SYLLABICS CARRIER NG'
let s:d[0x14D2]='CANADIAN SYLLABICS NH'
let s:d[0x14D3]='CANADIAN SYLLABICS LE'
let s:d[0x14D4]='CANADIAN SYLLABICS LAAI'
let s:d[0x14D5]='CANADIAN SYLLABICS LI'
let s:d[0x14D6]='CANADIAN SYLLABICS LII'
let s:d[0x14D7]='CANADIAN SYLLABICS LO'
let s:d[0x14D8]='CANADIAN SYLLABICS LOO'
let s:d[0x14D9]='CANADIAN SYLLABICS Y-CREE LOO'
let s:d[0x14DA]='CANADIAN SYLLABICS LA'
let s:d[0x14DB]='CANADIAN SYLLABICS LAA'
let s:d[0x14DC]='CANADIAN SYLLABICS LWE'
let s:d[0x14DD]='CANADIAN SYLLABICS WEST-CREE LWE'
let s:d[0x14DE]='CANADIAN SYLLABICS LWI'
let s:d[0x14DF]='CANADIAN SYLLABICS WEST-CREE LWI'
let s:d[0x14E0]='CANADIAN SYLLABICS LWII'
let s:d[0x14E1]='CANADIAN SYLLABICS WEST-CREE LWII'
let s:d[0x14E2]='CANADIAN SYLLABICS LWO'
let s:d[0x14E3]='CANADIAN SYLLABICS WEST-CREE LWO'
let s:d[0x14E4]='CANADIAN SYLLABICS LWOO'
let s:d[0x14E5]='CANADIAN SYLLABICS WEST-CREE LWOO'
let s:d[0x14E6]='CANADIAN SYLLABICS LWA'
let s:d[0x14E7]='CANADIAN SYLLABICS WEST-CREE LWA'
let s:d[0x14E8]='CANADIAN SYLLABICS LWAA'
let s:d[0x14E9]='CANADIAN SYLLABICS WEST-CREE LWAA'
let s:d[0x14EA]='CANADIAN SYLLABICS L'
let s:d[0x14EB]='CANADIAN SYLLABICS WEST-CREE L'
let s:d[0x14EC]='CANADIAN SYLLABICS MEDIAL L'
let s:d[0x14ED]='CANADIAN SYLLABICS SE'
let s:d[0x14EE]='CANADIAN SYLLABICS SAAI'
let s:d[0x14EF]='CANADIAN SYLLABICS SI'
let s:d[0x14F0]='CANADIAN SYLLABICS SII'
let s:d[0x14F1]='CANADIAN SYLLABICS SO'
let s:d[0x14F2]='CANADIAN SYLLABICS SOO'
let s:d[0x14F3]='CANADIAN SYLLABICS Y-CREE SOO'
let s:d[0x14F4]='CANADIAN SYLLABICS SA'
let s:d[0x14F5]='CANADIAN SYLLABICS SAA'
let s:d[0x14F6]='CANADIAN SYLLABICS SWE'
let s:d[0x14F7]='CANADIAN SYLLABICS WEST-CREE SWE'
let s:d[0x14F8]='CANADIAN SYLLABICS SWI'
let s:d[0x14F9]='CANADIAN SYLLABICS WEST-CREE SWI'
let s:d[0x14FA]='CANADIAN SYLLABICS SWII'
let s:d[0x14FB]='CANADIAN SYLLABICS WEST-CREE SWII'
let s:d[0x14FC]='CANADIAN SYLLABICS SWO'
let s:d[0x14FD]='CANADIAN SYLLABICS WEST-CREE SWO'
let s:d[0x14FE]='CANADIAN SYLLABICS SWOO'
let s:d[0x14FF]='CANADIAN SYLLABICS WEST-CREE SWOO'
let s:d[0x1500]='CANADIAN SYLLABICS SWA'
let s:d[0x1501]='CANADIAN SYLLABICS WEST-CREE SWA'
let s:d[0x1502]='CANADIAN SYLLABICS SWAA'
let s:d[0x1503]='CANADIAN SYLLABICS WEST-CREE SWAA'
let s:d[0x1504]='CANADIAN SYLLABICS NASKAPI SWAA'
let s:d[0x1505]='CANADIAN SYLLABICS S'
let s:d[0x1506]='CANADIAN SYLLABICS ATHAPASCAN S'
let s:d[0x1507]='CANADIAN SYLLABICS SW'
let s:d[0x1508]='CANADIAN SYLLABICS BLACKFOOT S'
let s:d[0x1509]='CANADIAN SYLLABICS MOOSE-CREE SK'
let s:d[0x150A]='CANADIAN SYLLABICS NASKAPI SKW'
let s:d[0x150B]='CANADIAN SYLLABICS NASKAPI S-W'
let s:d[0x150C]='CANADIAN SYLLABICS NASKAPI SPWA'
let s:d[0x150D]='CANADIAN SYLLABICS NASKAPI STWA'
let s:d[0x150E]='CANADIAN SYLLABICS NASKAPI SKWA'
let s:d[0x150F]='CANADIAN SYLLABICS NASKAPI SCWA'
let s:d[0x1510]='CANADIAN SYLLABICS SHE'
let s:d[0x1511]='CANADIAN SYLLABICS SHI'
let s:d[0x1512]='CANADIAN SYLLABICS SHII'
let s:d[0x1513]='CANADIAN SYLLABICS SHO'
let s:d[0x1514]='CANADIAN SYLLABICS SHOO'
let s:d[0x1515]='CANADIAN SYLLABICS SHA'
let s:d[0x1516]='CANADIAN SYLLABICS SHAA'
let s:d[0x1517]='CANADIAN SYLLABICS SHWE'
let s:d[0x1518]='CANADIAN SYLLABICS WEST-CREE SHWE'
let s:d[0x1519]='CANADIAN SYLLABICS SHWI'
let s:d[0x151A]='CANADIAN SYLLABICS WEST-CREE SHWI'
let s:d[0x151B]='CANADIAN SYLLABICS SHWII'
let s:d[0x151C]='CANADIAN SYLLABICS WEST-CREE SHWII'
let s:d[0x151D]='CANADIAN SYLLABICS SHWO'
let s:d[0x151E]='CANADIAN SYLLABICS WEST-CREE SHWO'
let s:d[0x151F]='CANADIAN SYLLABICS SHWOO'
let s:d[0x1520]='CANADIAN SYLLABICS WEST-CREE SHWOO'
let s:d[0x1521]='CANADIAN SYLLABICS SHWA'
let s:d[0x1522]='CANADIAN SYLLABICS WEST-CREE SHWA'
let s:d[0x1523]='CANADIAN SYLLABICS SHWAA'
let s:d[0x1524]='CANADIAN SYLLABICS WEST-CREE SHWAA'
let s:d[0x1525]='CANADIAN SYLLABICS SH'
let s:d[0x1526]='CANADIAN SYLLABICS YE'
let s:d[0x1527]='CANADIAN SYLLABICS YAAI'
let s:d[0x1528]='CANADIAN SYLLABICS YI'
let s:d[0x1529]='CANADIAN SYLLABICS YII'
let s:d[0x152A]='CANADIAN SYLLABICS YO'
let s:d[0x152B]='CANADIAN SYLLABICS YOO'
let s:d[0x152C]='CANADIAN SYLLABICS Y-CREE YOO'
let s:d[0x152D]='CANADIAN SYLLABICS YA'
let s:d[0x152E]='CANADIAN SYLLABICS YAA'
let s:d[0x152F]='CANADIAN SYLLABICS YWE'
let s:d[0x1530]='CANADIAN SYLLABICS WEST-CREE YWE'
let s:d[0x1531]='CANADIAN SYLLABICS YWI'
let s:d[0x1532]='CANADIAN SYLLABICS WEST-CREE YWI'
let s:d[0x1533]='CANADIAN SYLLABICS YWII'
let s:d[0x1534]='CANADIAN SYLLABICS WEST-CREE YWII'
let s:d[0x1535]='CANADIAN SYLLABICS YWO'
let s:d[0x1536]='CANADIAN SYLLABICS WEST-CREE YWO'
let s:d[0x1537]='CANADIAN SYLLABICS YWOO'
let s:d[0x1538]='CANADIAN SYLLABICS WEST-CREE YWOO'
let s:d[0x1539]='CANADIAN SYLLABICS YWA'
let s:d[0x153A]='CANADIAN SYLLABICS WEST-CREE YWA'
let s:d[0x153B]='CANADIAN SYLLABICS YWAA'
let s:d[0x153C]='CANADIAN SYLLABICS WEST-CREE YWAA'
let s:d[0x153D]='CANADIAN SYLLABICS NASKAPI YWAA'
let s:d[0x153E]='CANADIAN SYLLABICS Y'
let s:d[0x153F]='CANADIAN SYLLABICS BIBLE-CREE Y'
let s:d[0x1540]='CANADIAN SYLLABICS WEST-CREE Y'
let s:d[0x1541]='CANADIAN SYLLABICS SAYISI YI'
let s:d[0x1542]='CANADIAN SYLLABICS RE'
let s:d[0x1543]='CANADIAN SYLLABICS R-CREE RE'
let s:d[0x1544]='CANADIAN SYLLABICS WEST-CREE LE'
let s:d[0x1545]='CANADIAN SYLLABICS RAAI'
let s:d[0x1546]='CANADIAN SYLLABICS RI'
let s:d[0x1547]='CANADIAN SYLLABICS RII'
let s:d[0x1548]='CANADIAN SYLLABICS RO'
let s:d[0x1549]='CANADIAN SYLLABICS ROO'
let s:d[0x154A]='CANADIAN SYLLABICS WEST-CREE LO'
let s:d[0x154B]='CANADIAN SYLLABICS RA'
let s:d[0x154C]='CANADIAN SYLLABICS RAA'
let s:d[0x154D]='CANADIAN SYLLABICS WEST-CREE LA'
let s:d[0x154E]='CANADIAN SYLLABICS RWAA'
let s:d[0x154F]='CANADIAN SYLLABICS WEST-CREE RWAA'
let s:d[0x1550]='CANADIAN SYLLABICS R'
let s:d[0x1551]='CANADIAN SYLLABICS WEST-CREE R'
let s:d[0x1552]='CANADIAN SYLLABICS MEDIAL R'
let s:d[0x1553]='CANADIAN SYLLABICS FE'
let s:d[0x1554]='CANADIAN SYLLABICS FAAI'
let s:d[0x1555]='CANADIAN SYLLABICS FI'
let s:d[0x1556]='CANADIAN SYLLABICS FII'
let s:d[0x1557]='CANADIAN SYLLABICS FO'
let s:d[0x1558]='CANADIAN SYLLABICS FOO'
let s:d[0x1559]='CANADIAN SYLLABICS FA'
let s:d[0x155A]='CANADIAN SYLLABICS FAA'
let s:d[0x155B]='CANADIAN SYLLABICS FWAA'
let s:d[0x155C]='CANADIAN SYLLABICS WEST-CREE FWAA'
let s:d[0x155D]='CANADIAN SYLLABICS F'
let s:d[0x155E]='CANADIAN SYLLABICS THE'
let s:d[0x155F]='CANADIAN SYLLABICS N-CREE THE'
let s:d[0x1560]='CANADIAN SYLLABICS THI'
let s:d[0x1561]='CANADIAN SYLLABICS N-CREE THI'
let s:d[0x1562]='CANADIAN SYLLABICS THII'
let s:d[0x1563]='CANADIAN SYLLABICS N-CREE THII'
let s:d[0x1564]='CANADIAN SYLLABICS THO'
let s:d[0x1565]='CANADIAN SYLLABICS THOO'
let s:d[0x1566]='CANADIAN SYLLABICS THA'
let s:d[0x1567]='CANADIAN SYLLABICS THAA'
let s:d[0x1568]='CANADIAN SYLLABICS THWAA'
let s:d[0x1569]='CANADIAN SYLLABICS WEST-CREE THWAA'
let s:d[0x156A]='CANADIAN SYLLABICS TH'
let s:d[0x156B]='CANADIAN SYLLABICS TTHE'
let s:d[0x156C]='CANADIAN SYLLABICS TTHI'
let s:d[0x156D]='CANADIAN SYLLABICS TTHO'
let s:d[0x156E]='CANADIAN SYLLABICS TTHA'
let s:d[0x156F]='CANADIAN SYLLABICS TTH'
let s:d[0x1570]='CANADIAN SYLLABICS TYE'
let s:d[0x1571]='CANADIAN SYLLABICS TYI'
let s:d[0x1572]='CANADIAN SYLLABICS TYO'
let s:d[0x1573]='CANADIAN SYLLABICS TYA'
let s:d[0x1574]='CANADIAN SYLLABICS NUNAVIK HE'
let s:d[0x1575]='CANADIAN SYLLABICS NUNAVIK HI'
let s:d[0x1576]='CANADIAN SYLLABICS NUNAVIK HII'
let s:d[0x1577]='CANADIAN SYLLABICS NUNAVIK HO'
let s:d[0x1578]='CANADIAN SYLLABICS NUNAVIK HOO'
let s:d[0x1579]='CANADIAN SYLLABICS NUNAVIK HA'
let s:d[0x157A]='CANADIAN SYLLABICS NUNAVIK HAA'
let s:d[0x157B]='CANADIAN SYLLABICS NUNAVIK H'
let s:d[0x157C]='CANADIAN SYLLABICS NUNAVUT H'
let s:d[0x157D]='CANADIAN SYLLABICS HK'
let s:d[0x157E]='CANADIAN SYLLABICS QAAI'
let s:d[0x157F]='CANADIAN SYLLABICS QI'
let s:d[0x1580]='CANADIAN SYLLABICS QII'
let s:d[0x1581]='CANADIAN SYLLABICS QO'
let s:d[0x1582]='CANADIAN SYLLABICS QOO'
let s:d[0x1583]='CANADIAN SYLLABICS QA'
let s:d[0x1584]='CANADIAN SYLLABICS QAA'
let s:d[0x1585]='CANADIAN SYLLABICS Q'
let s:d[0x1586]='CANADIAN SYLLABICS TLHE'
let s:d[0x1587]='CANADIAN SYLLABICS TLHI'
let s:d[0x1588]='CANADIAN SYLLABICS TLHO'
let s:d[0x1589]='CANADIAN SYLLABICS TLHA'
let s:d[0x158A]='CANADIAN SYLLABICS WEST-CREE RE'
let s:d[0x158B]='CANADIAN SYLLABICS WEST-CREE RI'
let s:d[0x158C]='CANADIAN SYLLABICS WEST-CREE RO'
let s:d[0x158D]='CANADIAN SYLLABICS WEST-CREE RA'
let s:d[0x158E]='CANADIAN SYLLABICS NGAAI'
let s:d[0x158F]='CANADIAN SYLLABICS NGI'
let s:d[0x1590]='CANADIAN SYLLABICS NGII'
let s:d[0x1591]='CANADIAN SYLLABICS NGO'
let s:d[0x1592]='CANADIAN SYLLABICS NGOO'
let s:d[0x1593]='CANADIAN SYLLABICS NGA'
let s:d[0x1594]='CANADIAN SYLLABICS NGAA'
let s:d[0x1595]='CANADIAN SYLLABICS NG'
let s:d[0x1596]='CANADIAN SYLLABICS NNG'
let s:d[0x1597]='CANADIAN SYLLABICS SAYISI SHE'
let s:d[0x1598]='CANADIAN SYLLABICS SAYISI SHI'
let s:d[0x1599]='CANADIAN SYLLABICS SAYISI SHO'
let s:d[0x159A]='CANADIAN SYLLABICS SAYISI SHA'
let s:d[0x159B]='CANADIAN SYLLABICS WOODS-CREE THE'
let s:d[0x159C]='CANADIAN SYLLABICS WOODS-CREE THI'
let s:d[0x159D]='CANADIAN SYLLABICS WOODS-CREE THO'
let s:d[0x159E]='CANADIAN SYLLABICS WOODS-CREE THA'
let s:d[0x159F]='CANADIAN SYLLABICS WOODS-CREE TH'
let s:d[0x15A0]='CANADIAN SYLLABICS LHI'
let s:d[0x15A1]='CANADIAN SYLLABICS LHII'
let s:d[0x15A2]='CANADIAN SYLLABICS LHO'
let s:d[0x15A3]='CANADIAN SYLLABICS LHOO'
let s:d[0x15A4]='CANADIAN SYLLABICS LHA'
let s:d[0x15A5]='CANADIAN SYLLABICS LHAA'
let s:d[0x15A6]='CANADIAN SYLLABICS LH'
let s:d[0x15A7]='CANADIAN SYLLABICS TH-CREE THE'
let s:d[0x15A8]='CANADIAN SYLLABICS TH-CREE THI'
let s:d[0x15A9]='CANADIAN SYLLABICS TH-CREE THII'
let s:d[0x15AA]='CANADIAN SYLLABICS TH-CREE THO'
let s:d[0x15AB]='CANADIAN SYLLABICS TH-CREE THOO'
let s:d[0x15AC]='CANADIAN SYLLABICS TH-CREE THA'
let s:d[0x15AD]='CANADIAN SYLLABICS TH-CREE THAA'
let s:d[0x15AE]='CANADIAN SYLLABICS TH-CREE TH'
let s:d[0x15AF]='CANADIAN SYLLABICS AIVILIK B'
let s:d[0x15B0]='CANADIAN SYLLABICS BLACKFOOT E'
let s:d[0x15B1]='CANADIAN SYLLABICS BLACKFOOT I'
let s:d[0x15B2]='CANADIAN SYLLABICS BLACKFOOT O'
let s:d[0x15B3]='CANADIAN SYLLABICS BLACKFOOT A'
let s:d[0x15B4]='CANADIAN SYLLABICS BLACKFOOT WE'
let s:d[0x15B5]='CANADIAN SYLLABICS BLACKFOOT WI'
let s:d[0x15B6]='CANADIAN SYLLABICS BLACKFOOT WO'
let s:d[0x15B7]='CANADIAN SYLLABICS BLACKFOOT WA'
let s:d[0x15B8]='CANADIAN SYLLABICS BLACKFOOT NE'
let s:d[0x15B9]='CANADIAN SYLLABICS BLACKFOOT NI'
let s:d[0x15BA]='CANADIAN SYLLABICS BLACKFOOT NO'
let s:d[0x15BB]='CANADIAN SYLLABICS BLACKFOOT NA'
let s:d[0x15BC]='CANADIAN SYLLABICS BLACKFOOT KE'
let s:d[0x15BD]='CANADIAN SYLLABICS BLACKFOOT KI'
let s:d[0x15BE]='CANADIAN SYLLABICS BLACKFOOT KO'
let s:d[0x15BF]='CANADIAN SYLLABICS BLACKFOOT KA'
let s:d[0x15C0]='CANADIAN SYLLABICS SAYISI HE'
let s:d[0x15C1]='CANADIAN SYLLABICS SAYISI HI'
let s:d[0x15C2]='CANADIAN SYLLABICS SAYISI HO'
let s:d[0x15C3]='CANADIAN SYLLABICS SAYISI HA'
let s:d[0x15C4]='CANADIAN SYLLABICS CARRIER GHU'
let s:d[0x15C5]='CANADIAN SYLLABICS CARRIER GHO'
let s:d[0x15C6]='CANADIAN SYLLABICS CARRIER GHE'
let s:d[0x15C7]='CANADIAN SYLLABICS CARRIER GHEE'
let s:d[0x15C8]='CANADIAN SYLLABICS CARRIER GHI'
let s:d[0x15C9]='CANADIAN SYLLABICS CARRIER GHA'
let s:d[0x15CA]='CANADIAN SYLLABICS CARRIER RU'
let s:d[0x15CB]='CANADIAN SYLLABICS CARRIER RO'
let s:d[0x15CC]='CANADIAN SYLLABICS CARRIER RE'
let s:d[0x15CD]='CANADIAN SYLLABICS CARRIER REE'
let s:d[0x15CE]='CANADIAN SYLLABICS CARRIER RI'
let s:d[0x15CF]='CANADIAN SYLLABICS CARRIER RA'
let s:d[0x15D0]='CANADIAN SYLLABICS CARRIER WU'
let s:d[0x15D1]='CANADIAN SYLLABICS CARRIER WO'
let s:d[0x15D2]='CANADIAN SYLLABICS CARRIER WE'
let s:d[0x15D3]='CANADIAN SYLLABICS CARRIER WEE'
let s:d[0x15D4]='CANADIAN SYLLABICS CARRIER WI'
let s:d[0x15D5]='CANADIAN SYLLABICS CARRIER WA'
let s:d[0x15D6]='CANADIAN SYLLABICS CARRIER HWU'
let s:d[0x15D7]='CANADIAN SYLLABICS CARRIER HWO'
let s:d[0x15D8]='CANADIAN SYLLABICS CARRIER HWE'
let s:d[0x15D9]='CANADIAN SYLLABICS CARRIER HWEE'
let s:d[0x15DA]='CANADIAN SYLLABICS CARRIER HWI'
let s:d[0x15DB]='CANADIAN SYLLABICS CARRIER HWA'
let s:d[0x15DC]='CANADIAN SYLLABICS CARRIER THU'
let s:d[0x15DD]='CANADIAN SYLLABICS CARRIER THO'
let s:d[0x15DE]='CANADIAN SYLLABICS CARRIER THE'
let s:d[0x15DF]='CANADIAN SYLLABICS CARRIER THEE'
let s:d[0x15E0]='CANADIAN SYLLABICS CARRIER THI'
let s:d[0x15E1]='CANADIAN SYLLABICS CARRIER THA'
let s:d[0x15E2]='CANADIAN SYLLABICS CARRIER TTU'
let s:d[0x15E3]='CANADIAN SYLLABICS CARRIER TTO'
let s:d[0x15E4]='CANADIAN SYLLABICS CARRIER TTE'
let s:d[0x15E5]='CANADIAN SYLLABICS CARRIER TTEE'
let s:d[0x15E6]='CANADIAN SYLLABICS CARRIER TTI'
let s:d[0x15E7]='CANADIAN SYLLABICS CARRIER TTA'
let s:d[0x15E8]='CANADIAN SYLLABICS CARRIER PU'
let s:d[0x15E9]='CANADIAN SYLLABICS CARRIER PO'
let s:d[0x15EA]='CANADIAN SYLLABICS CARRIER PE'
let s:d[0x15EB]='CANADIAN SYLLABICS CARRIER PEE'
let s:d[0x15EC]='CANADIAN SYLLABICS CARRIER PI'
let s:d[0x15ED]='CANADIAN SYLLABICS CARRIER PA'
let s:d[0x15EE]='CANADIAN SYLLABICS CARRIER P'
let s:d[0x15EF]='CANADIAN SYLLABICS CARRIER GU'
let s:d[0x15F0]='CANADIAN SYLLABICS CARRIER GO'
let s:d[0x15F1]='CANADIAN SYLLABICS CARRIER GE'
let s:d[0x15F2]='CANADIAN SYLLABICS CARRIER GEE'
let s:d[0x15F3]='CANADIAN SYLLABICS CARRIER GI'
let s:d[0x15F4]='CANADIAN SYLLABICS CARRIER GA'
let s:d[0x15F5]='CANADIAN SYLLABICS CARRIER KHU'
let s:d[0x15F6]='CANADIAN SYLLABICS CARRIER KHO'
let s:d[0x15F7]='CANADIAN SYLLABICS CARRIER KHE'
let s:d[0x15F8]='CANADIAN SYLLABICS CARRIER KHEE'
let s:d[0x15F9]='CANADIAN SYLLABICS CARRIER KHI'
let s:d[0x15FA]='CANADIAN SYLLABICS CARRIER KHA'
let s:d[0x15FB]='CANADIAN SYLLABICS CARRIER KKU'
let s:d[0x15FC]='CANADIAN SYLLABICS CARRIER KKO'
let s:d[0x15FD]='CANADIAN SYLLABICS CARRIER KKE'
let s:d[0x15FE]='CANADIAN SYLLABICS CARRIER KKEE'
let s:d[0x15FF]='CANADIAN SYLLABICS CARRIER KKI'
let s:d[0x1600]='CANADIAN SYLLABICS CARRIER KKA'
let s:d[0x1601]='CANADIAN SYLLABICS CARRIER KK'
let s:d[0x1602]='CANADIAN SYLLABICS CARRIER NU'
let s:d[0x1603]='CANADIAN SYLLABICS CARRIER NO'
let s:d[0x1604]='CANADIAN SYLLABICS CARRIER NE'
let s:d[0x1605]='CANADIAN SYLLABICS CARRIER NEE'
let s:d[0x1606]='CANADIAN SYLLABICS CARRIER NI'
let s:d[0x1607]='CANADIAN SYLLABICS CARRIER NA'
let s:d[0x1608]='CANADIAN SYLLABICS CARRIER MU'
let s:d[0x1609]='CANADIAN SYLLABICS CARRIER MO'
let s:d[0x160A]='CANADIAN SYLLABICS CARRIER ME'
let s:d[0x160B]='CANADIAN SYLLABICS CARRIER MEE'
let s:d[0x160C]='CANADIAN SYLLABICS CARRIER MI'
let s:d[0x160D]='CANADIAN SYLLABICS CARRIER MA'
let s:d[0x160E]='CANADIAN SYLLABICS CARRIER YU'
let s:d[0x160F]='CANADIAN SYLLABICS CARRIER YO'
let s:d[0x1610]='CANADIAN SYLLABICS CARRIER YE'
let s:d[0x1611]='CANADIAN SYLLABICS CARRIER YEE'
let s:d[0x1612]='CANADIAN SYLLABICS CARRIER YI'
let s:d[0x1613]='CANADIAN SYLLABICS CARRIER YA'
let s:d[0x1614]='CANADIAN SYLLABICS CARRIER JU'
let s:d[0x1615]='CANADIAN SYLLABICS SAYISI JU'
let s:d[0x1616]='CANADIAN SYLLABICS CARRIER JO'
let s:d[0x1617]='CANADIAN SYLLABICS CARRIER JE'
let s:d[0x1618]='CANADIAN SYLLABICS CARRIER JEE'
let s:d[0x1619]='CANADIAN SYLLABICS CARRIER JI'
let s:d[0x161A]='CANADIAN SYLLABICS SAYISI JI'
let s:d[0x161B]='CANADIAN SYLLABICS CARRIER JA'
let s:d[0x161C]='CANADIAN SYLLABICS CARRIER JJU'
let s:d[0x161D]='CANADIAN SYLLABICS CARRIER JJO'
let s:d[0x161E]='CANADIAN SYLLABICS CARRIER JJE'
let s:d[0x161F]='CANADIAN SYLLABICS CARRIER JJEE'
let s:d[0x1620]='CANADIAN SYLLABICS CARRIER JJI'
let s:d[0x1621]='CANADIAN SYLLABICS CARRIER JJA'
let s:d[0x1622]='CANADIAN SYLLABICS CARRIER LU'
let s:d[0x1623]='CANADIAN SYLLABICS CARRIER LO'
let s:d[0x1624]='CANADIAN SYLLABICS CARRIER LE'
let s:d[0x1625]='CANADIAN SYLLABICS CARRIER LEE'
let s:d[0x1626]='CANADIAN SYLLABICS CARRIER LI'
let s:d[0x1627]='CANADIAN SYLLABICS CARRIER LA'
let s:d[0x1628]='CANADIAN SYLLABICS CARRIER DLU'
let s:d[0x1629]='CANADIAN SYLLABICS CARRIER DLO'
let s:d[0x162A]='CANADIAN SYLLABICS CARRIER DLE'
let s:d[0x162B]='CANADIAN SYLLABICS CARRIER DLEE'
let s:d[0x162C]='CANADIAN SYLLABICS CARRIER DLI'
let s:d[0x162D]='CANADIAN SYLLABICS CARRIER DLA'
let s:d[0x162E]='CANADIAN SYLLABICS CARRIER LHU'
let s:d[0x162F]='CANADIAN SYLLABICS CARRIER LHO'
let s:d[0x1630]='CANADIAN SYLLABICS CARRIER LHE'
let s:d[0x1631]='CANADIAN SYLLABICS CARRIER LHEE'
let s:d[0x1632]='CANADIAN SYLLABICS CARRIER LHI'
let s:d[0x1633]='CANADIAN SYLLABICS CARRIER LHA'
let s:d[0x1634]='CANADIAN SYLLABICS CARRIER TLHU'
let s:d[0x1635]='CANADIAN SYLLABICS CARRIER TLHO'
let s:d[0x1636]='CANADIAN SYLLABICS CARRIER TLHE'
let s:d[0x1637]='CANADIAN SYLLABICS CARRIER TLHEE'
let s:d[0x1638]='CANADIAN SYLLABICS CARRIER TLHI'
let s:d[0x1639]='CANADIAN SYLLABICS CARRIER TLHA'
let s:d[0x163A]='CANADIAN SYLLABICS CARRIER TLU'
let s:d[0x163B]='CANADIAN SYLLABICS CARRIER TLO'
let s:d[0x163C]='CANADIAN SYLLABICS CARRIER TLE'
let s:d[0x163D]='CANADIAN SYLLABICS CARRIER TLEE'
let s:d[0x163E]='CANADIAN SYLLABICS CARRIER TLI'
let s:d[0x163F]='CANADIAN SYLLABICS CARRIER TLA'
let s:d[0x1640]='CANADIAN SYLLABICS CARRIER ZU'
let s:d[0x1641]='CANADIAN SYLLABICS CARRIER ZO'
let s:d[0x1642]='CANADIAN SYLLABICS CARRIER ZE'
let s:d[0x1643]='CANADIAN SYLLABICS CARRIER ZEE'
let s:d[0x1644]='CANADIAN SYLLABICS CARRIER ZI'
let s:d[0x1645]='CANADIAN SYLLABICS CARRIER ZA'
let s:d[0x1646]='CANADIAN SYLLABICS CARRIER Z'
let s:d[0x1647]='CANADIAN SYLLABICS CARRIER INITIAL Z'
let s:d[0x1648]='CANADIAN SYLLABICS CARRIER DZU'
let s:d[0x1649]='CANADIAN SYLLABICS CARRIER DZO'
let s:d[0x164A]='CANADIAN SYLLABICS CARRIER DZE'
let s:d[0x164B]='CANADIAN SYLLABICS CARRIER DZEE'
let s:d[0x164C]='CANADIAN SYLLABICS CARRIER DZI'
let s:d[0x164D]='CANADIAN SYLLABICS CARRIER DZA'
let s:d[0x164E]='CANADIAN SYLLABICS CARRIER SU'
let s:d[0x164F]='CANADIAN SYLLABICS CARRIER SO'
let s:d[0x1650]='CANADIAN SYLLABICS CARRIER SE'
let s:d[0x1651]='CANADIAN SYLLABICS CARRIER SEE'
let s:d[0x1652]='CANADIAN SYLLABICS CARRIER SI'
let s:d[0x1653]='CANADIAN SYLLABICS CARRIER SA'
let s:d[0x1654]='CANADIAN SYLLABICS CARRIER SHU'
let s:d[0x1655]='CANADIAN SYLLABICS CARRIER SHO'
let s:d[0x1656]='CANADIAN SYLLABICS CARRIER SHE'
let s:d[0x1657]='CANADIAN SYLLABICS CARRIER SHEE'
let s:d[0x1658]='CANADIAN SYLLABICS CARRIER SHI'
let s:d[0x1659]='CANADIAN SYLLABICS CARRIER SHA'
let s:d[0x165A]='CANADIAN SYLLABICS CARRIER SH'
let s:d[0x165B]='CANADIAN SYLLABICS CARRIER TSU'
let s:d[0x165C]='CANADIAN SYLLABICS CARRIER TSO'
let s:d[0x165D]='CANADIAN SYLLABICS CARRIER TSE'
let s:d[0x165E]='CANADIAN SYLLABICS CARRIER TSEE'
let s:d[0x165F]='CANADIAN SYLLABICS CARRIER TSI'
let s:d[0x1660]='CANADIAN SYLLABICS CARRIER TSA'
let s:d[0x1661]='CANADIAN SYLLABICS CARRIER CHU'
let s:d[0x1662]='CANADIAN SYLLABICS CARRIER CHO'
let s:d[0x1663]='CANADIAN SYLLABICS CARRIER CHE'
let s:d[0x1664]='CANADIAN SYLLABICS CARRIER CHEE'
let s:d[0x1665]='CANADIAN SYLLABICS CARRIER CHI'
let s:d[0x1666]='CANADIAN SYLLABICS CARRIER CHA'
let s:d[0x1667]='CANADIAN SYLLABICS CARRIER TTSU'
let s:d[0x1668]='CANADIAN SYLLABICS CARRIER TTSO'
let s:d[0x1669]='CANADIAN SYLLABICS CARRIER TTSE'
let s:d[0x166A]='CANADIAN SYLLABICS CARRIER TTSEE'
let s:d[0x166B]='CANADIAN SYLLABICS CARRIER TTSI'
let s:d[0x166C]='CANADIAN SYLLABICS CARRIER TTSA'
let s:d[0x166D]='CANADIAN SYLLABICS CHI SIGN'
let s:d[0x166E]='CANADIAN SYLLABICS FULL STOP'
let s:d[0x166F]='CANADIAN SYLLABICS QAI'
let s:d[0x1670]='CANADIAN SYLLABICS NGAI'
let s:d[0x1671]='CANADIAN SYLLABICS NNGI'
let s:d[0x1672]='CANADIAN SYLLABICS NNGII'
let s:d[0x1673]='CANADIAN SYLLABICS NNGO'
let s:d[0x1674]='CANADIAN SYLLABICS NNGOO'
let s:d[0x1675]='CANADIAN SYLLABICS NNGA'
let s:d[0x1676]='CANADIAN SYLLABICS NNGAA'
let s:d[0x1677]='CANADIAN SYLLABICS WOODS-CREE THWEE'
let s:d[0x1678]='CANADIAN SYLLABICS WOODS-CREE THWI'
let s:d[0x1679]='CANADIAN SYLLABICS WOODS-CREE THWII'
let s:d[0x167A]='CANADIAN SYLLABICS WOODS-CREE THWO'
let s:d[0x167B]='CANADIAN SYLLABICS WOODS-CREE THWOO'
let s:d[0x167C]='CANADIAN SYLLABICS WOODS-CREE THWA'
let s:d[0x167D]='CANADIAN SYLLABICS WOODS-CREE THWAA'
let s:d[0x167E]='CANADIAN SYLLABICS WOODS-CREE FINAL TH'
let s:d[0x167F]='CANADIAN SYLLABICS BLACKFOOT W'
let s:d[0x1680]='OGHAM SPACE MARK'
let s:d[0x1681]='OGHAM LETTER BEITH'
let s:d[0x1682]='OGHAM LETTER LUIS'
let s:d[0x1683]='OGHAM LETTER FEARN'
let s:d[0x1684]='OGHAM LETTER SAIL'
let s:d[0x1685]='OGHAM LETTER NION'
let s:d[0x1686]='OGHAM LETTER UATH'
let s:d[0x1687]='OGHAM LETTER DAIR'
let s:d[0x1688]='OGHAM LETTER TINNE'
let s:d[0x1689]='OGHAM LETTER COLL'
let s:d[0x168A]='OGHAM LETTER CEIRT'
let s:d[0x168B]='OGHAM LETTER MUIN'
let s:d[0x168C]='OGHAM LETTER GORT'
let s:d[0x168D]='OGHAM LETTER NGEADAL'
let s:d[0x168E]='OGHAM LETTER STRAIF'
let s:d[0x168F]='OGHAM LETTER RUIS'
let s:d[0x1690]='OGHAM LETTER AILM'
let s:d[0x1691]='OGHAM LETTER ONN'
let s:d[0x1692]='OGHAM LETTER UR'
let s:d[0x1693]='OGHAM LETTER EADHADH'
let s:d[0x1694]='OGHAM LETTER IODHADH'
let s:d[0x1695]='OGHAM LETTER EABHADH'
let s:d[0x1696]='OGHAM LETTER OR'
let s:d[0x1697]='OGHAM LETTER UILLEANN'
let s:d[0x1698]='OGHAM LETTER IFIN'
let s:d[0x1699]='OGHAM LETTER EAMHANCHOLL'
let s:d[0x169A]='OGHAM LETTER PEITH'
let s:d[0x169B]='OGHAM FEATHER MARK'
let s:d[0x169C]='OGHAM REVERSED FEATHER MARK'
let s:d[0x16A0]='RUNIC LETTER FEHU FEOH FE F'
let s:d[0x16A1]='RUNIC LETTER V'
let s:d[0x16A2]='RUNIC LETTER URUZ UR U'
let s:d[0x16A3]='RUNIC LETTER YR'
let s:d[0x16A4]='RUNIC LETTER Y'
let s:d[0x16A5]='RUNIC LETTER W'
let s:d[0x16A6]='RUNIC LETTER THURISAZ THURS THORN'
let s:d[0x16A7]='RUNIC LETTER ETH'
let s:d[0x16A8]='RUNIC LETTER ANSUZ A'
let s:d[0x16A9]='RUNIC LETTER OS O'
let s:d[0x16AA]='RUNIC LETTER AC A'
let s:d[0x16AB]='RUNIC LETTER AESC'
let s:d[0x16AC]='RUNIC LETTER LONG-BRANCH-OSS O'
let s:d[0x16AD]='RUNIC LETTER SHORT-TWIG-OSS O'
let s:d[0x16AE]='RUNIC LETTER O'
let s:d[0x16AF]='RUNIC LETTER OE'
let s:d[0x16B0]='RUNIC LETTER ON'
let s:d[0x16B1]='RUNIC LETTER RAIDO RAD REID R'
let s:d[0x16B2]='RUNIC LETTER KAUNA'
let s:d[0x16B3]='RUNIC LETTER CEN'
let s:d[0x16B4]='RUNIC LETTER KAUN K'
let s:d[0x16B5]='RUNIC LETTER G'
let s:d[0x16B6]='RUNIC LETTER ENG'
let s:d[0x16B7]='RUNIC LETTER GEBO GYFU G'
let s:d[0x16B8]='RUNIC LETTER GAR'
let s:d[0x16B9]='RUNIC LETTER WUNJO WYNN W'
let s:d[0x16BA]='RUNIC LETTER HAGLAZ H'
let s:d[0x16BB]='RUNIC LETTER HAEGL H'
let s:d[0x16BC]='RUNIC LETTER LONG-BRANCH-HAGALL H'
let s:d[0x16BD]='RUNIC LETTER SHORT-TWIG-HAGALL H'
let s:d[0x16BE]='RUNIC LETTER NAUDIZ NYD NAUD N'
let s:d[0x16BF]='RUNIC LETTER SHORT-TWIG-NAUD N'
let s:d[0x16C0]='RUNIC LETTER DOTTED-N'
let s:d[0x16C1]='RUNIC LETTER ISAZ IS ISS I'
let s:d[0x16C2]='RUNIC LETTER E'
let s:d[0x16C3]='RUNIC LETTER JERAN J'
let s:d[0x16C4]='RUNIC LETTER GER'
let s:d[0x16C5]='RUNIC LETTER LONG-BRANCH-AR AE'
let s:d[0x16C6]='RUNIC LETTER SHORT-TWIG-AR A'
let s:d[0x16C7]='RUNIC LETTER IWAZ EOH'
let s:d[0x16C8]='RUNIC LETTER PERTHO PEORTH P'
let s:d[0x16C9]='RUNIC LETTER ALGIZ EOLHX'
let s:d[0x16CA]='RUNIC LETTER SOWILO S'
let s:d[0x16CB]='RUNIC LETTER SIGEL LONG-BRANCH-SOL S'
let s:d[0x16CC]='RUNIC LETTER SHORT-TWIG-SOL S'
let s:d[0x16CD]='RUNIC LETTER C'
let s:d[0x16CE]='RUNIC LETTER Z'
let s:d[0x16CF]='RUNIC LETTER TIWAZ TIR TYR T'
let s:d[0x16D0]='RUNIC LETTER SHORT-TWIG-TYR T'
let s:d[0x16D1]='RUNIC LETTER D'
let s:d[0x16D2]='RUNIC LETTER BERKANAN BEORC BJARKAN B'
let s:d[0x16D3]='RUNIC LETTER SHORT-TWIG-BJARKAN B'
let s:d[0x16D4]='RUNIC LETTER DOTTED-P'
let s:d[0x16D5]='RUNIC LETTER OPEN-P'
let s:d[0x16D6]='RUNIC LETTER EHWAZ EH E'
let s:d[0x16D7]='RUNIC LETTER MANNAZ MAN M'
let s:d[0x16D8]='RUNIC LETTER LONG-BRANCH-MADR M'
let s:d[0x16D9]='RUNIC LETTER SHORT-TWIG-MADR M'
let s:d[0x16DA]='RUNIC LETTER LAUKAZ LAGU LOGR L'
let s:d[0x16DB]='RUNIC LETTER DOTTED-L'
let s:d[0x16DC]='RUNIC LETTER INGWAZ'
let s:d[0x16DD]='RUNIC LETTER ING'
let s:d[0x16DE]='RUNIC LETTER DAGAZ DAEG D'
let s:d[0x16DF]='RUNIC LETTER OTHALAN ETHEL O'
let s:d[0x16E0]='RUNIC LETTER EAR'
let s:d[0x16E1]='RUNIC LETTER IOR'
let s:d[0x16E2]='RUNIC LETTER CWEORTH'
let s:d[0x16E3]='RUNIC LETTER CALC'
let s:d[0x16E4]='RUNIC LETTER CEALC'
let s:d[0x16E5]='RUNIC LETTER STAN'
let s:d[0x16E6]='RUNIC LETTER LONG-BRANCH-YR'
let s:d[0x16E7]='RUNIC LETTER SHORT-TWIG-YR'
let s:d[0x16E8]='RUNIC LETTER ICELANDIC-YR'
let s:d[0x16E9]='RUNIC LETTER Q'
let s:d[0x16EA]='RUNIC LETTER X'
let s:d[0x16EB]='RUNIC SINGLE PUNCTUATION'
let s:d[0x16EC]='RUNIC MULTIPLE PUNCTUATION'
let s:d[0x16ED]='RUNIC CROSS PUNCTUATION'
let s:d[0x16EE]='RUNIC ARLAUG SYMBOL'
let s:d[0x16EF]='RUNIC TVIMADUR SYMBOL'
let s:d[0x16F0]='RUNIC BELGTHOR SYMBOL'
let s:d[0x1700]='TAGALOG LETTER A'
let s:d[0x1701]='TAGALOG LETTER I'
let s:d[0x1702]='TAGALOG LETTER U'
let s:d[0x1703]='TAGALOG LETTER KA'
let s:d[0x1704]='TAGALOG LETTER GA'
let s:d[0x1705]='TAGALOG LETTER NGA'
let s:d[0x1706]='TAGALOG LETTER TA'
let s:d[0x1707]='TAGALOG LETTER DA'
let s:d[0x1708]='TAGALOG LETTER NA'
let s:d[0x1709]='TAGALOG LETTER PA'
let s:d[0x170A]='TAGALOG LETTER BA'
let s:d[0x170B]='TAGALOG LETTER MA'
let s:d[0x170C]='TAGALOG LETTER YA'
let s:d[0x170E]='TAGALOG LETTER LA'
let s:d[0x170F]='TAGALOG LETTER WA'
let s:d[0x1710]='TAGALOG LETTER SA'
let s:d[0x1711]='TAGALOG LETTER HA'
let s:d[0x1712]='TAGALOG VOWEL SIGN I'
let s:d[0x1713]='TAGALOG VOWEL SIGN U'
let s:d[0x1714]='TAGALOG SIGN VIRAMA'
let s:d[0x1720]='HANUNOO LETTER A'
let s:d[0x1721]='HANUNOO LETTER I'
let s:d[0x1722]='HANUNOO LETTER U'
let s:d[0x1723]='HANUNOO LETTER KA'
let s:d[0x1724]='HANUNOO LETTER GA'
let s:d[0x1725]='HANUNOO LETTER NGA'
let s:d[0x1726]='HANUNOO LETTER TA'
let s:d[0x1727]='HANUNOO LETTER DA'
let s:d[0x1728]='HANUNOO LETTER NA'
let s:d[0x1729]='HANUNOO LETTER PA'
let s:d[0x172A]='HANUNOO LETTER BA'
let s:d[0x172B]='HANUNOO LETTER MA'
let s:d[0x172C]='HANUNOO LETTER YA'
let s:d[0x172D]='HANUNOO LETTER RA'
let s:d[0x172E]='HANUNOO LETTER LA'
let s:d[0x172F]='HANUNOO LETTER WA'
let s:d[0x1730]='HANUNOO LETTER SA'
let s:d[0x1731]='HANUNOO LETTER HA'
let s:d[0x1732]='HANUNOO VOWEL SIGN I'
let s:d[0x1733]='HANUNOO VOWEL SIGN U'
let s:d[0x1734]='HANUNOO SIGN PAMUDPOD'
let s:d[0x1735]='PHILIPPINE SINGLE PUNCTUATION'
let s:d[0x1736]='PHILIPPINE DOUBLE PUNCTUATION'
let s:d[0x1740]='BUHID LETTER A'
let s:d[0x1741]='BUHID LETTER I'
let s:d[0x1742]='BUHID LETTER U'
let s:d[0x1743]='BUHID LETTER KA'
let s:d[0x1744]='BUHID LETTER GA'
let s:d[0x1745]='BUHID LETTER NGA'
let s:d[0x1746]='BUHID LETTER TA'
let s:d[0x1747]='BUHID LETTER DA'
let s:d[0x1748]='BUHID LETTER NA'
let s:d[0x1749]='BUHID LETTER PA'
let s:d[0x174A]='BUHID LETTER BA'
let s:d[0x174B]='BUHID LETTER MA'
let s:d[0x174C]='BUHID LETTER YA'
let s:d[0x174D]='BUHID LETTER RA'
let s:d[0x174E]='BUHID LETTER LA'
let s:d[0x174F]='BUHID LETTER WA'
let s:d[0x1750]='BUHID LETTER SA'
let s:d[0x1751]='BUHID LETTER HA'
let s:d[0x1752]='BUHID VOWEL SIGN I'
let s:d[0x1753]='BUHID VOWEL SIGN U'
let s:d[0x1760]='TAGBANWA LETTER A'
let s:d[0x1761]='TAGBANWA LETTER I'
let s:d[0x1762]='TAGBANWA LETTER U'
let s:d[0x1763]='TAGBANWA LETTER KA'
let s:d[0x1764]='TAGBANWA LETTER GA'
let s:d[0x1765]='TAGBANWA LETTER NGA'
let s:d[0x1766]='TAGBANWA LETTER TA'
let s:d[0x1767]='TAGBANWA LETTER DA'
let s:d[0x1768]='TAGBANWA LETTER NA'
let s:d[0x1769]='TAGBANWA LETTER PA'
let s:d[0x176A]='TAGBANWA LETTER BA'
let s:d[0x176B]='TAGBANWA LETTER MA'
let s:d[0x176C]='TAGBANWA LETTER YA'
let s:d[0x176E]='TAGBANWA LETTER LA'
let s:d[0x176F]='TAGBANWA LETTER WA'
let s:d[0x1770]='TAGBANWA LETTER SA'
let s:d[0x1772]='TAGBANWA VOWEL SIGN I'
let s:d[0x1773]='TAGBANWA VOWEL SIGN U'
let s:d[0x1780]='KHMER LETTER KA'
let s:d[0x1781]='KHMER LETTER KHA'
let s:d[0x1782]='KHMER LETTER KO'
let s:d[0x1783]='KHMER LETTER KHO'
let s:d[0x1784]='KHMER LETTER NGO'
let s:d[0x1785]='KHMER LETTER CA'
let s:d[0x1786]='KHMER LETTER CHA'
let s:d[0x1787]='KHMER LETTER CO'
let s:d[0x1788]='KHMER LETTER CHO'
let s:d[0x1789]='KHMER LETTER NYO'
let s:d[0x178A]='KHMER LETTER DA'
let s:d[0x178B]='KHMER LETTER TTHA'
let s:d[0x178C]='KHMER LETTER DO'
let s:d[0x178D]='KHMER LETTER TTHO'
let s:d[0x178E]='KHMER LETTER NNO'
let s:d[0x178F]='KHMER LETTER TA'
let s:d[0x1790]='KHMER LETTER THA'
let s:d[0x1791]='KHMER LETTER TO'
let s:d[0x1792]='KHMER LETTER THO'
let s:d[0x1793]='KHMER LETTER NO'
let s:d[0x1794]='KHMER LETTER BA'
let s:d[0x1795]='KHMER LETTER PHA'
let s:d[0x1796]='KHMER LETTER PO'
let s:d[0x1797]='KHMER LETTER PHO'
let s:d[0x1798]='KHMER LETTER MO'
let s:d[0x1799]='KHMER LETTER YO'
let s:d[0x179A]='KHMER LETTER RO'
let s:d[0x179B]='KHMER LETTER LO'
let s:d[0x179C]='KHMER LETTER VO'
let s:d[0x179D]='KHMER LETTER SHA'
let s:d[0x179E]='KHMER LETTER SSO'
let s:d[0x179F]='KHMER LETTER SA'
let s:d[0x17A0]='KHMER LETTER HA'
let s:d[0x17A1]='KHMER LETTER LA'
let s:d[0x17A2]='KHMER LETTER QA'
let s:d[0x17A3]='KHMER INDEPENDENT VOWEL QAQ'
let s:d[0x17A4]='KHMER INDEPENDENT VOWEL QAA'
let s:d[0x17A5]='KHMER INDEPENDENT VOWEL QI'
let s:d[0x17A6]='KHMER INDEPENDENT VOWEL QII'
let s:d[0x17A7]='KHMER INDEPENDENT VOWEL QU'
let s:d[0x17A8]='KHMER INDEPENDENT VOWEL QUK'
let s:d[0x17A9]='KHMER INDEPENDENT VOWEL QUU'
let s:d[0x17AA]='KHMER INDEPENDENT VOWEL QUUV'
let s:d[0x17AB]='KHMER INDEPENDENT VOWEL RY'
let s:d[0x17AC]='KHMER INDEPENDENT VOWEL RYY'
let s:d[0x17AD]='KHMER INDEPENDENT VOWEL LY'
let s:d[0x17AE]='KHMER INDEPENDENT VOWEL LYY'
let s:d[0x17AF]='KHMER INDEPENDENT VOWEL QE'
let s:d[0x17B0]='KHMER INDEPENDENT VOWEL QAI'
let s:d[0x17B1]='KHMER INDEPENDENT VOWEL QOO TYPE ONE'
let s:d[0x17B2]='KHMER INDEPENDENT VOWEL QOO TYPE TWO'
let s:d[0x17B3]='KHMER INDEPENDENT VOWEL QAU'
let s:d[0x17B4]='KHMER VOWEL INHERENT AQ'
let s:d[0x17B5]='KHMER VOWEL INHERENT AA'
let s:d[0x17B6]='KHMER VOWEL SIGN AA'
let s:d[0x17B7]='KHMER VOWEL SIGN I'
let s:d[0x17B8]='KHMER VOWEL SIGN II'
let s:d[0x17B9]='KHMER VOWEL SIGN Y'
let s:d[0x17BA]='KHMER VOWEL SIGN YY'
let s:d[0x17BB]='KHMER VOWEL SIGN U'
let s:d[0x17BC]='KHMER VOWEL SIGN UU'
let s:d[0x17BD]='KHMER VOWEL SIGN UA'
let s:d[0x17BE]='KHMER VOWEL SIGN OE'
let s:d[0x17BF]='KHMER VOWEL SIGN YA'
let s:d[0x17C0]='KHMER VOWEL SIGN IE'
let s:d[0x17C1]='KHMER VOWEL SIGN E'
let s:d[0x17C2]='KHMER VOWEL SIGN AE'
let s:d[0x17C3]='KHMER VOWEL SIGN AI'
let s:d[0x17C4]='KHMER VOWEL SIGN OO'
let s:d[0x17C5]='KHMER VOWEL SIGN AU'
let s:d[0x17C6]='KHMER SIGN NIKAHIT'
let s:d[0x17C7]='KHMER SIGN REAHMUK'
let s:d[0x17C8]='KHMER SIGN YUUKALEAPINTU'
let s:d[0x17C9]='KHMER SIGN MUUSIKATOAN'
let s:d[0x17CA]='KHMER SIGN TRIISAP'
let s:d[0x17CB]='KHMER SIGN BANTOC'
let s:d[0x17CC]='KHMER SIGN ROBAT'
let s:d[0x17CD]='KHMER SIGN TOANDAKHIAT'
let s:d[0x17CE]='KHMER SIGN KAKABAT'
let s:d[0x17CF]='KHMER SIGN AHSDA'
let s:d[0x17D0]='KHMER SIGN SAMYOK SANNYA'
let s:d[0x17D1]='KHMER SIGN VIRIAM'
let s:d[0x17D2]='KHMER SIGN COENG'
let s:d[0x17D3]='KHMER SIGN BATHAMASAT'
let s:d[0x17D4]='KHMER SIGN KHAN'
let s:d[0x17D5]='KHMER SIGN BARIYOOSAN'
let s:d[0x17D6]='KHMER SIGN CAMNUC PII KUUH'
let s:d[0x17D7]='KHMER SIGN LEK TOO'
let s:d[0x17D8]='KHMER SIGN BEYYAL'
let s:d[0x17D9]='KHMER SIGN PHNAEK MUAN'
let s:d[0x17DA]='KHMER SIGN KOOMUUT'
let s:d[0x17DB]='KHMER CURRENCY SYMBOL RIEL'
let s:d[0x17DC]='KHMER SIGN AVAKRAHASANYA'
let s:d[0x17DD]='KHMER SIGN ATTHACAN'
let s:d[0x17E0]='KHMER DIGIT ZERO'
let s:d[0x17E1]='KHMER DIGIT ONE'
let s:d[0x17E2]='KHMER DIGIT TWO'
let s:d[0x17E3]='KHMER DIGIT THREE'
let s:d[0x17E4]='KHMER DIGIT FOUR'
let s:d[0x17E5]='KHMER DIGIT FIVE'
let s:d[0x17E6]='KHMER DIGIT SIX'
let s:d[0x17E7]='KHMER DIGIT SEVEN'
let s:d[0x17E8]='KHMER DIGIT EIGHT'
let s:d[0x17E9]='KHMER DIGIT NINE'
let s:d[0x17F0]='KHMER SYMBOL LEK ATTAK SON'
let s:d[0x17F1]='KHMER SYMBOL LEK ATTAK MUOY'
let s:d[0x17F2]='KHMER SYMBOL LEK ATTAK PII'
let s:d[0x17F3]='KHMER SYMBOL LEK ATTAK BEI'
let s:d[0x17F4]='KHMER SYMBOL LEK ATTAK BUON'
let s:d[0x17F5]='KHMER SYMBOL LEK ATTAK PRAM'
let s:d[0x17F6]='KHMER SYMBOL LEK ATTAK PRAM-MUOY'
let s:d[0x17F7]='KHMER SYMBOL LEK ATTAK PRAM-PII'
let s:d[0x17F8]='KHMER SYMBOL LEK ATTAK PRAM-BEI'
let s:d[0x17F9]='KHMER SYMBOL LEK ATTAK PRAM-BUON'
let s:d[0x1800]='MONGOLIAN BIRGA'
let s:d[0x1801]='MONGOLIAN ELLIPSIS'
let s:d[0x1802]='MONGOLIAN COMMA'
let s:d[0x1803]='MONGOLIAN FULL STOP'
let s:d[0x1804]='MONGOLIAN COLON'
let s:d[0x1805]='MONGOLIAN FOUR DOTS'
let s:d[0x1806]='MONGOLIAN TODO SOFT HYPHEN'
let s:d[0x1807]='MONGOLIAN SIBE SYLLABLE BOUNDARY MARKER'
let s:d[0x1808]='MONGOLIAN MANCHU COMMA'
let s:d[0x1809]='MONGOLIAN MANCHU FULL STOP'
let s:d[0x180A]='MONGOLIAN NIRUGU'
let s:d[0x180B]='MONGOLIAN FREE VARIATION SELECTOR ONE'
let s:d[0x180C]='MONGOLIAN FREE VARIATION SELECTOR TWO'
let s:d[0x180D]='MONGOLIAN FREE VARIATION SELECTOR THREE'
let s:d[0x180E]='MONGOLIAN VOWEL SEPARATOR'
let s:d[0x1810]='MONGOLIAN DIGIT ZERO'
let s:d[0x1811]='MONGOLIAN DIGIT ONE'
let s:d[0x1812]='MONGOLIAN DIGIT TWO'
let s:d[0x1813]='MONGOLIAN DIGIT THREE'
let s:d[0x1814]='MONGOLIAN DIGIT FOUR'
let s:d[0x1815]='MONGOLIAN DIGIT FIVE'
let s:d[0x1816]='MONGOLIAN DIGIT SIX'
let s:d[0x1817]='MONGOLIAN DIGIT SEVEN'
let s:d[0x1818]='MONGOLIAN DIGIT EIGHT'
let s:d[0x1819]='MONGOLIAN DIGIT NINE'
let s:d[0x1820]='MONGOLIAN LETTER A'
let s:d[0x1821]='MONGOLIAN LETTER E'
let s:d[0x1822]='MONGOLIAN LETTER I'
let s:d[0x1823]='MONGOLIAN LETTER O'
let s:d[0x1824]='MONGOLIAN LETTER U'
let s:d[0x1825]='MONGOLIAN LETTER OE'
let s:d[0x1826]='MONGOLIAN LETTER UE'
let s:d[0x1827]='MONGOLIAN LETTER EE'
let s:d[0x1828]='MONGOLIAN LETTER NA'
let s:d[0x1829]='MONGOLIAN LETTER ANG'
let s:d[0x182A]='MONGOLIAN LETTER BA'
let s:d[0x182B]='MONGOLIAN LETTER PA'
let s:d[0x182C]='MONGOLIAN LETTER QA'
let s:d[0x182D]='MONGOLIAN LETTER GA'
let s:d[0x182E]='MONGOLIAN LETTER MA'
let s:d[0x182F]='MONGOLIAN LETTER LA'
let s:d[0x1830]='MONGOLIAN LETTER SA'
let s:d[0x1831]='MONGOLIAN LETTER SHA'
let s:d[0x1832]='MONGOLIAN LETTER TA'
let s:d[0x1833]='MONGOLIAN LETTER DA'
let s:d[0x1834]='MONGOLIAN LETTER CHA'
let s:d[0x1835]='MONGOLIAN LETTER JA'
let s:d[0x1836]='MONGOLIAN LETTER YA'
let s:d[0x1837]='MONGOLIAN LETTER RA'
let s:d[0x1838]='MONGOLIAN LETTER WA'
let s:d[0x1839]='MONGOLIAN LETTER FA'
let s:d[0x183A]='MONGOLIAN LETTER KA'
let s:d[0x183B]='MONGOLIAN LETTER KHA'
let s:d[0x183C]='MONGOLIAN LETTER TSA'
let s:d[0x183D]='MONGOLIAN LETTER ZA'
let s:d[0x183E]='MONGOLIAN LETTER HAA'
let s:d[0x183F]='MONGOLIAN LETTER ZRA'
let s:d[0x1840]='MONGOLIAN LETTER LHA'
let s:d[0x1841]='MONGOLIAN LETTER ZHI'
let s:d[0x1842]='MONGOLIAN LETTER CHI'
let s:d[0x1843]='MONGOLIAN LETTER TODO LONG VOWEL SIGN'
let s:d[0x1844]='MONGOLIAN LETTER TODO E'
let s:d[0x1845]='MONGOLIAN LETTER TODO I'
let s:d[0x1846]='MONGOLIAN LETTER TODO O'
let s:d[0x1847]='MONGOLIAN LETTER TODO U'
let s:d[0x1848]='MONGOLIAN LETTER TODO OE'
let s:d[0x1849]='MONGOLIAN LETTER TODO UE'
let s:d[0x184A]='MONGOLIAN LETTER TODO ANG'
let s:d[0x184B]='MONGOLIAN LETTER TODO BA'
let s:d[0x184C]='MONGOLIAN LETTER TODO PA'
let s:d[0x184D]='MONGOLIAN LETTER TODO QA'
let s:d[0x184E]='MONGOLIAN LETTER TODO GA'
let s:d[0x184F]='MONGOLIAN LETTER TODO MA'
let s:d[0x1850]='MONGOLIAN LETTER TODO TA'
let s:d[0x1851]='MONGOLIAN LETTER TODO DA'
let s:d[0x1852]='MONGOLIAN LETTER TODO CHA'
let s:d[0x1853]='MONGOLIAN LETTER TODO JA'
let s:d[0x1854]='MONGOLIAN LETTER TODO TSA'
let s:d[0x1855]='MONGOLIAN LETTER TODO YA'
let s:d[0x1856]='MONGOLIAN LETTER TODO WA'
let s:d[0x1857]='MONGOLIAN LETTER TODO KA'
let s:d[0x1858]='MONGOLIAN LETTER TODO GAA'
let s:d[0x1859]='MONGOLIAN LETTER TODO HAA'
let s:d[0x185A]='MONGOLIAN LETTER TODO JIA'
let s:d[0x185B]='MONGOLIAN LETTER TODO NIA'
let s:d[0x185C]='MONGOLIAN LETTER TODO DZA'
let s:d[0x185D]='MONGOLIAN LETTER SIBE E'
let s:d[0x185E]='MONGOLIAN LETTER SIBE I'
let s:d[0x185F]='MONGOLIAN LETTER SIBE IY'
let s:d[0x1860]='MONGOLIAN LETTER SIBE UE'
let s:d[0x1861]='MONGOLIAN LETTER SIBE U'
let s:d[0x1862]='MONGOLIAN LETTER SIBE ANG'
let s:d[0x1863]='MONGOLIAN LETTER SIBE KA'
let s:d[0x1864]='MONGOLIAN LETTER SIBE GA'
let s:d[0x1865]='MONGOLIAN LETTER SIBE HA'
let s:d[0x1866]='MONGOLIAN LETTER SIBE PA'
let s:d[0x1867]='MONGOLIAN LETTER SIBE SHA'
let s:d[0x1868]='MONGOLIAN LETTER SIBE TA'
let s:d[0x1869]='MONGOLIAN LETTER SIBE DA'
let s:d[0x186A]='MONGOLIAN LETTER SIBE JA'
let s:d[0x186B]='MONGOLIAN LETTER SIBE FA'
let s:d[0x186C]='MONGOLIAN LETTER SIBE GAA'
let s:d[0x186D]='MONGOLIAN LETTER SIBE HAA'
let s:d[0x186E]='MONGOLIAN LETTER SIBE TSA'
let s:d[0x186F]='MONGOLIAN LETTER SIBE ZA'
let s:d[0x1870]='MONGOLIAN LETTER SIBE RAA'
let s:d[0x1871]='MONGOLIAN LETTER SIBE CHA'
let s:d[0x1872]='MONGOLIAN LETTER SIBE ZHA'
let s:d[0x1873]='MONGOLIAN LETTER MANCHU I'
let s:d[0x1874]='MONGOLIAN LETTER MANCHU KA'
let s:d[0x1875]='MONGOLIAN LETTER MANCHU RA'
let s:d[0x1876]='MONGOLIAN LETTER MANCHU FA'
let s:d[0x1877]='MONGOLIAN LETTER MANCHU ZHA'
let s:d[0x1880]='MONGOLIAN LETTER ALI GALI ANUSVARA ONE'
let s:d[0x1881]='MONGOLIAN LETTER ALI GALI VISARGA ONE'
let s:d[0x1882]='MONGOLIAN LETTER ALI GALI DAMARU'
let s:d[0x1883]='MONGOLIAN LETTER ALI GALI UBADAMA'
let s:d[0x1884]='MONGOLIAN LETTER ALI GALI INVERTED UBADAMA'
let s:d[0x1885]='MONGOLIAN LETTER ALI GALI BALUDA'
let s:d[0x1886]='MONGOLIAN LETTER ALI GALI THREE BALUDA'
let s:d[0x1887]='MONGOLIAN LETTER ALI GALI A'
let s:d[0x1888]='MONGOLIAN LETTER ALI GALI I'
let s:d[0x1889]='MONGOLIAN LETTER ALI GALI KA'
let s:d[0x188A]='MONGOLIAN LETTER ALI GALI NGA'
let s:d[0x188B]='MONGOLIAN LETTER ALI GALI CA'
let s:d[0x188C]='MONGOLIAN LETTER ALI GALI TTA'
let s:d[0x188D]='MONGOLIAN LETTER ALI GALI TTHA'
let s:d[0x188E]='MONGOLIAN LETTER ALI GALI DDA'
let s:d[0x188F]='MONGOLIAN LETTER ALI GALI NNA'
let s:d[0x1890]='MONGOLIAN LETTER ALI GALI TA'
let s:d[0x1891]='MONGOLIAN LETTER ALI GALI DA'
let s:d[0x1892]='MONGOLIAN LETTER ALI GALI PA'
let s:d[0x1893]='MONGOLIAN LETTER ALI GALI PHA'
let s:d[0x1894]='MONGOLIAN LETTER ALI GALI SSA'
let s:d[0x1895]='MONGOLIAN LETTER ALI GALI ZHA'
let s:d[0x1896]='MONGOLIAN LETTER ALI GALI ZA'
let s:d[0x1897]='MONGOLIAN LETTER ALI GALI AH'
let s:d[0x1898]='MONGOLIAN LETTER TODO ALI GALI TA'
let s:d[0x1899]='MONGOLIAN LETTER TODO ALI GALI ZHA'
let s:d[0x189A]='MONGOLIAN LETTER MANCHU ALI GALI GHA'
let s:d[0x189B]='MONGOLIAN LETTER MANCHU ALI GALI NGA'
let s:d[0x189C]='MONGOLIAN LETTER MANCHU ALI GALI CA'
let s:d[0x189D]='MONGOLIAN LETTER MANCHU ALI GALI JHA'
let s:d[0x189E]='MONGOLIAN LETTER MANCHU ALI GALI TTA'
let s:d[0x189F]='MONGOLIAN LETTER MANCHU ALI GALI DDHA'
let s:d[0x18A0]='MONGOLIAN LETTER MANCHU ALI GALI TA'
let s:d[0x18A1]='MONGOLIAN LETTER MANCHU ALI GALI DHA'
let s:d[0x18A2]='MONGOLIAN LETTER MANCHU ALI GALI SSA'
let s:d[0x18A3]='MONGOLIAN LETTER MANCHU ALI GALI CYA'
let s:d[0x18A4]='MONGOLIAN LETTER MANCHU ALI GALI ZHA'
let s:d[0x18A5]='MONGOLIAN LETTER MANCHU ALI GALI ZA'
let s:d[0x18A6]='MONGOLIAN LETTER ALI GALI HALF U'
let s:d[0x18A7]='MONGOLIAN LETTER ALI GALI HALF YA'
let s:d[0x18A8]='MONGOLIAN LETTER MANCHU ALI GALI BHA'
let s:d[0x18A9]='MONGOLIAN LETTER ALI GALI DAGALGA'
let s:d[0x18AA]='MONGOLIAN LETTER MANCHU ALI GALI LHA'
let s:d[0x18B0]='CANADIAN SYLLABICS OY'
let s:d[0x18B1]='CANADIAN SYLLABICS AY'
let s:d[0x18B2]='CANADIAN SYLLABICS AAY'
let s:d[0x18B3]='CANADIAN SYLLABICS WAY'
let s:d[0x18B4]='CANADIAN SYLLABICS POY'
let s:d[0x18B5]='CANADIAN SYLLABICS PAY'
let s:d[0x18B6]='CANADIAN SYLLABICS PWOY'
let s:d[0x18B7]='CANADIAN SYLLABICS TAY'
let s:d[0x18B8]='CANADIAN SYLLABICS KAY'
let s:d[0x18B9]='CANADIAN SYLLABICS KWAY'
let s:d[0x18BA]='CANADIAN SYLLABICS MAY'
let s:d[0x18BB]='CANADIAN SYLLABICS NOY'
let s:d[0x18BC]='CANADIAN SYLLABICS NAY'
let s:d[0x18BD]='CANADIAN SYLLABICS LAY'
let s:d[0x18BE]='CANADIAN SYLLABICS SOY'
let s:d[0x18BF]='CANADIAN SYLLABICS SAY'
let s:d[0x18C0]='CANADIAN SYLLABICS SHOY'
let s:d[0x18C1]='CANADIAN SYLLABICS SHAY'
let s:d[0x18C2]='CANADIAN SYLLABICS SHWOY'
let s:d[0x18C3]='CANADIAN SYLLABICS YOY'
let s:d[0x18C4]='CANADIAN SYLLABICS YAY'
let s:d[0x18C5]='CANADIAN SYLLABICS RAY'
let s:d[0x18C6]='CANADIAN SYLLABICS NWI'
let s:d[0x18C7]='CANADIAN SYLLABICS OJIBWAY NWI'
let s:d[0x18C8]='CANADIAN SYLLABICS NWII'
let s:d[0x18C9]='CANADIAN SYLLABICS OJIBWAY NWII'
let s:d[0x18CA]='CANADIAN SYLLABICS NWO'
let s:d[0x18CB]='CANADIAN SYLLABICS OJIBWAY NWO'
let s:d[0x18CC]='CANADIAN SYLLABICS NWOO'
let s:d[0x18CD]='CANADIAN SYLLABICS OJIBWAY NWOO'
let s:d[0x18CE]='CANADIAN SYLLABICS RWEE'
let s:d[0x18CF]='CANADIAN SYLLABICS RWI'
let s:d[0x18D0]='CANADIAN SYLLABICS RWII'
let s:d[0x18D1]='CANADIAN SYLLABICS RWO'
let s:d[0x18D2]='CANADIAN SYLLABICS RWOO'
let s:d[0x18D3]='CANADIAN SYLLABICS RWA'
let s:d[0x18D4]='CANADIAN SYLLABICS OJIBWAY P'
let s:d[0x18D5]='CANADIAN SYLLABICS OJIBWAY T'
let s:d[0x18D6]='CANADIAN SYLLABICS OJIBWAY K'
let s:d[0x18D7]='CANADIAN SYLLABICS OJIBWAY C'
let s:d[0x18D8]='CANADIAN SYLLABICS OJIBWAY M'
let s:d[0x18D9]='CANADIAN SYLLABICS OJIBWAY N'
let s:d[0x18DA]='CANADIAN SYLLABICS OJIBWAY S'
let s:d[0x18DB]='CANADIAN SYLLABICS OJIBWAY SH'
let s:d[0x18DC]='CANADIAN SYLLABICS EASTERN W'
let s:d[0x18DD]='CANADIAN SYLLABICS WESTERN W'
let s:d[0x18DE]='CANADIAN SYLLABICS FINAL SMALL RING'
let s:d[0x18DF]='CANADIAN SYLLABICS FINAL RAISED DOT'
let s:d[0x18E0]='CANADIAN SYLLABICS R-CREE RWE'
let s:d[0x18E1]='CANADIAN SYLLABICS WEST-CREE LOO'
let s:d[0x18E2]='CANADIAN SYLLABICS WEST-CREE LAA'
let s:d[0x18E3]='CANADIAN SYLLABICS THWE'
let s:d[0x18E4]='CANADIAN SYLLABICS THWA'
let s:d[0x18E5]='CANADIAN SYLLABICS TTHWE'
let s:d[0x18E6]='CANADIAN SYLLABICS TTHOO'
let s:d[0x18E7]='CANADIAN SYLLABICS TTHAA'
let s:d[0x18E8]='CANADIAN SYLLABICS TLHWE'
let s:d[0x18E9]='CANADIAN SYLLABICS TLHOO'
let s:d[0x18EA]='CANADIAN SYLLABICS SAYISI SHWE'
let s:d[0x18EB]='CANADIAN SYLLABICS SAYISI SHOO'
let s:d[0x18EC]='CANADIAN SYLLABICS SAYISI HOO'
let s:d[0x18ED]='CANADIAN SYLLABICS CARRIER GWU'
let s:d[0x18EE]='CANADIAN SYLLABICS CARRIER DENE GEE'
let s:d[0x18EF]='CANADIAN SYLLABICS CARRIER GAA'
let s:d[0x18F0]='CANADIAN SYLLABICS CARRIER GWA'
let s:d[0x18F1]='CANADIAN SYLLABICS SAYISI JUU'
let s:d[0x18F2]='CANADIAN SYLLABICS CARRIER JWA'
let s:d[0x18F3]='CANADIAN SYLLABICS BEAVER DENE L'
let s:d[0x18F4]='CANADIAN SYLLABICS BEAVER DENE R'
let s:d[0x18F5]='CANADIAN SYLLABICS CARRIER DENTAL S'
let s:d[0x1900]='LIMBU VOWEL-CARRIER LETTER'
let s:d[0x1901]='LIMBU LETTER KA'
let s:d[0x1902]='LIMBU LETTER KHA'
let s:d[0x1903]='LIMBU LETTER GA'
let s:d[0x1904]='LIMBU LETTER GHA'
let s:d[0x1905]='LIMBU LETTER NGA'
let s:d[0x1906]='LIMBU LETTER CA'
let s:d[0x1907]='LIMBU LETTER CHA'
let s:d[0x1908]='LIMBU LETTER JA'
let s:d[0x1909]='LIMBU LETTER JHA'
let s:d[0x190A]='LIMBU LETTER YAN'
let s:d[0x190B]='LIMBU LETTER TA'
let s:d[0x190C]='LIMBU LETTER THA'
let s:d[0x190D]='LIMBU LETTER DA'
let s:d[0x190E]='LIMBU LETTER DHA'
let s:d[0x190F]='LIMBU LETTER NA'
let s:d[0x1910]='LIMBU LETTER PA'
let s:d[0x1911]='LIMBU LETTER PHA'
let s:d[0x1912]='LIMBU LETTER BA'
let s:d[0x1913]='LIMBU LETTER BHA'
let s:d[0x1914]='LIMBU LETTER MA'
let s:d[0x1915]='LIMBU LETTER YA'
let s:d[0x1916]='LIMBU LETTER RA'
let s:d[0x1917]='LIMBU LETTER LA'
let s:d[0x1918]='LIMBU LETTER WA'
let s:d[0x1919]='LIMBU LETTER SHA'
let s:d[0x191A]='LIMBU LETTER SSA'
let s:d[0x191B]='LIMBU LETTER SA'
let s:d[0x191C]='LIMBU LETTER HA'
let s:d[0x1920]='LIMBU VOWEL SIGN A'
let s:d[0x1921]='LIMBU VOWEL SIGN I'
let s:d[0x1922]='LIMBU VOWEL SIGN U'
let s:d[0x1923]='LIMBU VOWEL SIGN EE'
let s:d[0x1924]='LIMBU VOWEL SIGN AI'
let s:d[0x1925]='LIMBU VOWEL SIGN OO'
let s:d[0x1926]='LIMBU VOWEL SIGN AU'
let s:d[0x1927]='LIMBU VOWEL SIGN E'
let s:d[0x1928]='LIMBU VOWEL SIGN O'
let s:d[0x1929]='LIMBU SUBJOINED LETTER YA'
let s:d[0x192A]='LIMBU SUBJOINED LETTER RA'
let s:d[0x192B]='LIMBU SUBJOINED LETTER WA'
let s:d[0x1930]='LIMBU SMALL LETTER KA'
let s:d[0x1931]='LIMBU SMALL LETTER NGA'
let s:d[0x1932]='LIMBU SMALL LETTER ANUSVARA'
let s:d[0x1933]='LIMBU SMALL LETTER TA'
let s:d[0x1934]='LIMBU SMALL LETTER NA'
let s:d[0x1935]='LIMBU SMALL LETTER PA'
let s:d[0x1936]='LIMBU SMALL LETTER MA'
let s:d[0x1937]='LIMBU SMALL LETTER RA'
let s:d[0x1938]='LIMBU SMALL LETTER LA'
let s:d[0x1939]='LIMBU SIGN MUKPHRENG'
let s:d[0x193A]='LIMBU SIGN KEMPHRENG'
let s:d[0x193B]='LIMBU SIGN SA-I'
let s:d[0x1940]='LIMBU SIGN LOO'
let s:d[0x1944]='LIMBU EXCLAMATION MARK'
let s:d[0x1945]='LIMBU QUESTION MARK'
let s:d[0x1946]='LIMBU DIGIT ZERO'
let s:d[0x1947]='LIMBU DIGIT ONE'
let s:d[0x1948]='LIMBU DIGIT TWO'
let s:d[0x1949]='LIMBU DIGIT THREE'
let s:d[0x194A]='LIMBU DIGIT FOUR'
let s:d[0x194B]='LIMBU DIGIT FIVE'
let s:d[0x194C]='LIMBU DIGIT SIX'
let s:d[0x194D]='LIMBU DIGIT SEVEN'
let s:d[0x194E]='LIMBU DIGIT EIGHT'
let s:d[0x194F]='LIMBU DIGIT NINE'
let s:d[0x1950]='TAI LE LETTER KA'
let s:d[0x1951]='TAI LE LETTER XA'
let s:d[0x1952]='TAI LE LETTER NGA'
let s:d[0x1953]='TAI LE LETTER TSA'
let s:d[0x1954]='TAI LE LETTER SA'
let s:d[0x1955]='TAI LE LETTER YA'
let s:d[0x1956]='TAI LE LETTER TA'
let s:d[0x1957]='TAI LE LETTER THA'
let s:d[0x1958]='TAI LE LETTER LA'
let s:d[0x1959]='TAI LE LETTER PA'
let s:d[0x195A]='TAI LE LETTER PHA'
let s:d[0x195B]='TAI LE LETTER MA'
let s:d[0x195C]='TAI LE LETTER FA'
let s:d[0x195D]='TAI LE LETTER VA'
let s:d[0x195E]='TAI LE LETTER HA'
let s:d[0x195F]='TAI LE LETTER QA'
let s:d[0x1960]='TAI LE LETTER KHA'
let s:d[0x1961]='TAI LE LETTER TSHA'
let s:d[0x1962]='TAI LE LETTER NA'
let s:d[0x1963]='TAI LE LETTER A'
let s:d[0x1964]='TAI LE LETTER I'
let s:d[0x1965]='TAI LE LETTER EE'
let s:d[0x1966]='TAI LE LETTER EH'
let s:d[0x1967]='TAI LE LETTER U'
let s:d[0x1968]='TAI LE LETTER OO'
let s:d[0x1969]='TAI LE LETTER O'
let s:d[0x196A]='TAI LE LETTER UE'
let s:d[0x196B]='TAI LE LETTER E'
let s:d[0x196C]='TAI LE LETTER AUE'
let s:d[0x196D]='TAI LE LETTER AI'
let s:d[0x1970]='TAI LE LETTER TONE-2'
let s:d[0x1971]='TAI LE LETTER TONE-3'
let s:d[0x1972]='TAI LE LETTER TONE-4'
let s:d[0x1973]='TAI LE LETTER TONE-5'
let s:d[0x1974]='TAI LE LETTER TONE-6'
let s:d[0x1980]='NEW TAI LUE LETTER HIGH QA'
let s:d[0x1981]='NEW TAI LUE LETTER LOW QA'
let s:d[0x1982]='NEW TAI LUE LETTER HIGH KA'
let s:d[0x1983]='NEW TAI LUE LETTER HIGH XA'
let s:d[0x1984]='NEW TAI LUE LETTER HIGH NGA'
let s:d[0x1985]='NEW TAI LUE LETTER LOW KA'
let s:d[0x1986]='NEW TAI LUE LETTER LOW XA'
let s:d[0x1987]='NEW TAI LUE LETTER LOW NGA'
let s:d[0x1988]='NEW TAI LUE LETTER HIGH TSA'
let s:d[0x1989]='NEW TAI LUE LETTER HIGH SA'
let s:d[0x198A]='NEW TAI LUE LETTER HIGH YA'
let s:d[0x198B]='NEW TAI LUE LETTER LOW TSA'
let s:d[0x198C]='NEW TAI LUE LETTER LOW SA'
let s:d[0x198D]='NEW TAI LUE LETTER LOW YA'
let s:d[0x198E]='NEW TAI LUE LETTER HIGH TA'
let s:d[0x198F]='NEW TAI LUE LETTER HIGH THA'
let s:d[0x1990]='NEW TAI LUE LETTER HIGH NA'
let s:d[0x1991]='NEW TAI LUE LETTER LOW TA'
let s:d[0x1992]='NEW TAI LUE LETTER LOW THA'
let s:d[0x1993]='NEW TAI LUE LETTER LOW NA'
let s:d[0x1994]='NEW TAI LUE LETTER HIGH PA'
let s:d[0x1995]='NEW TAI LUE LETTER HIGH PHA'
let s:d[0x1996]='NEW TAI LUE LETTER HIGH MA'
let s:d[0x1997]='NEW TAI LUE LETTER LOW PA'
let s:d[0x1998]='NEW TAI LUE LETTER LOW PHA'
let s:d[0x1999]='NEW TAI LUE LETTER LOW MA'
let s:d[0x199A]='NEW TAI LUE LETTER HIGH FA'
let s:d[0x199B]='NEW TAI LUE LETTER HIGH VA'
let s:d[0x199C]='NEW TAI LUE LETTER HIGH LA'
let s:d[0x199D]='NEW TAI LUE LETTER LOW FA'
let s:d[0x199E]='NEW TAI LUE LETTER LOW VA'
let s:d[0x199F]='NEW TAI LUE LETTER LOW LA'
let s:d[0x19A0]='NEW TAI LUE LETTER HIGH HA'
let s:d[0x19A1]='NEW TAI LUE LETTER HIGH DA'
let s:d[0x19A2]='NEW TAI LUE LETTER HIGH BA'
let s:d[0x19A3]='NEW TAI LUE LETTER LOW HA'
let s:d[0x19A4]='NEW TAI LUE LETTER LOW DA'
let s:d[0x19A5]='NEW TAI LUE LETTER LOW BA'
let s:d[0x19A6]='NEW TAI LUE LETTER HIGH KVA'
let s:d[0x19A7]='NEW TAI LUE LETTER HIGH XVA'
let s:d[0x19A8]='NEW TAI LUE LETTER LOW KVA'
let s:d[0x19A9]='NEW TAI LUE LETTER LOW XVA'
let s:d[0x19AA]='NEW TAI LUE LETTER HIGH SUA'
let s:d[0x19AB]='NEW TAI LUE LETTER LOW SUA'
let s:d[0x19B0]='NEW TAI LUE VOWEL SIGN VOWEL SHORTENER'
let s:d[0x19B1]='NEW TAI LUE VOWEL SIGN AA'
let s:d[0x19B2]='NEW TAI LUE VOWEL SIGN II'
let s:d[0x19B3]='NEW TAI LUE VOWEL SIGN U'
let s:d[0x19B4]='NEW TAI LUE VOWEL SIGN UU'
let s:d[0x19B5]='NEW TAI LUE VOWEL SIGN E'
let s:d[0x19B6]='NEW TAI LUE VOWEL SIGN AE'
let s:d[0x19B7]='NEW TAI LUE VOWEL SIGN O'
let s:d[0x19B8]='NEW TAI LUE VOWEL SIGN OA'
let s:d[0x19B9]='NEW TAI LUE VOWEL SIGN UE'
let s:d[0x19BA]='NEW TAI LUE VOWEL SIGN AY'
let s:d[0x19BB]='NEW TAI LUE VOWEL SIGN AAY'
let s:d[0x19BC]='NEW TAI LUE VOWEL SIGN UY'
let s:d[0x19BD]='NEW TAI LUE VOWEL SIGN OY'
let s:d[0x19BE]='NEW TAI LUE VOWEL SIGN OAY'
let s:d[0x19BF]='NEW TAI LUE VOWEL SIGN UEY'
let s:d[0x19C0]='NEW TAI LUE VOWEL SIGN IY'
let s:d[0x19C1]='NEW TAI LUE LETTER FINAL V'
let s:d[0x19C2]='NEW TAI LUE LETTER FINAL NG'
let s:d[0x19C3]='NEW TAI LUE LETTER FINAL N'
let s:d[0x19C4]='NEW TAI LUE LETTER FINAL M'
let s:d[0x19C5]='NEW TAI LUE LETTER FINAL K'
let s:d[0x19C6]='NEW TAI LUE LETTER FINAL D'
let s:d[0x19C7]='NEW TAI LUE LETTER FINAL B'
let s:d[0x19C8]='NEW TAI LUE TONE MARK-1'
let s:d[0x19C9]='NEW TAI LUE TONE MARK-2'
let s:d[0x19D0]='NEW TAI LUE DIGIT ZERO'
let s:d[0x19D1]='NEW TAI LUE DIGIT ONE'
let s:d[0x19D2]='NEW TAI LUE DIGIT TWO'
let s:d[0x19D3]='NEW TAI LUE DIGIT THREE'
let s:d[0x19D4]='NEW TAI LUE DIGIT FOUR'
let s:d[0x19D5]='NEW TAI LUE DIGIT FIVE'
let s:d[0x19D6]='NEW TAI LUE DIGIT SIX'
let s:d[0x19D7]='NEW TAI LUE DIGIT SEVEN'
let s:d[0x19D8]='NEW TAI LUE DIGIT EIGHT'
let s:d[0x19D9]='NEW TAI LUE DIGIT NINE'
let s:d[0x19DA]='NEW TAI LUE THAM DIGIT ONE'
let s:d[0x19DE]='NEW TAI LUE SIGN LAE'
let s:d[0x19DF]='NEW TAI LUE SIGN LAEV'
let s:d[0x19E0]='KHMER SYMBOL PATHAMASAT'
let s:d[0x19E1]='KHMER SYMBOL MUOY KOET'
let s:d[0x19E2]='KHMER SYMBOL PII KOET'
let s:d[0x19E3]='KHMER SYMBOL BEI KOET'
let s:d[0x19E4]='KHMER SYMBOL BUON KOET'
let s:d[0x19E5]='KHMER SYMBOL PRAM KOET'
let s:d[0x19E6]='KHMER SYMBOL PRAM-MUOY KOET'
let s:d[0x19E7]='KHMER SYMBOL PRAM-PII KOET'
let s:d[0x19E8]='KHMER SYMBOL PRAM-BEI KOET'
let s:d[0x19E9]='KHMER SYMBOL PRAM-BUON KOET'
let s:d[0x19EA]='KHMER SYMBOL DAP KOET'
let s:d[0x19EB]='KHMER SYMBOL DAP-MUOY KOET'
let s:d[0x19EC]='KHMER SYMBOL DAP-PII KOET'
let s:d[0x19ED]='KHMER SYMBOL DAP-BEI KOET'
let s:d[0x19EE]='KHMER SYMBOL DAP-BUON KOET'
let s:d[0x19EF]='KHMER SYMBOL DAP-PRAM KOET'
let s:d[0x19F0]='KHMER SYMBOL TUTEYASAT'
let s:d[0x19F1]='KHMER SYMBOL MUOY ROC'
let s:d[0x19F2]='KHMER SYMBOL PII ROC'
let s:d[0x19F3]='KHMER SYMBOL BEI ROC'
let s:d[0x19F4]='KHMER SYMBOL BUON ROC'
let s:d[0x19F5]='KHMER SYMBOL PRAM ROC'
let s:d[0x19F6]='KHMER SYMBOL PRAM-MUOY ROC'
let s:d[0x19F7]='KHMER SYMBOL PRAM-PII ROC'
let s:d[0x19F8]='KHMER SYMBOL PRAM-BEI ROC'
let s:d[0x19F9]='KHMER SYMBOL PRAM-BUON ROC'
let s:d[0x19FA]='KHMER SYMBOL DAP ROC'
let s:d[0x19FB]='KHMER SYMBOL DAP-MUOY ROC'
let s:d[0x19FC]='KHMER SYMBOL DAP-PII ROC'
let s:d[0x19FD]='KHMER SYMBOL DAP-BEI ROC'
let s:d[0x19FE]='KHMER SYMBOL DAP-BUON ROC'
let s:d[0x19FF]='KHMER SYMBOL DAP-PRAM ROC'
let s:d[0x1A00]='BUGINESE LETTER KA'
let s:d[0x1A01]='BUGINESE LETTER GA'
let s:d[0x1A02]='BUGINESE LETTER NGA'
let s:d[0x1A03]='BUGINESE LETTER NGKA'
let s:d[0x1A04]='BUGINESE LETTER PA'
let s:d[0x1A05]='BUGINESE LETTER BA'
let s:d[0x1A06]='BUGINESE LETTER MA'
let s:d[0x1A07]='BUGINESE LETTER MPA'
let s:d[0x1A08]='BUGINESE LETTER TA'
let s:d[0x1A09]='BUGINESE LETTER DA'
let s:d[0x1A0A]='BUGINESE LETTER NA'
let s:d[0x1A0B]='BUGINESE LETTER NRA'
let s:d[0x1A0C]='BUGINESE LETTER CA'
let s:d[0x1A0D]='BUGINESE LETTER JA'
let s:d[0x1A0E]='BUGINESE LETTER NYA'
let s:d[0x1A0F]='BUGINESE LETTER NYCA'
let s:d[0x1A10]='BUGINESE LETTER YA'
let s:d[0x1A11]='BUGINESE LETTER RA'
let s:d[0x1A12]='BUGINESE LETTER LA'
let s:d[0x1A13]='BUGINESE LETTER VA'
let s:d[0x1A14]='BUGINESE LETTER SA'
let s:d[0x1A15]='BUGINESE LETTER A'
let s:d[0x1A16]='BUGINESE LETTER HA'
let s:d[0x1A17]='BUGINESE VOWEL SIGN I'
let s:d[0x1A18]='BUGINESE VOWEL SIGN U'
let s:d[0x1A19]='BUGINESE VOWEL SIGN E'
let s:d[0x1A1A]='BUGINESE VOWEL SIGN O'
let s:d[0x1A1B]='BUGINESE VOWEL SIGN AE'
let s:d[0x1A1E]='BUGINESE PALLAWA'
let s:d[0x1A1F]='BUGINESE END OF SECTION'
let s:d[0x1A20]='TAI THAM LETTER HIGH KA'
let s:d[0x1A21]='TAI THAM LETTER HIGH KHA'
let s:d[0x1A22]='TAI THAM LETTER HIGH KXA'
let s:d[0x1A23]='TAI THAM LETTER LOW KA'
let s:d[0x1A24]='TAI THAM LETTER LOW KXA'
let s:d[0x1A25]='TAI THAM LETTER LOW KHA'
let s:d[0x1A26]='TAI THAM LETTER NGA'
let s:d[0x1A27]='TAI THAM LETTER HIGH CA'
let s:d[0x1A28]='TAI THAM LETTER HIGH CHA'
let s:d[0x1A29]='TAI THAM LETTER LOW CA'
let s:d[0x1A2A]='TAI THAM LETTER LOW SA'
let s:d[0x1A2B]='TAI THAM LETTER LOW CHA'
let s:d[0x1A2C]='TAI THAM LETTER NYA'
let s:d[0x1A2D]='TAI THAM LETTER RATA'
let s:d[0x1A2E]='TAI THAM LETTER HIGH RATHA'
let s:d[0x1A2F]='TAI THAM LETTER DA'
let s:d[0x1A30]='TAI THAM LETTER LOW RATHA'
let s:d[0x1A31]='TAI THAM LETTER RANA'
let s:d[0x1A32]='TAI THAM LETTER HIGH TA'
let s:d[0x1A33]='TAI THAM LETTER HIGH THA'
let s:d[0x1A34]='TAI THAM LETTER LOW TA'
let s:d[0x1A35]='TAI THAM LETTER LOW THA'
let s:d[0x1A36]='TAI THAM LETTER NA'
let s:d[0x1A37]='TAI THAM LETTER BA'
let s:d[0x1A38]='TAI THAM LETTER HIGH PA'
let s:d[0x1A39]='TAI THAM LETTER HIGH PHA'
let s:d[0x1A3A]='TAI THAM LETTER HIGH FA'
let s:d[0x1A3B]='TAI THAM LETTER LOW PA'
let s:d[0x1A3C]='TAI THAM LETTER LOW FA'
let s:d[0x1A3D]='TAI THAM LETTER LOW PHA'
let s:d[0x1A3E]='TAI THAM LETTER MA'
let s:d[0x1A3F]='TAI THAM LETTER LOW YA'
let s:d[0x1A40]='TAI THAM LETTER HIGH YA'
let s:d[0x1A41]='TAI THAM LETTER RA'
let s:d[0x1A42]='TAI THAM LETTER RUE'
let s:d[0x1A43]='TAI THAM LETTER LA'
let s:d[0x1A44]='TAI THAM LETTER LUE'
let s:d[0x1A45]='TAI THAM LETTER WA'
let s:d[0x1A46]='TAI THAM LETTER HIGH SHA'
let s:d[0x1A47]='TAI THAM LETTER HIGH SSA'
let s:d[0x1A48]='TAI THAM LETTER HIGH SA'
let s:d[0x1A49]='TAI THAM LETTER HIGH HA'
let s:d[0x1A4A]='TAI THAM LETTER LLA'
let s:d[0x1A4B]='TAI THAM LETTER A'
let s:d[0x1A4C]='TAI THAM LETTER LOW HA'
let s:d[0x1A4D]='TAI THAM LETTER I'
let s:d[0x1A4E]='TAI THAM LETTER II'
let s:d[0x1A4F]='TAI THAM LETTER U'
let s:d[0x1A50]='TAI THAM LETTER UU'
let s:d[0x1A51]='TAI THAM LETTER EE'
let s:d[0x1A52]='TAI THAM LETTER OO'
let s:d[0x1A53]='TAI THAM LETTER LAE'
let s:d[0x1A54]='TAI THAM LETTER GREAT SA'
let s:d[0x1A55]='TAI THAM CONSONANT SIGN MEDIAL RA'
let s:d[0x1A56]='TAI THAM CONSONANT SIGN MEDIAL LA'
let s:d[0x1A57]='TAI THAM CONSONANT SIGN LA TANG LAI'
let s:d[0x1A58]='TAI THAM SIGN MAI KANG LAI'
let s:d[0x1A59]='TAI THAM CONSONANT SIGN FINAL NGA'
let s:d[0x1A5A]='TAI THAM CONSONANT SIGN LOW PA'
let s:d[0x1A5B]='TAI THAM CONSONANT SIGN HIGH RATHA OR LOW PA'
let s:d[0x1A5C]='TAI THAM CONSONANT SIGN MA'
let s:d[0x1A5D]='TAI THAM CONSONANT SIGN BA'
let s:d[0x1A5E]='TAI THAM CONSONANT SIGN SA'
let s:d[0x1A60]='TAI THAM SIGN SAKOT'
let s:d[0x1A61]='TAI THAM VOWEL SIGN A'
let s:d[0x1A62]='TAI THAM VOWEL SIGN MAI SAT'
let s:d[0x1A63]='TAI THAM VOWEL SIGN AA'
let s:d[0x1A64]='TAI THAM VOWEL SIGN TALL AA'
let s:d[0x1A65]='TAI THAM VOWEL SIGN I'
let s:d[0x1A66]='TAI THAM VOWEL SIGN II'
let s:d[0x1A67]='TAI THAM VOWEL SIGN UE'
let s:d[0x1A68]='TAI THAM VOWEL SIGN UUE'
let s:d[0x1A69]='TAI THAM VOWEL SIGN U'
let s:d[0x1A6A]='TAI THAM VOWEL SIGN UU'
let s:d[0x1A6B]='TAI THAM VOWEL SIGN O'
let s:d[0x1A6C]='TAI THAM VOWEL SIGN OA BELOW'
let s:d[0x1A6D]='TAI THAM VOWEL SIGN OY'
let s:d[0x1A6E]='TAI THAM VOWEL SIGN E'
let s:d[0x1A6F]='TAI THAM VOWEL SIGN AE'
let s:d[0x1A70]='TAI THAM VOWEL SIGN OO'
let s:d[0x1A71]='TAI THAM VOWEL SIGN AI'
let s:d[0x1A72]='TAI THAM VOWEL SIGN THAM AI'
let s:d[0x1A73]='TAI THAM VOWEL SIGN OA ABOVE'
let s:d[0x1A74]='TAI THAM SIGN MAI KANG'
let s:d[0x1A75]='TAI THAM SIGN TONE-1'
let s:d[0x1A76]='TAI THAM SIGN TONE-2'
let s:d[0x1A77]='TAI THAM SIGN KHUEN TONE-3'
let s:d[0x1A78]='TAI THAM SIGN KHUEN TONE-4'
let s:d[0x1A79]='TAI THAM SIGN KHUEN TONE-5'
let s:d[0x1A7A]='TAI THAM SIGN RA HAAM'
let s:d[0x1A7B]='TAI THAM SIGN MAI SAM'
let s:d[0x1A7C]='TAI THAM SIGN KHUEN-LUE KARAN'
let s:d[0x1A7F]='TAI THAM COMBINING CRYPTOGRAMMIC DOT'
let s:d[0x1A80]='TAI THAM HORA DIGIT ZERO'
let s:d[0x1A81]='TAI THAM HORA DIGIT ONE'
let s:d[0x1A82]='TAI THAM HORA DIGIT TWO'
let s:d[0x1A83]='TAI THAM HORA DIGIT THREE'
let s:d[0x1A84]='TAI THAM HORA DIGIT FOUR'
let s:d[0x1A85]='TAI THAM HORA DIGIT FIVE'
let s:d[0x1A86]='TAI THAM HORA DIGIT SIX'
let s:d[0x1A87]='TAI THAM HORA DIGIT SEVEN'
let s:d[0x1A88]='TAI THAM HORA DIGIT EIGHT'
let s:d[0x1A89]='TAI THAM HORA DIGIT NINE'
let s:d[0x1A90]='TAI THAM THAM DIGIT ZERO'
let s:d[0x1A91]='TAI THAM THAM DIGIT ONE'
let s:d[0x1A92]='TAI THAM THAM DIGIT TWO'
let s:d[0x1A93]='TAI THAM THAM DIGIT THREE'
let s:d[0x1A94]='TAI THAM THAM DIGIT FOUR'
let s:d[0x1A95]='TAI THAM THAM DIGIT FIVE'
let s:d[0x1A96]='TAI THAM THAM DIGIT SIX'
let s:d[0x1A97]='TAI THAM THAM DIGIT SEVEN'
let s:d[0x1A98]='TAI THAM THAM DIGIT EIGHT'
let s:d[0x1A99]='TAI THAM THAM DIGIT NINE'
let s:d[0x1AA0]='TAI THAM SIGN WIANG'
let s:d[0x1AA1]='TAI THAM SIGN WIANGWAAK'
let s:d[0x1AA2]='TAI THAM SIGN SAWAN'
let s:d[0x1AA3]='TAI THAM SIGN KEOW'
let s:d[0x1AA4]='TAI THAM SIGN HOY'
let s:d[0x1AA5]='TAI THAM SIGN DOKMAI'
let s:d[0x1AA6]='TAI THAM SIGN REVERSED ROTATED RANA'
let s:d[0x1AA7]='TAI THAM SIGN MAI YAMOK'
let s:d[0x1AA8]='TAI THAM SIGN KAAN'
let s:d[0x1AA9]='TAI THAM SIGN KAANKUU'
let s:d[0x1AAA]='TAI THAM SIGN SATKAAN'
let s:d[0x1AAB]='TAI THAM SIGN SATKAANKUU'
let s:d[0x1AAC]='TAI THAM SIGN HANG'
let s:d[0x1AAD]='TAI THAM SIGN CAANG'
let s:d[0x1B00]='BALINESE SIGN ULU RICEM'
let s:d[0x1B01]='BALINESE SIGN ULU CANDRA'
let s:d[0x1B02]='BALINESE SIGN CECEK'
let s:d[0x1B03]='BALINESE SIGN SURANG'
let s:d[0x1B04]='BALINESE SIGN BISAH'
let s:d[0x1B05]='BALINESE LETTER AKARA'
let s:d[0x1B06]='BALINESE LETTER AKARA TEDUNG'
let s:d[0x1B07]='BALINESE LETTER IKARA'
let s:d[0x1B08]='BALINESE LETTER IKARA TEDUNG'
let s:d[0x1B09]='BALINESE LETTER UKARA'
let s:d[0x1B0A]='BALINESE LETTER UKARA TEDUNG'
let s:d[0x1B0B]='BALINESE LETTER RA REPA'
let s:d[0x1B0C]='BALINESE LETTER RA REPA TEDUNG'
let s:d[0x1B0D]='BALINESE LETTER LA LENGA'
let s:d[0x1B0E]='BALINESE LETTER LA LENGA TEDUNG'
let s:d[0x1B0F]='BALINESE LETTER EKARA'
let s:d[0x1B10]='BALINESE LETTER AIKARA'
let s:d[0x1B11]='BALINESE LETTER OKARA'
let s:d[0x1B12]='BALINESE LETTER OKARA TEDUNG'
let s:d[0x1B13]='BALINESE LETTER KA'
let s:d[0x1B14]='BALINESE LETTER KA MAHAPRANA'
let s:d[0x1B15]='BALINESE LETTER GA'
let s:d[0x1B16]='BALINESE LETTER GA GORA'
let s:d[0x1B17]='BALINESE LETTER NGA'
let s:d[0x1B18]='BALINESE LETTER CA'
let s:d[0x1B19]='BALINESE LETTER CA LACA'
let s:d[0x1B1A]='BALINESE LETTER JA'
let s:d[0x1B1B]='BALINESE LETTER JA JERA'
let s:d[0x1B1C]='BALINESE LETTER NYA'
let s:d[0x1B1D]='BALINESE LETTER TA LATIK'
let s:d[0x1B1E]='BALINESE LETTER TA MURDA MAHAPRANA'
let s:d[0x1B1F]='BALINESE LETTER DA MURDA ALPAPRANA'
let s:d[0x1B20]='BALINESE LETTER DA MURDA MAHAPRANA'
let s:d[0x1B21]='BALINESE LETTER NA RAMBAT'
let s:d[0x1B22]='BALINESE LETTER TA'
let s:d[0x1B23]='BALINESE LETTER TA TAWA'
let s:d[0x1B24]='BALINESE LETTER DA'
let s:d[0x1B25]='BALINESE LETTER DA MADU'
let s:d[0x1B26]='BALINESE LETTER NA'
let s:d[0x1B27]='BALINESE LETTER PA'
let s:d[0x1B28]='BALINESE LETTER PA KAPAL'
let s:d[0x1B29]='BALINESE LETTER BA'
let s:d[0x1B2A]='BALINESE LETTER BA KEMBANG'
let s:d[0x1B2B]='BALINESE LETTER MA'
let s:d[0x1B2C]='BALINESE LETTER YA'
let s:d[0x1B2D]='BALINESE LETTER RA'
let s:d[0x1B2E]='BALINESE LETTER LA'
let s:d[0x1B2F]='BALINESE LETTER WA'
let s:d[0x1B30]='BALINESE LETTER SA SAGA'
let s:d[0x1B31]='BALINESE LETTER SA SAPA'
let s:d[0x1B32]='BALINESE LETTER SA'
let s:d[0x1B33]='BALINESE LETTER HA'
let s:d[0x1B34]='BALINESE SIGN REREKAN'
let s:d[0x1B35]='BALINESE VOWEL SIGN TEDUNG'
let s:d[0x1B36]='BALINESE VOWEL SIGN ULU'
let s:d[0x1B37]='BALINESE VOWEL SIGN ULU SARI'
let s:d[0x1B38]='BALINESE VOWEL SIGN SUKU'
let s:d[0x1B39]='BALINESE VOWEL SIGN SUKU ILUT'
let s:d[0x1B3A]='BALINESE VOWEL SIGN RA REPA'
let s:d[0x1B3B]='BALINESE VOWEL SIGN RA REPA TEDUNG'
let s:d[0x1B3C]='BALINESE VOWEL SIGN LA LENGA'
let s:d[0x1B3D]='BALINESE VOWEL SIGN LA LENGA TEDUNG'
let s:d[0x1B3E]='BALINESE VOWEL SIGN TALING'
let s:d[0x1B3F]='BALINESE VOWEL SIGN TALING REPA'
let s:d[0x1B40]='BALINESE VOWEL SIGN TALING TEDUNG'
let s:d[0x1B41]='BALINESE VOWEL SIGN TALING REPA TEDUNG'
let s:d[0x1B42]='BALINESE VOWEL SIGN PEPET'
let s:d[0x1B43]='BALINESE VOWEL SIGN PEPET TEDUNG'
let s:d[0x1B44]='BALINESE ADEG ADEG'
let s:d[0x1B45]='BALINESE LETTER KAF SASAK'
let s:d[0x1B46]='BALINESE LETTER KHOT SASAK'
let s:d[0x1B47]='BALINESE LETTER TZIR SASAK'
let s:d[0x1B48]='BALINESE LETTER EF SASAK'
let s:d[0x1B49]='BALINESE LETTER VE SASAK'
let s:d[0x1B4A]='BALINESE LETTER ZAL SASAK'
let s:d[0x1B4B]='BALINESE LETTER ASYURA SASAK'
let s:d[0x1B50]='BALINESE DIGIT ZERO'
let s:d[0x1B51]='BALINESE DIGIT ONE'
let s:d[0x1B52]='BALINESE DIGIT TWO'
let s:d[0x1B53]='BALINESE DIGIT THREE'
let s:d[0x1B54]='BALINESE DIGIT FOUR'
let s:d[0x1B55]='BALINESE DIGIT FIVE'
let s:d[0x1B56]='BALINESE DIGIT SIX'
let s:d[0x1B57]='BALINESE DIGIT SEVEN'
let s:d[0x1B58]='BALINESE DIGIT EIGHT'
let s:d[0x1B59]='BALINESE DIGIT NINE'
let s:d[0x1B5A]='BALINESE PANTI'
let s:d[0x1B5B]='BALINESE PAMADA'
let s:d[0x1B5C]='BALINESE WINDU'
let s:d[0x1B5D]='BALINESE CARIK PAMUNGKAH'
let s:d[0x1B5E]='BALINESE CARIK SIKI'
let s:d[0x1B5F]='BALINESE CARIK PAREREN'
let s:d[0x1B60]='BALINESE PAMENENG'
let s:d[0x1B61]='BALINESE MUSICAL SYMBOL DONG'
let s:d[0x1B62]='BALINESE MUSICAL SYMBOL DENG'
let s:d[0x1B63]='BALINESE MUSICAL SYMBOL DUNG'
let s:d[0x1B64]='BALINESE MUSICAL SYMBOL DANG'
let s:d[0x1B65]='BALINESE MUSICAL SYMBOL DANG SURANG'
let s:d[0x1B66]='BALINESE MUSICAL SYMBOL DING'
let s:d[0x1B67]='BALINESE MUSICAL SYMBOL DAENG'
let s:d[0x1B68]='BALINESE MUSICAL SYMBOL DEUNG'
let s:d[0x1B69]='BALINESE MUSICAL SYMBOL DAING'
let s:d[0x1B6A]='BALINESE MUSICAL SYMBOL DANG GEDE'
let s:d[0x1B6B]='BALINESE MUSICAL SYMBOL COMBINING TEGEH'
let s:d[0x1B6C]='BALINESE MUSICAL SYMBOL COMBINING ENDEP'
let s:d[0x1B6D]='BALINESE MUSICAL SYMBOL COMBINING KEMPUL'
let s:d[0x1B6E]='BALINESE MUSICAL SYMBOL COMBINING KEMPLI'
let s:d[0x1B6F]='BALINESE MUSICAL SYMBOL COMBINING JEGOGAN'
let s:d[0x1B70]='BALINESE MUSICAL SYMBOL COMBINING KEMPUL WITH JEGOGAN'
let s:d[0x1B71]='BALINESE MUSICAL SYMBOL COMBINING KEMPLI WITH JEGOGAN'
let s:d[0x1B72]='BALINESE MUSICAL SYMBOL COMBINING BENDE'
let s:d[0x1B73]='BALINESE MUSICAL SYMBOL COMBINING GONG'
let s:d[0x1B74]='BALINESE MUSICAL SYMBOL RIGHT-HAND OPEN DUG'
let s:d[0x1B75]='BALINESE MUSICAL SYMBOL RIGHT-HAND OPEN DAG'
let s:d[0x1B76]='BALINESE MUSICAL SYMBOL RIGHT-HAND CLOSED TUK'
let s:d[0x1B77]='BALINESE MUSICAL SYMBOL RIGHT-HAND CLOSED TAK'
let s:d[0x1B78]='BALINESE MUSICAL SYMBOL LEFT-HAND OPEN PANG'
let s:d[0x1B79]='BALINESE MUSICAL SYMBOL LEFT-HAND OPEN PUNG'
let s:d[0x1B7A]='BALINESE MUSICAL SYMBOL LEFT-HAND CLOSED PLAK'
let s:d[0x1B7B]='BALINESE MUSICAL SYMBOL LEFT-HAND CLOSED PLUK'
let s:d[0x1B7C]='BALINESE MUSICAL SYMBOL LEFT-HAND OPEN PING'
let s:d[0x1B80]='SUNDANESE SIGN PANYECEK'
let s:d[0x1B81]='SUNDANESE SIGN PANGLAYAR'
let s:d[0x1B82]='SUNDANESE SIGN PANGWISAD'
let s:d[0x1B83]='SUNDANESE LETTER A'
let s:d[0x1B84]='SUNDANESE LETTER I'
let s:d[0x1B85]='SUNDANESE LETTER U'
let s:d[0x1B86]='SUNDANESE LETTER AE'
let s:d[0x1B87]='SUNDANESE LETTER O'
let s:d[0x1B88]='SUNDANESE LETTER E'
let s:d[0x1B89]='SUNDANESE LETTER EU'
let s:d[0x1B8A]='SUNDANESE LETTER KA'
let s:d[0x1B8B]='SUNDANESE LETTER QA'
let s:d[0x1B8C]='SUNDANESE LETTER GA'
let s:d[0x1B8D]='SUNDANESE LETTER NGA'
let s:d[0x1B8E]='SUNDANESE LETTER CA'
let s:d[0x1B8F]='SUNDANESE LETTER JA'
let s:d[0x1B90]='SUNDANESE LETTER ZA'
let s:d[0x1B91]='SUNDANESE LETTER NYA'
let s:d[0x1B92]='SUNDANESE LETTER TA'
let s:d[0x1B93]='SUNDANESE LETTER DA'
let s:d[0x1B94]='SUNDANESE LETTER NA'
let s:d[0x1B95]='SUNDANESE LETTER PA'
let s:d[0x1B96]='SUNDANESE LETTER FA'
let s:d[0x1B97]='SUNDANESE LETTER VA'
let s:d[0x1B98]='SUNDANESE LETTER BA'
let s:d[0x1B99]='SUNDANESE LETTER MA'
let s:d[0x1B9A]='SUNDANESE LETTER YA'
let s:d[0x1B9B]='SUNDANESE LETTER RA'
let s:d[0x1B9C]='SUNDANESE LETTER LA'
let s:d[0x1B9D]='SUNDANESE LETTER WA'
let s:d[0x1B9E]='SUNDANESE LETTER SA'
let s:d[0x1B9F]='SUNDANESE LETTER XA'
let s:d[0x1BA0]='SUNDANESE LETTER HA'
let s:d[0x1BA1]='SUNDANESE CONSONANT SIGN PAMINGKAL'
let s:d[0x1BA2]='SUNDANESE CONSONANT SIGN PANYAKRA'
let s:d[0x1BA3]='SUNDANESE CONSONANT SIGN PANYIKU'
let s:d[0x1BA4]='SUNDANESE VOWEL SIGN PANGHULU'
let s:d[0x1BA5]='SUNDANESE VOWEL SIGN PANYUKU'
let s:d[0x1BA6]='SUNDANESE VOWEL SIGN PANAELAENG'
let s:d[0x1BA7]='SUNDANESE VOWEL SIGN PANOLONG'
let s:d[0x1BA8]='SUNDANESE VOWEL SIGN PAMEPET'
let s:d[0x1BA9]='SUNDANESE VOWEL SIGN PANEULEUNG'
let s:d[0x1BAA]='SUNDANESE SIGN PAMAAEH'
let s:d[0x1BAB]='SUNDANESE SIGN VIRAMA'
let s:d[0x1BAC]='SUNDANESE CONSONANT SIGN PASANGAN MA'
let s:d[0x1BAD]='SUNDANESE CONSONANT SIGN PASANGAN WA'
let s:d[0x1BAE]='SUNDANESE LETTER KHA'
let s:d[0x1BAF]='SUNDANESE LETTER SYA'
let s:d[0x1BB0]='SUNDANESE DIGIT ZERO'
let s:d[0x1BB1]='SUNDANESE DIGIT ONE'
let s:d[0x1BB2]='SUNDANESE DIGIT TWO'
let s:d[0x1BB3]='SUNDANESE DIGIT THREE'
let s:d[0x1BB4]='SUNDANESE DIGIT FOUR'
let s:d[0x1BB5]='SUNDANESE DIGIT FIVE'
let s:d[0x1BB6]='SUNDANESE DIGIT SIX'
let s:d[0x1BB7]='SUNDANESE DIGIT SEVEN'
let s:d[0x1BB8]='SUNDANESE DIGIT EIGHT'
let s:d[0x1BB9]='SUNDANESE DIGIT NINE'
let s:d[0x1BBA]='SUNDANESE AVAGRAHA'
let s:d[0x1BBB]='SUNDANESE LETTER REU'
let s:d[0x1BBC]='SUNDANESE LETTER LEU'
let s:d[0x1BBD]='SUNDANESE LETTER BHA'
let s:d[0x1BBE]='SUNDANESE LETTER FINAL K'
let s:d[0x1BBF]='SUNDANESE LETTER FINAL M'
let s:d[0x1BC0]='BATAK LETTER A'
let s:d[0x1BC1]='BATAK LETTER SIMALUNGUN A'
let s:d[0x1BC2]='BATAK LETTER HA'
let s:d[0x1BC3]='BATAK LETTER SIMALUNGUN HA'
let s:d[0x1BC4]='BATAK LETTER MANDAILING HA'
let s:d[0x1BC5]='BATAK LETTER BA'
let s:d[0x1BC6]='BATAK LETTER KARO BA'
let s:d[0x1BC7]='BATAK LETTER PA'
let s:d[0x1BC8]='BATAK LETTER SIMALUNGUN PA'
let s:d[0x1BC9]='BATAK LETTER NA'
let s:d[0x1BCA]='BATAK LETTER MANDAILING NA'
let s:d[0x1BCB]='BATAK LETTER WA'
let s:d[0x1BCC]='BATAK LETTER SIMALUNGUN WA'
let s:d[0x1BCD]='BATAK LETTER PAKPAK WA'
let s:d[0x1BCE]='BATAK LETTER GA'
let s:d[0x1BCF]='BATAK LETTER SIMALUNGUN GA'
let s:d[0x1BD0]='BATAK LETTER JA'
let s:d[0x1BD1]='BATAK LETTER DA'
let s:d[0x1BD2]='BATAK LETTER RA'
let s:d[0x1BD3]='BATAK LETTER SIMALUNGUN RA'
let s:d[0x1BD4]='BATAK LETTER MA'
let s:d[0x1BD5]='BATAK LETTER SIMALUNGUN MA'
let s:d[0x1BD6]='BATAK LETTER SOUTHERN TA'
let s:d[0x1BD7]='BATAK LETTER NORTHERN TA'
let s:d[0x1BD8]='BATAK LETTER SA'
let s:d[0x1BD9]='BATAK LETTER SIMALUNGUN SA'
let s:d[0x1BDA]='BATAK LETTER MANDAILING SA'
let s:d[0x1BDB]='BATAK LETTER YA'
let s:d[0x1BDC]='BATAK LETTER SIMALUNGUN YA'
let s:d[0x1BDD]='BATAK LETTER NGA'
let s:d[0x1BDE]='BATAK LETTER LA'
let s:d[0x1BDF]='BATAK LETTER SIMALUNGUN LA'
let s:d[0x1BE0]='BATAK LETTER NYA'
let s:d[0x1BE1]='BATAK LETTER CA'
let s:d[0x1BE2]='BATAK LETTER NDA'
let s:d[0x1BE3]='BATAK LETTER MBA'
let s:d[0x1BE4]='BATAK LETTER I'
let s:d[0x1BE5]='BATAK LETTER U'
let s:d[0x1BE6]='BATAK SIGN TOMPI'
let s:d[0x1BE7]='BATAK VOWEL SIGN E'
let s:d[0x1BE8]='BATAK VOWEL SIGN PAKPAK E'
let s:d[0x1BE9]='BATAK VOWEL SIGN EE'
let s:d[0x1BEA]='BATAK VOWEL SIGN I'
let s:d[0x1BEB]='BATAK VOWEL SIGN KARO I'
let s:d[0x1BEC]='BATAK VOWEL SIGN O'
let s:d[0x1BED]='BATAK VOWEL SIGN KARO O'
let s:d[0x1BEE]='BATAK VOWEL SIGN U'
let s:d[0x1BEF]='BATAK VOWEL SIGN U FOR SIMALUNGUN SA'
let s:d[0x1BF0]='BATAK CONSONANT SIGN NG'
let s:d[0x1BF1]='BATAK CONSONANT SIGN H'
let s:d[0x1BF2]='BATAK PANGOLAT'
let s:d[0x1BF3]='BATAK PANONGONAN'
let s:d[0x1BFC]='BATAK SYMBOL BINDU NA METEK'
let s:d[0x1BFD]='BATAK SYMBOL BINDU PINARBORAS'
let s:d[0x1BFE]='BATAK SYMBOL BINDU JUDUL'
let s:d[0x1BFF]='BATAK SYMBOL BINDU PANGOLAT'
let s:d[0x1C00]='LEPCHA LETTER KA'
let s:d[0x1C01]='LEPCHA LETTER KLA'
let s:d[0x1C02]='LEPCHA LETTER KHA'
let s:d[0x1C03]='LEPCHA LETTER GA'
let s:d[0x1C04]='LEPCHA LETTER GLA'
let s:d[0x1C05]='LEPCHA LETTER NGA'
let s:d[0x1C06]='LEPCHA LETTER CA'
let s:d[0x1C07]='LEPCHA LETTER CHA'
let s:d[0x1C08]='LEPCHA LETTER JA'
let s:d[0x1C09]='LEPCHA LETTER NYA'
let s:d[0x1C0A]='LEPCHA LETTER TA'
let s:d[0x1C0B]='LEPCHA LETTER THA'
let s:d[0x1C0C]='LEPCHA LETTER DA'
let s:d[0x1C0D]='LEPCHA LETTER NA'
let s:d[0x1C0E]='LEPCHA LETTER PA'
let s:d[0x1C0F]='LEPCHA LETTER PLA'
let s:d[0x1C10]='LEPCHA LETTER PHA'
let s:d[0x1C11]='LEPCHA LETTER FA'
let s:d[0x1C12]='LEPCHA LETTER FLA'
let s:d[0x1C13]='LEPCHA LETTER BA'
let s:d[0x1C14]='LEPCHA LETTER BLA'
let s:d[0x1C15]='LEPCHA LETTER MA'
let s:d[0x1C16]='LEPCHA LETTER MLA'
let s:d[0x1C17]='LEPCHA LETTER TSA'
let s:d[0x1C18]='LEPCHA LETTER TSHA'
let s:d[0x1C19]='LEPCHA LETTER DZA'
let s:d[0x1C1A]='LEPCHA LETTER YA'
let s:d[0x1C1B]='LEPCHA LETTER RA'
let s:d[0x1C1C]='LEPCHA LETTER LA'
let s:d[0x1C1D]='LEPCHA LETTER HA'
let s:d[0x1C1E]='LEPCHA LETTER HLA'
let s:d[0x1C1F]='LEPCHA LETTER VA'
let s:d[0x1C20]='LEPCHA LETTER SA'
let s:d[0x1C21]='LEPCHA LETTER SHA'
let s:d[0x1C22]='LEPCHA LETTER WA'
let s:d[0x1C23]='LEPCHA LETTER A'
let s:d[0x1C24]='LEPCHA SUBJOINED LETTER YA'
let s:d[0x1C25]='LEPCHA SUBJOINED LETTER RA'
let s:d[0x1C26]='LEPCHA VOWEL SIGN AA'
let s:d[0x1C27]='LEPCHA VOWEL SIGN I'
let s:d[0x1C28]='LEPCHA VOWEL SIGN O'
let s:d[0x1C29]='LEPCHA VOWEL SIGN OO'
let s:d[0x1C2A]='LEPCHA VOWEL SIGN U'
let s:d[0x1C2B]='LEPCHA VOWEL SIGN UU'
let s:d[0x1C2C]='LEPCHA VOWEL SIGN E'
let s:d[0x1C2D]='LEPCHA CONSONANT SIGN K'
let s:d[0x1C2E]='LEPCHA CONSONANT SIGN M'
let s:d[0x1C2F]='LEPCHA CONSONANT SIGN L'
let s:d[0x1C30]='LEPCHA CONSONANT SIGN N'
let s:d[0x1C31]='LEPCHA CONSONANT SIGN P'
let s:d[0x1C32]='LEPCHA CONSONANT SIGN R'
let s:d[0x1C33]='LEPCHA CONSONANT SIGN T'
let s:d[0x1C34]='LEPCHA CONSONANT SIGN NYIN-DO'
let s:d[0x1C35]='LEPCHA CONSONANT SIGN KANG'
let s:d[0x1C36]='LEPCHA SIGN RAN'
let s:d[0x1C37]='LEPCHA SIGN NUKTA'
let s:d[0x1C3B]='LEPCHA PUNCTUATION TA-ROL'
let s:d[0x1C3C]='LEPCHA PUNCTUATION NYET THYOOM TA-ROL'
let s:d[0x1C3D]='LEPCHA PUNCTUATION CER-WA'
let s:d[0x1C3E]='LEPCHA PUNCTUATION TSHOOK CER-WA'
let s:d[0x1C3F]='LEPCHA PUNCTUATION TSHOOK'
let s:d[0x1C40]='LEPCHA DIGIT ZERO'
let s:d[0x1C41]='LEPCHA DIGIT ONE'
let s:d[0x1C42]='LEPCHA DIGIT TWO'
let s:d[0x1C43]='LEPCHA DIGIT THREE'
let s:d[0x1C44]='LEPCHA DIGIT FOUR'
let s:d[0x1C45]='LEPCHA DIGIT FIVE'
let s:d[0x1C46]='LEPCHA DIGIT SIX'
let s:d[0x1C47]='LEPCHA DIGIT SEVEN'
let s:d[0x1C48]='LEPCHA DIGIT EIGHT'
let s:d[0x1C49]='LEPCHA DIGIT NINE'
let s:d[0x1C4D]='LEPCHA LETTER TTA'
let s:d[0x1C4E]='LEPCHA LETTER TTHA'
let s:d[0x1C4F]='LEPCHA LETTER DDA'
let s:d[0x1C50]='OL CHIKI DIGIT ZERO'
let s:d[0x1C51]='OL CHIKI DIGIT ONE'
let s:d[0x1C52]='OL CHIKI DIGIT TWO'
let s:d[0x1C53]='OL CHIKI DIGIT THREE'
let s:d[0x1C54]='OL CHIKI DIGIT FOUR'
let s:d[0x1C55]='OL CHIKI DIGIT FIVE'
let s:d[0x1C56]='OL CHIKI DIGIT SIX'
let s:d[0x1C57]='OL CHIKI DIGIT SEVEN'
let s:d[0x1C58]='OL CHIKI DIGIT EIGHT'
let s:d[0x1C59]='OL CHIKI DIGIT NINE'
let s:d[0x1C5A]='OL CHIKI LETTER LA'
let s:d[0x1C5B]='OL CHIKI LETTER AT'
let s:d[0x1C5C]='OL CHIKI LETTER AG'
let s:d[0x1C5D]='OL CHIKI LETTER ANG'
let s:d[0x1C5E]='OL CHIKI LETTER AL'
let s:d[0x1C5F]='OL CHIKI LETTER LAA'
let s:d[0x1C60]='OL CHIKI LETTER AAK'
let s:d[0x1C61]='OL CHIKI LETTER AAJ'
let s:d[0x1C62]='OL CHIKI LETTER AAM'
let s:d[0x1C63]='OL CHIKI LETTER AAW'
let s:d[0x1C64]='OL CHIKI LETTER LI'
let s:d[0x1C65]='OL CHIKI LETTER IS'
let s:d[0x1C66]='OL CHIKI LETTER IH'
let s:d[0x1C67]='OL CHIKI LETTER INY'
let s:d[0x1C68]='OL CHIKI LETTER IR'
let s:d[0x1C69]='OL CHIKI LETTER LU'
let s:d[0x1C6A]='OL CHIKI LETTER UC'
let s:d[0x1C6B]='OL CHIKI LETTER UD'
let s:d[0x1C6C]='OL CHIKI LETTER UNN'
let s:d[0x1C6D]='OL CHIKI LETTER UY'
let s:d[0x1C6E]='OL CHIKI LETTER LE'
let s:d[0x1C6F]='OL CHIKI LETTER EP'
let s:d[0x1C70]='OL CHIKI LETTER EDD'
let s:d[0x1C71]='OL CHIKI LETTER EN'
let s:d[0x1C72]='OL CHIKI LETTER ERR'
let s:d[0x1C73]='OL CHIKI LETTER LO'
let s:d[0x1C74]='OL CHIKI LETTER OTT'
let s:d[0x1C75]='OL CHIKI LETTER OB'
let s:d[0x1C76]='OL CHIKI LETTER OV'
let s:d[0x1C77]='OL CHIKI LETTER OH'
let s:d[0x1C78]='OL CHIKI MU TTUDDAG'
let s:d[0x1C79]='OL CHIKI GAAHLAA TTUDDAAG'
let s:d[0x1C7A]='OL CHIKI MU-GAAHLAA TTUDDAAG'
let s:d[0x1C7B]='OL CHIKI RELAA'
let s:d[0x1C7C]='OL CHIKI PHAARKAA'
let s:d[0x1C7D]='OL CHIKI AHAD'
let s:d[0x1C7E]='OL CHIKI PUNCTUATION MUCAAD'
let s:d[0x1C7F]='OL CHIKI PUNCTUATION DOUBLE MUCAAD'
let s:d[0x1CC0]='SUNDANESE PUNCTUATION BINDU SURYA'
let s:d[0x1CC1]='SUNDANESE PUNCTUATION BINDU PANGLONG'
let s:d[0x1CC2]='SUNDANESE PUNCTUATION BINDU PURNAMA'
let s:d[0x1CC3]='SUNDANESE PUNCTUATION BINDU CAKRA'
let s:d[0x1CC4]='SUNDANESE PUNCTUATION BINDU LEU SATANGA'
let s:d[0x1CC5]='SUNDANESE PUNCTUATION BINDU KA SATANGA'
let s:d[0x1CC6]='SUNDANESE PUNCTUATION BINDU DA SATANGA'
let s:d[0x1CC7]='SUNDANESE PUNCTUATION BINDU BA SATANGA'
let s:d[0x1CD0]='VEDIC TONE KARSHANA'
let s:d[0x1CD1]='VEDIC TONE SHARA'
let s:d[0x1CD2]='VEDIC TONE PRENKHA'
let s:d[0x1CD3]='VEDIC SIGN NIHSHVASA'
let s:d[0x1CD4]='VEDIC SIGN YAJURVEDIC MIDLINE SVARITA'
let s:d[0x1CD5]='VEDIC TONE YAJURVEDIC AGGRAVATED INDEPENDENT SVARITA'
let s:d[0x1CD6]='VEDIC TONE YAJURVEDIC INDEPENDENT SVARITA'
let s:d[0x1CD7]='VEDIC TONE YAJURVEDIC KATHAKA INDEPENDENT SVARITA'
let s:d[0x1CD8]='VEDIC TONE CANDRA BELOW'
let s:d[0x1CD9]='VEDIC TONE YAJURVEDIC KATHAKA INDEPENDENT SVARITA SCHROEDER'
let s:d[0x1CDA]='VEDIC TONE DOUBLE SVARITA'
let s:d[0x1CDB]='VEDIC TONE TRIPLE SVARITA'
let s:d[0x1CDC]='VEDIC TONE KATHAKA ANUDATTA'
let s:d[0x1CDD]='VEDIC TONE DOT BELOW'
let s:d[0x1CDE]='VEDIC TONE TWO DOTS BELOW'
let s:d[0x1CDF]='VEDIC TONE THREE DOTS BELOW'
let s:d[0x1CE0]='VEDIC TONE RIGVEDIC KASHMIRI INDEPENDENT SVARITA'
let s:d[0x1CE1]='VEDIC TONE ATHARVAVEDIC INDEPENDENT SVARITA'
let s:d[0x1CE2]='VEDIC SIGN VISARGA SVARITA'
let s:d[0x1CE3]='VEDIC SIGN VISARGA UDATTA'
let s:d[0x1CE4]='VEDIC SIGN REVERSED VISARGA UDATTA'
let s:d[0x1CE5]='VEDIC SIGN VISARGA ANUDATTA'
let s:d[0x1CE6]='VEDIC SIGN REVERSED VISARGA ANUDATTA'
let s:d[0x1CE7]='VEDIC SIGN VISARGA UDATTA WITH TAIL'
let s:d[0x1CE8]='VEDIC SIGN VISARGA ANUDATTA WITH TAIL'
let s:d[0x1CE9]='VEDIC SIGN ANUSVARA ANTARGOMUKHA'
let s:d[0x1CEA]='VEDIC SIGN ANUSVARA BAHIRGOMUKHA'
let s:d[0x1CEB]='VEDIC SIGN ANUSVARA VAMAGOMUKHA'
let s:d[0x1CEC]='VEDIC SIGN ANUSVARA VAMAGOMUKHA WITH TAIL'
let s:d[0x1CED]='VEDIC SIGN TIRYAK'
let s:d[0x1CEE]='VEDIC SIGN HEXIFORM LONG ANUSVARA'
let s:d[0x1CEF]='VEDIC SIGN LONG ANUSVARA'
let s:d[0x1CF0]='VEDIC SIGN RTHANG LONG ANUSVARA'
let s:d[0x1CF1]='VEDIC SIGN ANUSVARA UBHAYATO MUKHA'
let s:d[0x1CF2]='VEDIC SIGN ARDHAVISARGA'
let s:d[0x1CF3]='VEDIC SIGN ROTATED ARDHAVISARGA'
let s:d[0x1CF4]='VEDIC TONE CANDRA ABOVE'
let s:d[0x1CF5]='VEDIC SIGN JIHVAMULIYA'
let s:d[0x1CF6]='VEDIC SIGN UPADHMANIYA'
let s:d[0x1D00]='LATIN LETTER SMALL CAPITAL A'
let s:d[0x1D01]='LATIN LETTER SMALL CAPITAL AE'
let s:d[0x1D02]='LATIN SMALL LETTER TURNED AE'
let s:d[0x1D03]='LATIN LETTER SMALL CAPITAL BARRED B'
let s:d[0x1D04]='LATIN LETTER SMALL CAPITAL C'
let s:d[0x1D05]='LATIN LETTER SMALL CAPITAL D'
let s:d[0x1D06]='LATIN LETTER SMALL CAPITAL ETH'
let s:d[0x1D07]='LATIN LETTER SMALL CAPITAL E'
let s:d[0x1D08]='LATIN SMALL LETTER TURNED OPEN E'
let s:d[0x1D09]='LATIN SMALL LETTER TURNED I'
let s:d[0x1D0A]='LATIN LETTER SMALL CAPITAL J'
let s:d[0x1D0B]='LATIN LETTER SMALL CAPITAL K'
let s:d[0x1D0C]='LATIN LETTER SMALL CAPITAL L WITH STROKE'
let s:d[0x1D0D]='LATIN LETTER SMALL CAPITAL M'
let s:d[0x1D0E]='LATIN LETTER SMALL CAPITAL REVERSED N'
let s:d[0x1D0F]='LATIN LETTER SMALL CAPITAL O'
let s:d[0x1D10]='LATIN LETTER SMALL CAPITAL OPEN O'
let s:d[0x1D11]='LATIN SMALL LETTER SIDEWAYS O'
let s:d[0x1D12]='LATIN SMALL LETTER SIDEWAYS OPEN O'
let s:d[0x1D13]='LATIN SMALL LETTER SIDEWAYS O WITH STROKE'
let s:d[0x1D14]='LATIN SMALL LETTER TURNED OE'
let s:d[0x1D15]='LATIN LETTER SMALL CAPITAL OU'
let s:d[0x1D16]='LATIN SMALL LETTER TOP HALF O'
let s:d[0x1D17]='LATIN SMALL LETTER BOTTOM HALF O'
let s:d[0x1D18]='LATIN LETTER SMALL CAPITAL P'
let s:d[0x1D19]='LATIN LETTER SMALL CAPITAL REVERSED R'
let s:d[0x1D1A]='LATIN LETTER SMALL CAPITAL TURNED R'
let s:d[0x1D1B]='LATIN LETTER SMALL CAPITAL T'
let s:d[0x1D1C]='LATIN LETTER SMALL CAPITAL U'
let s:d[0x1D1D]='LATIN SMALL LETTER SIDEWAYS U'
let s:d[0x1D1E]='LATIN SMALL LETTER SIDEWAYS DIAERESIZED U'
let s:d[0x1D1F]='LATIN SMALL LETTER SIDEWAYS TURNED M'
let s:d[0x1D20]='LATIN LETTER SMALL CAPITAL V'
let s:d[0x1D21]='LATIN LETTER SMALL CAPITAL W'
let s:d[0x1D22]='LATIN LETTER SMALL CAPITAL Z'
let s:d[0x1D23]='LATIN LETTER SMALL CAPITAL EZH'
let s:d[0x1D24]='LATIN LETTER VOICED LARYNGEAL SPIRANT'
let s:d[0x1D25]='LATIN LETTER AIN'
let s:d[0x1D26]='GREEK LETTER SMALL CAPITAL GAMMA'
let s:d[0x1D27]='GREEK LETTER SMALL CAPITAL LAMDA'
let s:d[0x1D28]='GREEK LETTER SMALL CAPITAL PI'
let s:d[0x1D29]='GREEK LETTER SMALL CAPITAL RHO'
let s:d[0x1D2A]='GREEK LETTER SMALL CAPITAL PSI'
let s:d[0x1D2B]='CYRILLIC LETTER SMALL CAPITAL EL'
let s:d[0x1D2C]='MODIFIER LETTER CAPITAL A'
let s:d[0x1D2D]='MODIFIER LETTER CAPITAL AE'
let s:d[0x1D2E]='MODIFIER LETTER CAPITAL B'
let s:d[0x1D2F]='MODIFIER LETTER CAPITAL BARRED B'
let s:d[0x1D30]='MODIFIER LETTER CAPITAL D'
let s:d[0x1D31]='MODIFIER LETTER CAPITAL E'
let s:d[0x1D32]='MODIFIER LETTER CAPITAL REVERSED E'
let s:d[0x1D33]='MODIFIER LETTER CAPITAL G'
let s:d[0x1D34]='MODIFIER LETTER CAPITAL H'
let s:d[0x1D35]='MODIFIER LETTER CAPITAL I'
let s:d[0x1D36]='MODIFIER LETTER CAPITAL J'
let s:d[0x1D37]='MODIFIER LETTER CAPITAL K'
let s:d[0x1D38]='MODIFIER LETTER CAPITAL L'
let s:d[0x1D39]='MODIFIER LETTER CAPITAL M'
let s:d[0x1D3A]='MODIFIER LETTER CAPITAL N'
let s:d[0x1D3B]='MODIFIER LETTER CAPITAL REVERSED N'
let s:d[0x1D3C]='MODIFIER LETTER CAPITAL O'
let s:d[0x1D3D]='MODIFIER LETTER CAPITAL OU'
let s:d[0x1D3E]='MODIFIER LETTER CAPITAL P'
let s:d[0x1D3F]='MODIFIER LETTER CAPITAL R'
let s:d[0x1D40]='MODIFIER LETTER CAPITAL T'
let s:d[0x1D41]='MODIFIER LETTER CAPITAL U'
let s:d[0x1D42]='MODIFIER LETTER CAPITAL W'
let s:d[0x1D43]='MODIFIER LETTER SMALL A'
let s:d[0x1D44]='MODIFIER LETTER SMALL TURNED A'
let s:d[0x1D45]='MODIFIER LETTER SMALL ALPHA'
let s:d[0x1D46]='MODIFIER LETTER SMALL TURNED AE'
let s:d[0x1D47]='MODIFIER LETTER SMALL B'
let s:d[0x1D48]='MODIFIER LETTER SMALL D'
let s:d[0x1D49]='MODIFIER LETTER SMALL E'
let s:d[0x1D4A]='MODIFIER LETTER SMALL SCHWA'
let s:d[0x1D4B]='MODIFIER LETTER SMALL OPEN E'
let s:d[0x1D4C]='MODIFIER LETTER SMALL TURNED OPEN E'
let s:d[0x1D4D]='MODIFIER LETTER SMALL G'
let s:d[0x1D4E]='MODIFIER LETTER SMALL TURNED I'
let s:d[0x1D4F]='MODIFIER LETTER SMALL K'
let s:d[0x1D50]='MODIFIER LETTER SMALL M'
let s:d[0x1D51]='MODIFIER LETTER SMALL ENG'
let s:d[0x1D52]='MODIFIER LETTER SMALL O'
let s:d[0x1D53]='MODIFIER LETTER SMALL OPEN O'
let s:d[0x1D54]='MODIFIER LETTER SMALL TOP HALF O'
let s:d[0x1D55]='MODIFIER LETTER SMALL BOTTOM HALF O'
let s:d[0x1D56]='MODIFIER LETTER SMALL P'
let s:d[0x1D57]='MODIFIER LETTER SMALL T'
let s:d[0x1D58]='MODIFIER LETTER SMALL U'
let s:d[0x1D59]='MODIFIER LETTER SMALL SIDEWAYS U'
let s:d[0x1D5A]='MODIFIER LETTER SMALL TURNED M'
let s:d[0x1D5B]='MODIFIER LETTER SMALL V'
let s:d[0x1D5C]='MODIFIER LETTER SMALL AIN'
let s:d[0x1D5D]='MODIFIER LETTER SMALL BETA'
let s:d[0x1D5E]='MODIFIER LETTER SMALL GREEK GAMMA'
let s:d[0x1D5F]='MODIFIER LETTER SMALL DELTA'
let s:d[0x1D60]='MODIFIER LETTER SMALL GREEK PHI'
let s:d[0x1D61]='MODIFIER LETTER SMALL CHI'
let s:d[0x1D62]='LATIN SUBSCRIPT SMALL LETTER I'
let s:d[0x1D63]='LATIN SUBSCRIPT SMALL LETTER R'
let s:d[0x1D64]='LATIN SUBSCRIPT SMALL LETTER U'
let s:d[0x1D65]='LATIN SUBSCRIPT SMALL LETTER V'
let s:d[0x1D66]='GREEK SUBSCRIPT SMALL LETTER BETA'
let s:d[0x1D67]='GREEK SUBSCRIPT SMALL LETTER GAMMA'
let s:d[0x1D68]='GREEK SUBSCRIPT SMALL LETTER RHO'
let s:d[0x1D69]='GREEK SUBSCRIPT SMALL LETTER PHI'
let s:d[0x1D6A]='GREEK SUBSCRIPT SMALL LETTER CHI'
let s:d[0x1D6B]='LATIN SMALL LETTER UE'
let s:d[0x1D6C]='LATIN SMALL LETTER B WITH MIDDLE TILDE'
let s:d[0x1D6D]='LATIN SMALL LETTER D WITH MIDDLE TILDE'
let s:d[0x1D6E]='LATIN SMALL LETTER F WITH MIDDLE TILDE'
let s:d[0x1D6F]='LATIN SMALL LETTER M WITH MIDDLE TILDE'
let s:d[0x1D70]='LATIN SMALL LETTER N WITH MIDDLE TILDE'
let s:d[0x1D71]='LATIN SMALL LETTER P WITH MIDDLE TILDE'
let s:d[0x1D72]='LATIN SMALL LETTER R WITH MIDDLE TILDE'
let s:d[0x1D73]='LATIN SMALL LETTER R WITH FISHHOOK AND MIDDLE TILDE'
let s:d[0x1D74]='LATIN SMALL LETTER S WITH MIDDLE TILDE'
let s:d[0x1D75]='LATIN SMALL LETTER T WITH MIDDLE TILDE'
let s:d[0x1D76]='LATIN SMALL LETTER Z WITH MIDDLE TILDE'
let s:d[0x1D77]='LATIN SMALL LETTER TURNED G'
let s:d[0x1D78]='MODIFIER LETTER CYRILLIC EN'
let s:d[0x1D79]='LATIN SMALL LETTER INSULAR G'
let s:d[0x1D7A]='LATIN SMALL LETTER TH WITH STRIKETHROUGH'
let s:d[0x1D7B]='LATIN SMALL CAPITAL LETTER I WITH STROKE'
let s:d[0x1D7C]='LATIN SMALL LETTER IOTA WITH STROKE'
let s:d[0x1D7D]='LATIN SMALL LETTER P WITH STROKE'
let s:d[0x1D7E]='LATIN SMALL CAPITAL LETTER U WITH STROKE'
let s:d[0x1D7F]='LATIN SMALL LETTER UPSILON WITH STROKE'
let s:d[0x1D80]='LATIN SMALL LETTER B WITH PALATAL HOOK'
let s:d[0x1D81]='LATIN SMALL LETTER D WITH PALATAL HOOK'
let s:d[0x1D82]='LATIN SMALL LETTER F WITH PALATAL HOOK'
let s:d[0x1D83]='LATIN SMALL LETTER G WITH PALATAL HOOK'
let s:d[0x1D84]='LATIN SMALL LETTER K WITH PALATAL HOOK'
let s:d[0x1D85]='LATIN SMALL LETTER L WITH PALATAL HOOK'
let s:d[0x1D86]='LATIN SMALL LETTER M WITH PALATAL HOOK'
let s:d[0x1D87]='LATIN SMALL LETTER N WITH PALATAL HOOK'
let s:d[0x1D88]='LATIN SMALL LETTER P WITH PALATAL HOOK'
let s:d[0x1D89]='LATIN SMALL LETTER R WITH PALATAL HOOK'
let s:d[0x1D8A]='LATIN SMALL LETTER S WITH PALATAL HOOK'
let s:d[0x1D8B]='LATIN SMALL LETTER ESH WITH PALATAL HOOK'
let s:d[0x1D8C]='LATIN SMALL LETTER V WITH PALATAL HOOK'
let s:d[0x1D8D]='LATIN SMALL LETTER X WITH PALATAL HOOK'
let s:d[0x1D8E]='LATIN SMALL LETTER Z WITH PALATAL HOOK'
let s:d[0x1D8F]='LATIN SMALL LETTER A WITH RETROFLEX HOOK'
let s:d[0x1D90]='LATIN SMALL LETTER ALPHA WITH RETROFLEX HOOK'
let s:d[0x1D91]='LATIN SMALL LETTER D WITH HOOK AND TAIL'
let s:d[0x1D92]='LATIN SMALL LETTER E WITH RETROFLEX HOOK'
let s:d[0x1D93]='LATIN SMALL LETTER OPEN E WITH RETROFLEX HOOK'
let s:d[0x1D94]='LATIN SMALL LETTER REVERSED OPEN E WITH RETROFLEX HOOK'
let s:d[0x1D95]='LATIN SMALL LETTER SCHWA WITH RETROFLEX HOOK'
let s:d[0x1D96]='LATIN SMALL LETTER I WITH RETROFLEX HOOK'
let s:d[0x1D97]='LATIN SMALL LETTER OPEN O WITH RETROFLEX HOOK'
let s:d[0x1D98]='LATIN SMALL LETTER ESH WITH RETROFLEX HOOK'
let s:d[0x1D99]='LATIN SMALL LETTER U WITH RETROFLEX HOOK'
let s:d[0x1D9A]='LATIN SMALL LETTER EZH WITH RETROFLEX HOOK'
let s:d[0x1D9B]='MODIFIER LETTER SMALL TURNED ALPHA'
let s:d[0x1D9C]='MODIFIER LETTER SMALL C'
let s:d[0x1D9D]='MODIFIER LETTER SMALL C WITH CURL'
let s:d[0x1D9E]='MODIFIER LETTER SMALL ETH'
let s:d[0x1D9F]='MODIFIER LETTER SMALL REVERSED OPEN E'
let s:d[0x1DA0]='MODIFIER LETTER SMALL F'
let s:d[0x1DA1]='MODIFIER LETTER SMALL DOTLESS J WITH STROKE'
let s:d[0x1DA2]='MODIFIER LETTER SMALL SCRIPT G'
let s:d[0x1DA3]='MODIFIER LETTER SMALL TURNED H'
let s:d[0x1DA4]='MODIFIER LETTER SMALL I WITH STROKE'
let s:d[0x1DA5]='MODIFIER LETTER SMALL IOTA'
let s:d[0x1DA6]='MODIFIER LETTER SMALL CAPITAL I'
let s:d[0x1DA7]='MODIFIER LETTER SMALL CAPITAL I WITH STROKE'
let s:d[0x1DA8]='MODIFIER LETTER SMALL J WITH CROSSED-TAIL'
let s:d[0x1DA9]='MODIFIER LETTER SMALL L WITH RETROFLEX HOOK'
let s:d[0x1DAA]='MODIFIER LETTER SMALL L WITH PALATAL HOOK'
let s:d[0x1DAB]='MODIFIER LETTER SMALL CAPITAL L'
let s:d[0x1DAC]='MODIFIER LETTER SMALL M WITH HOOK'
let s:d[0x1DAD]='MODIFIER LETTER SMALL TURNED M WITH LONG LEG'
let s:d[0x1DAE]='MODIFIER LETTER SMALL N WITH LEFT HOOK'
let s:d[0x1DAF]='MODIFIER LETTER SMALL N WITH RETROFLEX HOOK'
let s:d[0x1DB0]='MODIFIER LETTER SMALL CAPITAL N'
let s:d[0x1DB1]='MODIFIER LETTER SMALL BARRED O'
let s:d[0x1DB2]='MODIFIER LETTER SMALL PHI'
let s:d[0x1DB3]='MODIFIER LETTER SMALL S WITH HOOK'
let s:d[0x1DB4]='MODIFIER LETTER SMALL ESH'
let s:d[0x1DB5]='MODIFIER LETTER SMALL T WITH PALATAL HOOK'
let s:d[0x1DB6]='MODIFIER LETTER SMALL U BAR'
let s:d[0x1DB7]='MODIFIER LETTER SMALL UPSILON'
let s:d[0x1DB8]='MODIFIER LETTER SMALL CAPITAL U'
let s:d[0x1DB9]='MODIFIER LETTER SMALL V WITH HOOK'
let s:d[0x1DBA]='MODIFIER LETTER SMALL TURNED V'
let s:d[0x1DBB]='MODIFIER LETTER SMALL Z'
let s:d[0x1DBC]='MODIFIER LETTER SMALL Z WITH RETROFLEX HOOK'
let s:d[0x1DBD]='MODIFIER LETTER SMALL Z WITH CURL'
let s:d[0x1DBE]='MODIFIER LETTER SMALL EZH'
let s:d[0x1DBF]='MODIFIER LETTER SMALL THETA'
let s:d[0x1DC0]='COMBINING DOTTED GRAVE ACCENT'
let s:d[0x1DC1]='COMBINING DOTTED ACUTE ACCENT'
let s:d[0x1DC2]='COMBINING SNAKE BELOW'
let s:d[0x1DC3]='COMBINING SUSPENSION MARK'
let s:d[0x1DC4]='COMBINING MACRON-ACUTE'
let s:d[0x1DC5]='COMBINING GRAVE-MACRON'
let s:d[0x1DC6]='COMBINING MACRON-GRAVE'
let s:d[0x1DC7]='COMBINING ACUTE-MACRON'
let s:d[0x1DC8]='COMBINING GRAVE-ACUTE-GRAVE'
let s:d[0x1DC9]='COMBINING ACUTE-GRAVE-ACUTE'
let s:d[0x1DCA]='COMBINING LATIN SMALL LETTER R BELOW'
let s:d[0x1DCB]='COMBINING BREVE-MACRON'
let s:d[0x1DCC]='COMBINING MACRON-BREVE'
let s:d[0x1DCD]='COMBINING DOUBLE CIRCUMFLEX ABOVE'
let s:d[0x1DCE]='COMBINING OGONEK ABOVE'
let s:d[0x1DCF]='COMBINING ZIGZAG BELOW'
let s:d[0x1DD0]='COMBINING IS BELOW'
let s:d[0x1DD1]='COMBINING UR ABOVE'
let s:d[0x1DD2]='COMBINING US ABOVE'
let s:d[0x1DD3]='COMBINING LATIN SMALL LETTER FLATTENED OPEN A ABOVE'
let s:d[0x1DD4]='COMBINING LATIN SMALL LETTER AE'
let s:d[0x1DD5]='COMBINING LATIN SMALL LETTER AO'
let s:d[0x1DD6]='COMBINING LATIN SMALL LETTER AV'
let s:d[0x1DD7]='COMBINING LATIN SMALL LETTER C CEDILLA'
let s:d[0x1DD8]='COMBINING LATIN SMALL LETTER INSULAR D'
let s:d[0x1DD9]='COMBINING LATIN SMALL LETTER ETH'
let s:d[0x1DDA]='COMBINING LATIN SMALL LETTER G'
let s:d[0x1DDB]='COMBINING LATIN LETTER SMALL CAPITAL G'
let s:d[0x1DDC]='COMBINING LATIN SMALL LETTER K'
let s:d[0x1DDD]='COMBINING LATIN SMALL LETTER L'
let s:d[0x1DDE]='COMBINING LATIN LETTER SMALL CAPITAL L'
let s:d[0x1DDF]='COMBINING LATIN LETTER SMALL CAPITAL M'
let s:d[0x1DE0]='COMBINING LATIN SMALL LETTER N'
let s:d[0x1DE1]='COMBINING LATIN LETTER SMALL CAPITAL N'
let s:d[0x1DE2]='COMBINING LATIN LETTER SMALL CAPITAL R'
let s:d[0x1DE3]='COMBINING LATIN SMALL LETTER R ROTUNDA'
let s:d[0x1DE4]='COMBINING LATIN SMALL LETTER S'
let s:d[0x1DE5]='COMBINING LATIN SMALL LETTER LONG S'
let s:d[0x1DE6]='COMBINING LATIN SMALL LETTER Z'
let s:d[0x1DFC]='COMBINING DOUBLE INVERTED BREVE BELOW'
let s:d[0x1DFD]='COMBINING ALMOST EQUAL TO BELOW'
let s:d[0x1DFE]='COMBINING LEFT ARROWHEAD ABOVE'
let s:d[0x1DFF]='COMBINING RIGHT ARROWHEAD AND DOWN ARROWHEAD BELOW'
let s:d[0x1E00]='LATIN CAPITAL LETTER A WITH RING BELOW'
let s:d[0x1E01]='LATIN SMALL LETTER A WITH RING BELOW'
let s:d[0x1E02]='LATIN CAPITAL LETTER B WITH DOT ABOVE'
let s:d[0x1E03]='LATIN SMALL LETTER B WITH DOT ABOVE'
let s:d[0x1E04]='LATIN CAPITAL LETTER B WITH DOT BELOW'
let s:d[0x1E05]='LATIN SMALL LETTER B WITH DOT BELOW'
let s:d[0x1E06]='LATIN CAPITAL LETTER B WITH LINE BELOW'
let s:d[0x1E07]='LATIN SMALL LETTER B WITH LINE BELOW'
let s:d[0x1E08]='LATIN CAPITAL LETTER C WITH CEDILLA AND ACUTE'
let s:d[0x1E09]='LATIN SMALL LETTER C WITH CEDILLA AND ACUTE'
let s:d[0x1E0A]='LATIN CAPITAL LETTER D WITH DOT ABOVE'
let s:d[0x1E0B]='LATIN SMALL LETTER D WITH DOT ABOVE'
let s:d[0x1E0C]='LATIN CAPITAL LETTER D WITH DOT BELOW'
let s:d[0x1E0D]='LATIN SMALL LETTER D WITH DOT BELOW'
let s:d[0x1E0E]='LATIN CAPITAL LETTER D WITH LINE BELOW'
let s:d[0x1E0F]='LATIN SMALL LETTER D WITH LINE BELOW'
let s:d[0x1E10]='LATIN CAPITAL LETTER D WITH CEDILLA'
let s:d[0x1E11]='LATIN SMALL LETTER D WITH CEDILLA'
let s:d[0x1E12]='LATIN CAPITAL LETTER D WITH CIRCUMFLEX BELOW'
let s:d[0x1E13]='LATIN SMALL LETTER D WITH CIRCUMFLEX BELOW'
let s:d[0x1E14]='LATIN CAPITAL LETTER E WITH MACRON AND GRAVE'
let s:d[0x1E15]='LATIN SMALL LETTER E WITH MACRON AND GRAVE'
let s:d[0x1E16]='LATIN CAPITAL LETTER E WITH MACRON AND ACUTE'
let s:d[0x1E17]='LATIN SMALL LETTER E WITH MACRON AND ACUTE'
let s:d[0x1E18]='LATIN CAPITAL LETTER E WITH CIRCUMFLEX BELOW'
let s:d[0x1E19]='LATIN SMALL LETTER E WITH CIRCUMFLEX BELOW'
let s:d[0x1E1A]='LATIN CAPITAL LETTER E WITH TILDE BELOW'
let s:d[0x1E1B]='LATIN SMALL LETTER E WITH TILDE BELOW'
let s:d[0x1E1C]='LATIN CAPITAL LETTER E WITH CEDILLA AND BREVE'
let s:d[0x1E1D]='LATIN SMALL LETTER E WITH CEDILLA AND BREVE'
let s:d[0x1E1E]='LATIN CAPITAL LETTER F WITH DOT ABOVE'
let s:d[0x1E1F]='LATIN SMALL LETTER F WITH DOT ABOVE'
let s:d[0x1E20]='LATIN CAPITAL LETTER G WITH MACRON'
let s:d[0x1E21]='LATIN SMALL LETTER G WITH MACRON'
let s:d[0x1E22]='LATIN CAPITAL LETTER H WITH DOT ABOVE'
let s:d[0x1E23]='LATIN SMALL LETTER H WITH DOT ABOVE'
let s:d[0x1E24]='LATIN CAPITAL LETTER H WITH DOT BELOW'
let s:d[0x1E25]='LATIN SMALL LETTER H WITH DOT BELOW'
let s:d[0x1E26]='LATIN CAPITAL LETTER H WITH DIAERESIS'
let s:d[0x1E27]='LATIN SMALL LETTER H WITH DIAERESIS'
let s:d[0x1E28]='LATIN CAPITAL LETTER H WITH CEDILLA'
let s:d[0x1E29]='LATIN SMALL LETTER H WITH CEDILLA'
let s:d[0x1E2A]='LATIN CAPITAL LETTER H WITH BREVE BELOW'
let s:d[0x1E2B]='LATIN SMALL LETTER H WITH BREVE BELOW'
let s:d[0x1E2C]='LATIN CAPITAL LETTER I WITH TILDE BELOW'
let s:d[0x1E2D]='LATIN SMALL LETTER I WITH TILDE BELOW'
let s:d[0x1E2E]='LATIN CAPITAL LETTER I WITH DIAERESIS AND ACUTE'
let s:d[0x1E2F]='LATIN SMALL LETTER I WITH DIAERESIS AND ACUTE'
let s:d[0x1E30]='LATIN CAPITAL LETTER K WITH ACUTE'
let s:d[0x1E31]='LATIN SMALL LETTER K WITH ACUTE'
let s:d[0x1E32]='LATIN CAPITAL LETTER K WITH DOT BELOW'
let s:d[0x1E33]='LATIN SMALL LETTER K WITH DOT BELOW'
let s:d[0x1E34]='LATIN CAPITAL LETTER K WITH LINE BELOW'
let s:d[0x1E35]='LATIN SMALL LETTER K WITH LINE BELOW'
let s:d[0x1E36]='LATIN CAPITAL LETTER L WITH DOT BELOW'
let s:d[0x1E37]='LATIN SMALL LETTER L WITH DOT BELOW'
let s:d[0x1E38]='LATIN CAPITAL LETTER L WITH DOT BELOW AND MACRON'
let s:d[0x1E39]='LATIN SMALL LETTER L WITH DOT BELOW AND MACRON'
let s:d[0x1E3A]='LATIN CAPITAL LETTER L WITH LINE BELOW'
let s:d[0x1E3B]='LATIN SMALL LETTER L WITH LINE BELOW'
let s:d[0x1E3C]='LATIN CAPITAL LETTER L WITH CIRCUMFLEX BELOW'
let s:d[0x1E3D]='LATIN SMALL LETTER L WITH CIRCUMFLEX BELOW'
let s:d[0x1E3E]='LATIN CAPITAL LETTER M WITH ACUTE'
let s:d[0x1E3F]='LATIN SMALL LETTER M WITH ACUTE'
let s:d[0x1E40]='LATIN CAPITAL LETTER M WITH DOT ABOVE'
let s:d[0x1E41]='LATIN SMALL LETTER M WITH DOT ABOVE'
let s:d[0x1E42]='LATIN CAPITAL LETTER M WITH DOT BELOW'
let s:d[0x1E43]='LATIN SMALL LETTER M WITH DOT BELOW'
let s:d[0x1E44]='LATIN CAPITAL LETTER N WITH DOT ABOVE'
let s:d[0x1E45]='LATIN SMALL LETTER N WITH DOT ABOVE'
let s:d[0x1E46]='LATIN CAPITAL LETTER N WITH DOT BELOW'
let s:d[0x1E47]='LATIN SMALL LETTER N WITH DOT BELOW'
let s:d[0x1E48]='LATIN CAPITAL LETTER N WITH LINE BELOW'
let s:d[0x1E49]='LATIN SMALL LETTER N WITH LINE BELOW'
let s:d[0x1E4A]='LATIN CAPITAL LETTER N WITH CIRCUMFLEX BELOW'
let s:d[0x1E4B]='LATIN SMALL LETTER N WITH CIRCUMFLEX BELOW'
let s:d[0x1E4C]='LATIN CAPITAL LETTER O WITH TILDE AND ACUTE'
let s:d[0x1E4D]='LATIN SMALL LETTER O WITH TILDE AND ACUTE'
let s:d[0x1E4E]='LATIN CAPITAL LETTER O WITH TILDE AND DIAERESIS'
let s:d[0x1E4F]='LATIN SMALL LETTER O WITH TILDE AND DIAERESIS'
let s:d[0x1E50]='LATIN CAPITAL LETTER O WITH MACRON AND GRAVE'
let s:d[0x1E51]='LATIN SMALL LETTER O WITH MACRON AND GRAVE'
let s:d[0x1E52]='LATIN CAPITAL LETTER O WITH MACRON AND ACUTE'
let s:d[0x1E53]='LATIN SMALL LETTER O WITH MACRON AND ACUTE'
let s:d[0x1E54]='LATIN CAPITAL LETTER P WITH ACUTE'
let s:d[0x1E55]='LATIN SMALL LETTER P WITH ACUTE'
let s:d[0x1E56]='LATIN CAPITAL LETTER P WITH DOT ABOVE'
let s:d[0x1E57]='LATIN SMALL LETTER P WITH DOT ABOVE'
let s:d[0x1E58]='LATIN CAPITAL LETTER R WITH DOT ABOVE'
let s:d[0x1E59]='LATIN SMALL LETTER R WITH DOT ABOVE'
let s:d[0x1E5A]='LATIN CAPITAL LETTER R WITH DOT BELOW'
let s:d[0x1E5B]='LATIN SMALL LETTER R WITH DOT BELOW'
let s:d[0x1E5C]='LATIN CAPITAL LETTER R WITH DOT BELOW AND MACRON'
let s:d[0x1E5D]='LATIN SMALL LETTER R WITH DOT BELOW AND MACRON'
let s:d[0x1E5E]='LATIN CAPITAL LETTER R WITH LINE BELOW'
let s:d[0x1E5F]='LATIN SMALL LETTER R WITH LINE BELOW'
let s:d[0x1E60]='LATIN CAPITAL LETTER S WITH DOT ABOVE'
let s:d[0x1E61]='LATIN SMALL LETTER S WITH DOT ABOVE'
let s:d[0x1E62]='LATIN CAPITAL LETTER S WITH DOT BELOW'
let s:d[0x1E63]='LATIN SMALL LETTER S WITH DOT BELOW'
let s:d[0x1E64]='LATIN CAPITAL LETTER S WITH ACUTE AND DOT ABOVE'
let s:d[0x1E65]='LATIN SMALL LETTER S WITH ACUTE AND DOT ABOVE'
let s:d[0x1E66]='LATIN CAPITAL LETTER S WITH CARON AND DOT ABOVE'
let s:d[0x1E67]='LATIN SMALL LETTER S WITH CARON AND DOT ABOVE'
let s:d[0x1E68]='LATIN CAPITAL LETTER S WITH DOT BELOW AND DOT ABOVE'
let s:d[0x1E69]='LATIN SMALL LETTER S WITH DOT BELOW AND DOT ABOVE'
let s:d[0x1E6A]='LATIN CAPITAL LETTER T WITH DOT ABOVE'
let s:d[0x1E6B]='LATIN SMALL LETTER T WITH DOT ABOVE'
let s:d[0x1E6C]='LATIN CAPITAL LETTER T WITH DOT BELOW'
let s:d[0x1E6D]='LATIN SMALL LETTER T WITH DOT BELOW'
let s:d[0x1E6E]='LATIN CAPITAL LETTER T WITH LINE BELOW'
let s:d[0x1E6F]='LATIN SMALL LETTER T WITH LINE BELOW'
let s:d[0x1E70]='LATIN CAPITAL LETTER T WITH CIRCUMFLEX BELOW'
let s:d[0x1E71]='LATIN SMALL LETTER T WITH CIRCUMFLEX BELOW'
let s:d[0x1E72]='LATIN CAPITAL LETTER U WITH DIAERESIS BELOW'
let s:d[0x1E73]='LATIN SMALL LETTER U WITH DIAERESIS BELOW'
let s:d[0x1E74]='LATIN CAPITAL LETTER U WITH TILDE BELOW'
let s:d[0x1E75]='LATIN SMALL LETTER U WITH TILDE BELOW'
let s:d[0x1E76]='LATIN CAPITAL LETTER U WITH CIRCUMFLEX BELOW'
let s:d[0x1E77]='LATIN SMALL LETTER U WITH CIRCUMFLEX BELOW'
let s:d[0x1E78]='LATIN CAPITAL LETTER U WITH TILDE AND ACUTE'
let s:d[0x1E79]='LATIN SMALL LETTER U WITH TILDE AND ACUTE'
let s:d[0x1E7A]='LATIN CAPITAL LETTER U WITH MACRON AND DIAERESIS'
let s:d[0x1E7B]='LATIN SMALL LETTER U WITH MACRON AND DIAERESIS'
let s:d[0x1E7C]='LATIN CAPITAL LETTER V WITH TILDE'
let s:d[0x1E7D]='LATIN SMALL LETTER V WITH TILDE'
let s:d[0x1E7E]='LATIN CAPITAL LETTER V WITH DOT BELOW'
let s:d[0x1E7F]='LATIN SMALL LETTER V WITH DOT BELOW'
let s:d[0x1E80]='LATIN CAPITAL LETTER W WITH GRAVE'
let s:d[0x1E81]='LATIN SMALL LETTER W WITH GRAVE'
let s:d[0x1E82]='LATIN CAPITAL LETTER W WITH ACUTE'
let s:d[0x1E83]='LATIN SMALL LETTER W WITH ACUTE'
let s:d[0x1E84]='LATIN CAPITAL LETTER W WITH DIAERESIS'
let s:d[0x1E85]='LATIN SMALL LETTER W WITH DIAERESIS'
let s:d[0x1E86]='LATIN CAPITAL LETTER W WITH DOT ABOVE'
let s:d[0x1E87]='LATIN SMALL LETTER W WITH DOT ABOVE'
let s:d[0x1E88]='LATIN CAPITAL LETTER W WITH DOT BELOW'
let s:d[0x1E89]='LATIN SMALL LETTER W WITH DOT BELOW'
let s:d[0x1E8A]='LATIN CAPITAL LETTER X WITH DOT ABOVE'
let s:d[0x1E8B]='LATIN SMALL LETTER X WITH DOT ABOVE'
let s:d[0x1E8C]='LATIN CAPITAL LETTER X WITH DIAERESIS'
let s:d[0x1E8D]='LATIN SMALL LETTER X WITH DIAERESIS'
let s:d[0x1E8E]='LATIN CAPITAL LETTER Y WITH DOT ABOVE'
let s:d[0x1E8F]='LATIN SMALL LETTER Y WITH DOT ABOVE'
let s:d[0x1E90]='LATIN CAPITAL LETTER Z WITH CIRCUMFLEX'
let s:d[0x1E91]='LATIN SMALL LETTER Z WITH CIRCUMFLEX'
let s:d[0x1E92]='LATIN CAPITAL LETTER Z WITH DOT BELOW'
let s:d[0x1E93]='LATIN SMALL LETTER Z WITH DOT BELOW'
let s:d[0x1E94]='LATIN CAPITAL LETTER Z WITH LINE BELOW'
let s:d[0x1E95]='LATIN SMALL LETTER Z WITH LINE BELOW'
let s:d[0x1E96]='LATIN SMALL LETTER H WITH LINE BELOW'
let s:d[0x1E97]='LATIN SMALL LETTER T WITH DIAERESIS'
let s:d[0x1E98]='LATIN SMALL LETTER W WITH RING ABOVE'
let s:d[0x1E99]='LATIN SMALL LETTER Y WITH RING ABOVE'
let s:d[0x1E9A]='LATIN SMALL LETTER A WITH RIGHT HALF RING'
let s:d[0x1E9B]='LATIN SMALL LETTER LONG S WITH DOT ABOVE'
let s:d[0x1E9C]='LATIN SMALL LETTER LONG S WITH DIAGONAL STROKE'
let s:d[0x1E9D]='LATIN SMALL LETTER LONG S WITH HIGH STROKE'
let s:d[0x1E9E]='LATIN CAPITAL LETTER SHARP S'
let s:d[0x1E9F]='LATIN SMALL LETTER DELTA'
let s:d[0x1EA0]='LATIN CAPITAL LETTER A WITH DOT BELOW'
let s:d[0x1EA1]='LATIN SMALL LETTER A WITH DOT BELOW'
let s:d[0x1EA2]='LATIN CAPITAL LETTER A WITH HOOK ABOVE'
let s:d[0x1EA3]='LATIN SMALL LETTER A WITH HOOK ABOVE'
let s:d[0x1EA4]='LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND ACUTE'
let s:d[0x1EA5]='LATIN SMALL LETTER A WITH CIRCUMFLEX AND ACUTE'
let s:d[0x1EA6]='LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND GRAVE'
let s:d[0x1EA7]='LATIN SMALL LETTER A WITH CIRCUMFLEX AND GRAVE'
let s:d[0x1EA8]='LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND HOOK ABOVE'
let s:d[0x1EA9]='LATIN SMALL LETTER A WITH CIRCUMFLEX AND HOOK ABOVE'
let s:d[0x1EAA]='LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND TILDE'
let s:d[0x1EAB]='LATIN SMALL LETTER A WITH CIRCUMFLEX AND TILDE'
let s:d[0x1EAC]='LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND DOT BELOW'
let s:d[0x1EAD]='LATIN SMALL LETTER A WITH CIRCUMFLEX AND DOT BELOW'
let s:d[0x1EAE]='LATIN CAPITAL LETTER A WITH BREVE AND ACUTE'
let s:d[0x1EAF]='LATIN SMALL LETTER A WITH BREVE AND ACUTE'
let s:d[0x1EB0]='LATIN CAPITAL LETTER A WITH BREVE AND GRAVE'
let s:d[0x1EB1]='LATIN SMALL LETTER A WITH BREVE AND GRAVE'
let s:d[0x1EB2]='LATIN CAPITAL LETTER A WITH BREVE AND HOOK ABOVE'
let s:d[0x1EB3]='LATIN SMALL LETTER A WITH BREVE AND HOOK ABOVE'
let s:d[0x1EB4]='LATIN CAPITAL LETTER A WITH BREVE AND TILDE'
let s:d[0x1EB5]='LATIN SMALL LETTER A WITH BREVE AND TILDE'
let s:d[0x1EB6]='LATIN CAPITAL LETTER A WITH BREVE AND DOT BELOW'
let s:d[0x1EB7]='LATIN SMALL LETTER A WITH BREVE AND DOT BELOW'
let s:d[0x1EB8]='LATIN CAPITAL LETTER E WITH DOT BELOW'
let s:d[0x1EB9]='LATIN SMALL LETTER E WITH DOT BELOW'
let s:d[0x1EBA]='LATIN CAPITAL LETTER E WITH HOOK ABOVE'
let s:d[0x1EBB]='LATIN SMALL LETTER E WITH HOOK ABOVE'
let s:d[0x1EBC]='LATIN CAPITAL LETTER E WITH TILDE'
let s:d[0x1EBD]='LATIN SMALL LETTER E WITH TILDE'
let s:d[0x1EBE]='LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND ACUTE'
let s:d[0x1EBF]='LATIN SMALL LETTER E WITH CIRCUMFLEX AND ACUTE'
let s:d[0x1EC0]='LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND GRAVE'
let s:d[0x1EC1]='LATIN SMALL LETTER E WITH CIRCUMFLEX AND GRAVE'
let s:d[0x1EC2]='LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND HOOK ABOVE'
let s:d[0x1EC3]='LATIN SMALL LETTER E WITH CIRCUMFLEX AND HOOK ABOVE'
let s:d[0x1EC4]='LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND TILDE'
let s:d[0x1EC5]='LATIN SMALL LETTER E WITH CIRCUMFLEX AND TILDE'
let s:d[0x1EC6]='LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND DOT BELOW'
let s:d[0x1EC7]='LATIN SMALL LETTER E WITH CIRCUMFLEX AND DOT BELOW'
let s:d[0x1EC8]='LATIN CAPITAL LETTER I WITH HOOK ABOVE'
let s:d[0x1EC9]='LATIN SMALL LETTER I WITH HOOK ABOVE'
let s:d[0x1ECA]='LATIN CAPITAL LETTER I WITH DOT BELOW'
let s:d[0x1ECB]='LATIN SMALL LETTER I WITH DOT BELOW'
let s:d[0x1ECC]='LATIN CAPITAL LETTER O WITH DOT BELOW'
let s:d[0x1ECD]='LATIN SMALL LETTER O WITH DOT BELOW'
let s:d[0x1ECE]='LATIN CAPITAL LETTER O WITH HOOK ABOVE'
let s:d[0x1ECF]='LATIN SMALL LETTER O WITH HOOK ABOVE'
let s:d[0x1ED0]='LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND ACUTE'
let s:d[0x1ED1]='LATIN SMALL LETTER O WITH CIRCUMFLEX AND ACUTE'
let s:d[0x1ED2]='LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND GRAVE'
let s:d[0x1ED3]='LATIN SMALL LETTER O WITH CIRCUMFLEX AND GRAVE'
let s:d[0x1ED4]='LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND HOOK ABOVE'
let s:d[0x1ED5]='LATIN SMALL LETTER O WITH CIRCUMFLEX AND HOOK ABOVE'
let s:d[0x1ED6]='LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND TILDE'
let s:d[0x1ED7]='LATIN SMALL LETTER O WITH CIRCUMFLEX AND TILDE'
let s:d[0x1ED8]='LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND DOT BELOW'
let s:d[0x1ED9]='LATIN SMALL LETTER O WITH CIRCUMFLEX AND DOT BELOW'
let s:d[0x1EDA]='LATIN CAPITAL LETTER O WITH HORN AND ACUTE'
let s:d[0x1EDB]='LATIN SMALL LETTER O WITH HORN AND ACUTE'
let s:d[0x1EDC]='LATIN CAPITAL LETTER O WITH HORN AND GRAVE'
let s:d[0x1EDD]='LATIN SMALL LETTER O WITH HORN AND GRAVE'
let s:d[0x1EDE]='LATIN CAPITAL LETTER O WITH HORN AND HOOK ABOVE'
let s:d[0x1EDF]='LATIN SMALL LETTER O WITH HORN AND HOOK ABOVE'
let s:d[0x1EE0]='LATIN CAPITAL LETTER O WITH HORN AND TILDE'
let s:d[0x1EE1]='LATIN SMALL LETTER O WITH HORN AND TILDE'
let s:d[0x1EE2]='LATIN CAPITAL LETTER O WITH HORN AND DOT BELOW'
let s:d[0x1EE3]='LATIN SMALL LETTER O WITH HORN AND DOT BELOW'
let s:d[0x1EE4]='LATIN CAPITAL LETTER U WITH DOT BELOW'
let s:d[0x1EE5]='LATIN SMALL LETTER U WITH DOT BELOW'
let s:d[0x1EE6]='LATIN CAPITAL LETTER U WITH HOOK ABOVE'
let s:d[0x1EE7]='LATIN SMALL LETTER U WITH HOOK ABOVE'
let s:d[0x1EE8]='LATIN CAPITAL LETTER U WITH HORN AND ACUTE'
let s:d[0x1EE9]='LATIN SMALL LETTER U WITH HORN AND ACUTE'
let s:d[0x1EEA]='LATIN CAPITAL LETTER U WITH HORN AND GRAVE'
let s:d[0x1EEB]='LATIN SMALL LETTER U WITH HORN AND GRAVE'
let s:d[0x1EEC]='LATIN CAPITAL LETTER U WITH HORN AND HOOK ABOVE'
let s:d[0x1EED]='LATIN SMALL LETTER U WITH HORN AND HOOK ABOVE'
let s:d[0x1EEE]='LATIN CAPITAL LETTER U WITH HORN AND TILDE'
let s:d[0x1EEF]='LATIN SMALL LETTER U WITH HORN AND TILDE'
let s:d[0x1EF0]='LATIN CAPITAL LETTER U WITH HORN AND DOT BELOW'
let s:d[0x1EF1]='LATIN SMALL LETTER U WITH HORN AND DOT BELOW'
let s:d[0x1EF2]='LATIN CAPITAL LETTER Y WITH GRAVE'
let s:d[0x1EF3]='LATIN SMALL LETTER Y WITH GRAVE'
let s:d[0x1EF4]='LATIN CAPITAL LETTER Y WITH DOT BELOW'
let s:d[0x1EF5]='LATIN SMALL LETTER Y WITH DOT BELOW'
let s:d[0x1EF6]='LATIN CAPITAL LETTER Y WITH HOOK ABOVE'
let s:d[0x1EF7]='LATIN SMALL LETTER Y WITH HOOK ABOVE'
let s:d[0x1EF8]='LATIN CAPITAL LETTER Y WITH TILDE'
let s:d[0x1EF9]='LATIN SMALL LETTER Y WITH TILDE'
let s:d[0x1EFA]='LATIN CAPITAL LETTER MIDDLE-WELSH LL'
let s:d[0x1EFB]='LATIN SMALL LETTER MIDDLE-WELSH LL'
let s:d[0x1EFC]='LATIN CAPITAL LETTER MIDDLE-WELSH V'
let s:d[0x1EFD]='LATIN SMALL LETTER MIDDLE-WELSH V'
let s:d[0x1EFE]='LATIN CAPITAL LETTER Y WITH LOOP'
let s:d[0x1EFF]='LATIN SMALL LETTER Y WITH LOOP'
let s:d[0x1F00]='GREEK SMALL LETTER ALPHA WITH PSILI'
let s:d[0x1F01]='GREEK SMALL LETTER ALPHA WITH DASIA'
let s:d[0x1F02]='GREEK SMALL LETTER ALPHA WITH PSILI AND VARIA'
let s:d[0x1F03]='GREEK SMALL LETTER ALPHA WITH DASIA AND VARIA'
let s:d[0x1F04]='GREEK SMALL LETTER ALPHA WITH PSILI AND OXIA'
let s:d[0x1F05]='GREEK SMALL LETTER ALPHA WITH DASIA AND OXIA'
let s:d[0x1F06]='GREEK SMALL LETTER ALPHA WITH PSILI AND PERISPOMENI'
let s:d[0x1F07]='GREEK SMALL LETTER ALPHA WITH DASIA AND PERISPOMENI'
let s:d[0x1F08]='GREEK CAPITAL LETTER ALPHA WITH PSILI'
let s:d[0x1F09]='GREEK CAPITAL LETTER ALPHA WITH DASIA'
let s:d[0x1F0A]='GREEK CAPITAL LETTER ALPHA WITH PSILI AND VARIA'
let s:d[0x1F0B]='GREEK CAPITAL LETTER ALPHA WITH DASIA AND VARIA'
let s:d[0x1F0C]='GREEK CAPITAL LETTER ALPHA WITH PSILI AND OXIA'
let s:d[0x1F0D]='GREEK CAPITAL LETTER ALPHA WITH DASIA AND OXIA'
let s:d[0x1F0E]='GREEK CAPITAL LETTER ALPHA WITH PSILI AND PERISPOMENI'
let s:d[0x1F0F]='GREEK CAPITAL LETTER ALPHA WITH DASIA AND PERISPOMENI'
let s:d[0x1F10]='GREEK SMALL LETTER EPSILON WITH PSILI'
let s:d[0x1F11]='GREEK SMALL LETTER EPSILON WITH DASIA'
let s:d[0x1F12]='GREEK SMALL LETTER EPSILON WITH PSILI AND VARIA'
let s:d[0x1F13]='GREEK SMALL LETTER EPSILON WITH DASIA AND VARIA'
let s:d[0x1F14]='GREEK SMALL LETTER EPSILON WITH PSILI AND OXIA'
let s:d[0x1F15]='GREEK SMALL LETTER EPSILON WITH DASIA AND OXIA'
let s:d[0x1F18]='GREEK CAPITAL LETTER EPSILON WITH PSILI'
let s:d[0x1F19]='GREEK CAPITAL LETTER EPSILON WITH DASIA'
let s:d[0x1F1A]='GREEK CAPITAL LETTER EPSILON WITH PSILI AND VARIA'
let s:d[0x1F1B]='GREEK CAPITAL LETTER EPSILON WITH DASIA AND VARIA'
let s:d[0x1F1C]='GREEK CAPITAL LETTER EPSILON WITH PSILI AND OXIA'
let s:d[0x1F1D]='GREEK CAPITAL LETTER EPSILON WITH DASIA AND OXIA'
let s:d[0x1F20]='GREEK SMALL LETTER ETA WITH PSILI'
let s:d[0x1F21]='GREEK SMALL LETTER ETA WITH DASIA'
let s:d[0x1F22]='GREEK SMALL LETTER ETA WITH PSILI AND VARIA'
let s:d[0x1F23]='GREEK SMALL LETTER ETA WITH DASIA AND VARIA'
let s:d[0x1F24]='GREEK SMALL LETTER ETA WITH PSILI AND OXIA'
let s:d[0x1F25]='GREEK SMALL LETTER ETA WITH DASIA AND OXIA'
let s:d[0x1F26]='GREEK SMALL LETTER ETA WITH PSILI AND PERISPOMENI'
let s:d[0x1F27]='GREEK SMALL LETTER ETA WITH DASIA AND PERISPOMENI'
let s:d[0x1F28]='GREEK CAPITAL LETTER ETA WITH PSILI'
let s:d[0x1F29]='GREEK CAPITAL LETTER ETA WITH DASIA'
let s:d[0x1F2A]='GREEK CAPITAL LETTER ETA WITH PSILI AND VARIA'
let s:d[0x1F2B]='GREEK CAPITAL LETTER ETA WITH DASIA AND VARIA'
let s:d[0x1F2C]='GREEK CAPITAL LETTER ETA WITH PSILI AND OXIA'
let s:d[0x1F2D]='GREEK CAPITAL LETTER ETA WITH DASIA AND OXIA'
let s:d[0x1F2E]='GREEK CAPITAL LETTER ETA WITH PSILI AND PERISPOMENI'
let s:d[0x1F2F]='GREEK CAPITAL LETTER ETA WITH DASIA AND PERISPOMENI'
let s:d[0x1F30]='GREEK SMALL LETTER IOTA WITH PSILI'
let s:d[0x1F31]='GREEK SMALL LETTER IOTA WITH DASIA'
let s:d[0x1F32]='GREEK SMALL LETTER IOTA WITH PSILI AND VARIA'
let s:d[0x1F33]='GREEK SMALL LETTER IOTA WITH DASIA AND VARIA'
let s:d[0x1F34]='GREEK SMALL LETTER IOTA WITH PSILI AND OXIA'
let s:d[0x1F35]='GREEK SMALL LETTER IOTA WITH DASIA AND OXIA'
let s:d[0x1F36]='GREEK SMALL LETTER IOTA WITH PSILI AND PERISPOMENI'
let s:d[0x1F37]='GREEK SMALL LETTER IOTA WITH DASIA AND PERISPOMENI'
let s:d[0x1F38]='GREEK CAPITAL LETTER IOTA WITH PSILI'
let s:d[0x1F39]='GREEK CAPITAL LETTER IOTA WITH DASIA'
let s:d[0x1F3A]='GREEK CAPITAL LETTER IOTA WITH PSILI AND VARIA'
let s:d[0x1F3B]='GREEK CAPITAL LETTER IOTA WITH DASIA AND VARIA'
let s:d[0x1F3C]='GREEK CAPITAL LETTER IOTA WITH PSILI AND OXIA'
let s:d[0x1F3D]='GREEK CAPITAL LETTER IOTA WITH DASIA AND OXIA'
let s:d[0x1F3E]='GREEK CAPITAL LETTER IOTA WITH PSILI AND PERISPOMENI'
let s:d[0x1F3F]='GREEK CAPITAL LETTER IOTA WITH DASIA AND PERISPOMENI'
let s:d[0x1F40]='GREEK SMALL LETTER OMICRON WITH PSILI'
let s:d[0x1F41]='GREEK SMALL LETTER OMICRON WITH DASIA'
let s:d[0x1F42]='GREEK SMALL LETTER OMICRON WITH PSILI AND VARIA'
let s:d[0x1F43]='GREEK SMALL LETTER OMICRON WITH DASIA AND VARIA'
let s:d[0x1F44]='GREEK SMALL LETTER OMICRON WITH PSILI AND OXIA'
let s:d[0x1F45]='GREEK SMALL LETTER OMICRON WITH DASIA AND OXIA'
let s:d[0x1F48]='GREEK CAPITAL LETTER OMICRON WITH PSILI'
let s:d[0x1F49]='GREEK CAPITAL LETTER OMICRON WITH DASIA'
let s:d[0x1F4A]='GREEK CAPITAL LETTER OMICRON WITH PSILI AND VARIA'
let s:d[0x1F4B]='GREEK CAPITAL LETTER OMICRON WITH DASIA AND VARIA'
let s:d[0x1F4C]='GREEK CAPITAL LETTER OMICRON WITH PSILI AND OXIA'
let s:d[0x1F4D]='GREEK CAPITAL LETTER OMICRON WITH DASIA AND OXIA'
let s:d[0x1F50]='GREEK SMALL LETTER UPSILON WITH PSILI'
let s:d[0x1F51]='GREEK SMALL LETTER UPSILON WITH DASIA'
let s:d[0x1F52]='GREEK SMALL LETTER UPSILON WITH PSILI AND VARIA'
let s:d[0x1F53]='GREEK SMALL LETTER UPSILON WITH DASIA AND VARIA'
let s:d[0x1F54]='GREEK SMALL LETTER UPSILON WITH PSILI AND OXIA'
let s:d[0x1F55]='GREEK SMALL LETTER UPSILON WITH DASIA AND OXIA'
let s:d[0x1F56]='GREEK SMALL LETTER UPSILON WITH PSILI AND PERISPOMENI'
let s:d[0x1F57]='GREEK SMALL LETTER UPSILON WITH DASIA AND PERISPOMENI'
let s:d[0x1F59]='GREEK CAPITAL LETTER UPSILON WITH DASIA'
let s:d[0x1F5B]='GREEK CAPITAL LETTER UPSILON WITH DASIA AND VARIA'
let s:d[0x1F5D]='GREEK CAPITAL LETTER UPSILON WITH DASIA AND OXIA'
let s:d[0x1F5F]='GREEK CAPITAL LETTER UPSILON WITH DASIA AND PERISPOMENI'
let s:d[0x1F60]='GREEK SMALL LETTER OMEGA WITH PSILI'
let s:d[0x1F61]='GREEK SMALL LETTER OMEGA WITH DASIA'
let s:d[0x1F62]='GREEK SMALL LETTER OMEGA WITH PSILI AND VARIA'
let s:d[0x1F63]='GREEK SMALL LETTER OMEGA WITH DASIA AND VARIA'
let s:d[0x1F64]='GREEK SMALL LETTER OMEGA WITH PSILI AND OXIA'
let s:d[0x1F65]='GREEK SMALL LETTER OMEGA WITH DASIA AND OXIA'
let s:d[0x1F66]='GREEK SMALL LETTER OMEGA WITH PSILI AND PERISPOMENI'
let s:d[0x1F67]='GREEK SMALL LETTER OMEGA WITH DASIA AND PERISPOMENI'
let s:d[0x1F68]='GREEK CAPITAL LETTER OMEGA WITH PSILI'
let s:d[0x1F69]='GREEK CAPITAL LETTER OMEGA WITH DASIA'
let s:d[0x1F6A]='GREEK CAPITAL LETTER OMEGA WITH PSILI AND VARIA'
let s:d[0x1F6B]='GREEK CAPITAL LETTER OMEGA WITH DASIA AND VARIA'
let s:d[0x1F6C]='GREEK CAPITAL LETTER OMEGA WITH PSILI AND OXIA'
let s:d[0x1F6D]='GREEK CAPITAL LETTER OMEGA WITH DASIA AND OXIA'
let s:d[0x1F6E]='GREEK CAPITAL LETTER OMEGA WITH PSILI AND PERISPOMENI'
let s:d[0x1F6F]='GREEK CAPITAL LETTER OMEGA WITH DASIA AND PERISPOMENI'
let s:d[0x1F70]='GREEK SMALL LETTER ALPHA WITH VARIA'
let s:d[0x1F71]='GREEK SMALL LETTER ALPHA WITH OXIA'
let s:d[0x1F72]='GREEK SMALL LETTER EPSILON WITH VARIA'
let s:d[0x1F73]='GREEK SMALL LETTER EPSILON WITH OXIA'
let s:d[0x1F74]='GREEK SMALL LETTER ETA WITH VARIA'
let s:d[0x1F75]='GREEK SMALL LETTER ETA WITH OXIA'
let s:d[0x1F76]='GREEK SMALL LETTER IOTA WITH VARIA'
let s:d[0x1F77]='GREEK SMALL LETTER IOTA WITH OXIA'
let s:d[0x1F78]='GREEK SMALL LETTER OMICRON WITH VARIA'
let s:d[0x1F79]='GREEK SMALL LETTER OMICRON WITH OXIA'
let s:d[0x1F7A]='GREEK SMALL LETTER UPSILON WITH VARIA'
let s:d[0x1F7B]='GREEK SMALL LETTER UPSILON WITH OXIA'
let s:d[0x1F7C]='GREEK SMALL LETTER OMEGA WITH VARIA'
let s:d[0x1F7D]='GREEK SMALL LETTER OMEGA WITH OXIA'
let s:d[0x1F80]='GREEK SMALL LETTER ALPHA WITH PSILI AND YPOGEGRAMMENI'
let s:d[0x1F81]='GREEK SMALL LETTER ALPHA WITH DASIA AND YPOGEGRAMMENI'
let s:d[0x1F82]='GREEK SMALL LETTER ALPHA WITH PSILI AND VARIA AND YPOGEGRAMMENI'
let s:d[0x1F83]='GREEK SMALL LETTER ALPHA WITH DASIA AND VARIA AND YPOGEGRAMMENI'
let s:d[0x1F84]='GREEK SMALL LETTER ALPHA WITH PSILI AND OXIA AND YPOGEGRAMMENI'
let s:d[0x1F85]='GREEK SMALL LETTER ALPHA WITH DASIA AND OXIA AND YPOGEGRAMMENI'
let s:d[0x1F86]='GREEK SMALL LETTER ALPHA WITH PSILI AND PERISPOMENI AND YPOGEGRAMMENI'
let s:d[0x1F87]='GREEK SMALL LETTER ALPHA WITH DASIA AND PERISPOMENI AND YPOGEGRAMMENI'
let s:d[0x1F88]='GREEK CAPITAL LETTER ALPHA WITH PSILI AND PROSGEGRAMMENI'
let s:d[0x1F89]='GREEK CAPITAL LETTER ALPHA WITH DASIA AND PROSGEGRAMMENI'
let s:d[0x1F8A]='GREEK CAPITAL LETTER ALPHA WITH PSILI AND VARIA AND PROSGEGRAMMENI'
let s:d[0x1F8B]='GREEK CAPITAL LETTER ALPHA WITH DASIA AND VARIA AND PROSGEGRAMMENI'
let s:d[0x1F8C]='GREEK CAPITAL LETTER ALPHA WITH PSILI AND OXIA AND PROSGEGRAMMENI'
let s:d[0x1F8D]='GREEK CAPITAL LETTER ALPHA WITH DASIA AND OXIA AND PROSGEGRAMMENI'
let s:d[0x1F8E]='GREEK CAPITAL LETTER ALPHA WITH PSILI AND PERISPOMENI AND PROSGEGRAMMENI'
let s:d[0x1F8F]='GREEK CAPITAL LETTER ALPHA WITH DASIA AND PERISPOMENI AND PROSGEGRAMMENI'
let s:d[0x1F90]='GREEK SMALL LETTER ETA WITH PSILI AND YPOGEGRAMMENI'
let s:d[0x1F91]='GREEK SMALL LETTER ETA WITH DASIA AND YPOGEGRAMMENI'
let s:d[0x1F92]='GREEK SMALL LETTER ETA WITH PSILI AND VARIA AND YPOGEGRAMMENI'
let s:d[0x1F93]='GREEK SMALL LETTER ETA WITH DASIA AND VARIA AND YPOGEGRAMMENI'
let s:d[0x1F94]='GREEK SMALL LETTER ETA WITH PSILI AND OXIA AND YPOGEGRAMMENI'
let s:d[0x1F95]='GREEK SMALL LETTER ETA WITH DASIA AND OXIA AND YPOGEGRAMMENI'
let s:d[0x1F96]='GREEK SMALL LETTER ETA WITH PSILI AND PERISPOMENI AND YPOGEGRAMMENI'
let s:d[0x1F97]='GREEK SMALL LETTER ETA WITH DASIA AND PERISPOMENI AND YPOGEGRAMMENI'
let s:d[0x1F98]='GREEK CAPITAL LETTER ETA WITH PSILI AND PROSGEGRAMMENI'
let s:d[0x1F99]='GREEK CAPITAL LETTER ETA WITH DASIA AND PROSGEGRAMMENI'
let s:d[0x1F9A]='GREEK CAPITAL LETTER ETA WITH PSILI AND VARIA AND PROSGEGRAMMENI'
let s:d[0x1F9B]='GREEK CAPITAL LETTER ETA WITH DASIA AND VARIA AND PROSGEGRAMMENI'
let s:d[0x1F9C]='GREEK CAPITAL LETTER ETA WITH PSILI AND OXIA AND PROSGEGRAMMENI'
let s:d[0x1F9D]='GREEK CAPITAL LETTER ETA WITH DASIA AND OXIA AND PROSGEGRAMMENI'
let s:d[0x1F9E]='GREEK CAPITAL LETTER ETA WITH PSILI AND PERISPOMENI AND PROSGEGRAMMENI'
let s:d[0x1F9F]='GREEK CAPITAL LETTER ETA WITH DASIA AND PERISPOMENI AND PROSGEGRAMMENI'
let s:d[0x1FA0]='GREEK SMALL LETTER OMEGA WITH PSILI AND YPOGEGRAMMENI'
let s:d[0x1FA1]='GREEK SMALL LETTER OMEGA WITH DASIA AND YPOGEGRAMMENI'
let s:d[0x1FA2]='GREEK SMALL LETTER OMEGA WITH PSILI AND VARIA AND YPOGEGRAMMENI'
let s:d[0x1FA3]='GREEK SMALL LETTER OMEGA WITH DASIA AND VARIA AND YPOGEGRAMMENI'
let s:d[0x1FA4]='GREEK SMALL LETTER OMEGA WITH PSILI AND OXIA AND YPOGEGRAMMENI'
let s:d[0x1FA5]='GREEK SMALL LETTER OMEGA WITH DASIA AND OXIA AND YPOGEGRAMMENI'
let s:d[0x1FA6]='GREEK SMALL LETTER OMEGA WITH PSILI AND PERISPOMENI AND YPOGEGRAMMENI'
let s:d[0x1FA7]='GREEK SMALL LETTER OMEGA WITH DASIA AND PERISPOMENI AND YPOGEGRAMMENI'
let s:d[0x1FA8]='GREEK CAPITAL LETTER OMEGA WITH PSILI AND PROSGEGRAMMENI'
let s:d[0x1FA9]='GREEK CAPITAL LETTER OMEGA WITH DASIA AND PROSGEGRAMMENI'
let s:d[0x1FAA]='GREEK CAPITAL LETTER OMEGA WITH PSILI AND VARIA AND PROSGEGRAMMENI'
let s:d[0x1FAB]='GREEK CAPITAL LETTER OMEGA WITH DASIA AND VARIA AND PROSGEGRAMMENI'
let s:d[0x1FAC]='GREEK CAPITAL LETTER OMEGA WITH PSILI AND OXIA AND PROSGEGRAMMENI'
let s:d[0x1FAD]='GREEK CAPITAL LETTER OMEGA WITH DASIA AND OXIA AND PROSGEGRAMMENI'
let s:d[0x1FAE]='GREEK CAPITAL LETTER OMEGA WITH PSILI AND PERISPOMENI AND PROSGEGRAMMENI'
let s:d[0x1FAF]='GREEK CAPITAL LETTER OMEGA WITH DASIA AND PERISPOMENI AND PROSGEGRAMMENI'
let s:d[0x1FB0]='GREEK SMALL LETTER ALPHA WITH VRACHY'
let s:d[0x1FB1]='GREEK SMALL LETTER ALPHA WITH MACRON'
let s:d[0x1FB2]='GREEK SMALL LETTER ALPHA WITH VARIA AND YPOGEGRAMMENI'
let s:d[0x1FB3]='GREEK SMALL LETTER ALPHA WITH YPOGEGRAMMENI'
let s:d[0x1FB4]='GREEK SMALL LETTER ALPHA WITH OXIA AND YPOGEGRAMMENI'
let s:d[0x1FB6]='GREEK SMALL LETTER ALPHA WITH PERISPOMENI'
let s:d[0x1FB7]='GREEK SMALL LETTER ALPHA WITH PERISPOMENI AND YPOGEGRAMMENI'
let s:d[0x1FB8]='GREEK CAPITAL LETTER ALPHA WITH VRACHY'
let s:d[0x1FB9]='GREEK CAPITAL LETTER ALPHA WITH MACRON'
let s:d[0x1FBA]='GREEK CAPITAL LETTER ALPHA WITH VARIA'
let s:d[0x1FBB]='GREEK CAPITAL LETTER ALPHA WITH OXIA'
let s:d[0x1FBC]='GREEK CAPITAL LETTER ALPHA WITH PROSGEGRAMMENI'
let s:d[0x1FBD]='GREEK KORONIS'
let s:d[0x1FBE]='GREEK PROSGEGRAMMENI'
let s:d[0x1FBF]='GREEK PSILI'
let s:d[0x1FC0]='GREEK PERISPOMENI'
let s:d[0x1FC1]='GREEK DIALYTIKA AND PERISPOMENI'
let s:d[0x1FC2]='GREEK SMALL LETTER ETA WITH VARIA AND YPOGEGRAMMENI'
let s:d[0x1FC3]='GREEK SMALL LETTER ETA WITH YPOGEGRAMMENI'
let s:d[0x1FC4]='GREEK SMALL LETTER ETA WITH OXIA AND YPOGEGRAMMENI'
let s:d[0x1FC6]='GREEK SMALL LETTER ETA WITH PERISPOMENI'
let s:d[0x1FC7]='GREEK SMALL LETTER ETA WITH PERISPOMENI AND YPOGEGRAMMENI'
let s:d[0x1FC8]='GREEK CAPITAL LETTER EPSILON WITH VARIA'
let s:d[0x1FC9]='GREEK CAPITAL LETTER EPSILON WITH OXIA'
let s:d[0x1FCA]='GREEK CAPITAL LETTER ETA WITH VARIA'
let s:d[0x1FCB]='GREEK CAPITAL LETTER ETA WITH OXIA'
let s:d[0x1FCC]='GREEK CAPITAL LETTER ETA WITH PROSGEGRAMMENI'
let s:d[0x1FCD]='GREEK PSILI AND VARIA'
let s:d[0x1FCE]='GREEK PSILI AND OXIA'
let s:d[0x1FCF]='GREEK PSILI AND PERISPOMENI'
let s:d[0x1FD0]='GREEK SMALL LETTER IOTA WITH VRACHY'
let s:d[0x1FD1]='GREEK SMALL LETTER IOTA WITH MACRON'
let s:d[0x1FD2]='GREEK SMALL LETTER IOTA WITH DIALYTIKA AND VARIA'
let s:d[0x1FD3]='GREEK SMALL LETTER IOTA WITH DIALYTIKA AND OXIA'
let s:d[0x1FD6]='GREEK SMALL LETTER IOTA WITH PERISPOMENI'
let s:d[0x1FD7]='GREEK SMALL LETTER IOTA WITH DIALYTIKA AND PERISPOMENI'
let s:d[0x1FD8]='GREEK CAPITAL LETTER IOTA WITH VRACHY'
let s:d[0x1FD9]='GREEK CAPITAL LETTER IOTA WITH MACRON'
let s:d[0x1FDA]='GREEK CAPITAL LETTER IOTA WITH VARIA'
let s:d[0x1FDB]='GREEK CAPITAL LETTER IOTA WITH OXIA'
let s:d[0x1FDD]='GREEK DASIA AND VARIA'
let s:d[0x1FDE]='GREEK DASIA AND OXIA'
let s:d[0x1FDF]='GREEK DASIA AND PERISPOMENI'
let s:d[0x1FE0]='GREEK SMALL LETTER UPSILON WITH VRACHY'
let s:d[0x1FE1]='GREEK SMALL LETTER UPSILON WITH MACRON'
let s:d[0x1FE2]='GREEK SMALL LETTER UPSILON WITH DIALYTIKA AND VARIA'
let s:d[0x1FE3]='GREEK SMALL LETTER UPSILON WITH DIALYTIKA AND OXIA'
let s:d[0x1FE4]='GREEK SMALL LETTER RHO WITH PSILI'
let s:d[0x1FE5]='GREEK SMALL LETTER RHO WITH DASIA'
let s:d[0x1FE6]='GREEK SMALL LETTER UPSILON WITH PERISPOMENI'
let s:d[0x1FE7]='GREEK SMALL LETTER UPSILON WITH DIALYTIKA AND PERISPOMENI'
let s:d[0x1FE8]='GREEK CAPITAL LETTER UPSILON WITH VRACHY'
let s:d[0x1FE9]='GREEK CAPITAL LETTER UPSILON WITH MACRON'
let s:d[0x1FEA]='GREEK CAPITAL LETTER UPSILON WITH VARIA'
let s:d[0x1FEB]='GREEK CAPITAL LETTER UPSILON WITH OXIA'
let s:d[0x1FEC]='GREEK CAPITAL LETTER RHO WITH DASIA'
let s:d[0x1FED]='GREEK DIALYTIKA AND VARIA'
let s:d[0x1FEE]='GREEK DIALYTIKA AND OXIA'
let s:d[0x1FEF]='GREEK VARIA'
let s:d[0x1FF2]='GREEK SMALL LETTER OMEGA WITH VARIA AND YPOGEGRAMMENI'
let s:d[0x1FF3]='GREEK SMALL LETTER OMEGA WITH YPOGEGRAMMENI'
let s:d[0x1FF4]='GREEK SMALL LETTER OMEGA WITH OXIA AND YPOGEGRAMMENI'
let s:d[0x1FF6]='GREEK SMALL LETTER OMEGA WITH PERISPOMENI'
let s:d[0x1FF7]='GREEK SMALL LETTER OMEGA WITH PERISPOMENI AND YPOGEGRAMMENI'
let s:d[0x1FF8]='GREEK CAPITAL LETTER OMICRON WITH VARIA'
let s:d[0x1FF9]='GREEK CAPITAL LETTER OMICRON WITH OXIA'
let s:d[0x1FFA]='GREEK CAPITAL LETTER OMEGA WITH VARIA'
let s:d[0x1FFB]='GREEK CAPITAL LETTER OMEGA WITH OXIA'
let s:d[0x1FFC]='GREEK CAPITAL LETTER OMEGA WITH PROSGEGRAMMENI'
let s:d[0x1FFD]='GREEK OXIA'
let s:d[0x1FFE]='GREEK DASIA'
let s:d[0x2000]='EN QUAD'
let s:d[0x2001]='EM QUAD'
let s:d[0x2002]='EN SPACE'
let s:d[0x2003]='EM SPACE'
let s:d[0x2004]='THREE-PER-EM SPACE'
let s:d[0x2005]='FOUR-PER-EM SPACE'
let s:d[0x2006]='SIX-PER-EM SPACE'
let s:d[0x2007]='FIGURE SPACE'
let s:d[0x2008]='PUNCTUATION SPACE'
let s:d[0x2009]='THIN SPACE'
let s:d[0x200A]='HAIR SPACE'
let s:d[0x200B]='ZERO WIDTH SPACE'
let s:d[0x200C]='ZERO WIDTH NON-JOINER'
let s:d[0x200D]='ZERO WIDTH JOINER'
let s:d[0x200E]='LEFT-TO-RIGHT MARK'
let s:d[0x200F]='RIGHT-TO-LEFT MARK'
let s:d[0x2010]='HYPHEN'
let s:d[0x2011]='NON-BREAKING HYPHEN'
let s:d[0x2012]='FIGURE DASH'
let s:d[0x2013]='EN DASH'
let s:d[0x2014]='EM DASH'
let s:d[0x2015]='HORIZONTAL BAR'
let s:d[0x2016]='DOUBLE VERTICAL LINE'
let s:d[0x2017]='DOUBLE LOW LINE'
let s:d[0x2018]='LEFT SINGLE QUOTATION MARK'
let s:d[0x2019]='RIGHT SINGLE QUOTATION MARK'
let s:d[0x201A]='SINGLE LOW-9 QUOTATION MARK'
let s:d[0x201B]='SINGLE HIGH-REVERSED-9 QUOTATION MARK'
let s:d[0x201C]='LEFT DOUBLE QUOTATION MARK'
let s:d[0x201D]='RIGHT DOUBLE QUOTATION MARK'
let s:d[0x201E]='DOUBLE LOW-9 QUOTATION MARK'
let s:d[0x201F]='DOUBLE HIGH-REVERSED-9 QUOTATION MARK'
let s:d[0x2020]='DAGGER'
let s:d[0x2021]='DOUBLE DAGGER'
let s:d[0x2022]='BULLET'
let s:d[0x2023]='TRIANGULAR BULLET'
let s:d[0x2024]='ONE DOT LEADER'
let s:d[0x2025]='TWO DOT LEADER'
let s:d[0x2026]='HORIZONTAL ELLIPSIS'
let s:d[0x2027]='HYPHENATION POINT'
let s:d[0x2028]='LINE SEPARATOR'
let s:d[0x2029]='PARAGRAPH SEPARATOR'
let s:d[0x202A]='LEFT-TO-RIGHT EMBEDDING'
let s:d[0x202B]='RIGHT-TO-LEFT EMBEDDING'
let s:d[0x202C]='POP DIRECTIONAL FORMATTING'
let s:d[0x202D]='LEFT-TO-RIGHT OVERRIDE'
let s:d[0x202E]='RIGHT-TO-LEFT OVERRIDE'
let s:d[0x202F]='NARROW NO-BREAK SPACE'
let s:d[0x2030]='PER MILLE SIGN'
let s:d[0x2031]='PER TEN THOUSAND SIGN'
let s:d[0x2032]='PRIME'
let s:d[0x2033]='DOUBLE PRIME'
let s:d[0x2034]='TRIPLE PRIME'
let s:d[0x2035]='REVERSED PRIME'
let s:d[0x2036]='REVERSED DOUBLE PRIME'
let s:d[0x2037]='REVERSED TRIPLE PRIME'
let s:d[0x2038]='CARET'
let s:d[0x2039]='SINGLE LEFT-POINTING ANGLE QUOTATION MARK'
let s:d[0x203A]='SINGLE RIGHT-POINTING ANGLE QUOTATION MARK'
let s:d[0x203B]='REFERENCE MARK'
let s:d[0x203C]='DOUBLE EXCLAMATION MARK'
let s:d[0x203D]='INTERROBANG'
let s:d[0x203E]='OVERLINE'
let s:d[0x203F]='UNDERTIE'
let s:d[0x2040]='CHARACTER TIE'
let s:d[0x2041]='CARET INSERTION POINT'
let s:d[0x2042]='ASTERISM'
let s:d[0x2043]='HYPHEN BULLET'
let s:d[0x2044]='FRACTION SLASH'
let s:d[0x2045]='LEFT SQUARE BRACKET WITH QUILL'
let s:d[0x2046]='RIGHT SQUARE BRACKET WITH QUILL'
let s:d[0x2047]='DOUBLE QUESTION MARK'
let s:d[0x2048]='QUESTION EXCLAMATION MARK'
let s:d[0x2049]='EXCLAMATION QUESTION MARK'
let s:d[0x204A]='TIRONIAN SIGN ET'
let s:d[0x204B]='REVERSED PILCROW SIGN'
let s:d[0x204C]='BLACK LEFTWARDS BULLET'
let s:d[0x204D]='BLACK RIGHTWARDS BULLET'
let s:d[0x204E]='LOW ASTERISK'
let s:d[0x204F]='REVERSED SEMICOLON'
let s:d[0x2050]='CLOSE UP'
let s:d[0x2051]='TWO ASTERISKS ALIGNED VERTICALLY'
let s:d[0x2052]='COMMERCIAL MINUS SIGN'
let s:d[0x2053]='SWUNG DASH'
let s:d[0x2054]='INVERTED UNDERTIE'
let s:d[0x2055]='FLOWER PUNCTUATION MARK'
let s:d[0x2056]='THREE DOT PUNCTUATION'
let s:d[0x2057]='QUADRUPLE PRIME'
let s:d[0x2058]='FOUR DOT PUNCTUATION'
let s:d[0x2059]='FIVE DOT PUNCTUATION'
let s:d[0x205A]='TWO DOT PUNCTUATION'
let s:d[0x205B]='FOUR DOT MARK'
let s:d[0x205C]='DOTTED CROSS'
let s:d[0x205D]='TRICOLON'
let s:d[0x205E]='VERTICAL FOUR DOTS'
let s:d[0x205F]='MEDIUM MATHEMATICAL SPACE'
let s:d[0x2060]='WORD JOINER'
let s:d[0x2061]='FUNCTION APPLICATION'
let s:d[0x2062]='INVISIBLE TIMES'
let s:d[0x2063]='INVISIBLE SEPARATOR'
let s:d[0x2064]='INVISIBLE PLUS'
let s:d[0x206A]='INHIBIT SYMMETRIC SWAPPING'
let s:d[0x206B]='ACTIVATE SYMMETRIC SWAPPING'
let s:d[0x206C]='INHIBIT ARABIC FORM SHAPING'
let s:d[0x206D]='ACTIVATE ARABIC FORM SHAPING'
let s:d[0x206E]='NATIONAL DIGIT SHAPES'
let s:d[0x206F]='NOMINAL DIGIT SHAPES'
let s:d[0x2070]='SUPERSCRIPT ZERO'
let s:d[0x2071]='SUPERSCRIPT LATIN SMALL LETTER I'
let s:d[0x2072]='<reserved>'
let s:d[0x2073]='<reserved>'
let s:d[0x2074]='SUPERSCRIPT FOUR'
let s:d[0x2075]='SUPERSCRIPT FIVE'
let s:d[0x2076]='SUPERSCRIPT SIX'
let s:d[0x2077]='SUPERSCRIPT SEVEN'
let s:d[0x2078]='SUPERSCRIPT EIGHT'
let s:d[0x2079]='SUPERSCRIPT NINE'
let s:d[0x207A]='SUPERSCRIPT PLUS SIGN'
let s:d[0x207B]='SUPERSCRIPT MINUS'
let s:d[0x207C]='SUPERSCRIPT EQUALS SIGN'
let s:d[0x207D]='SUPERSCRIPT LEFT PARENTHESIS'
let s:d[0x207E]='SUPERSCRIPT RIGHT PARENTHESIS'
let s:d[0x207F]='SUPERSCRIPT LATIN SMALL LETTER N'
let s:d[0x2080]='SUBSCRIPT ZERO'
let s:d[0x2081]='SUBSCRIPT ONE'
let s:d[0x2082]='SUBSCRIPT TWO'
let s:d[0x2083]='SUBSCRIPT THREE'
let s:d[0x2084]='SUBSCRIPT FOUR'
let s:d[0x2085]='SUBSCRIPT FIVE'
let s:d[0x2086]='SUBSCRIPT SIX'
let s:d[0x2087]='SUBSCRIPT SEVEN'
let s:d[0x2088]='SUBSCRIPT EIGHT'
let s:d[0x2089]='SUBSCRIPT NINE'
let s:d[0x208A]='SUBSCRIPT PLUS SIGN'
let s:d[0x208B]='SUBSCRIPT MINUS'
let s:d[0x208C]='SUBSCRIPT EQUALS SIGN'
let s:d[0x208D]='SUBSCRIPT LEFT PARENTHESIS'
let s:d[0x208E]='SUBSCRIPT RIGHT PARENTHESIS'
let s:d[0x2090]='LATIN SUBSCRIPT SMALL LETTER A'
let s:d[0x2091]='LATIN SUBSCRIPT SMALL LETTER E'
let s:d[0x2092]='LATIN SUBSCRIPT SMALL LETTER O'
let s:d[0x2093]='LATIN SUBSCRIPT SMALL LETTER X'
let s:d[0x2094]='LATIN SUBSCRIPT SMALL LETTER SCHWA'
let s:d[0x2095]='LATIN SUBSCRIPT SMALL LETTER H'
let s:d[0x2096]='LATIN SUBSCRIPT SMALL LETTER K'
let s:d[0x2097]='LATIN SUBSCRIPT SMALL LETTER L'
let s:d[0x2098]='LATIN SUBSCRIPT SMALL LETTER M'
let s:d[0x2099]='LATIN SUBSCRIPT SMALL LETTER N'
let s:d[0x209A]='LATIN SUBSCRIPT SMALL LETTER P'
let s:d[0x209B]='LATIN SUBSCRIPT SMALL LETTER S'
let s:d[0x209C]='LATIN SUBSCRIPT SMALL LETTER T'
let s:d[0x20A0]='EURO-CURRENCY SIGN'
let s:d[0x20A1]='COLON SIGN'
let s:d[0x20A2]='CRUZEIRO SIGN'
let s:d[0x20A3]='FRENCH FRANC SIGN'
let s:d[0x20A4]='LIRA SIGN'
let s:d[0x20A5]='MILL SIGN'
let s:d[0x20A6]='NAIRA SIGN'
let s:d[0x20A7]='PESETA SIGN'
let s:d[0x20A8]='RUPEE SIGN'
let s:d[0x20A9]='WON SIGN'
let s:d[0x20AA]='NEW SHEQEL SIGN'
let s:d[0x20AB]='DONG SIGN'
let s:d[0x20AC]='EURO SIGN'
let s:d[0x20AD]='KIP SIGN'
let s:d[0x20AE]='TUGRIK SIGN'
let s:d[0x20AF]='DRACHMA SIGN'
let s:d[0x20B0]='GERMAN PENNY SIGN'
let s:d[0x20B1]='PESO SIGN'
let s:d[0x20B2]='GUARANI SIGN'
let s:d[0x20B3]='AUSTRAL SIGN'
let s:d[0x20B4]='HRYVNIA SIGN'
let s:d[0x20B5]='CEDI SIGN'
let s:d[0x20B6]='LIVRE TOURNOIS SIGN'
let s:d[0x20B7]='SPESMILO SIGN'
let s:d[0x20B8]='TENGE SIGN'
let s:d[0x20B9]='INDIAN RUPEE SIGN'
let s:d[0x20BA]='TURKISH LIRA SIGN'
let s:d[0x20D0]='COMBINING LEFT HARPOON ABOVE'
let s:d[0x20D1]='COMBINING RIGHT HARPOON ABOVE'
let s:d[0x20D2]='COMBINING LONG VERTICAL LINE OVERLAY'
let s:d[0x20D3]='COMBINING SHORT VERTICAL LINE OVERLAY'
let s:d[0x20D4]='COMBINING ANTICLOCKWISE ARROW ABOVE'
let s:d[0x20D5]='COMBINING CLOCKWISE ARROW ABOVE'
let s:d[0x20D6]='COMBINING LEFT ARROW ABOVE'
let s:d[0x20D7]='COMBINING RIGHT ARROW ABOVE'
let s:d[0x20D8]='COMBINING RING OVERLAY'
let s:d[0x20D9]='COMBINING CLOCKWISE RING OVERLAY'
let s:d[0x20DA]='COMBINING ANTICLOCKWISE RING OVERLAY'
let s:d[0x20DB]='COMBINING THREE DOTS ABOVE'
let s:d[0x20DC]='COMBINING FOUR DOTS ABOVE'
let s:d[0x20DD]='COMBINING ENCLOSING CIRCLE'
let s:d[0x20DE]='COMBINING ENCLOSING SQUARE'
let s:d[0x20DF]='COMBINING ENCLOSING DIAMOND'
let s:d[0x20E0]='COMBINING ENCLOSING CIRCLE BACKSLASH'
let s:d[0x20E1]='COMBINING LEFT RIGHT ARROW ABOVE'
let s:d[0x20E2]='COMBINING ENCLOSING SCREEN'
let s:d[0x20E3]='COMBINING ENCLOSING KEYCAP'
let s:d[0x20E4]='COMBINING ENCLOSING UPWARD POINTING TRIANGLE'
let s:d[0x20E5]='COMBINING REVERSE SOLIDUS OVERLAY'
let s:d[0x20E6]='COMBINING DOUBLE VERTICAL STROKE OVERLAY'
let s:d[0x20E7]='COMBINING ANNUITY SYMBOL'
let s:d[0x20E8]='COMBINING TRIPLE UNDERDOT'
let s:d[0x20E9]='COMBINING WIDE BRIDGE ABOVE'
let s:d[0x20EA]='COMBINING LEFTWARDS ARROW OVERLAY'
let s:d[0x20EB]='COMBINING LONG DOUBLE SOLIDUS OVERLAY'
let s:d[0x20EC]='COMBINING RIGHTWARDS HARPOON WITH BARB DOWNWARDS'
let s:d[0x20ED]='COMBINING LEFTWARDS HARPOON WITH BARB DOWNWARDS'
let s:d[0x20EE]='COMBINING LEFT ARROW BELOW'
let s:d[0x20EF]='COMBINING RIGHT ARROW BELOW'
let s:d[0x20F0]='COMBINING ASTERISK ABOVE'
let s:d[0x2100]='ACCOUNT OF'
let s:d[0x2101]='ADDRESSED TO THE SUBJECT'
let s:d[0x2102]='DOUBLE-STRUCK CAPITAL C'
let s:d[0x2103]='DEGREE CELSIUS'
let s:d[0x2104]='CENTRE LINE SYMBOL'
let s:d[0x2105]='CARE OF'
let s:d[0x2106]='CADA UNA'
let s:d[0x2107]='EULER CONSTANT'
let s:d[0x2108]='SCRUPLE'
let s:d[0x2109]='DEGREE FAHRENHEIT'
let s:d[0x210A]='SCRIPT SMALL G'
let s:d[0x210B]='SCRIPT CAPITAL H'
let s:d[0x210C]='BLACK-LETTER CAPITAL H'
let s:d[0x210D]='DOUBLE-STRUCK CAPITAL H'
let s:d[0x210E]='PLANCK CONSTANT'
let s:d[0x210F]='PLANCK CONSTANT OVER TWO PI'
let s:d[0x2110]='SCRIPT CAPITAL I'
let s:d[0x2111]='BLACK-LETTER CAPITAL I'
let s:d[0x2112]='SCRIPT CAPITAL L'
let s:d[0x2113]='SCRIPT SMALL L'
let s:d[0x2114]='L B BAR SYMBOL'
let s:d[0x2115]='DOUBLE-STRUCK CAPITAL N'
let s:d[0x2116]='NUMERO SIGN'
let s:d[0x2117]='SOUND RECORDING COPYRIGHT'
let s:d[0x2118]='SCRIPT CAPITAL P'
let s:d[0x2119]='DOUBLE-STRUCK CAPITAL P'
let s:d[0x211A]='DOUBLE-STRUCK CAPITAL Q'
let s:d[0x211B]='SCRIPT CAPITAL R'
let s:d[0x211C]='BLACK-LETTER CAPITAL R'
let s:d[0x211D]='DOUBLE-STRUCK CAPITAL R'
let s:d[0x211E]='PRESCRIPTION TAKE'
let s:d[0x211F]='RESPONSE'
let s:d[0x2120]='SERVICE MARK'
let s:d[0x2121]='TELEPHONE SIGN'
let s:d[0x2122]='TRADE MARK SIGN'
let s:d[0x2123]='VERSICLE'
let s:d[0x2124]='DOUBLE-STRUCK CAPITAL Z'
let s:d[0x2125]='OUNCE SIGN'
let s:d[0x2126]='OHM SIGN'
let s:d[0x2127]='INVERTED OHM SIGN'
let s:d[0x2128]='BLACK-LETTER CAPITAL Z'
let s:d[0x2129]='TURNED GREEK SMALL LETTER IOTA'
let s:d[0x212A]='KELVIN SIGN'
let s:d[0x212B]='ANGSTROM SIGN'
let s:d[0x212C]='SCRIPT CAPITAL B'
let s:d[0x212D]='BLACK-LETTER CAPITAL C'
let s:d[0x212E]='ESTIMATED SYMBOL'
let s:d[0x212F]='SCRIPT SMALL E'
let s:d[0x2130]='SCRIPT CAPITAL E'
let s:d[0x2131]='SCRIPT CAPITAL F'
let s:d[0x2132]='TURNED CAPITAL F'
let s:d[0x2133]='SCRIPT CAPITAL M'
let s:d[0x2134]='SCRIPT SMALL O'
let s:d[0x2135]='ALEF SYMBOL'
let s:d[0x2136]='BET SYMBOL'
let s:d[0x2137]='GIMEL SYMBOL'
let s:d[0x2138]='DALET SYMBOL'
let s:d[0x2139]='INFORMATION SOURCE'
let s:d[0x213A]='ROTATED CAPITAL Q'
let s:d[0x213B]='FACSIMILE SIGN'
let s:d[0x213C]='DOUBLE-STRUCK SMALL PI'
let s:d[0x213D]='DOUBLE-STRUCK SMALL GAMMA'
let s:d[0x213E]='DOUBLE-STRUCK CAPITAL GAMMA'
let s:d[0x213F]='DOUBLE-STRUCK CAPITAL PI'
let s:d[0x2140]='DOUBLE-STRUCK N-ARY SUMMATION'
let s:d[0x2141]='TURNED SANS-SERIF CAPITAL G'
let s:d[0x2142]='TURNED SANS-SERIF CAPITAL L'
let s:d[0x2143]='REVERSED SANS-SERIF CAPITAL L'
let s:d[0x2144]='TURNED SANS-SERIF CAPITAL Y'
let s:d[0x2145]='DOUBLE-STRUCK ITALIC CAPITAL D'
let s:d[0x2146]='DOUBLE-STRUCK ITALIC SMALL D'
let s:d[0x2147]='DOUBLE-STRUCK ITALIC SMALL E'
let s:d[0x2148]='DOUBLE-STRUCK ITALIC SMALL I'
let s:d[0x2149]='DOUBLE-STRUCK ITALIC SMALL J'
let s:d[0x214A]='PROPERTY LINE'
let s:d[0x214B]='TURNED AMPERSAND'
let s:d[0x214C]='PER SIGN'
let s:d[0x214D]='AKTIESELSKAB'
let s:d[0x214E]='TURNED SMALL F'
let s:d[0x214F]='SYMBOL FOR SAMARITAN SOURCE'
let s:d[0x2150]='VULGAR FRACTION ONE SEVENTH'
let s:d[0x2151]='VULGAR FRACTION ONE NINTH'
let s:d[0x2152]='VULGAR FRACTION ONE TENTH'
let s:d[0x2153]='VULGAR FRACTION ONE THIRD'
let s:d[0x2154]='VULGAR FRACTION TWO THIRDS'
let s:d[0x2155]='VULGAR FRACTION ONE FIFTH'
let s:d[0x2156]='VULGAR FRACTION TWO FIFTHS'
let s:d[0x2157]='VULGAR FRACTION THREE FIFTHS'
let s:d[0x2158]='VULGAR FRACTION FOUR FIFTHS'
let s:d[0x2159]='VULGAR FRACTION ONE SIXTH'
let s:d[0x215A]='VULGAR FRACTION FIVE SIXTHS'
let s:d[0x215B]='VULGAR FRACTION ONE EIGHTH'
let s:d[0x215C]='VULGAR FRACTION THREE EIGHTHS'
let s:d[0x215D]='VULGAR FRACTION FIVE EIGHTHS'
let s:d[0x215E]='VULGAR FRACTION SEVEN EIGHTHS'
let s:d[0x215F]='FRACTION NUMERATOR ONE'
let s:d[0x2160]='ROMAN NUMERAL ONE'
let s:d[0x2161]='ROMAN NUMERAL TWO'
let s:d[0x2162]='ROMAN NUMERAL THREE'
let s:d[0x2163]='ROMAN NUMERAL FOUR'
let s:d[0x2164]='ROMAN NUMERAL FIVE'
let s:d[0x2165]='ROMAN NUMERAL SIX'
let s:d[0x2166]='ROMAN NUMERAL SEVEN'
let s:d[0x2167]='ROMAN NUMERAL EIGHT'
let s:d[0x2168]='ROMAN NUMERAL NINE'
let s:d[0x2169]='ROMAN NUMERAL TEN'
let s:d[0x216A]='ROMAN NUMERAL ELEVEN'
let s:d[0x216B]='ROMAN NUMERAL TWELVE'
let s:d[0x216C]='ROMAN NUMERAL FIFTY'
let s:d[0x216D]='ROMAN NUMERAL ONE HUNDRED'
let s:d[0x216E]='ROMAN NUMERAL FIVE HUNDRED'
let s:d[0x216F]='ROMAN NUMERAL ONE THOUSAND'
let s:d[0x2170]='SMALL ROMAN NUMERAL ONE'
let s:d[0x2171]='SMALL ROMAN NUMERAL TWO'
let s:d[0x2172]='SMALL ROMAN NUMERAL THREE'
let s:d[0x2173]='SMALL ROMAN NUMERAL FOUR'
let s:d[0x2174]='SMALL ROMAN NUMERAL FIVE'
let s:d[0x2175]='SMALL ROMAN NUMERAL SIX'
let s:d[0x2176]='SMALL ROMAN NUMERAL SEVEN'
let s:d[0x2177]='SMALL ROMAN NUMERAL EIGHT'
let s:d[0x2178]='SMALL ROMAN NUMERAL NINE'
let s:d[0x2179]='SMALL ROMAN NUMERAL TEN'
let s:d[0x217A]='SMALL ROMAN NUMERAL ELEVEN'
let s:d[0x217B]='SMALL ROMAN NUMERAL TWELVE'
let s:d[0x217C]='SMALL ROMAN NUMERAL FIFTY'
let s:d[0x217D]='SMALL ROMAN NUMERAL ONE HUNDRED'
let s:d[0x217E]='SMALL ROMAN NUMERAL FIVE HUNDRED'
let s:d[0x217F]='SMALL ROMAN NUMERAL ONE THOUSAND'
let s:d[0x2180]='ROMAN NUMERAL ONE THOUSAND C D'
let s:d[0x2181]='ROMAN NUMERAL FIVE THOUSAND'
let s:d[0x2182]='ROMAN NUMERAL TEN THOUSAND'
let s:d[0x2183]='ROMAN NUMERAL REVERSED ONE HUNDRED'
let s:d[0x2184]='LATIN SMALL LETTER REVERSED C'
let s:d[0x2185]='ROMAN NUMERAL SIX LATE FORM'
let s:d[0x2186]='ROMAN NUMERAL FIFTY EARLY FORM'
let s:d[0x2187]='ROMAN NUMERAL FIFTY THOUSAND'
let s:d[0x2188]='ROMAN NUMERAL ONE HUNDRED THOUSAND'
let s:d[0x2189]='VULGAR FRACTION ZERO THIRDS'
let s:d[0x2190]='LEFTWARDS ARROW'
let s:d[0x2191]='UPWARDS ARROW'
let s:d[0x2192]='RIGHTWARDS ARROW'
let s:d[0x2193]='DOWNWARDS ARROW'
let s:d[0x2194]='LEFT RIGHT ARROW'
let s:d[0x2195]='UP DOWN ARROW'
let s:d[0x2196]='NORTH WEST ARROW'
let s:d[0x2197]='NORTH EAST ARROW'
let s:d[0x2198]='SOUTH EAST ARROW'
let s:d[0x2199]='SOUTH WEST ARROW'
let s:d[0x219A]='LEFTWARDS ARROW WITH STROKE'
let s:d[0x219B]='RIGHTWARDS ARROW WITH STROKE'
let s:d[0x219C]='LEFTWARDS WAVE ARROW'
let s:d[0x219D]='RIGHTWARDS WAVE ARROW'
let s:d[0x219E]='LEFTWARDS TWO HEADED ARROW'
let s:d[0x219F]='UPWARDS TWO HEADED ARROW'
let s:d[0x21A0]='RIGHTWARDS TWO HEADED ARROW'
let s:d[0x21A1]='DOWNWARDS TWO HEADED ARROW'
let s:d[0x21A2]='LEFTWARDS ARROW WITH TAIL'
let s:d[0x21A3]='RIGHTWARDS ARROW WITH TAIL'
let s:d[0x21A4]='LEFTWARDS ARROW FROM BAR'
let s:d[0x21A5]='UPWARDS ARROW FROM BAR'
let s:d[0x21A6]='RIGHTWARDS ARROW FROM BAR'
let s:d[0x21A7]='DOWNWARDS ARROW FROM BAR'
let s:d[0x21A8]='UP DOWN ARROW WITH BASE'
let s:d[0x21A9]='LEFTWARDS ARROW WITH HOOK'
let s:d[0x21AA]='RIGHTWARDS ARROW WITH HOOK'
let s:d[0x21AB]='LEFTWARDS ARROW WITH LOOP'
let s:d[0x21AC]='RIGHTWARDS ARROW WITH LOOP'
let s:d[0x21AD]='LEFT RIGHT WAVE ARROW'
let s:d[0x21AE]='LEFT RIGHT ARROW WITH STROKE'
let s:d[0x21AF]='DOWNWARDS ZIGZAG ARROW'
let s:d[0x21B0]='UPWARDS ARROW WITH TIP LEFTWARDS'
let s:d[0x21B1]='UPWARDS ARROW WITH TIP RIGHTWARDS'
let s:d[0x21B2]='DOWNWARDS ARROW WITH TIP LEFTWARDS'
let s:d[0x21B3]='DOWNWARDS ARROW WITH TIP RIGHTWARDS'
let s:d[0x21B4]='RIGHTWARDS ARROW WITH CORNER DOWNWARDS'
let s:d[0x21B5]='DOWNWARDS ARROW WITH CORNER LEFTWARDS'
let s:d[0x21B6]='ANTICLOCKWISE TOP SEMICIRCLE ARROW'
let s:d[0x21B7]='CLOCKWISE TOP SEMICIRCLE ARROW'
let s:d[0x21B8]='NORTH WEST ARROW TO LONG BAR'
let s:d[0x21B9]='LEFTWARDS ARROW TO BAR OVER RIGHTWARDS ARROW TO BAR'
let s:d[0x21BA]='ANTICLOCKWISE OPEN CIRCLE ARROW'
let s:d[0x21BB]='CLOCKWISE OPEN CIRCLE ARROW'
let s:d[0x21BC]='LEFTWARDS HARPOON WITH BARB UPWARDS'
let s:d[0x21BD]='LEFTWARDS HARPOON WITH BARB DOWNWARDS'
let s:d[0x21BE]='UPWARDS HARPOON WITH BARB RIGHTWARDS'
let s:d[0x21BF]='UPWARDS HARPOON WITH BARB LEFTWARDS'
let s:d[0x21C0]='RIGHTWARDS HARPOON WITH BARB UPWARDS'
let s:d[0x21C1]='RIGHTWARDS HARPOON WITH BARB DOWNWARDS'
let s:d[0x21C2]='DOWNWARDS HARPOON WITH BARB RIGHTWARDS'
let s:d[0x21C3]='DOWNWARDS HARPOON WITH BARB LEFTWARDS'
let s:d[0x21C4]='RIGHTWARDS ARROW OVER LEFTWARDS ARROW'
let s:d[0x21C5]='UPWARDS ARROW LEFTWARDS OF DOWNWARDS ARROW'
let s:d[0x21C6]='LEFTWARDS ARROW OVER RIGHTWARDS ARROW'
let s:d[0x21C7]='LEFTWARDS PAIRED ARROWS'
let s:d[0x21C8]='UPWARDS PAIRED ARROWS'
let s:d[0x21C9]='RIGHTWARDS PAIRED ARROWS'
let s:d[0x21CA]='DOWNWARDS PAIRED ARROWS'
let s:d[0x21CB]='LEFTWARDS HARPOON OVER RIGHTWARDS HARPOON'
let s:d[0x21CC]='RIGHTWARDS HARPOON OVER LEFTWARDS HARPOON'
let s:d[0x21CD]='LEFTWARDS DOUBLE ARROW WITH STROKE'
let s:d[0x21CE]='LEFT RIGHT DOUBLE ARROW WITH STROKE'
let s:d[0x21CF]='RIGHTWARDS DOUBLE ARROW WITH STROKE'
let s:d[0x21D0]='LEFTWARDS DOUBLE ARROW'
let s:d[0x21D1]='UPWARDS DOUBLE ARROW'
let s:d[0x21D2]='RIGHTWARDS DOUBLE ARROW'
let s:d[0x21D3]='DOWNWARDS DOUBLE ARROW'
let s:d[0x21D4]='LEFT RIGHT DOUBLE ARROW'
let s:d[0x21D5]='UP DOWN DOUBLE ARROW'
let s:d[0x21D6]='NORTH WEST DOUBLE ARROW'
let s:d[0x21D7]='NORTH EAST DOUBLE ARROW'
let s:d[0x21D8]='SOUTH EAST DOUBLE ARROW'
let s:d[0x21D9]='SOUTH WEST DOUBLE ARROW'
let s:d[0x21DA]='LEFTWARDS TRIPLE ARROW'
let s:d[0x21DB]='RIGHTWARDS TRIPLE ARROW'
let s:d[0x21DC]='LEFTWARDS SQUIGGLE ARROW'
let s:d[0x21DD]='RIGHTWARDS SQUIGGLE ARROW'
let s:d[0x21DE]='UPWARDS ARROW WITH DOUBLE STROKE'
let s:d[0x21DF]='DOWNWARDS ARROW WITH DOUBLE STROKE'
let s:d[0x21E0]='LEFTWARDS DASHED ARROW'
let s:d[0x21E1]='UPWARDS DASHED ARROW'
let s:d[0x21E2]='RIGHTWARDS DASHED ARROW'
let s:d[0x21E3]='DOWNWARDS DASHED ARROW'
let s:d[0x21E4]='LEFTWARDS ARROW TO BAR'
let s:d[0x21E5]='RIGHTWARDS ARROW TO BAR'
let s:d[0x21E6]='LEFTWARDS WHITE ARROW'
let s:d[0x21E7]='UPWARDS WHITE ARROW'
let s:d[0x21E8]='RIGHTWARDS WHITE ARROW'
let s:d[0x21E9]='DOWNWARDS WHITE ARROW'
let s:d[0x21EA]='UPWARDS WHITE ARROW FROM BAR'
let s:d[0x21EB]='UPWARDS WHITE ARROW ON PEDESTAL'
let s:d[0x21EC]='UPWARDS WHITE ARROW ON PEDESTAL WITH HORIZONTAL BAR'
let s:d[0x21ED]='UPWARDS WHITE ARROW ON PEDESTAL WITH VERTICAL BAR'
let s:d[0x21EE]='UPWARDS WHITE DOUBLE ARROW'
let s:d[0x21EF]='UPWARDS WHITE DOUBLE ARROW ON PEDESTAL'
let s:d[0x21F0]='RIGHTWARDS WHITE ARROW FROM WALL'
let s:d[0x21F1]='NORTH WEST ARROW TO CORNER'
let s:d[0x21F2]='SOUTH EAST ARROW TO CORNER'
let s:d[0x21F3]='UP DOWN WHITE ARROW'
let s:d[0x21F4]='RIGHT ARROW WITH SMALL CIRCLE'
let s:d[0x21F5]='DOWNWARDS ARROW LEFTWARDS OF UPWARDS ARROW'
let s:d[0x21F6]='THREE RIGHTWARDS ARROWS'
let s:d[0x21F7]='LEFTWARDS ARROW WITH VERTICAL STROKE'
let s:d[0x21F8]='RIGHTWARDS ARROW WITH VERTICAL STROKE'
let s:d[0x21F9]='LEFT RIGHT ARROW WITH VERTICAL STROKE'
let s:d[0x21FA]='LEFTWARDS ARROW WITH DOUBLE VERTICAL STROKE'
let s:d[0x21FB]='RIGHTWARDS ARROW WITH DOUBLE VERTICAL STROKE'
let s:d[0x21FC]='LEFT RIGHT ARROW WITH DOUBLE VERTICAL STROKE'
let s:d[0x21FD]='LEFTWARDS OPEN-HEADED ARROW'
let s:d[0x21FE]='RIGHTWARDS OPEN-HEADED ARROW'
let s:d[0x21FF]='LEFT RIGHT OPEN-HEADED ARROW'
let s:d[0x2200]='FOR ALL'
let s:d[0x2201]='COMPLEMENT'
let s:d[0x2202]='PARTIAL DIFFERENTIAL'
let s:d[0x2203]='THERE EXISTS'
let s:d[0x2204]='THERE DOES NOT EXIST'
let s:d[0x2205]='EMPTY SET'
let s:d[0x2206]='INCREMENT'
let s:d[0x2207]='NABLA'
let s:d[0x2208]='ELEMENT OF'
let s:d[0x2209]='NOT AN ELEMENT OF'
let s:d[0x220A]='SMALL ELEMENT OF'
let s:d[0x220B]='CONTAINS AS MEMBER'
let s:d[0x220C]='DOES NOT CONTAIN AS MEMBER'
let s:d[0x220D]='SMALL CONTAINS AS MEMBER'
let s:d[0x220E]='END OF PROOF'
let s:d[0x220F]='N-ARY PRODUCT'
let s:d[0x2210]='N-ARY COPRODUCT'
let s:d[0x2211]='N-ARY SUMMATION'
let s:d[0x2212]='MINUS SIGN'
let s:d[0x2213]='MINUS-OR-PLUS SIGN'
let s:d[0x2214]='DOT PLUS'
let s:d[0x2215]='DIVISION SLASH'
let s:d[0x2216]='SET MINUS'
let s:d[0x2217]='ASTERISK OPERATOR'
let s:d[0x2218]='RING OPERATOR'
let s:d[0x2219]='BULLET OPERATOR'
let s:d[0x221A]='SQUARE ROOT'
let s:d[0x221B]='CUBE ROOT'
let s:d[0x221C]='FOURTH ROOT'
let s:d[0x221D]='PROPORTIONAL TO'
let s:d[0x221E]='INFINITY'
let s:d[0x221F]='RIGHT ANGLE'
let s:d[0x2220]='ANGLE'
let s:d[0x2221]='MEASURED ANGLE'
let s:d[0x2222]='SPHERICAL ANGLE'
let s:d[0x2223]='DIVIDES'
let s:d[0x2224]='DOES NOT DIVIDE'
let s:d[0x2225]='PARALLEL TO'
let s:d[0x2226]='NOT PARALLEL TO'
let s:d[0x2227]='LOGICAL AND'
let s:d[0x2228]='LOGICAL OR'
let s:d[0x2229]='INTERSECTION'
let s:d[0x222A]='UNION'
let s:d[0x222B]='INTEGRAL'
let s:d[0x222C]='DOUBLE INTEGRAL'
let s:d[0x222D]='TRIPLE INTEGRAL'
let s:d[0x222E]='CONTOUR INTEGRAL'
let s:d[0x222F]='SURFACE INTEGRAL'
let s:d[0x2230]='VOLUME INTEGRAL'
let s:d[0x2231]='CLOCKWISE INTEGRAL'
let s:d[0x2232]='CLOCKWISE CONTOUR INTEGRAL'
let s:d[0x2233]='ANTICLOCKWISE CONTOUR INTEGRAL'
let s:d[0x2234]='THEREFORE'
let s:d[0x2235]='BECAUSE'
let s:d[0x2236]='RATIO'
let s:d[0x2237]='PROPORTION'
let s:d[0x2238]='DOT MINUS'
let s:d[0x2239]='EXCESS'
let s:d[0x223A]='GEOMETRIC PROPORTION'
let s:d[0x223B]='HOMOTHETIC'
let s:d[0x223C]='TILDE OPERATOR'
let s:d[0x223D]='REVERSED TILDE'
let s:d[0x223E]='INVERTED LAZY S'
let s:d[0x223F]='SINE WAVE'
let s:d[0x2240]='WREATH PRODUCT'
let s:d[0x2241]='NOT TILDE'
let s:d[0x2242]='MINUS TILDE'
let s:d[0x2243]='ASYMPTOTICALLY EQUAL TO'
let s:d[0x2244]='NOT ASYMPTOTICALLY EQUAL TO'
let s:d[0x2245]='APPROXIMATELY EQUAL TO'
let s:d[0x2246]='APPROXIMATELY BUT NOT ACTUALLY EQUAL TO'
let s:d[0x2247]='NEITHER APPROXIMATELY NOR ACTUALLY EQUAL TO'
let s:d[0x2248]='ALMOST EQUAL TO'
let s:d[0x2249]='NOT ALMOST EQUAL TO'
let s:d[0x224A]='ALMOST EQUAL OR EQUAL TO'
let s:d[0x224B]='TRIPLE TILDE'
let s:d[0x224C]='ALL EQUAL TO'
let s:d[0x224D]='EQUIVALENT TO'
let s:d[0x224E]='GEOMETRICALLY EQUIVALENT TO'
let s:d[0x224F]='DIFFERENCE BETWEEN'
let s:d[0x2250]='APPROACHES THE LIMIT'
let s:d[0x2251]='GEOMETRICALLY EQUAL TO'
let s:d[0x2252]='APPROXIMATELY EQUAL TO OR THE IMAGE OF'
let s:d[0x2253]='IMAGE OF OR APPROXIMATELY EQUAL TO'
let s:d[0x2254]='COLON EQUALS'
let s:d[0x2255]='EQUALS COLON'
let s:d[0x2256]='RING IN EQUAL TO'
let s:d[0x2257]='RING EQUAL TO'
let s:d[0x2258]='CORRESPONDS TO'
let s:d[0x2259]='ESTIMATES'
let s:d[0x225A]='EQUIANGULAR TO'
let s:d[0x225B]='STAR EQUALS'
let s:d[0x225C]='DELTA EQUAL TO'
let s:d[0x225D]='EQUAL TO BY DEFINITION'
let s:d[0x225E]='MEASURED BY'
let s:d[0x225F]='QUESTIONED EQUAL TO'
let s:d[0x2260]='NOT EQUAL TO'
let s:d[0x2261]='IDENTICAL TO'
let s:d[0x2262]='NOT IDENTICAL TO'
let s:d[0x2263]='STRICTLY EQUIVALENT TO'
let s:d[0x2264]='LESS-THAN OR EQUAL TO'
let s:d[0x2265]='GREATER-THAN OR EQUAL TO'
let s:d[0x2266]='LESS-THAN OVER EQUAL TO'
let s:d[0x2267]='GREATER-THAN OVER EQUAL TO'
let s:d[0x2268]='LESS-THAN BUT NOT EQUAL TO'
let s:d[0x2269]='GREATER-THAN BUT NOT EQUAL TO'
let s:d[0x226A]='MUCH LESS-THAN'
let s:d[0x226B]='MUCH GREATER-THAN'
let s:d[0x226C]='BETWEEN'
let s:d[0x226D]='NOT EQUIVALENT TO'
let s:d[0x226E]='NOT LESS-THAN'
let s:d[0x226F]='NOT GREATER-THAN'
let s:d[0x2270]='NEITHER LESS-THAN NOR EQUAL TO'
let s:d[0x2271]='NEITHER GREATER-THAN NOR EQUAL TO'
let s:d[0x2272]='LESS-THAN OR EQUIVALENT TO'
let s:d[0x2273]='GREATER-THAN OR EQUIVALENT TO'
let s:d[0x2274]='NEITHER LESS-THAN NOR EQUIVALENT TO'
let s:d[0x2275]='NEITHER GREATER-THAN NOR EQUIVALENT TO'
let s:d[0x2276]='LESS-THAN OR GREATER-THAN'
let s:d[0x2277]='GREATER-THAN OR LESS-THAN'
let s:d[0x2278]='NEITHER LESS-THAN NOR GREATER-THAN'
let s:d[0x2279]='NEITHER GREATER-THAN NOR LESS-THAN'
let s:d[0x227A]='PRECEDES'
let s:d[0x227B]='SUCCEEDS'
let s:d[0x227C]='PRECEDES OR EQUAL TO'
let s:d[0x227D]='SUCCEEDS OR EQUAL TO'
let s:d[0x227E]='PRECEDES OR EQUIVALENT TO'
let s:d[0x227F]='SUCCEEDS OR EQUIVALENT TO'
let s:d[0x2280]='DOES NOT PRECEDE'
let s:d[0x2281]='DOES NOT SUCCEED'
let s:d[0x2282]='SUBSET OF'
let s:d[0x2283]='SUPERSET OF'
let s:d[0x2284]='NOT A SUBSET OF'
let s:d[0x2285]='NOT A SUPERSET OF'
let s:d[0x2286]='SUBSET OF OR EQUAL TO'
let s:d[0x2287]='SUPERSET OF OR EQUAL TO'
let s:d[0x2288]='NEITHER A SUBSET OF NOR EQUAL TO'
let s:d[0x2289]='NEITHER A SUPERSET OF NOR EQUAL TO'
let s:d[0x228A]='SUBSET OF WITH NOT EQUAL TO'
let s:d[0x228B]='SUPERSET OF WITH NOT EQUAL TO'
let s:d[0x228C]='MULTISET'
let s:d[0x228D]='MULTISET MULTIPLICATION'
let s:d[0x228E]='MULTISET UNION'
let s:d[0x228F]='SQUARE IMAGE OF'
let s:d[0x2290]='SQUARE ORIGINAL OF'
let s:d[0x2291]='SQUARE IMAGE OF OR EQUAL TO'
let s:d[0x2292]='SQUARE ORIGINAL OF OR EQUAL TO'
let s:d[0x2293]='SQUARE CAP'
let s:d[0x2294]='SQUARE CUP'
let s:d[0x2295]='CIRCLED PLUS'
let s:d[0x2296]='CIRCLED MINUS'
let s:d[0x2297]='CIRCLED TIMES'
let s:d[0x2298]='CIRCLED DIVISION SLASH'
let s:d[0x2299]='CIRCLED DOT OPERATOR'
let s:d[0x229A]='CIRCLED RING OPERATOR'
let s:d[0x229B]='CIRCLED ASTERISK OPERATOR'
let s:d[0x229C]='CIRCLED EQUALS'
let s:d[0x229D]='CIRCLED DASH'
let s:d[0x229E]='SQUARED PLUS'
let s:d[0x229F]='SQUARED MINUS'
let s:d[0x22A0]='SQUARED TIMES'
let s:d[0x22A1]='SQUARED DOT OPERATOR'
let s:d[0x22A2]='RIGHT TACK'
let s:d[0x22A3]='LEFT TACK'
let s:d[0x22A4]='DOWN TACK'
let s:d[0x22A5]='UP TACK'
let s:d[0x22A6]='ASSERTION'
let s:d[0x22A7]='MODELS'
let s:d[0x22A8]='TRUE'
let s:d[0x22A9]='FORCES'
let s:d[0x22AA]='TRIPLE VERTICAL BAR RIGHT TURNSTILE'
let s:d[0x22AB]='DOUBLE VERTICAL BAR DOUBLE RIGHT TURNSTILE'
let s:d[0x22AC]='DOES NOT PROVE'
let s:d[0x22AD]='NOT TRUE'
let s:d[0x22AE]='DOES NOT FORCE'
let s:d[0x22AF]='NEGATED DOUBLE VERTICAL BAR DOUBLE RIGHT TURNSTILE'
let s:d[0x22B0]='PRECEDES UNDER RELATION'
let s:d[0x22B1]='SUCCEEDS UNDER RELATION'
let s:d[0x22B2]='NORMAL SUBGROUP OF'
let s:d[0x22B3]='CONTAINS AS NORMAL SUBGROUP'
let s:d[0x22B4]='NORMAL SUBGROUP OF OR EQUAL TO'
let s:d[0x22B5]='CONTAINS AS NORMAL SUBGROUP OR EQUAL TO'
let s:d[0x22B6]='ORIGINAL OF'
let s:d[0x22B7]='IMAGE OF'
let s:d[0x22B8]='MULTIMAP'
let s:d[0x22B9]='HERMITIAN CONJUGATE MATRIX'
let s:d[0x22BA]='INTERCALATE'
let s:d[0x22BB]='XOR'
let s:d[0x22BC]='NAND'
let s:d[0x22BD]='NOR'
let s:d[0x22BE]='RIGHT ANGLE WITH ARC'
let s:d[0x22BF]='RIGHT TRIANGLE'
let s:d[0x22C0]='N-ARY LOGICAL AND'
let s:d[0x22C1]='N-ARY LOGICAL OR'
let s:d[0x22C2]='N-ARY INTERSECTION'
let s:d[0x22C3]='N-ARY UNION'
let s:d[0x22C4]='DIAMOND OPERATOR'
let s:d[0x22C5]='DOT OPERATOR'
let s:d[0x22C6]='STAR OPERATOR'
let s:d[0x22C7]='DIVISION TIMES'
let s:d[0x22C8]='BOWTIE'
let s:d[0x22C9]='LEFT NORMAL FACTOR SEMIDIRECT PRODUCT'
let s:d[0x22CA]='RIGHT NORMAL FACTOR SEMIDIRECT PRODUCT'
let s:d[0x22CB]='LEFT SEMIDIRECT PRODUCT'
let s:d[0x22CC]='RIGHT SEMIDIRECT PRODUCT'
let s:d[0x22CD]='REVERSED TILDE EQUALS'
let s:d[0x22CE]='CURLY LOGICAL OR'
let s:d[0x22CF]='CURLY LOGICAL AND'
let s:d[0x22D0]='DOUBLE SUBSET'
let s:d[0x22D1]='DOUBLE SUPERSET'
let s:d[0x22D2]='DOUBLE INTERSECTION'
let s:d[0x22D3]='DOUBLE UNION'
let s:d[0x22D4]='PITCHFORK'
let s:d[0x22D5]='EQUAL AND PARALLEL TO'
let s:d[0x22D6]='LESS-THAN WITH DOT'
let s:d[0x22D7]='GREATER-THAN WITH DOT'
let s:d[0x22D8]='VERY MUCH LESS-THAN'
let s:d[0x22D9]='VERY MUCH GREATER-THAN'
let s:d[0x22DA]='LESS-THAN EQUAL TO OR GREATER-THAN'
let s:d[0x22DB]='GREATER-THAN EQUAL TO OR LESS-THAN'
let s:d[0x22DC]='EQUAL TO OR LESS-THAN'
let s:d[0x22DD]='EQUAL TO OR GREATER-THAN'
let s:d[0x22DE]='EQUAL TO OR PRECEDES'
let s:d[0x22DF]='EQUAL TO OR SUCCEEDS'
let s:d[0x22E0]='DOES NOT PRECEDE OR EQUAL'
let s:d[0x22E1]='DOES NOT SUCCEED OR EQUAL'
let s:d[0x22E2]='NOT SQUARE IMAGE OF OR EQUAL TO'
let s:d[0x22E3]='NOT SQUARE ORIGINAL OF OR EQUAL TO'
let s:d[0x22E4]='SQUARE IMAGE OF OR NOT EQUAL TO'
let s:d[0x22E5]='SQUARE ORIGINAL OF OR NOT EQUAL TO'
let s:d[0x22E6]='LESS-THAN BUT NOT EQUIVALENT TO'
let s:d[0x22E7]='GREATER-THAN BUT NOT EQUIVALENT TO'
let s:d[0x22E8]='PRECEDES BUT NOT EQUIVALENT TO'
let s:d[0x22E9]='SUCCEEDS BUT NOT EQUIVALENT TO'
let s:d[0x22EA]='NOT NORMAL SUBGROUP OF'
let s:d[0x22EB]='DOES NOT CONTAIN AS NORMAL SUBGROUP'
let s:d[0x22EC]='NOT NORMAL SUBGROUP OF OR EQUAL TO'
let s:d[0x22ED]='DOES NOT CONTAIN AS NORMAL SUBGROUP OR EQUAL'
let s:d[0x22EE]='VERTICAL ELLIPSIS'
let s:d[0x22EF]='MIDLINE HORIZONTAL ELLIPSIS'
let s:d[0x22F0]='UP RIGHT DIAGONAL ELLIPSIS'
let s:d[0x22F1]='DOWN RIGHT DIAGONAL ELLIPSIS'
let s:d[0x22F2]='ELEMENT OF WITH LONG HORIZONTAL STROKE'
let s:d[0x22F3]='ELEMENT OF WITH VERTICAL BAR AT END OF HORIZONTAL STROKE'
let s:d[0x22F4]='SMALL ELEMENT OF WITH VERTICAL BAR AT END OF HORIZONTAL STROKE'
let s:d[0x22F5]='ELEMENT OF WITH DOT ABOVE'
let s:d[0x22F6]='ELEMENT OF WITH OVERBAR'
let s:d[0x22F7]='SMALL ELEMENT OF WITH OVERBAR'
let s:d[0x22F8]='ELEMENT OF WITH UNDERBAR'
let s:d[0x22F9]='ELEMENT OF WITH TWO HORIZONTAL STROKES'
let s:d[0x22FA]='CONTAINS WITH LONG HORIZONTAL STROKE'
let s:d[0x22FB]='CONTAINS WITH VERTICAL BAR AT END OF HORIZONTAL STROKE'
let s:d[0x22FC]='SMALL CONTAINS WITH VERTICAL BAR AT END OF HORIZONTAL STROKE'
let s:d[0x22FD]='CONTAINS WITH OVERBAR'
let s:d[0x22FE]='SMALL CONTAINS WITH OVERBAR'
let s:d[0x22FF]='Z NOTATION BAG MEMBERSHIP'
let s:d[0x2300]='DIAMETER SIGN'
let s:d[0x2301]='ELECTRIC ARROW'
let s:d[0x2302]='HOUSE'
let s:d[0x2303]='UP ARROWHEAD'
let s:d[0x2304]='DOWN ARROWHEAD'
let s:d[0x2305]='PROJECTIVE'
let s:d[0x2306]='PERSPECTIVE'
let s:d[0x2307]='WAVY LINE'
let s:d[0x2308]='LEFT CEILING'
let s:d[0x2309]='RIGHT CEILING'
let s:d[0x230A]='LEFT FLOOR'
let s:d[0x230B]='RIGHT FLOOR'
let s:d[0x230C]='BOTTOM RIGHT CROP'
let s:d[0x230D]='BOTTOM LEFT CROP'
let s:d[0x230E]='TOP RIGHT CROP'
let s:d[0x230F]='TOP LEFT CROP'
let s:d[0x2310]='REVERSED NOT SIGN'
let s:d[0x2311]='SQUARE LOZENGE'
let s:d[0x2312]='ARC'
let s:d[0x2313]='SEGMENT'
let s:d[0x2314]='SECTOR'
let s:d[0x2315]='TELEPHONE RECORDER'
let s:d[0x2316]='POSITION INDICATOR'
let s:d[0x2317]='VIEWDATA SQUARE'
let s:d[0x2318]='PLACE OF INTEREST SIGN'
let s:d[0x2319]='TURNED NOT SIGN'
let s:d[0x231A]='WATCH'
let s:d[0x231B]='HOURGLASS'
let s:d[0x231C]='TOP LEFT CORNER'
let s:d[0x231D]='TOP RIGHT CORNER'
let s:d[0x231E]='BOTTOM LEFT CORNER'
let s:d[0x231F]='BOTTOM RIGHT CORNER'
let s:d[0x2320]='TOP HALF INTEGRAL'
let s:d[0x2321]='BOTTOM HALF INTEGRAL'
let s:d[0x2322]='FROWN'
let s:d[0x2323]='SMILE'
let s:d[0x2324]='UP ARROWHEAD BETWEEN TWO HORIZONTAL BARS'
let s:d[0x2325]='OPTION KEY'
let s:d[0x2326]='ERASE TO THE RIGHT'
let s:d[0x2327]='X IN A RECTANGLE BOX'
let s:d[0x2328]='KEYBOARD'
let s:d[0x2329]='LEFT-POINTING ANGLE BRACKET'
let s:d[0x232A]='RIGHT-POINTING ANGLE BRACKET'
let s:d[0x232B]='ERASE TO THE LEFT'
let s:d[0x232C]='BENZENE RING'
let s:d[0x232D]='CYLINDRICITY'
let s:d[0x232E]='ALL AROUND-PROFILE'
let s:d[0x232F]='SYMMETRY'
let s:d[0x2330]='TOTAL RUNOUT'
let s:d[0x2331]='DIMENSION ORIGIN'
let s:d[0x2332]='CONICAL TAPER'
let s:d[0x2333]='SLOPE'
let s:d[0x2334]='COUNTERBORE'
let s:d[0x2335]='COUNTERSINK'
let s:d[0x2336]='APL FUNCTIONAL SYMBOL I-BEAM'
let s:d[0x2337]='APL FUNCTIONAL SYMBOL SQUISH QUAD'
let s:d[0x2338]='APL FUNCTIONAL SYMBOL QUAD EQUAL'
let s:d[0x2339]='APL FUNCTIONAL SYMBOL QUAD DIVIDE'
let s:d[0x233A]='APL FUNCTIONAL SYMBOL QUAD DIAMOND'
let s:d[0x233B]='APL FUNCTIONAL SYMBOL QUAD JOT'
let s:d[0x233C]='APL FUNCTIONAL SYMBOL QUAD CIRCLE'
let s:d[0x233D]='APL FUNCTIONAL SYMBOL CIRCLE STILE'
let s:d[0x233E]='APL FUNCTIONAL SYMBOL CIRCLE JOT'
let s:d[0x233F]='APL FUNCTIONAL SYMBOL SLASH BAR'
let s:d[0x2340]='APL FUNCTIONAL SYMBOL BACKSLASH BAR'
let s:d[0x2341]='APL FUNCTIONAL SYMBOL QUAD SLASH'
let s:d[0x2342]='APL FUNCTIONAL SYMBOL QUAD BACKSLASH'
let s:d[0x2343]='APL FUNCTIONAL SYMBOL QUAD LESS-THAN'
let s:d[0x2344]='APL FUNCTIONAL SYMBOL QUAD GREATER-THAN'
let s:d[0x2345]='APL FUNCTIONAL SYMBOL LEFTWARDS VANE'
let s:d[0x2346]='APL FUNCTIONAL SYMBOL RIGHTWARDS VANE'
let s:d[0x2347]='APL FUNCTIONAL SYMBOL QUAD LEFTWARDS ARROW'
let s:d[0x2348]='APL FUNCTIONAL SYMBOL QUAD RIGHTWARDS ARROW'
let s:d[0x2349]='APL FUNCTIONAL SYMBOL CIRCLE BACKSLASH'
let s:d[0x234A]='APL FUNCTIONAL SYMBOL DOWN TACK UNDERBAR'
let s:d[0x234B]='APL FUNCTIONAL SYMBOL DELTA STILE'
let s:d[0x234C]='APL FUNCTIONAL SYMBOL QUAD DOWN CARET'
let s:d[0x234D]='APL FUNCTIONAL SYMBOL QUAD DELTA'
let s:d[0x234E]='APL FUNCTIONAL SYMBOL DOWN TACK JOT'
let s:d[0x234F]='APL FUNCTIONAL SYMBOL UPWARDS VANE'
let s:d[0x2350]='APL FUNCTIONAL SYMBOL QUAD UPWARDS ARROW'
let s:d[0x2351]='APL FUNCTIONAL SYMBOL UP TACK OVERBAR'
let s:d[0x2352]='APL FUNCTIONAL SYMBOL DEL STILE'
let s:d[0x2353]='APL FUNCTIONAL SYMBOL QUAD UP CARET'
let s:d[0x2354]='APL FUNCTIONAL SYMBOL QUAD DEL'
let s:d[0x2355]='APL FUNCTIONAL SYMBOL UP TACK JOT'
let s:d[0x2356]='APL FUNCTIONAL SYMBOL DOWNWARDS VANE'
let s:d[0x2357]='APL FUNCTIONAL SYMBOL QUAD DOWNWARDS ARROW'
let s:d[0x2358]='APL FUNCTIONAL SYMBOL QUOTE UNDERBAR'
let s:d[0x2359]='APL FUNCTIONAL SYMBOL DELTA UNDERBAR'
let s:d[0x235A]='APL FUNCTIONAL SYMBOL DIAMOND UNDERBAR'
let s:d[0x235B]='APL FUNCTIONAL SYMBOL JOT UNDERBAR'
let s:d[0x235C]='APL FUNCTIONAL SYMBOL CIRCLE UNDERBAR'
let s:d[0x235D]='APL FUNCTIONAL SYMBOL UP SHOE JOT'
let s:d[0x235E]='APL FUNCTIONAL SYMBOL QUOTE QUAD'
let s:d[0x235F]='APL FUNCTIONAL SYMBOL CIRCLE STAR'
let s:d[0x2360]='APL FUNCTIONAL SYMBOL QUAD COLON'
let s:d[0x2361]='APL FUNCTIONAL SYMBOL UP TACK DIAERESIS'
let s:d[0x2362]='APL FUNCTIONAL SYMBOL DEL DIAERESIS'
let s:d[0x2363]='APL FUNCTIONAL SYMBOL STAR DIAERESIS'
let s:d[0x2364]='APL FUNCTIONAL SYMBOL JOT DIAERESIS'
let s:d[0x2365]='APL FUNCTIONAL SYMBOL CIRCLE DIAERESIS'
let s:d[0x2366]='APL FUNCTIONAL SYMBOL DOWN SHOE STILE'
let s:d[0x2367]='APL FUNCTIONAL SYMBOL LEFT SHOE STILE'
let s:d[0x2368]='APL FUNCTIONAL SYMBOL TILDE DIAERESIS'
let s:d[0x2369]='APL FUNCTIONAL SYMBOL GREATER-THAN DIAERESIS'
let s:d[0x236A]='APL FUNCTIONAL SYMBOL COMMA BAR'
let s:d[0x236B]='APL FUNCTIONAL SYMBOL DEL TILDE'
let s:d[0x236C]='APL FUNCTIONAL SYMBOL ZILDE'
let s:d[0x236D]='APL FUNCTIONAL SYMBOL STILE TILDE'
let s:d[0x236E]='APL FUNCTIONAL SYMBOL SEMICOLON UNDERBAR'
let s:d[0x236F]='APL FUNCTIONAL SYMBOL QUAD NOT EQUAL'
let s:d[0x2370]='APL FUNCTIONAL SYMBOL QUAD QUESTION'
let s:d[0x2371]='APL FUNCTIONAL SYMBOL DOWN CARET TILDE'
let s:d[0x2372]='APL FUNCTIONAL SYMBOL UP CARET TILDE'
let s:d[0x2373]='APL FUNCTIONAL SYMBOL IOTA'
let s:d[0x2374]='APL FUNCTIONAL SYMBOL RHO'
let s:d[0x2375]='APL FUNCTIONAL SYMBOL OMEGA'
let s:d[0x2376]='APL FUNCTIONAL SYMBOL ALPHA UNDERBAR'
let s:d[0x2377]='APL FUNCTIONAL SYMBOL EPSILON UNDERBAR'
let s:d[0x2378]='APL FUNCTIONAL SYMBOL IOTA UNDERBAR'
let s:d[0x2379]='APL FUNCTIONAL SYMBOL OMEGA UNDERBAR'
let s:d[0x237A]='APL FUNCTIONAL SYMBOL ALPHA'
let s:d[0x237B]='NOT CHECK MARK'
let s:d[0x237C]='RIGHT ANGLE WITH DOWNWARDS ZIGZAG ARROW'
let s:d[0x237D]='SHOULDERED OPEN BOX'
let s:d[0x237E]='BELL SYMBOL'
let s:d[0x237F]='VERTICAL LINE WITH MIDDLE DOT'
let s:d[0x2380]='INSERTION SYMBOL'
let s:d[0x2381]='CONTINUOUS UNDERLINE SYMBOL'
let s:d[0x2382]='DISCONTINUOUS UNDERLINE SYMBOL'
let s:d[0x2383]='EMPHASIS SYMBOL'
let s:d[0x2384]='COMPOSITION SYMBOL'
let s:d[0x2385]='WHITE SQUARE WITH CENTRE VERTICAL LINE'
let s:d[0x2386]='ENTER SYMBOL'
let s:d[0x2387]='ALTERNATIVE KEY SYMBOL'
let s:d[0x2388]='HELM SYMBOL'
let s:d[0x2389]='CIRCLED HORIZONTAL BAR WITH NOTCH'
let s:d[0x238A]='CIRCLED TRIANGLE DOWN'
let s:d[0x238B]='BROKEN CIRCLE WITH NORTHWEST ARROW'
let s:d[0x238C]='UNDO SYMBOL'
let s:d[0x238D]='MONOSTABLE SYMBOL'
let s:d[0x238E]='HYSTERESIS SYMBOL'
let s:d[0x238F]='OPEN-CIRCUIT-OUTPUT H-TYPE SYMBOL'
let s:d[0x2390]='OPEN-CIRCUIT-OUTPUT L-TYPE SYMBOL'
let s:d[0x2391]='PASSIVE-PULL-DOWN-OUTPUT SYMBOL'
let s:d[0x2392]='PASSIVE-PULL-UP-OUTPUT SYMBOL'
let s:d[0x2393]='DIRECT CURRENT SYMBOL FORM TWO'
let s:d[0x2394]='SOFTWARE-FUNCTION SYMBOL'
let s:d[0x2395]='APL FUNCTIONAL SYMBOL QUAD'
let s:d[0x2396]='DECIMAL SEPARATOR KEY SYMBOL'
let s:d[0x2397]='PREVIOUS PAGE'
let s:d[0x2398]='NEXT PAGE'
let s:d[0x2399]='PRINT SCREEN SYMBOL'
let s:d[0x239A]='CLEAR SCREEN SYMBOL'
let s:d[0x239B]='LEFT PARENTHESIS UPPER HOOK'
let s:d[0x239C]='LEFT PARENTHESIS EXTENSION'
let s:d[0x239D]='LEFT PARENTHESIS LOWER HOOK'
let s:d[0x239E]='RIGHT PARENTHESIS UPPER HOOK'
let s:d[0x239F]='RIGHT PARENTHESIS EXTENSION'
let s:d[0x23A0]='RIGHT PARENTHESIS LOWER HOOK'
let s:d[0x23A1]='LEFT SQUARE BRACKET UPPER CORNER'
let s:d[0x23A2]='LEFT SQUARE BRACKET EXTENSION'
let s:d[0x23A3]='LEFT SQUARE BRACKET LOWER CORNER'
let s:d[0x23A4]='RIGHT SQUARE BRACKET UPPER CORNER'
let s:d[0x23A5]='RIGHT SQUARE BRACKET EXTENSION'
let s:d[0x23A6]='RIGHT SQUARE BRACKET LOWER CORNER'
let s:d[0x23A7]='LEFT CURLY BRACKET UPPER HOOK'
let s:d[0x23A8]='LEFT CURLY BRACKET MIDDLE PIECE'
let s:d[0x23A9]='LEFT CURLY BRACKET LOWER HOOK'
let s:d[0x23AA]='CURLY BRACKET EXTENSION'
let s:d[0x23AB]='RIGHT CURLY BRACKET UPPER HOOK'
let s:d[0x23AC]='RIGHT CURLY BRACKET MIDDLE PIECE'
let s:d[0x23AD]='RIGHT CURLY BRACKET LOWER HOOK'
let s:d[0x23AE]='INTEGRAL EXTENSION'
let s:d[0x23AF]='HORIZONTAL LINE EXTENSION'
let s:d[0x23B0]='UPPER LEFT OR LOWER RIGHT CURLY BRACKET SECTION'
let s:d[0x23B1]='UPPER RIGHT OR LOWER LEFT CURLY BRACKET SECTION'
let s:d[0x23B2]='SUMMATION TOP'
let s:d[0x23B3]='SUMMATION BOTTOM'
let s:d[0x23B4]='TOP SQUARE BRACKET'
let s:d[0x23B5]='BOTTOM SQUARE BRACKET'
let s:d[0x23B6]='BOTTOM SQUARE BRACKET OVER TOP SQUARE BRACKET'
let s:d[0x23B7]='RADICAL SYMBOL BOTTOM'
let s:d[0x23B8]='LEFT VERTICAL BOX LINE'
let s:d[0x23B9]='RIGHT VERTICAL BOX LINE'
let s:d[0x23BA]='HORIZONTAL SCAN LINE-1'
let s:d[0x23BB]='HORIZONTAL SCAN LINE-3'
let s:d[0x23BC]='HORIZONTAL SCAN LINE-7'
let s:d[0x23BD]='HORIZONTAL SCAN LINE-9'
let s:d[0x23BE]='DENTISTRY SYMBOL LIGHT VERTICAL AND TOP RIGHT'
let s:d[0x23BF]='DENTISTRY SYMBOL LIGHT VERTICAL AND BOTTOM RIGHT'
let s:d[0x23C0]='DENTISTRY SYMBOL LIGHT VERTICAL WITH CIRCLE'
let s:d[0x23C1]='DENTISTRY SYMBOL LIGHT DOWN AND HORIZONTAL WITH CIRCLE'
let s:d[0x23C2]='DENTISTRY SYMBOL LIGHT UP AND HORIZONTAL WITH CIRCLE'
let s:d[0x23C3]='DENTISTRY SYMBOL LIGHT VERTICAL WITH TRIANGLE'
let s:d[0x23C4]='DENTISTRY SYMBOL LIGHT DOWN AND HORIZONTAL WITH TRIANGLE'
let s:d[0x23C5]='DENTISTRY SYMBOL LIGHT UP AND HORIZONTAL WITH TRIANGLE'
let s:d[0x23C6]='DENTISTRY SYMBOL LIGHT VERTICAL AND WAVE'
let s:d[0x23C7]='DENTISTRY SYMBOL LIGHT DOWN AND HORIZONTAL WITH WAVE'
let s:d[0x23C8]='DENTISTRY SYMBOL LIGHT UP AND HORIZONTAL WITH WAVE'
let s:d[0x23C9]='DENTISTRY SYMBOL LIGHT DOWN AND HORIZONTAL'
let s:d[0x23CA]='DENTISTRY SYMBOL LIGHT UP AND HORIZONTAL'
let s:d[0x23CB]='DENTISTRY SYMBOL LIGHT VERTICAL AND TOP LEFT'
let s:d[0x23CC]='DENTISTRY SYMBOL LIGHT VERTICAL AND BOTTOM LEFT'
let s:d[0x23CD]='SQUARE FOOT'
let s:d[0x23CE]='RETURN SYMBOL'
let s:d[0x23CF]='EJECT SYMBOL'
let s:d[0x23D0]='VERTICAL LINE EXTENSION'
let s:d[0x23D1]='METRICAL BREVE'
let s:d[0x23D2]='METRICAL LONG OVER SHORT'
let s:d[0x23D3]='METRICAL SHORT OVER LONG'
let s:d[0x23D4]='METRICAL LONG OVER TWO SHORTS'
let s:d[0x23D5]='METRICAL TWO SHORTS OVER LONG'
let s:d[0x23D6]='METRICAL TWO SHORTS JOINED'
let s:d[0x23D7]='METRICAL TRISEME'
let s:d[0x23D8]='METRICAL TETRASEME'
let s:d[0x23D9]='METRICAL PENTASEME'
let s:d[0x23DA]='EARTH GROUND'
let s:d[0x23DB]='FUSE'
let s:d[0x23DC]='TOP PARENTHESIS'
let s:d[0x23DD]='BOTTOM PARENTHESIS'
let s:d[0x23DE]='TOP CURLY BRACKET'
let s:d[0x23DF]='BOTTOM CURLY BRACKET'
let s:d[0x23E0]='TOP TORTOISE SHELL BRACKET'
let s:d[0x23E1]='BOTTOM TORTOISE SHELL BRACKET'
let s:d[0x23E2]='WHITE TRAPEZIUM'
let s:d[0x23E3]='BENZENE RING WITH CIRCLE'
let s:d[0x23E4]='STRAIGHTNESS'
let s:d[0x23E5]='FLATNESS'
let s:d[0x23E6]='AC CURRENT'
let s:d[0x23E7]='ELECTRICAL INTERSECTION'
let s:d[0x23E8]='DECIMAL EXPONENT SYMBOL'
let s:d[0x23E9]='BLACK RIGHT-POINTING DOUBLE TRIANGLE'
let s:d[0x23EA]='BLACK LEFT-POINTING DOUBLE TRIANGLE'
let s:d[0x23EB]='BLACK UP-POINTING DOUBLE TRIANGLE'
let s:d[0x23EC]='BLACK DOWN-POINTING DOUBLE TRIANGLE'
let s:d[0x23ED]='BLACK RIGHT-POINTING DOUBLE TRIANGLE WITH VERTICAL BAR'
let s:d[0x23EE]='BLACK LEFT-POINTING DOUBLE TRIANGLE WITH VERTICAL BAR'
let s:d[0x23EF]='BLACK RIGHT-POINTING TRIANGLE WITH DOUBLE VERTICAL BAR'
let s:d[0x23F0]='ALARM CLOCK'
let s:d[0x23F1]='STOPWATCH'
let s:d[0x23F2]='TIMER CLOCK'
let s:d[0x23F3]='HOURGLASS WITH FLOWING SAND'
let s:d[0x2400]='SYMBOL FOR NULL'
let s:d[0x2401]='SYMBOL FOR START OF HEADING'
let s:d[0x2402]='SYMBOL FOR START OF TEXT'
let s:d[0x2403]='SYMBOL FOR END OF TEXT'
let s:d[0x2404]='SYMBOL FOR END OF TRANSMISSION'
let s:d[0x2405]='SYMBOL FOR ENQUIRY'
let s:d[0x2406]='SYMBOL FOR ACKNOWLEDGE'
let s:d[0x2407]='SYMBOL FOR BELL'
let s:d[0x2408]='SYMBOL FOR BACKSPACE'
let s:d[0x2409]='SYMBOL FOR HORIZONTAL TABULATION'
let s:d[0x240A]='SYMBOL FOR LINE FEED'
let s:d[0x240B]='SYMBOL FOR VERTICAL TABULATION'
let s:d[0x240C]='SYMBOL FOR FORM FEED'
let s:d[0x240D]='SYMBOL FOR CARRIAGE RETURN'
let s:d[0x240E]='SYMBOL FOR SHIFT OUT'
let s:d[0x240F]='SYMBOL FOR SHIFT IN'
let s:d[0x2410]='SYMBOL FOR DATA LINK ESCAPE'
let s:d[0x2411]='SYMBOL FOR DEVICE CONTROL ONE'
let s:d[0x2412]='SYMBOL FOR DEVICE CONTROL TWO'
let s:d[0x2413]='SYMBOL FOR DEVICE CONTROL THREE'
let s:d[0x2414]='SYMBOL FOR DEVICE CONTROL FOUR'
let s:d[0x2415]='SYMBOL FOR NEGATIVE ACKNOWLEDGE'
let s:d[0x2416]='SYMBOL FOR SYNCHRONOUS IDLE'
let s:d[0x2417]='SYMBOL FOR END OF TRANSMISSION BLOCK'
let s:d[0x2418]='SYMBOL FOR CANCEL'
let s:d[0x2419]='SYMBOL FOR END OF MEDIUM'
let s:d[0x241A]='SYMBOL FOR SUBSTITUTE'
let s:d[0x241B]='SYMBOL FOR ESCAPE'
let s:d[0x241C]='SYMBOL FOR FILE SEPARATOR'
let s:d[0x241D]='SYMBOL FOR GROUP SEPARATOR'
let s:d[0x241E]='SYMBOL FOR RECORD SEPARATOR'
let s:d[0x241F]='SYMBOL FOR UNIT SEPARATOR'
let s:d[0x2420]='SYMBOL FOR SPACE'
let s:d[0x2421]='SYMBOL FOR DELETE'
let s:d[0x2422]='BLANK SYMBOL'
let s:d[0x2423]='OPEN BOX'
let s:d[0x2424]='SYMBOL FOR NEWLINE'
let s:d[0x2425]='SYMBOL FOR DELETE FORM TWO'
let s:d[0x2426]='SYMBOL FOR SUBSTITUTE FORM TWO'
let s:d[0x2440]='OCR HOOK'
let s:d[0x2441]='OCR CHAIR'
let s:d[0x2442]='OCR FORK'
let s:d[0x2443]='OCR INVERTED FORK'
let s:d[0x2444]='OCR BELT BUCKLE'
let s:d[0x2445]='OCR BOW TIE'
let s:d[0x2446]='OCR BRANCH BANK IDENTIFICATION'
let s:d[0x2447]='OCR AMOUNT OF CHECK'
let s:d[0x2448]='OCR DASH'
let s:d[0x2449]='OCR CUSTOMER ACCOUNT NUMBER'
let s:d[0x244A]='OCR DOUBLE BACKSLASH'
let s:d[0x2460]='CIRCLED DIGIT ONE'
let s:d[0x2461]='CIRCLED DIGIT TWO'
let s:d[0x2462]='CIRCLED DIGIT THREE'
let s:d[0x2463]='CIRCLED DIGIT FOUR'
let s:d[0x2464]='CIRCLED DIGIT FIVE'
let s:d[0x2465]='CIRCLED DIGIT SIX'
let s:d[0x2466]='CIRCLED DIGIT SEVEN'
let s:d[0x2467]='CIRCLED DIGIT EIGHT'
let s:d[0x2468]='CIRCLED DIGIT NINE'
let s:d[0x2469]='CIRCLED NUMBER TEN'
let s:d[0x246A]='CIRCLED NUMBER ELEVEN'
let s:d[0x246B]='CIRCLED NUMBER TWELVE'
let s:d[0x246C]='CIRCLED NUMBER THIRTEEN'
let s:d[0x246D]='CIRCLED NUMBER FOURTEEN'
let s:d[0x246E]='CIRCLED NUMBER FIFTEEN'
let s:d[0x246F]='CIRCLED NUMBER SIXTEEN'
let s:d[0x2470]='CIRCLED NUMBER SEVENTEEN'
let s:d[0x2471]='CIRCLED NUMBER EIGHTEEN'
let s:d[0x2472]='CIRCLED NUMBER NINETEEN'
let s:d[0x2473]='CIRCLED NUMBER TWENTY'
let s:d[0x2474]='PARENTHESIZED DIGIT ONE'
let s:d[0x2475]='PARENTHESIZED DIGIT TWO'
let s:d[0x2476]='PARENTHESIZED DIGIT THREE'
let s:d[0x2477]='PARENTHESIZED DIGIT FOUR'
let s:d[0x2478]='PARENTHESIZED DIGIT FIVE'
let s:d[0x2479]='PARENTHESIZED DIGIT SIX'
let s:d[0x247A]='PARENTHESIZED DIGIT SEVEN'
let s:d[0x247B]='PARENTHESIZED DIGIT EIGHT'
let s:d[0x247C]='PARENTHESIZED DIGIT NINE'
let s:d[0x247D]='PARENTHESIZED NUMBER TEN'
let s:d[0x247E]='PARENTHESIZED NUMBER ELEVEN'
let s:d[0x247F]='PARENTHESIZED NUMBER TWELVE'
let s:d[0x2480]='PARENTHESIZED NUMBER THIRTEEN'
let s:d[0x2481]='PARENTHESIZED NUMBER FOURTEEN'
let s:d[0x2482]='PARENTHESIZED NUMBER FIFTEEN'
let s:d[0x2483]='PARENTHESIZED NUMBER SIXTEEN'
let s:d[0x2484]='PARENTHESIZED NUMBER SEVENTEEN'
let s:d[0x2485]='PARENTHESIZED NUMBER EIGHTEEN'
let s:d[0x2486]='PARENTHESIZED NUMBER NINETEEN'
let s:d[0x2487]='PARENTHESIZED NUMBER TWENTY'
let s:d[0x2488]='DIGIT ONE FULL STOP'
let s:d[0x2489]='DIGIT TWO FULL STOP'
let s:d[0x248A]='DIGIT THREE FULL STOP'
let s:d[0x248B]='DIGIT FOUR FULL STOP'
let s:d[0x248C]='DIGIT FIVE FULL STOP'
let s:d[0x248D]='DIGIT SIX FULL STOP'
let s:d[0x248E]='DIGIT SEVEN FULL STOP'
let s:d[0x248F]='DIGIT EIGHT FULL STOP'
let s:d[0x2490]='DIGIT NINE FULL STOP'
let s:d[0x2491]='NUMBER TEN FULL STOP'
let s:d[0x2492]='NUMBER ELEVEN FULL STOP'
let s:d[0x2493]='NUMBER TWELVE FULL STOP'
let s:d[0x2494]='NUMBER THIRTEEN FULL STOP'
let s:d[0x2495]='NUMBER FOURTEEN FULL STOP'
let s:d[0x2496]='NUMBER FIFTEEN FULL STOP'
let s:d[0x2497]='NUMBER SIXTEEN FULL STOP'
let s:d[0x2498]='NUMBER SEVENTEEN FULL STOP'
let s:d[0x2499]='NUMBER EIGHTEEN FULL STOP'
let s:d[0x249A]='NUMBER NINETEEN FULL STOP'
let s:d[0x249B]='NUMBER TWENTY FULL STOP'
let s:d[0x249C]='PARENTHESIZED LATIN SMALL LETTER A'
let s:d[0x249D]='PARENTHESIZED LATIN SMALL LETTER B'
let s:d[0x249E]='PARENTHESIZED LATIN SMALL LETTER C'
let s:d[0x249F]='PARENTHESIZED LATIN SMALL LETTER D'
let s:d[0x24A0]='PARENTHESIZED LATIN SMALL LETTER E'
let s:d[0x24A1]='PARENTHESIZED LATIN SMALL LETTER F'
let s:d[0x24A2]='PARENTHESIZED LATIN SMALL LETTER G'
let s:d[0x24A3]='PARENTHESIZED LATIN SMALL LETTER H'
let s:d[0x24A4]='PARENTHESIZED LATIN SMALL LETTER I'
let s:d[0x24A5]='PARENTHESIZED LATIN SMALL LETTER J'
let s:d[0x24A6]='PARENTHESIZED LATIN SMALL LETTER K'
let s:d[0x24A7]='PARENTHESIZED LATIN SMALL LETTER L'
let s:d[0x24A8]='PARENTHESIZED LATIN SMALL LETTER M'
let s:d[0x24A9]='PARENTHESIZED LATIN SMALL LETTER N'
let s:d[0x24AA]='PARENTHESIZED LATIN SMALL LETTER O'
let s:d[0x24AB]='PARENTHESIZED LATIN SMALL LETTER P'
let s:d[0x24AC]='PARENTHESIZED LATIN SMALL LETTER Q'
let s:d[0x24AD]='PARENTHESIZED LATIN SMALL LETTER R'
let s:d[0x24AE]='PARENTHESIZED LATIN SMALL LETTER S'
let s:d[0x24AF]='PARENTHESIZED LATIN SMALL LETTER T'
let s:d[0x24B0]='PARENTHESIZED LATIN SMALL LETTER U'
let s:d[0x24B1]='PARENTHESIZED LATIN SMALL LETTER V'
let s:d[0x24B2]='PARENTHESIZED LATIN SMALL LETTER W'
let s:d[0x24B3]='PARENTHESIZED LATIN SMALL LETTER X'
let s:d[0x24B4]='PARENTHESIZED LATIN SMALL LETTER Y'
let s:d[0x24B5]='PARENTHESIZED LATIN SMALL LETTER Z'
let s:d[0x24B6]='CIRCLED LATIN CAPITAL LETTER A'
let s:d[0x24B7]='CIRCLED LATIN CAPITAL LETTER B'
let s:d[0x24B8]='CIRCLED LATIN CAPITAL LETTER C'
let s:d[0x24B9]='CIRCLED LATIN CAPITAL LETTER D'
let s:d[0x24BA]='CIRCLED LATIN CAPITAL LETTER E'
let s:d[0x24BB]='CIRCLED LATIN CAPITAL LETTER F'
let s:d[0x24BC]='CIRCLED LATIN CAPITAL LETTER G'
let s:d[0x24BD]='CIRCLED LATIN CAPITAL LETTER H'
let s:d[0x24BE]='CIRCLED LATIN CAPITAL LETTER I'
let s:d[0x24BF]='CIRCLED LATIN CAPITAL LETTER J'
let s:d[0x24C0]='CIRCLED LATIN CAPITAL LETTER K'
let s:d[0x24C1]='CIRCLED LATIN CAPITAL LETTER L'
let s:d[0x24C2]='CIRCLED LATIN CAPITAL LETTER M'
let s:d[0x24C3]='CIRCLED LATIN CAPITAL LETTER N'
let s:d[0x24C4]='CIRCLED LATIN CAPITAL LETTER O'
let s:d[0x24C5]='CIRCLED LATIN CAPITAL LETTER P'
let s:d[0x24C6]='CIRCLED LATIN CAPITAL LETTER Q'
let s:d[0x24C7]='CIRCLED LATIN CAPITAL LETTER R'
let s:d[0x24C8]='CIRCLED LATIN CAPITAL LETTER S'
let s:d[0x24C9]='CIRCLED LATIN CAPITAL LETTER T'
let s:d[0x24CA]='CIRCLED LATIN CAPITAL LETTER U'
let s:d[0x24CB]='CIRCLED LATIN CAPITAL LETTER V'
let s:d[0x24CC]='CIRCLED LATIN CAPITAL LETTER W'
let s:d[0x24CD]='CIRCLED LATIN CAPITAL LETTER X'
let s:d[0x24CE]='CIRCLED LATIN CAPITAL LETTER Y'
let s:d[0x24CF]='CIRCLED LATIN CAPITAL LETTER Z'
let s:d[0x24D0]='CIRCLED LATIN SMALL LETTER A'
let s:d[0x24D1]='CIRCLED LATIN SMALL LETTER B'
let s:d[0x24D2]='CIRCLED LATIN SMALL LETTER C'
let s:d[0x24D3]='CIRCLED LATIN SMALL LETTER D'
let s:d[0x24D4]='CIRCLED LATIN SMALL LETTER E'
let s:d[0x24D5]='CIRCLED LATIN SMALL LETTER F'
let s:d[0x24D6]='CIRCLED LATIN SMALL LETTER G'
let s:d[0x24D7]='CIRCLED LATIN SMALL LETTER H'
let s:d[0x24D8]='CIRCLED LATIN SMALL LETTER I'
let s:d[0x24D9]='CIRCLED LATIN SMALL LETTER J'
let s:d[0x24DA]='CIRCLED LATIN SMALL LETTER K'
let s:d[0x24DB]='CIRCLED LATIN SMALL LETTER L'
let s:d[0x24DC]='CIRCLED LATIN SMALL LETTER M'
let s:d[0x24DD]='CIRCLED LATIN SMALL LETTER N'
let s:d[0x24DE]='CIRCLED LATIN SMALL LETTER O'
let s:d[0x24DF]='CIRCLED LATIN SMALL LETTER P'
let s:d[0x24E0]='CIRCLED LATIN SMALL LETTER Q'
let s:d[0x24E1]='CIRCLED LATIN SMALL LETTER R'
let s:d[0x24E2]='CIRCLED LATIN SMALL LETTER S'
let s:d[0x24E3]='CIRCLED LATIN SMALL LETTER T'
let s:d[0x24E4]='CIRCLED LATIN SMALL LETTER U'
let s:d[0x24E5]='CIRCLED LATIN SMALL LETTER V'
let s:d[0x24E6]='CIRCLED LATIN SMALL LETTER W'
let s:d[0x24E7]='CIRCLED LATIN SMALL LETTER X'
let s:d[0x24E8]='CIRCLED LATIN SMALL LETTER Y'
let s:d[0x24E9]='CIRCLED LATIN SMALL LETTER Z'
let s:d[0x24EA]='CIRCLED DIGIT ZERO'
let s:d[0x24EB]='NEGATIVE CIRCLED NUMBER ELEVEN'
let s:d[0x24EC]='NEGATIVE CIRCLED NUMBER TWELVE'
let s:d[0x24ED]='NEGATIVE CIRCLED NUMBER THIRTEEN'
let s:d[0x24EE]='NEGATIVE CIRCLED NUMBER FOURTEEN'
let s:d[0x24EF]='NEGATIVE CIRCLED NUMBER FIFTEEN'
let s:d[0x24F0]='NEGATIVE CIRCLED NUMBER SIXTEEN'
let s:d[0x24F1]='NEGATIVE CIRCLED NUMBER SEVENTEEN'
let s:d[0x24F2]='NEGATIVE CIRCLED NUMBER EIGHTEEN'
let s:d[0x24F3]='NEGATIVE CIRCLED NUMBER NINETEEN'
let s:d[0x24F4]='NEGATIVE CIRCLED NUMBER TWENTY'
let s:d[0x24F5]='DOUBLE CIRCLED DIGIT ONE'
let s:d[0x24F6]='DOUBLE CIRCLED DIGIT TWO'
let s:d[0x24F7]='DOUBLE CIRCLED DIGIT THREE'
let s:d[0x24F8]='DOUBLE CIRCLED DIGIT FOUR'
let s:d[0x24F9]='DOUBLE CIRCLED DIGIT FIVE'
let s:d[0x24FA]='DOUBLE CIRCLED DIGIT SIX'
let s:d[0x24FB]='DOUBLE CIRCLED DIGIT SEVEN'
let s:d[0x24FC]='DOUBLE CIRCLED DIGIT EIGHT'
let s:d[0x24FD]='DOUBLE CIRCLED DIGIT NINE'
let s:d[0x24FE]='DOUBLE CIRCLED NUMBER TEN'
let s:d[0x24FF]='NEGATIVE CIRCLED DIGIT ZERO'
let s:d[0x2500]='BOX DRAWINGS LIGHT HORIZONTAL'
let s:d[0x2501]='BOX DRAWINGS HEAVY HORIZONTAL'
let s:d[0x2502]='BOX DRAWINGS LIGHT VERTICAL'
let s:d[0x2503]='BOX DRAWINGS HEAVY VERTICAL'
let s:d[0x2504]='BOX DRAWINGS LIGHT TRIPLE DASH HORIZONTAL'
let s:d[0x2505]='BOX DRAWINGS HEAVY TRIPLE DASH HORIZONTAL'
let s:d[0x2506]='BOX DRAWINGS LIGHT TRIPLE DASH VERTICAL'
let s:d[0x2507]='BOX DRAWINGS HEAVY TRIPLE DASH VERTICAL'
let s:d[0x2508]='BOX DRAWINGS LIGHT QUADRUPLE DASH HORIZONTAL'
let s:d[0x2509]='BOX DRAWINGS HEAVY QUADRUPLE DASH HORIZONTAL'
let s:d[0x250A]='BOX DRAWINGS LIGHT QUADRUPLE DASH VERTICAL'
let s:d[0x250B]='BOX DRAWINGS HEAVY QUADRUPLE DASH VERTICAL'
let s:d[0x250C]='BOX DRAWINGS LIGHT DOWN AND RIGHT'
let s:d[0x250D]='BOX DRAWINGS DOWN LIGHT AND RIGHT HEAVY'
let s:d[0x250E]='BOX DRAWINGS DOWN HEAVY AND RIGHT LIGHT'
let s:d[0x250F]='BOX DRAWINGS HEAVY DOWN AND RIGHT'
let s:d[0x2510]='BOX DRAWINGS LIGHT DOWN AND LEFT'
let s:d[0x2511]='BOX DRAWINGS DOWN LIGHT AND LEFT HEAVY'
let s:d[0x2512]='BOX DRAWINGS DOWN HEAVY AND LEFT LIGHT'
let s:d[0x2513]='BOX DRAWINGS HEAVY DOWN AND LEFT'
let s:d[0x2514]='BOX DRAWINGS LIGHT UP AND RIGHT'
let s:d[0x2515]='BOX DRAWINGS UP LIGHT AND RIGHT HEAVY'
let s:d[0x2516]='BOX DRAWINGS UP HEAVY AND RIGHT LIGHT'
let s:d[0x2517]='BOX DRAWINGS HEAVY UP AND RIGHT'
let s:d[0x2518]='BOX DRAWINGS LIGHT UP AND LEFT'
let s:d[0x2519]='BOX DRAWINGS UP LIGHT AND LEFT HEAVY'
let s:d[0x251A]='BOX DRAWINGS UP HEAVY AND LEFT LIGHT'
let s:d[0x251B]='BOX DRAWINGS HEAVY UP AND LEFT'
let s:d[0x251C]='BOX DRAWINGS LIGHT VERTICAL AND RIGHT'
let s:d[0x251D]='BOX DRAWINGS VERTICAL LIGHT AND RIGHT HEAVY'
let s:d[0x251E]='BOX DRAWINGS UP HEAVY AND RIGHT DOWN LIGHT'
let s:d[0x251F]='BOX DRAWINGS DOWN HEAVY AND RIGHT UP LIGHT'
let s:d[0x2520]='BOX DRAWINGS VERTICAL HEAVY AND RIGHT LIGHT'
let s:d[0x2521]='BOX DRAWINGS DOWN LIGHT AND RIGHT UP HEAVY'
let s:d[0x2522]='BOX DRAWINGS UP LIGHT AND RIGHT DOWN HEAVY'
let s:d[0x2523]='BOX DRAWINGS HEAVY VERTICAL AND RIGHT'
let s:d[0x2524]='BOX DRAWINGS LIGHT VERTICAL AND LEFT'
let s:d[0x2525]='BOX DRAWINGS VERTICAL LIGHT AND LEFT HEAVY'
let s:d[0x2526]='BOX DRAWINGS UP HEAVY AND LEFT DOWN LIGHT'
let s:d[0x2527]='BOX DRAWINGS DOWN HEAVY AND LEFT UP LIGHT'
let s:d[0x2528]='BOX DRAWINGS VERTICAL HEAVY AND LEFT LIGHT'
let s:d[0x2529]='BOX DRAWINGS DOWN LIGHT AND LEFT UP HEAVY'
let s:d[0x252A]='BOX DRAWINGS UP LIGHT AND LEFT DOWN HEAVY'
let s:d[0x252B]='BOX DRAWINGS HEAVY VERTICAL AND LEFT'
let s:d[0x252C]='BOX DRAWINGS LIGHT DOWN AND HORIZONTAL'
let s:d[0x252D]='BOX DRAWINGS LEFT HEAVY AND RIGHT DOWN LIGHT'
let s:d[0x252E]='BOX DRAWINGS RIGHT HEAVY AND LEFT DOWN LIGHT'
let s:d[0x252F]='BOX DRAWINGS DOWN LIGHT AND HORIZONTAL HEAVY'
let s:d[0x2530]='BOX DRAWINGS DOWN HEAVY AND HORIZONTAL LIGHT'
let s:d[0x2531]='BOX DRAWINGS RIGHT LIGHT AND LEFT DOWN HEAVY'
let s:d[0x2532]='BOX DRAWINGS LEFT LIGHT AND RIGHT DOWN HEAVY'
let s:d[0x2533]='BOX DRAWINGS HEAVY DOWN AND HORIZONTAL'
let s:d[0x2534]='BOX DRAWINGS LIGHT UP AND HORIZONTAL'
let s:d[0x2535]='BOX DRAWINGS LEFT HEAVY AND RIGHT UP LIGHT'
let s:d[0x2536]='BOX DRAWINGS RIGHT HEAVY AND LEFT UP LIGHT'
let s:d[0x2537]='BOX DRAWINGS UP LIGHT AND HORIZONTAL HEAVY'
let s:d[0x2538]='BOX DRAWINGS UP HEAVY AND HORIZONTAL LIGHT'
let s:d[0x2539]='BOX DRAWINGS RIGHT LIGHT AND LEFT UP HEAVY'
let s:d[0x253A]='BOX DRAWINGS LEFT LIGHT AND RIGHT UP HEAVY'
let s:d[0x253B]='BOX DRAWINGS HEAVY UP AND HORIZONTAL'
let s:d[0x253C]='BOX DRAWINGS LIGHT VERTICAL AND HORIZONTAL'
let s:d[0x253D]='BOX DRAWINGS LEFT HEAVY AND RIGHT VERTICAL LIGHT'
let s:d[0x253E]='BOX DRAWINGS RIGHT HEAVY AND LEFT VERTICAL LIGHT'
let s:d[0x253F]='BOX DRAWINGS VERTICAL LIGHT AND HORIZONTAL HEAVY'
let s:d[0x2540]='BOX DRAWINGS UP HEAVY AND DOWN HORIZONTAL LIGHT'
let s:d[0x2541]='BOX DRAWINGS DOWN HEAVY AND UP HORIZONTAL LIGHT'
let s:d[0x2542]='BOX DRAWINGS VERTICAL HEAVY AND HORIZONTAL LIGHT'
let s:d[0x2543]='BOX DRAWINGS LEFT UP HEAVY AND RIGHT DOWN LIGHT'
let s:d[0x2544]='BOX DRAWINGS RIGHT UP HEAVY AND LEFT DOWN LIGHT'
let s:d[0x2545]='BOX DRAWINGS LEFT DOWN HEAVY AND RIGHT UP LIGHT'
let s:d[0x2546]='BOX DRAWINGS RIGHT DOWN HEAVY AND LEFT UP LIGHT'
let s:d[0x2547]='BOX DRAWINGS DOWN LIGHT AND UP HORIZONTAL HEAVY'
let s:d[0x2548]='BOX DRAWINGS UP LIGHT AND DOWN HORIZONTAL HEAVY'
let s:d[0x2549]='BOX DRAWINGS RIGHT LIGHT AND LEFT VERTICAL HEAVY'
let s:d[0x254A]='BOX DRAWINGS LEFT LIGHT AND RIGHT VERTICAL HEAVY'
let s:d[0x254B]='BOX DRAWINGS HEAVY VERTICAL AND HORIZONTAL'
let s:d[0x254C]='BOX DRAWINGS LIGHT DOUBLE DASH HORIZONTAL'
let s:d[0x254D]='BOX DRAWINGS HEAVY DOUBLE DASH HORIZONTAL'
let s:d[0x254E]='BOX DRAWINGS LIGHT DOUBLE DASH VERTICAL'
let s:d[0x254F]='BOX DRAWINGS HEAVY DOUBLE DASH VERTICAL'
let s:d[0x2550]='BOX DRAWINGS DOUBLE HORIZONTAL'
let s:d[0x2551]='BOX DRAWINGS DOUBLE VERTICAL'
let s:d[0x2552]='BOX DRAWINGS DOWN SINGLE AND RIGHT DOUBLE'
let s:d[0x2553]='BOX DRAWINGS DOWN DOUBLE AND RIGHT SINGLE'
let s:d[0x2554]='BOX DRAWINGS DOUBLE DOWN AND RIGHT'
let s:d[0x2555]='BOX DRAWINGS DOWN SINGLE AND LEFT DOUBLE'
let s:d[0x2556]='BOX DRAWINGS DOWN DOUBLE AND LEFT SINGLE'
let s:d[0x2557]='BOX DRAWINGS DOUBLE DOWN AND LEFT'
let s:d[0x2558]='BOX DRAWINGS UP SINGLE AND RIGHT DOUBLE'
let s:d[0x2559]='BOX DRAWINGS UP DOUBLE AND RIGHT SINGLE'
let s:d[0x255A]='BOX DRAWINGS DOUBLE UP AND RIGHT'
let s:d[0x255B]='BOX DRAWINGS UP SINGLE AND LEFT DOUBLE'
let s:d[0x255C]='BOX DRAWINGS UP DOUBLE AND LEFT SINGLE'
let s:d[0x255D]='BOX DRAWINGS DOUBLE UP AND LEFT'
let s:d[0x255E]='BOX DRAWINGS VERTICAL SINGLE AND RIGHT DOUBLE'
let s:d[0x255F]='BOX DRAWINGS VERTICAL DOUBLE AND RIGHT SINGLE'
let s:d[0x2560]='BOX DRAWINGS DOUBLE VERTICAL AND RIGHT'
let s:d[0x2561]='BOX DRAWINGS VERTICAL SINGLE AND LEFT DOUBLE'
let s:d[0x2562]='BOX DRAWINGS VERTICAL DOUBLE AND LEFT SINGLE'
let s:d[0x2563]='BOX DRAWINGS DOUBLE VERTICAL AND LEFT'
let s:d[0x2564]='BOX DRAWINGS DOWN SINGLE AND HORIZONTAL DOUBLE'
let s:d[0x2565]='BOX DRAWINGS DOWN DOUBLE AND HORIZONTAL SINGLE'
let s:d[0x2566]='BOX DRAWINGS DOUBLE DOWN AND HORIZONTAL'
let s:d[0x2567]='BOX DRAWINGS UP SINGLE AND HORIZONTAL DOUBLE'
let s:d[0x2568]='BOX DRAWINGS UP DOUBLE AND HORIZONTAL SINGLE'
let s:d[0x2569]='BOX DRAWINGS DOUBLE UP AND HORIZONTAL'
let s:d[0x256A]='BOX DRAWINGS VERTICAL SINGLE AND HORIZONTAL DOUBLE'
let s:d[0x256B]='BOX DRAWINGS VERTICAL DOUBLE AND HORIZONTAL SINGLE'
let s:d[0x256C]='BOX DRAWINGS DOUBLE VERTICAL AND HORIZONTAL'
let s:d[0x256D]='BOX DRAWINGS LIGHT ARC DOWN AND RIGHT'
let s:d[0x256E]='BOX DRAWINGS LIGHT ARC DOWN AND LEFT'
let s:d[0x256F]='BOX DRAWINGS LIGHT ARC UP AND LEFT'
let s:d[0x2570]='BOX DRAWINGS LIGHT ARC UP AND RIGHT'
let s:d[0x2571]='BOX DRAWINGS LIGHT DIAGONAL UPPER RIGHT TO LOWER LEFT'
let s:d[0x2572]='BOX DRAWINGS LIGHT DIAGONAL UPPER LEFT TO LOWER RIGHT'
let s:d[0x2573]='BOX DRAWINGS LIGHT DIAGONAL CROSS'
let s:d[0x2574]='BOX DRAWINGS LIGHT LEFT'
let s:d[0x2575]='BOX DRAWINGS LIGHT UP'
let s:d[0x2576]='BOX DRAWINGS LIGHT RIGHT'
let s:d[0x2577]='BOX DRAWINGS LIGHT DOWN'
let s:d[0x2578]='BOX DRAWINGS HEAVY LEFT'
let s:d[0x2579]='BOX DRAWINGS HEAVY UP'
let s:d[0x257A]='BOX DRAWINGS HEAVY RIGHT'
let s:d[0x257B]='BOX DRAWINGS HEAVY DOWN'
let s:d[0x257C]='BOX DRAWINGS LIGHT LEFT AND HEAVY RIGHT'
let s:d[0x257D]='BOX DRAWINGS LIGHT UP AND HEAVY DOWN'
let s:d[0x257E]='BOX DRAWINGS HEAVY LEFT AND LIGHT RIGHT'
let s:d[0x257F]='BOX DRAWINGS HEAVY UP AND LIGHT DOWN'
let s:d[0x2580]='UPPER HALF BLOCK'
let s:d[0x2581]='LOWER ONE EIGHTH BLOCK'
let s:d[0x2582]='LOWER ONE QUARTER BLOCK'
let s:d[0x2583]='LOWER THREE EIGHTHS BLOCK'
let s:d[0x2584]='LOWER HALF BLOCK'
let s:d[0x2585]='LOWER FIVE EIGHTHS BLOCK'
let s:d[0x2586]='LOWER THREE QUARTERS BLOCK'
let s:d[0x2587]='LOWER SEVEN EIGHTHS BLOCK'
let s:d[0x2588]='FULL BLOCK'
let s:d[0x2589]='LEFT SEVEN EIGHTHS BLOCK'
let s:d[0x258A]='LEFT THREE QUARTERS BLOCK'
let s:d[0x258B]='LEFT FIVE EIGHTHS BLOCK'
let s:d[0x258C]='LEFT HALF BLOCK'
let s:d[0x258D]='LEFT THREE EIGHTHS BLOCK'
let s:d[0x258E]='LEFT ONE QUARTER BLOCK'
let s:d[0x258F]='LEFT ONE EIGHTH BLOCK'
let s:d[0x2590]='RIGHT HALF BLOCK'
let s:d[0x2591]='LIGHT SHADE'
let s:d[0x2592]='MEDIUM SHADE'
let s:d[0x2593]='DARK SHADE'
let s:d[0x2594]='UPPER ONE EIGHTH BLOCK'
let s:d[0x2595]='RIGHT ONE EIGHTH BLOCK'
let s:d[0x2596]='QUADRANT LOWER LEFT'
let s:d[0x2597]='QUADRANT LOWER RIGHT'
let s:d[0x2598]='QUADRANT UPPER LEFT'
let s:d[0x2599]='QUADRANT UPPER LEFT AND LOWER LEFT AND LOWER RIGHT'
let s:d[0x259A]='QUADRANT UPPER LEFT AND LOWER RIGHT'
let s:d[0x259B]='QUADRANT UPPER LEFT AND UPPER RIGHT AND LOWER LEFT'
let s:d[0x259C]='QUADRANT UPPER LEFT AND UPPER RIGHT AND LOWER RIGHT'
let s:d[0x259D]='QUADRANT UPPER RIGHT'
let s:d[0x259E]='QUADRANT UPPER RIGHT AND LOWER LEFT'
let s:d[0x259F]='QUADRANT UPPER RIGHT AND LOWER LEFT AND LOWER RIGHT'
let s:d[0x25A0]='BLACK SQUARE'
let s:d[0x25A1]='WHITE SQUARE'
let s:d[0x25A2]='WHITE SQUARE WITH ROUNDED CORNERS'
let s:d[0x25A3]='WHITE SQUARE CONTAINING BLACK SMALL SQUARE'
let s:d[0x25A4]='SQUARE WITH HORIZONTAL FILL'
let s:d[0x25A5]='SQUARE WITH VERTICAL FILL'
let s:d[0x25A6]='SQUARE WITH ORTHOGONAL CROSSHATCH FILL'
let s:d[0x25A7]='SQUARE WITH UPPER LEFT TO LOWER RIGHT FILL'
let s:d[0x25A8]='SQUARE WITH UPPER RIGHT TO LOWER LEFT FILL'
let s:d[0x25A9]='SQUARE WITH DIAGONAL CROSSHATCH FILL'
let s:d[0x25AA]='BLACK SMALL SQUARE'
let s:d[0x25AB]='WHITE SMALL SQUARE'
let s:d[0x25AC]='BLACK RECTANGLE'
let s:d[0x25AD]='WHITE RECTANGLE'
let s:d[0x25AE]='BLACK VERTICAL RECTANGLE'
let s:d[0x25AF]='WHITE VERTICAL RECTANGLE'
let s:d[0x25B0]='BLACK PARALLELOGRAM'
let s:d[0x25B1]='WHITE PARALLELOGRAM'
let s:d[0x25B2]='BLACK UP-POINTING TRIANGLE'
let s:d[0x25B3]='WHITE UP-POINTING TRIANGLE'
let s:d[0x25B4]='BLACK UP-POINTING SMALL TRIANGLE'
let s:d[0x25B5]='WHITE UP-POINTING SMALL TRIANGLE'
let s:d[0x25B6]='BLACK RIGHT-POINTING TRIANGLE'
let s:d[0x25B7]='WHITE RIGHT-POINTING TRIANGLE'
let s:d[0x25B8]='BLACK RIGHT-POINTING SMALL TRIANGLE'
let s:d[0x25B9]='WHITE RIGHT-POINTING SMALL TRIANGLE'
let s:d[0x25BA]='BLACK RIGHT-POINTING POINTER'
let s:d[0x25BB]='WHITE RIGHT-POINTING POINTER'
let s:d[0x25BC]='BLACK DOWN-POINTING TRIANGLE'
let s:d[0x25BD]='WHITE DOWN-POINTING TRIANGLE'
let s:d[0x25BE]='BLACK DOWN-POINTING SMALL TRIANGLE'
let s:d[0x25BF]='WHITE DOWN-POINTING SMALL TRIANGLE'
let s:d[0x25C0]='BLACK LEFT-POINTING TRIANGLE'
let s:d[0x25C1]='WHITE LEFT-POINTING TRIANGLE'
let s:d[0x25C2]='BLACK LEFT-POINTING SMALL TRIANGLE'
let s:d[0x25C3]='WHITE LEFT-POINTING SMALL TRIANGLE'
let s:d[0x25C4]='BLACK LEFT-POINTING POINTER'
let s:d[0x25C5]='WHITE LEFT-POINTING POINTER'
let s:d[0x25C6]='BLACK DIAMOND'
let s:d[0x25C7]='WHITE DIAMOND'
let s:d[0x25C8]='WHITE DIAMOND CONTAINING BLACK SMALL DIAMOND'
let s:d[0x25C9]='FISHEYE'
let s:d[0x25CA]='LOZENGE'
let s:d[0x25CB]='WHITE CIRCLE'
let s:d[0x25CC]='DOTTED CIRCLE'
let s:d[0x25CD]='CIRCLE WITH VERTICAL FILL'
let s:d[0x25CE]='BULLSEYE'
let s:d[0x25CF]='BLACK CIRCLE'
let s:d[0x25D0]='CIRCLE WITH LEFT HALF BLACK'
let s:d[0x25D1]='CIRCLE WITH RIGHT HALF BLACK'
let s:d[0x25D2]='CIRCLE WITH LOWER HALF BLACK'
let s:d[0x25D3]='CIRCLE WITH UPPER HALF BLACK'
let s:d[0x25D4]='CIRCLE WITH UPPER RIGHT QUADRANT BLACK'
let s:d[0x25D5]='CIRCLE WITH ALL BUT UPPER LEFT QUADRANT BLACK'
let s:d[0x25D6]='LEFT HALF BLACK CIRCLE'
let s:d[0x25D7]='RIGHT HALF BLACK CIRCLE'
let s:d[0x25D8]='INVERSE BULLET'
let s:d[0x25D9]='INVERSE WHITE CIRCLE'
let s:d[0x25DA]='UPPER HALF INVERSE WHITE CIRCLE'
let s:d[0x25DB]='LOWER HALF INVERSE WHITE CIRCLE'
let s:d[0x25DC]='UPPER LEFT QUADRANT CIRCULAR ARC'
let s:d[0x25DD]='UPPER RIGHT QUADRANT CIRCULAR ARC'
let s:d[0x25DE]='LOWER RIGHT QUADRANT CIRCULAR ARC'
let s:d[0x25DF]='LOWER LEFT QUADRANT CIRCULAR ARC'
let s:d[0x25E0]='UPPER HALF CIRCLE'
let s:d[0x25E1]='LOWER HALF CIRCLE'
let s:d[0x25E2]='BLACK LOWER RIGHT TRIANGLE'
let s:d[0x25E3]='BLACK LOWER LEFT TRIANGLE'
let s:d[0x25E4]='BLACK UPPER LEFT TRIANGLE'
let s:d[0x25E5]='BLACK UPPER RIGHT TRIANGLE'
let s:d[0x25E6]='WHITE BULLET'
let s:d[0x25E7]='SQUARE WITH LEFT HALF BLACK'
let s:d[0x25E8]='SQUARE WITH RIGHT HALF BLACK'
let s:d[0x25E9]='SQUARE WITH UPPER LEFT DIAGONAL HALF BLACK'
let s:d[0x25EA]='SQUARE WITH LOWER RIGHT DIAGONAL HALF BLACK'
let s:d[0x25EB]='WHITE SQUARE WITH VERTICAL BISECTING LINE'
let s:d[0x25EC]='WHITE UP-POINTING TRIANGLE WITH DOT'
let s:d[0x25ED]='UP-POINTING TRIANGLE WITH LEFT HALF BLACK'
let s:d[0x25EE]='UP-POINTING TRIANGLE WITH RIGHT HALF BLACK'
let s:d[0x25EF]='LARGE CIRCLE'
let s:d[0x25F0]='WHITE SQUARE WITH UPPER LEFT QUADRANT'
let s:d[0x25F1]='WHITE SQUARE WITH LOWER LEFT QUADRANT'
let s:d[0x25F2]='WHITE SQUARE WITH LOWER RIGHT QUADRANT'
let s:d[0x25F3]='WHITE SQUARE WITH UPPER RIGHT QUADRANT'
let s:d[0x25F4]='WHITE CIRCLE WITH UPPER LEFT QUADRANT'
let s:d[0x25F5]='WHITE CIRCLE WITH LOWER LEFT QUADRANT'
let s:d[0x25F6]='WHITE CIRCLE WITH LOWER RIGHT QUADRANT'
let s:d[0x25F7]='WHITE CIRCLE WITH UPPER RIGHT QUADRANT'
let s:d[0x25F8]='UPPER LEFT TRIANGLE'
let s:d[0x25F9]='UPPER RIGHT TRIANGLE'
let s:d[0x25FA]='LOWER LEFT TRIANGLE'
let s:d[0x25FB]='WHITE MEDIUM SQUARE'
let s:d[0x25FC]='BLACK MEDIUM SQUARE'
let s:d[0x25FD]='WHITE MEDIUM SMALL SQUARE'
let s:d[0x25FE]='BLACK MEDIUM SMALL SQUARE'
let s:d[0x25FF]='LOWER RIGHT TRIANGLE'
let s:d[0x2600]='BLACK SUN WITH RAYS'
let s:d[0x2601]='CLOUD'
let s:d[0x2602]='UMBRELLA'
let s:d[0x2603]='SNOWMAN'
let s:d[0x2604]='COMET'
let s:d[0x2605]='BLACK STAR'
let s:d[0x2606]='WHITE STAR'
let s:d[0x2607]='LIGHTNING'
let s:d[0x2608]='THUNDERSTORM'
let s:d[0x2609]='SUN'
let s:d[0x260A]='ASCENDING NODE'
let s:d[0x260B]='DESCENDING NODE'
let s:d[0x260C]='CONJUNCTION'
let s:d[0x260D]='OPPOSITION'
let s:d[0x260E]='BLACK TELEPHONE'
let s:d[0x260F]='WHITE TELEPHONE'
let s:d[0x2610]='BALLOT BOX'
let s:d[0x2611]='BALLOT BOX WITH CHECK'
let s:d[0x2612]='BALLOT BOX WITH X'
let s:d[0x2613]='SALTIRE'
let s:d[0x2614]='UMBRELLA WITH RAIN DROPS'
let s:d[0x2615]='HOT BEVERAGE'
let s:d[0x2616]='WHITE SHOGI PIECE'
let s:d[0x2617]='BLACK SHOGI PIECE'
let s:d[0x2618]='SHAMROCK'
let s:d[0x2619]='REVERSED ROTATED FLORAL HEART BULLET'
let s:d[0x261A]='BLACK LEFT POINTING INDEX'
let s:d[0x261B]='BLACK RIGHT POINTING INDEX'
let s:d[0x261C]='WHITE LEFT POINTING INDEX'
let s:d[0x261D]='WHITE UP POINTING INDEX'
let s:d[0x261E]='WHITE RIGHT POINTING INDEX'
let s:d[0x261F]='WHITE DOWN POINTING INDEX'
let s:d[0x2620]='SKULL AND CROSSBONES'
let s:d[0x2621]='CAUTION SIGN'
let s:d[0x2622]='RADIOACTIVE SIGN'
let s:d[0x2623]='BIOHAZARD SIGN'
let s:d[0x2624]='CADUCEUS'
let s:d[0x2625]='ANKH'
let s:d[0x2626]='ORTHODOX CROSS'
let s:d[0x2627]='CHI RHO'
let s:d[0x2628]='CROSS OF LORRAINE'
let s:d[0x2629]='CROSS OF JERUSALEM'
let s:d[0x262A]='STAR AND CRESCENT'
let s:d[0x262B]='FARSI SYMBOL'
let s:d[0x262C]='ADI SHAKTI'
let s:d[0x262D]='HAMMER AND SICKLE'
let s:d[0x262E]='PEACE SYMBOL'
let s:d[0x262F]='YIN YANG'
let s:d[0x2630]='TRIGRAM FOR HEAVEN'
let s:d[0x2631]='TRIGRAM FOR LAKE'
let s:d[0x2632]='TRIGRAM FOR FIRE'
let s:d[0x2633]='TRIGRAM FOR THUNDER'
let s:d[0x2634]='TRIGRAM FOR WIND'
let s:d[0x2635]='TRIGRAM FOR WATER'
let s:d[0x2636]='TRIGRAM FOR MOUNTAIN'
let s:d[0x2637]='TRIGRAM FOR EARTH'
let s:d[0x2638]='WHEEL OF DHARMA'
let s:d[0x2639]='WHITE FROWNING FACE'
let s:d[0x263A]='WHITE SMILING FACE'
let s:d[0x263B]='BLACK SMILING FACE'
let s:d[0x263C]='WHITE SUN WITH RAYS'
let s:d[0x263D]='FIRST QUARTER MOON'
let s:d[0x263E]='LAST QUARTER MOON'
let s:d[0x263F]='MERCURY'
let s:d[0x2640]='FEMALE SIGN'
let s:d[0x2641]='EARTH'
let s:d[0x2642]='MALE SIGN'
let s:d[0x2643]='JUPITER'
let s:d[0x2644]='SATURN'
let s:d[0x2645]='URANUS'
let s:d[0x2646]='NEPTUNE'
let s:d[0x2647]='PLUTO'
let s:d[0x2648]='ARIES'
let s:d[0x2649]='TAURUS'
let s:d[0x264A]='GEMINI'
let s:d[0x264B]='CANCER'
let s:d[0x264C]='LEO'
let s:d[0x264D]='VIRGO'
let s:d[0x264E]='LIBRA'
let s:d[0x264F]='SCORPIUS'
let s:d[0x2650]='SAGITTARIUS'
let s:d[0x2651]='CAPRICORN'
let s:d[0x2652]='AQUARIUS'
let s:d[0x2653]='PISCES'
let s:d[0x2654]='WHITE CHESS KING'
let s:d[0x2655]='WHITE CHESS QUEEN'
let s:d[0x2656]='WHITE CHESS ROOK'
let s:d[0x2657]='WHITE CHESS BISHOP'
let s:d[0x2658]='WHITE CHESS KNIGHT'
let s:d[0x2659]='WHITE CHESS PAWN'
let s:d[0x265A]='BLACK CHESS KING'
let s:d[0x265B]='BLACK CHESS QUEEN'
let s:d[0x265C]='BLACK CHESS ROOK'
let s:d[0x265D]='BLACK CHESS BISHOP'
let s:d[0x265E]='BLACK CHESS KNIGHT'
let s:d[0x265F]='BLACK CHESS PAWN'
let s:d[0x2660]='BLACK SPADE SUIT'
let s:d[0x2661]='WHITE HEART SUIT'
let s:d[0x2662]='WHITE DIAMOND SUIT'
let s:d[0x2663]='BLACK CLUB SUIT'
let s:d[0x2664]='WHITE SPADE SUIT'
let s:d[0x2665]='BLACK HEART SUIT'
let s:d[0x2666]='BLACK DIAMOND SUIT'
let s:d[0x2667]='WHITE CLUB SUIT'
let s:d[0x2668]='HOT SPRINGS'
let s:d[0x2669]='QUARTER NOTE'
let s:d[0x266A]='EIGHTH NOTE'
let s:d[0x266B]='BEAMED EIGHTH NOTES'
let s:d[0x266C]='BEAMED SIXTEENTH NOTES'
let s:d[0x266D]='MUSIC FLAT SIGN'
let s:d[0x266E]='MUSIC NATURAL SIGN'
let s:d[0x266F]='MUSIC SHARP SIGN'
let s:d[0x2670]='WEST SYRIAC CROSS'
let s:d[0x2671]='EAST SYRIAC CROSS'
let s:d[0x2672]='UNIVERSAL RECYCLING SYMBOL'
let s:d[0x2673]='RECYCLING SYMBOL FOR TYPE-1 PLASTICS'
let s:d[0x2674]='RECYCLING SYMBOL FOR TYPE-2 PLASTICS'
let s:d[0x2675]='RECYCLING SYMBOL FOR TYPE-3 PLASTICS'
let s:d[0x2676]='RECYCLING SYMBOL FOR TYPE-4 PLASTICS'
let s:d[0x2677]='RECYCLING SYMBOL FOR TYPE-5 PLASTICS'
let s:d[0x2678]='RECYCLING SYMBOL FOR TYPE-6 PLASTICS'
let s:d[0x2679]='RECYCLING SYMBOL FOR TYPE-7 PLASTICS'
let s:d[0x267A]='RECYCLING SYMBOL FOR GENERIC MATERIALS'
let s:d[0x267B]='BLACK UNIVERSAL RECYCLING SYMBOL'
let s:d[0x267C]='RECYCLED PAPER SYMBOL'
let s:d[0x267D]='PARTIALLY-RECYCLED PAPER SYMBOL'
let s:d[0x267E]='PERMANENT PAPER SIGN'
let s:d[0x267F]='WHEELCHAIR SYMBOL'
let s:d[0x2680]='DIE FACE-1'
let s:d[0x2681]='DIE FACE-2'
let s:d[0x2682]='DIE FACE-3'
let s:d[0x2683]='DIE FACE-4'
let s:d[0x2684]='DIE FACE-5'
let s:d[0x2685]='DIE FACE-6'
let s:d[0x2686]='WHITE CIRCLE WITH DOT RIGHT'
let s:d[0x2687]='WHITE CIRCLE WITH TWO DOTS'
let s:d[0x2688]='BLACK CIRCLE WITH WHITE DOT RIGHT'
let s:d[0x2689]='BLACK CIRCLE WITH TWO WHITE DOTS'
let s:d[0x268A]='MONOGRAM FOR YANG'
let s:d[0x268B]='MONOGRAM FOR YIN'
let s:d[0x268C]='DIGRAM FOR GREATER YANG'
let s:d[0x268D]='DIGRAM FOR LESSER YIN'
let s:d[0x268E]='DIGRAM FOR LESSER YANG'
let s:d[0x268F]='DIGRAM FOR GREATER YIN'
let s:d[0x2690]='WHITE FLAG'
let s:d[0x2691]='BLACK FLAG'
let s:d[0x2692]='HAMMER AND PICK'
let s:d[0x2693]='ANCHOR'
let s:d[0x2694]='CROSSED SWORDS'
let s:d[0x2695]='STAFF OF AESCULAPIUS'
let s:d[0x2696]='SCALES'
let s:d[0x2697]='ALEMBIC'
let s:d[0x2698]='FLOWER'
let s:d[0x2699]='GEAR'
let s:d[0x269A]='STAFF OF HERMES'
let s:d[0x269B]='ATOM SYMBOL'
let s:d[0x269C]='FLEUR-DE-LIS'
let s:d[0x269D]='OUTLINED WHITE STAR'
let s:d[0x269E]='THREE LINES CONVERGING RIGHT'
let s:d[0x269F]='THREE LINES CONVERGING LEFT'
let s:d[0x26A0]='WARNING SIGN'
let s:d[0x26A1]='HIGH VOLTAGE SIGN'
let s:d[0x26A2]='DOUBLED FEMALE SIGN'
let s:d[0x26A3]='DOUBLED MALE SIGN'
let s:d[0x26A4]='INTERLOCKED FEMALE AND MALE SIGN'
let s:d[0x26A5]='MALE AND FEMALE SIGN'
let s:d[0x26A6]='MALE WITH STROKE SIGN'
let s:d[0x26A7]='MALE WITH STROKE AND MALE AND FEMALE SIGN'
let s:d[0x26A8]='VERTICAL MALE WITH STROKE SIGN'
let s:d[0x26A9]='HORIZONTAL MALE WITH STROKE SIGN'
let s:d[0x26AA]='MEDIUM WHITE CIRCLE'
let s:d[0x26AB]='MEDIUM BLACK CIRCLE'
let s:d[0x26AC]='MEDIUM SMALL WHITE CIRCLE'
let s:d[0x26AD]='MARRIAGE SYMBOL'
let s:d[0x26AE]='DIVORCE SYMBOL'
let s:d[0x26AF]='UNMARRIED PARTNERSHIP SYMBOL'
let s:d[0x26B0]='COFFIN'
let s:d[0x26B1]='FUNERAL URN'
let s:d[0x26B2]='NEUTER'
let s:d[0x26B3]='CERES'
let s:d[0x26B4]='PALLAS'
let s:d[0x26B5]='JUNO'
let s:d[0x26B6]='VESTA'
let s:d[0x26B7]='CHIRON'
let s:d[0x26B8]='BLACK MOON LILITH'
let s:d[0x26B9]='SEXTILE'
let s:d[0x26BA]='SEMISEXTILE'
let s:d[0x26BB]='QUINCUNX'
let s:d[0x26BC]='SESQUIQUADRATE'
let s:d[0x26BD]='SOCCER BALL'
let s:d[0x26BE]='BASEBALL'
let s:d[0x26BF]='SQUARED KEY'
let s:d[0x26C0]='WHITE DRAUGHTS MAN'
let s:d[0x26C1]='WHITE DRAUGHTS KING'
let s:d[0x26C2]='BLACK DRAUGHTS MAN'
let s:d[0x26C3]='BLACK DRAUGHTS KING'
let s:d[0x26C4]='SNOWMAN WITHOUT SNOW'
let s:d[0x26C5]='SUN BEHIND CLOUD'
let s:d[0x26C6]='RAIN'
let s:d[0x26C7]='BLACK SNOWMAN'
let s:d[0x26C8]='THUNDER CLOUD AND RAIN'
let s:d[0x26C9]='TURNED WHITE SHOGI PIECE'
let s:d[0x26CA]='TURNED BLACK SHOGI PIECE'
let s:d[0x26CB]='WHITE DIAMOND IN SQUARE'
let s:d[0x26CC]='CROSSING LANES'
let s:d[0x26CD]='DISABLED CAR'
let s:d[0x26CE]='OPHIUCHUS'
let s:d[0x26CF]='PICK'
let s:d[0x26D0]='CAR SLIDING'
let s:d[0x26D1]='HELMET WITH WHITE CROSS'
let s:d[0x26D2]='CIRCLED CROSSING LANES'
let s:d[0x26D3]='CHAINS'
let s:d[0x26D4]='NO ENTRY'
let s:d[0x26D5]='ALTERNATE ONE-WAY LEFT WAY TRAFFIC'
let s:d[0x26D6]='BLACK TWO-WAY LEFT WAY TRAFFIC'
let s:d[0x26D7]='WHITE TWO-WAY LEFT WAY TRAFFIC'
let s:d[0x26D8]='BLACK LEFT LANE MERGE'
let s:d[0x26D9]='WHITE LEFT LANE MERGE'
let s:d[0x26DA]='DRIVE SLOW SIGN'
let s:d[0x26DB]='HEAVY WHITE DOWN-POINTING TRIANGLE'
let s:d[0x26DC]='LEFT CLOSED ENTRY'
let s:d[0x26DD]='SQUARED SALTIRE'
let s:d[0x26DE]='FALLING DIAGONAL IN WHITE CIRCLE IN BLACK SQUARE'
let s:d[0x26DF]='BLACK TRUCK'
let s:d[0x26E0]='RESTRICTED LEFT ENTRY-1'
let s:d[0x26E1]='RESTRICTED LEFT ENTRY-2'
let s:d[0x26E2]='ASTRONOMICAL SYMBOL FOR URANUS'
let s:d[0x26E3]='HEAVY CIRCLE WITH STROKE AND TWO DOTS ABOVE'
let s:d[0x26E4]='PENTAGRAM'
let s:d[0x26E5]='RIGHT-HANDED INTERLACED PENTAGRAM'
let s:d[0x26E6]='LEFT-HANDED INTERLACED PENTAGRAM'
let s:d[0x26E7]='INVERTED PENTAGRAM'
let s:d[0x26E8]='BLACK CROSS ON SHIELD'
let s:d[0x26E9]='SHINTO SHRINE'
let s:d[0x26EA]='CHURCH'
let s:d[0x26EB]='CASTLE'
let s:d[0x26EC]='HISTORIC SITE'
let s:d[0x26ED]='GEAR WITHOUT HUB'
let s:d[0x26EE]='GEAR WITH HANDLES'
let s:d[0x26EF]='MAP SYMBOL FOR LIGHTHOUSE'
let s:d[0x26F0]='MOUNTAIN'
let s:d[0x26F1]='UMBRELLA ON GROUND'
let s:d[0x26F2]='FOUNTAIN'
let s:d[0x26F3]='FLAG IN HOLE'
let s:d[0x26F4]='FERRY'
let s:d[0x26F5]='SAILBOAT'
let s:d[0x26F6]='SQUARE FOUR CORNERS'
let s:d[0x26F7]='SKIER'
let s:d[0x26F8]='ICE SKATE'
let s:d[0x26F9]='PERSON WITH BALL'
let s:d[0x26FA]='TENT'
let s:d[0x26FB]='JAPANESE BANK SYMBOL'
let s:d[0x26FC]='HEADSTONE GRAVEYARD SYMBOL'
let s:d[0x26FD]='FUEL PUMP'
let s:d[0x26FE]='CUP ON BLACK SQUARE'
let s:d[0x26FF]='WHITE FLAG WITH HORIZONTAL MIDDLE BLACK STRIPE'
let s:d[0x2701]='UPPER BLADE SCISSORS'
let s:d[0x2702]='BLACK SCISSORS'
let s:d[0x2703]='LOWER BLADE SCISSORS'
let s:d[0x2704]='WHITE SCISSORS'
let s:d[0x2705]='WHITE HEAVY CHECK MARK'
let s:d[0x2706]='TELEPHONE LOCATION SIGN'
let s:d[0x2707]='TAPE DRIVE'
let s:d[0x2708]='AIRPLANE'
let s:d[0x2709]='ENVELOPE'
let s:d[0x270A]='RAISED FIST'
let s:d[0x270B]='RAISED HAND'
let s:d[0x270C]='VICTORY HAND'
let s:d[0x270D]='WRITING HAND'
let s:d[0x270E]='LOWER RIGHT PENCIL'
let s:d[0x270F]='PENCIL'
let s:d[0x2710]='UPPER RIGHT PENCIL'
let s:d[0x2711]='WHITE NIB'
let s:d[0x2712]='BLACK NIB'
let s:d[0x2713]='CHECK MARK'
let s:d[0x2714]='HEAVY CHECK MARK'
let s:d[0x2715]='MULTIPLICATION X'
let s:d[0x2716]='HEAVY MULTIPLICATION X'
let s:d[0x2717]='BALLOT X'
let s:d[0x2718]='HEAVY BALLOT X'
let s:d[0x2719]='OUTLINED GREEK CROSS'
let s:d[0x271A]='HEAVY GREEK CROSS'
let s:d[0x271B]='OPEN CENTRE CROSS'
let s:d[0x271C]='HEAVY OPEN CENTRE CROSS'
let s:d[0x271D]='LATIN CROSS'
let s:d[0x271E]='SHADOWED WHITE LATIN CROSS'
let s:d[0x271F]='OUTLINED LATIN CROSS'
let s:d[0x2720]='MALTESE CROSS'
let s:d[0x2721]='STAR OF DAVID'
let s:d[0x2722]='FOUR TEARDROP-SPOKED ASTERISK'
let s:d[0x2723]='FOUR BALLOON-SPOKED ASTERISK'
let s:d[0x2724]='HEAVY FOUR BALLOON-SPOKED ASTERISK'
let s:d[0x2725]='FOUR CLUB-SPOKED ASTERISK'
let s:d[0x2726]='BLACK FOUR POINTED STAR'
let s:d[0x2727]='WHITE FOUR POINTED STAR'
let s:d[0x2728]='SPARKLES'
let s:d[0x2729]='STRESS OUTLINED WHITE STAR'
let s:d[0x272A]='CIRCLED WHITE STAR'
let s:d[0x272B]='OPEN CENTRE BLACK STAR'
let s:d[0x272C]='BLACK CENTRE WHITE STAR'
let s:d[0x272D]='OUTLINED BLACK STAR'
let s:d[0x272E]='HEAVY OUTLINED BLACK STAR'
let s:d[0x272F]='PINWHEEL STAR'
let s:d[0x2730]='SHADOWED WHITE STAR'
let s:d[0x2731]='HEAVY ASTERISK'
let s:d[0x2732]='OPEN CENTRE ASTERISK'
let s:d[0x2733]='EIGHT SPOKED ASTERISK'
let s:d[0x2734]='EIGHT POINTED BLACK STAR'
let s:d[0x2735]='EIGHT POINTED PINWHEEL STAR'
let s:d[0x2736]='SIX POINTED BLACK STAR'
let s:d[0x2737]='EIGHT POINTED RECTILINEAR BLACK STAR'
let s:d[0x2738]='HEAVY EIGHT POINTED RECTILINEAR BLACK STAR'
let s:d[0x2739]='TWELVE POINTED BLACK STAR'
let s:d[0x273A]='SIXTEEN POINTED ASTERISK'
let s:d[0x273B]='TEARDROP-SPOKED ASTERISK'
let s:d[0x273C]='OPEN CENTRE TEARDROP-SPOKED ASTERISK'
let s:d[0x273D]='HEAVY TEARDROP-SPOKED ASTERISK'
let s:d[0x273E]='SIX PETALLED BLACK AND WHITE FLORETTE'
let s:d[0x273F]='BLACK FLORETTE'
let s:d[0x2740]='WHITE FLORETTE'
let s:d[0x2741]='EIGHT PETALLED OUTLINED BLACK FLORETTE'
let s:d[0x2742]='CIRCLED OPEN CENTRE EIGHT POINTED STAR'
let s:d[0x2743]='HEAVY TEARDROP-SPOKED PINWHEEL ASTERISK'
let s:d[0x2744]='SNOWFLAKE'
let s:d[0x2745]='TIGHT TRIFOLIATE SNOWFLAKE'
let s:d[0x2746]='HEAVY CHEVRON SNOWFLAKE'
let s:d[0x2747]='SPARKLE'
let s:d[0x2748]='HEAVY SPARKLE'
let s:d[0x2749]='BALLOON-SPOKED ASTERISK'
let s:d[0x274A]='EIGHT TEARDROP-SPOKED PROPELLER ASTERISK'
let s:d[0x274B]='HEAVY EIGHT TEARDROP-SPOKED PROPELLER ASTERISK'
let s:d[0x274C]='CROSS MARK'
let s:d[0x274D]='SHADOWED WHITE CIRCLE'
let s:d[0x274E]='NEGATIVE SQUARED CROSS MARK'
let s:d[0x274F]='LOWER RIGHT DROP-SHADOWED WHITE SQUARE'
let s:d[0x2750]='UPPER RIGHT DROP-SHADOWED WHITE SQUARE'
let s:d[0x2751]='LOWER RIGHT SHADOWED WHITE SQUARE'
let s:d[0x2752]='UPPER RIGHT SHADOWED WHITE SQUARE'
let s:d[0x2753]='BLACK QUESTION MARK ORNAMENT'
let s:d[0x2754]='WHITE QUESTION MARK ORNAMENT'
let s:d[0x2755]='WHITE EXCLAMATION MARK ORNAMENT'
let s:d[0x2756]='BLACK DIAMOND MINUS WHITE X'
let s:d[0x2757]='HEAVY EXCLAMATION MARK SYMBOL'
let s:d[0x2758]='LIGHT VERTICAL BAR'
let s:d[0x2759]='MEDIUM VERTICAL BAR'
let s:d[0x275A]='HEAVY VERTICAL BAR'
let s:d[0x275B]='HEAVY SINGLE TURNED COMMA QUOTATION MARK ORNAMENT'
let s:d[0x275C]='HEAVY SINGLE COMMA QUOTATION MARK ORNAMENT'
let s:d[0x275D]='HEAVY DOUBLE TURNED COMMA QUOTATION MARK ORNAMENT'
let s:d[0x275E]='HEAVY DOUBLE COMMA QUOTATION MARK ORNAMENT'
let s:d[0x275F]='HEAVY LOW SINGLE COMMA QUOTATION MARK ORNAMENT'
let s:d[0x2760]='HEAVY LOW DOUBLE COMMA QUOTATION MARK ORNAMENT'
let s:d[0x2761]='CURVED STEM PARAGRAPH SIGN ORNAMENT'
let s:d[0x2762]='HEAVY EXCLAMATION MARK ORNAMENT'
let s:d[0x2763]='HEAVY HEART EXCLAMATION MARK ORNAMENT'
let s:d[0x2764]='HEAVY BLACK HEART'
let s:d[0x2765]='ROTATED HEAVY BLACK HEART BULLET'
let s:d[0x2766]='FLORAL HEART'
let s:d[0x2767]='ROTATED FLORAL HEART BULLET'
let s:d[0x2768]='MEDIUM LEFT PARENTHESIS ORNAMENT'
let s:d[0x2769]='MEDIUM RIGHT PARENTHESIS ORNAMENT'
let s:d[0x276A]='MEDIUM FLATTENED LEFT PARENTHESIS ORNAMENT'
let s:d[0x276B]='MEDIUM FLATTENED RIGHT PARENTHESIS ORNAMENT'
let s:d[0x276C]='MEDIUM LEFT-POINTING ANGLE BRACKET ORNAMENT'
let s:d[0x276D]='MEDIUM RIGHT-POINTING ANGLE BRACKET ORNAMENT'
let s:d[0x276E]='HEAVY LEFT-POINTING ANGLE QUOTATION MARK ORNAMENT'
let s:d[0x276F]='HEAVY RIGHT-POINTING ANGLE QUOTATION MARK ORNAMENT'
let s:d[0x2770]='HEAVY LEFT-POINTING ANGLE BRACKET ORNAMENT'
let s:d[0x2771]='HEAVY RIGHT-POINTING ANGLE BRACKET ORNAMENT'
let s:d[0x2772]='LIGHT LEFT TORTOISE SHELL BRACKET ORNAMENT'
let s:d[0x2773]='LIGHT RIGHT TORTOISE SHELL BRACKET ORNAMENT'
let s:d[0x2774]='MEDIUM LEFT CURLY BRACKET ORNAMENT'
let s:d[0x2775]='MEDIUM RIGHT CURLY BRACKET ORNAMENT'
let s:d[0x2776]='DINGBAT NEGATIVE CIRCLED DIGIT ONE'
let s:d[0x2777]='DINGBAT NEGATIVE CIRCLED DIGIT TWO'
let s:d[0x2778]='DINGBAT NEGATIVE CIRCLED DIGIT THREE'
let s:d[0x2779]='DINGBAT NEGATIVE CIRCLED DIGIT FOUR'
let s:d[0x277A]='DINGBAT NEGATIVE CIRCLED DIGIT FIVE'
let s:d[0x277B]='DINGBAT NEGATIVE CIRCLED DIGIT SIX'
let s:d[0x277C]='DINGBAT NEGATIVE CIRCLED DIGIT SEVEN'
let s:d[0x277D]='DINGBAT NEGATIVE CIRCLED DIGIT EIGHT'
let s:d[0x277E]='DINGBAT NEGATIVE CIRCLED DIGIT NINE'
let s:d[0x277F]='DINGBAT NEGATIVE CIRCLED NUMBER TEN'
let s:d[0x2780]='DINGBAT CIRCLED SANS-SERIF DIGIT ONE'
let s:d[0x2781]='DINGBAT CIRCLED SANS-SERIF DIGIT TWO'
let s:d[0x2782]='DINGBAT CIRCLED SANS-SERIF DIGIT THREE'
let s:d[0x2783]='DINGBAT CIRCLED SANS-SERIF DIGIT FOUR'
let s:d[0x2784]='DINGBAT CIRCLED SANS-SERIF DIGIT FIVE'
let s:d[0x2785]='DINGBAT CIRCLED SANS-SERIF DIGIT SIX'
let s:d[0x2786]='DINGBAT CIRCLED SANS-SERIF DIGIT SEVEN'
let s:d[0x2787]='DINGBAT CIRCLED SANS-SERIF DIGIT EIGHT'
let s:d[0x2788]='DINGBAT CIRCLED SANS-SERIF DIGIT NINE'
let s:d[0x2789]='DINGBAT CIRCLED SANS-SERIF NUMBER TEN'
let s:d[0x278A]='DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT ONE'
let s:d[0x278B]='DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT TWO'
let s:d[0x278C]='DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT THREE'
let s:d[0x278D]='DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT FOUR'
let s:d[0x278E]='DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT FIVE'
let s:d[0x278F]='DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT SIX'
let s:d[0x2790]='DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT SEVEN'
let s:d[0x2791]='DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT EIGHT'
let s:d[0x2792]='DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT NINE'
let s:d[0x2793]='DINGBAT NEGATIVE CIRCLED SANS-SERIF NUMBER TEN'
let s:d[0x2794]='HEAVY WIDE-HEADED RIGHTWARDS ARROW'
let s:d[0x2795]='HEAVY PLUS SIGN'
let s:d[0x2796]='HEAVY MINUS SIGN'
let s:d[0x2797]='HEAVY DIVISION SIGN'
let s:d[0x2798]='HEAVY SOUTH EAST ARROW'
let s:d[0x2799]='HEAVY RIGHTWARDS ARROW'
let s:d[0x279A]='HEAVY NORTH EAST ARROW'
let s:d[0x279B]='DRAFTING POINT RIGHTWARDS ARROW'
let s:d[0x279C]='HEAVY ROUND-TIPPED RIGHTWARDS ARROW'
let s:d[0x279D]='TRIANGLE-HEADED RIGHTWARDS ARROW'
let s:d[0x279E]='HEAVY TRIANGLE-HEADED RIGHTWARDS ARROW'
let s:d[0x279F]='DASHED TRIANGLE-HEADED RIGHTWARDS ARROW'
let s:d[0x27A0]='HEAVY DASHED TRIANGLE-HEADED RIGHTWARDS ARROW'
let s:d[0x27A1]='BLACK RIGHTWARDS ARROW'
let s:d[0x27A2]='THREE-D TOP-LIGHTED RIGHTWARDS ARROWHEAD'
let s:d[0x27A3]='THREE-D BOTTOM-LIGHTED RIGHTWARDS ARROWHEAD'
let s:d[0x27A4]='BLACK RIGHTWARDS ARROWHEAD'
let s:d[0x27A5]='HEAVY BLACK CURVED DOWNWARDS AND RIGHTWARDS ARROW'
let s:d[0x27A6]='HEAVY BLACK CURVED UPWARDS AND RIGHTWARDS ARROW'
let s:d[0x27A7]='SQUAT BLACK RIGHTWARDS ARROW'
let s:d[0x27A8]='HEAVY CONCAVE-POINTED BLACK RIGHTWARDS ARROW'
let s:d[0x27A9]='RIGHT-SHADED WHITE RIGHTWARDS ARROW'
let s:d[0x27AA]='LEFT-SHADED WHITE RIGHTWARDS ARROW'
let s:d[0x27AB]='BACK-TILTED SHADOWED WHITE RIGHTWARDS ARROW'
let s:d[0x27AC]='FRONT-TILTED SHADOWED WHITE RIGHTWARDS ARROW'
let s:d[0x27AD]='HEAVY LOWER RIGHT-SHADOWED WHITE RIGHTWARDS ARROW'
let s:d[0x27AE]='HEAVY UPPER RIGHT-SHADOWED WHITE RIGHTWARDS ARROW'
let s:d[0x27AF]='NOTCHED LOWER RIGHT-SHADOWED WHITE RIGHTWARDS ARROW'
let s:d[0x27B0]='CURLY LOOP'
let s:d[0x27B1]='NOTCHED UPPER RIGHT-SHADOWED WHITE RIGHTWARDS ARROW'
let s:d[0x27B2]='CIRCLED HEAVY WHITE RIGHTWARDS ARROW'
let s:d[0x27B3]='WHITE-FEATHERED RIGHTWARDS ARROW'
let s:d[0x27B4]='BLACK-FEATHERED SOUTH EAST ARROW'
let s:d[0x27B5]='BLACK-FEATHERED RIGHTWARDS ARROW'
let s:d[0x27B6]='BLACK-FEATHERED NORTH EAST ARROW'
let s:d[0x27B7]='HEAVY BLACK-FEATHERED SOUTH EAST ARROW'
let s:d[0x27B8]='HEAVY BLACK-FEATHERED RIGHTWARDS ARROW'
let s:d[0x27B9]='HEAVY BLACK-FEATHERED NORTH EAST ARROW'
let s:d[0x27BA]='TEARDROP-BARBED RIGHTWARDS ARROW'
let s:d[0x27BB]='HEAVY TEARDROP-SHANKED RIGHTWARDS ARROW'
let s:d[0x27BC]='WEDGE-TAILED RIGHTWARDS ARROW'
let s:d[0x27BD]='HEAVY WEDGE-TAILED RIGHTWARDS ARROW'
let s:d[0x27BE]='OPEN-OUTLINED RIGHTWARDS ARROW'
let s:d[0x27BF]='DOUBLE CURLY LOOP'
let s:d[0x27C0]='THREE DIMENSIONAL ANGLE'
let s:d[0x27C1]='WHITE TRIANGLE CONTAINING SMALL WHITE TRIANGLE'
let s:d[0x27C2]='PERPENDICULAR'
let s:d[0x27C3]='OPEN SUBSET'
let s:d[0x27C4]='OPEN SUPERSET'
let s:d[0x27C5]='LEFT S-SHAPED BAG DELIMITER'
let s:d[0x27C6]='RIGHT S-SHAPED BAG DELIMITER'
let s:d[0x27C7]='OR WITH DOT INSIDE'
let s:d[0x27C8]='REVERSE SOLIDUS PRECEDING SUBSET'
let s:d[0x27C9]='SUPERSET PRECEDING SOLIDUS'
let s:d[0x27CA]='VERTICAL BAR WITH HORIZONTAL STROKE'
let s:d[0x27CB]='MATHEMATICAL RISING DIAGONAL'
let s:d[0x27CC]='LONG DIVISION'
let s:d[0x27CD]='MATHEMATICAL FALLING DIAGONAL'
let s:d[0x27CE]='SQUARED LOGICAL AND'
let s:d[0x27CF]='SQUARED LOGICAL OR'
let s:d[0x27D0]='WHITE DIAMOND WITH CENTRED DOT'
let s:d[0x27D1]='AND WITH DOT'
let s:d[0x27D2]='ELEMENT OF OPENING UPWARDS'
let s:d[0x27D3]='LOWER RIGHT CORNER WITH DOT'
let s:d[0x27D4]='UPPER LEFT CORNER WITH DOT'
let s:d[0x27D5]='LEFT OUTER JOIN'
let s:d[0x27D6]='RIGHT OUTER JOIN'
let s:d[0x27D7]='FULL OUTER JOIN'
let s:d[0x27D8]='LARGE UP TACK'
let s:d[0x27D9]='LARGE DOWN TACK'
let s:d[0x27DA]='LEFT AND RIGHT DOUBLE TURNSTILE'
let s:d[0x27DB]='LEFT AND RIGHT TACK'
let s:d[0x27DC]='LEFT MULTIMAP'
let s:d[0x27DD]='LONG RIGHT TACK'
let s:d[0x27DE]='LONG LEFT TACK'
let s:d[0x27DF]='UP TACK WITH CIRCLE ABOVE'
let s:d[0x27E0]='LOZENGE DIVIDED BY HORIZONTAL RULE'
let s:d[0x27E1]='WHITE CONCAVE-SIDED DIAMOND'
let s:d[0x27E2]='WHITE CONCAVE-SIDED DIAMOND WITH LEFTWARDS TICK'
let s:d[0x27E3]='WHITE CONCAVE-SIDED DIAMOND WITH RIGHTWARDS TICK'
let s:d[0x27E4]='WHITE SQUARE WITH LEFTWARDS TICK'
let s:d[0x27E5]='WHITE SQUARE WITH RIGHTWARDS TICK'
let s:d[0x27E6]='MATHEMATICAL LEFT WHITE SQUARE BRACKET'
let s:d[0x27E7]='MATHEMATICAL RIGHT WHITE SQUARE BRACKET'
let s:d[0x27E8]='MATHEMATICAL LEFT ANGLE BRACKET'
let s:d[0x27E9]='MATHEMATICAL RIGHT ANGLE BRACKET'
let s:d[0x27EA]='MATHEMATICAL LEFT DOUBLE ANGLE BRACKET'
let s:d[0x27EB]='MATHEMATICAL RIGHT DOUBLE ANGLE BRACKET'
let s:d[0x27EC]='MATHEMATICAL LEFT WHITE TORTOISE SHELL BRACKET'
let s:d[0x27ED]='MATHEMATICAL RIGHT WHITE TORTOISE SHELL BRACKET'
let s:d[0x27EE]='MATHEMATICAL LEFT FLATTENED PARENTHESIS'
let s:d[0x27EF]='MATHEMATICAL RIGHT FLATTENED PARENTHESIS'
let s:d[0x27F0]='UPWARDS QUADRUPLE ARROW'
let s:d[0x27F1]='DOWNWARDS QUADRUPLE ARROW'
let s:d[0x27F2]='ANTICLOCKWISE GAPPED CIRCLE ARROW'
let s:d[0x27F3]='CLOCKWISE GAPPED CIRCLE ARROW'
let s:d[0x27F4]='RIGHT ARROW WITH CIRCLED PLUS'
let s:d[0x27F5]='LONG LEFTWARDS ARROW'
let s:d[0x27F6]='LONG RIGHTWARDS ARROW'
let s:d[0x27F7]='LONG LEFT RIGHT ARROW'
let s:d[0x27F8]='LONG LEFTWARDS DOUBLE ARROW'
let s:d[0x27F9]='LONG RIGHTWARDS DOUBLE ARROW'
let s:d[0x27FA]='LONG LEFT RIGHT DOUBLE ARROW'
let s:d[0x27FB]='LONG LEFTWARDS ARROW FROM BAR'
let s:d[0x27FC]='LONG RIGHTWARDS ARROW FROM BAR'
let s:d[0x27FD]='LONG LEFTWARDS DOUBLE ARROW FROM BAR'
let s:d[0x27FE]='LONG RIGHTWARDS DOUBLE ARROW FROM BAR'
let s:d[0x27FF]='LONG RIGHTWARDS SQUIGGLE ARROW'
let s:d[0x2800]='BRAILLE PATTERN BLANK'
let s:d[0x2801]='BRAILLE PATTERN DOTS-1'
let s:d[0x2802]='BRAILLE PATTERN DOTS-2'
let s:d[0x2803]='BRAILLE PATTERN DOTS-12'
let s:d[0x2804]='BRAILLE PATTERN DOTS-3'
let s:d[0x2805]='BRAILLE PATTERN DOTS-13'
let s:d[0x2806]='BRAILLE PATTERN DOTS-23'
let s:d[0x2807]='BRAILLE PATTERN DOTS-123'
let s:d[0x2808]='BRAILLE PATTERN DOTS-4'
let s:d[0x2809]='BRAILLE PATTERN DOTS-14'
let s:d[0x280A]='BRAILLE PATTERN DOTS-24'
let s:d[0x280B]='BRAILLE PATTERN DOTS-124'
let s:d[0x280C]='BRAILLE PATTERN DOTS-34'
let s:d[0x280D]='BRAILLE PATTERN DOTS-134'
let s:d[0x280E]='BRAILLE PATTERN DOTS-234'
let s:d[0x280F]='BRAILLE PATTERN DOTS-1234'
let s:d[0x2810]='BRAILLE PATTERN DOTS-5'
let s:d[0x2811]='BRAILLE PATTERN DOTS-15'
let s:d[0x2812]='BRAILLE PATTERN DOTS-25'
let s:d[0x2813]='BRAILLE PATTERN DOTS-125'
let s:d[0x2814]='BRAILLE PATTERN DOTS-35'
let s:d[0x2815]='BRAILLE PATTERN DOTS-135'
let s:d[0x2816]='BRAILLE PATTERN DOTS-235'
let s:d[0x2817]='BRAILLE PATTERN DOTS-1235'
let s:d[0x2818]='BRAILLE PATTERN DOTS-45'
let s:d[0x2819]='BRAILLE PATTERN DOTS-145'
let s:d[0x281A]='BRAILLE PATTERN DOTS-245'
let s:d[0x281B]='BRAILLE PATTERN DOTS-1245'
let s:d[0x281C]='BRAILLE PATTERN DOTS-345'
let s:d[0x281D]='BRAILLE PATTERN DOTS-1345'
let s:d[0x281E]='BRAILLE PATTERN DOTS-2345'
let s:d[0x281F]='BRAILLE PATTERN DOTS-12345'
let s:d[0x2820]='BRAILLE PATTERN DOTS-6'
let s:d[0x2821]='BRAILLE PATTERN DOTS-16'
let s:d[0x2822]='BRAILLE PATTERN DOTS-26'
let s:d[0x2823]='BRAILLE PATTERN DOTS-126'
let s:d[0x2824]='BRAILLE PATTERN DOTS-36'
let s:d[0x2825]='BRAILLE PATTERN DOTS-136'
let s:d[0x2826]='BRAILLE PATTERN DOTS-236'
let s:d[0x2827]='BRAILLE PATTERN DOTS-1236'
let s:d[0x2828]='BRAILLE PATTERN DOTS-46'
let s:d[0x2829]='BRAILLE PATTERN DOTS-146'
let s:d[0x282A]='BRAILLE PATTERN DOTS-246'
let s:d[0x282B]='BRAILLE PATTERN DOTS-1246'
let s:d[0x282C]='BRAILLE PATTERN DOTS-346'
let s:d[0x282D]='BRAILLE PATTERN DOTS-1346'
let s:d[0x282E]='BRAILLE PATTERN DOTS-2346'
let s:d[0x282F]='BRAILLE PATTERN DOTS-12346'
let s:d[0x2830]='BRAILLE PATTERN DOTS-56'
let s:d[0x2831]='BRAILLE PATTERN DOTS-156'
let s:d[0x2832]='BRAILLE PATTERN DOTS-256'
let s:d[0x2833]='BRAILLE PATTERN DOTS-1256'
let s:d[0x2834]='BRAILLE PATTERN DOTS-356'
let s:d[0x2835]='BRAILLE PATTERN DOTS-1356'
let s:d[0x2836]='BRAILLE PATTERN DOTS-2356'
let s:d[0x2837]='BRAILLE PATTERN DOTS-12356'
let s:d[0x2838]='BRAILLE PATTERN DOTS-456'
let s:d[0x2839]='BRAILLE PATTERN DOTS-1456'
let s:d[0x283A]='BRAILLE PATTERN DOTS-2456'
let s:d[0x283B]='BRAILLE PATTERN DOTS-12456'
let s:d[0x283C]='BRAILLE PATTERN DOTS-3456'
let s:d[0x283D]='BRAILLE PATTERN DOTS-13456'
let s:d[0x283E]='BRAILLE PATTERN DOTS-23456'
let s:d[0x283F]='BRAILLE PATTERN DOTS-123456'
let s:d[0x2840]='BRAILLE PATTERN DOTS-7'
let s:d[0x2841]='BRAILLE PATTERN DOTS-17'
let s:d[0x2842]='BRAILLE PATTERN DOTS-27'
let s:d[0x2843]='BRAILLE PATTERN DOTS-127'
let s:d[0x2844]='BRAILLE PATTERN DOTS-37'
let s:d[0x2845]='BRAILLE PATTERN DOTS-137'
let s:d[0x2846]='BRAILLE PATTERN DOTS-237'
let s:d[0x2847]='BRAILLE PATTERN DOTS-1237'
let s:d[0x2848]='BRAILLE PATTERN DOTS-47'
let s:d[0x2849]='BRAILLE PATTERN DOTS-147'
let s:d[0x284A]='BRAILLE PATTERN DOTS-247'
let s:d[0x284B]='BRAILLE PATTERN DOTS-1247'
let s:d[0x284C]='BRAILLE PATTERN DOTS-347'
let s:d[0x284D]='BRAILLE PATTERN DOTS-1347'
let s:d[0x284E]='BRAILLE PATTERN DOTS-2347'
let s:d[0x284F]='BRAILLE PATTERN DOTS-12347'
let s:d[0x2850]='BRAILLE PATTERN DOTS-57'
let s:d[0x2851]='BRAILLE PATTERN DOTS-157'
let s:d[0x2852]='BRAILLE PATTERN DOTS-257'
let s:d[0x2853]='BRAILLE PATTERN DOTS-1257'
let s:d[0x2854]='BRAILLE PATTERN DOTS-357'
let s:d[0x2855]='BRAILLE PATTERN DOTS-1357'
let s:d[0x2856]='BRAILLE PATTERN DOTS-2357'
let s:d[0x2857]='BRAILLE PATTERN DOTS-12357'
let s:d[0x2858]='BRAILLE PATTERN DOTS-457'
let s:d[0x2859]='BRAILLE PATTERN DOTS-1457'
let s:d[0x285A]='BRAILLE PATTERN DOTS-2457'
let s:d[0x285B]='BRAILLE PATTERN DOTS-12457'
let s:d[0x285C]='BRAILLE PATTERN DOTS-3457'
let s:d[0x285D]='BRAILLE PATTERN DOTS-13457'
let s:d[0x285E]='BRAILLE PATTERN DOTS-23457'
let s:d[0x285F]='BRAILLE PATTERN DOTS-123457'
let s:d[0x2860]='BRAILLE PATTERN DOTS-67'
let s:d[0x2861]='BRAILLE PATTERN DOTS-167'
let s:d[0x2862]='BRAILLE PATTERN DOTS-267'
let s:d[0x2863]='BRAILLE PATTERN DOTS-1267'
let s:d[0x2864]='BRAILLE PATTERN DOTS-367'
let s:d[0x2865]='BRAILLE PATTERN DOTS-1367'
let s:d[0x2866]='BRAILLE PATTERN DOTS-2367'
let s:d[0x2867]='BRAILLE PATTERN DOTS-12367'
let s:d[0x2868]='BRAILLE PATTERN DOTS-467'
let s:d[0x2869]='BRAILLE PATTERN DOTS-1467'
let s:d[0x286A]='BRAILLE PATTERN DOTS-2467'
let s:d[0x286B]='BRAILLE PATTERN DOTS-12467'
let s:d[0x286C]='BRAILLE PATTERN DOTS-3467'
let s:d[0x286D]='BRAILLE PATTERN DOTS-13467'
let s:d[0x286E]='BRAILLE PATTERN DOTS-23467'
let s:d[0x286F]='BRAILLE PATTERN DOTS-123467'
let s:d[0x2870]='BRAILLE PATTERN DOTS-567'
let s:d[0x2871]='BRAILLE PATTERN DOTS-1567'
let s:d[0x2872]='BRAILLE PATTERN DOTS-2567'
let s:d[0x2873]='BRAILLE PATTERN DOTS-12567'
let s:d[0x2874]='BRAILLE PATTERN DOTS-3567'
let s:d[0x2875]='BRAILLE PATTERN DOTS-13567'
let s:d[0x2876]='BRAILLE PATTERN DOTS-23567'
let s:d[0x2877]='BRAILLE PATTERN DOTS-123567'
let s:d[0x2878]='BRAILLE PATTERN DOTS-4567'
let s:d[0x2879]='BRAILLE PATTERN DOTS-14567'
let s:d[0x287A]='BRAILLE PATTERN DOTS-24567'
let s:d[0x287B]='BRAILLE PATTERN DOTS-124567'
let s:d[0x287C]='BRAILLE PATTERN DOTS-34567'
let s:d[0x287D]='BRAILLE PATTERN DOTS-134567'
let s:d[0x287E]='BRAILLE PATTERN DOTS-234567'
let s:d[0x287F]='BRAILLE PATTERN DOTS-1234567'
let s:d[0x2880]='BRAILLE PATTERN DOTS-8'
let s:d[0x2881]='BRAILLE PATTERN DOTS-18'
let s:d[0x2882]='BRAILLE PATTERN DOTS-28'
let s:d[0x2883]='BRAILLE PATTERN DOTS-128'
let s:d[0x2884]='BRAILLE PATTERN DOTS-38'
let s:d[0x2885]='BRAILLE PATTERN DOTS-138'
let s:d[0x2886]='BRAILLE PATTERN DOTS-238'
let s:d[0x2887]='BRAILLE PATTERN DOTS-1238'
let s:d[0x2888]='BRAILLE PATTERN DOTS-48'
let s:d[0x2889]='BRAILLE PATTERN DOTS-148'
let s:d[0x288A]='BRAILLE PATTERN DOTS-248'
let s:d[0x288B]='BRAILLE PATTERN DOTS-1248'
let s:d[0x288C]='BRAILLE PATTERN DOTS-348'
let s:d[0x288D]='BRAILLE PATTERN DOTS-1348'
let s:d[0x288E]='BRAILLE PATTERN DOTS-2348'
let s:d[0x288F]='BRAILLE PATTERN DOTS-12348'
let s:d[0x2890]='BRAILLE PATTERN DOTS-58'
let s:d[0x2891]='BRAILLE PATTERN DOTS-158'
let s:d[0x2892]='BRAILLE PATTERN DOTS-258'
let s:d[0x2893]='BRAILLE PATTERN DOTS-1258'
let s:d[0x2894]='BRAILLE PATTERN DOTS-358'
let s:d[0x2895]='BRAILLE PATTERN DOTS-1358'
let s:d[0x2896]='BRAILLE PATTERN DOTS-2358'
let s:d[0x2897]='BRAILLE PATTERN DOTS-12358'
let s:d[0x2898]='BRAILLE PATTERN DOTS-458'
let s:d[0x2899]='BRAILLE PATTERN DOTS-1458'
let s:d[0x289A]='BRAILLE PATTERN DOTS-2458'
let s:d[0x289B]='BRAILLE PATTERN DOTS-12458'
let s:d[0x289C]='BRAILLE PATTERN DOTS-3458'
let s:d[0x289D]='BRAILLE PATTERN DOTS-13458'
let s:d[0x289E]='BRAILLE PATTERN DOTS-23458'
let s:d[0x289F]='BRAILLE PATTERN DOTS-123458'
let s:d[0x28A0]='BRAILLE PATTERN DOTS-68'
let s:d[0x28A1]='BRAILLE PATTERN DOTS-168'
let s:d[0x28A2]='BRAILLE PATTERN DOTS-268'
let s:d[0x28A3]='BRAILLE PATTERN DOTS-1268'
let s:d[0x28A4]='BRAILLE PATTERN DOTS-368'
let s:d[0x28A5]='BRAILLE PATTERN DOTS-1368'
let s:d[0x28A6]='BRAILLE PATTERN DOTS-2368'
let s:d[0x28A7]='BRAILLE PATTERN DOTS-12368'
let s:d[0x28A8]='BRAILLE PATTERN DOTS-468'
let s:d[0x28A9]='BRAILLE PATTERN DOTS-1468'
let s:d[0x28AA]='BRAILLE PATTERN DOTS-2468'
let s:d[0x28AB]='BRAILLE PATTERN DOTS-12468'
let s:d[0x28AC]='BRAILLE PATTERN DOTS-3468'
let s:d[0x28AD]='BRAILLE PATTERN DOTS-13468'
let s:d[0x28AE]='BRAILLE PATTERN DOTS-23468'
let s:d[0x28AF]='BRAILLE PATTERN DOTS-123468'
let s:d[0x28B0]='BRAILLE PATTERN DOTS-568'
let s:d[0x28B1]='BRAILLE PATTERN DOTS-1568'
let s:d[0x28B2]='BRAILLE PATTERN DOTS-2568'
let s:d[0x28B3]='BRAILLE PATTERN DOTS-12568'
let s:d[0x28B4]='BRAILLE PATTERN DOTS-3568'
let s:d[0x28B5]='BRAILLE PATTERN DOTS-13568'
let s:d[0x28B6]='BRAILLE PATTERN DOTS-23568'
let s:d[0x28B7]='BRAILLE PATTERN DOTS-123568'
let s:d[0x28B8]='BRAILLE PATTERN DOTS-4568'
let s:d[0x28B9]='BRAILLE PATTERN DOTS-14568'
let s:d[0x28BA]='BRAILLE PATTERN DOTS-24568'
let s:d[0x28BB]='BRAILLE PATTERN DOTS-124568'
let s:d[0x28BC]='BRAILLE PATTERN DOTS-34568'
let s:d[0x28BD]='BRAILLE PATTERN DOTS-134568'
let s:d[0x28BE]='BRAILLE PATTERN DOTS-234568'
let s:d[0x28BF]='BRAILLE PATTERN DOTS-1234568'
let s:d[0x28C0]='BRAILLE PATTERN DOTS-78'
let s:d[0x28C1]='BRAILLE PATTERN DOTS-178'
let s:d[0x28C2]='BRAILLE PATTERN DOTS-278'
let s:d[0x28C3]='BRAILLE PATTERN DOTS-1278'
let s:d[0x28C4]='BRAILLE PATTERN DOTS-378'
let s:d[0x28C5]='BRAILLE PATTERN DOTS-1378'
let s:d[0x28C6]='BRAILLE PATTERN DOTS-2378'
let s:d[0x28C7]='BRAILLE PATTERN DOTS-12378'
let s:d[0x28C8]='BRAILLE PATTERN DOTS-478'
let s:d[0x28C9]='BRAILLE PATTERN DOTS-1478'
let s:d[0x28CA]='BRAILLE PATTERN DOTS-2478'
let s:d[0x28CB]='BRAILLE PATTERN DOTS-12478'
let s:d[0x28CC]='BRAILLE PATTERN DOTS-3478'
let s:d[0x28CD]='BRAILLE PATTERN DOTS-13478'
let s:d[0x28CE]='BRAILLE PATTERN DOTS-23478'
let s:d[0x28CF]='BRAILLE PATTERN DOTS-123478'
let s:d[0x28D0]='BRAILLE PATTERN DOTS-578'
let s:d[0x28D1]='BRAILLE PATTERN DOTS-1578'
let s:d[0x28D2]='BRAILLE PATTERN DOTS-2578'
let s:d[0x28D3]='BRAILLE PATTERN DOTS-12578'
let s:d[0x28D4]='BRAILLE PATTERN DOTS-3578'
let s:d[0x28D5]='BRAILLE PATTERN DOTS-13578'
let s:d[0x28D6]='BRAILLE PATTERN DOTS-23578'
let s:d[0x28D7]='BRAILLE PATTERN DOTS-123578'
let s:d[0x28D8]='BRAILLE PATTERN DOTS-4578'
let s:d[0x28D9]='BRAILLE PATTERN DOTS-14578'
let s:d[0x28DA]='BRAILLE PATTERN DOTS-24578'
let s:d[0x28DB]='BRAILLE PATTERN DOTS-124578'
let s:d[0x28DC]='BRAILLE PATTERN DOTS-34578'
let s:d[0x28DD]='BRAILLE PATTERN DOTS-134578'
let s:d[0x28DE]='BRAILLE PATTERN DOTS-234578'
let s:d[0x28DF]='BRAILLE PATTERN DOTS-1234578'
let s:d[0x28E0]='BRAILLE PATTERN DOTS-678'
let s:d[0x28E1]='BRAILLE PATTERN DOTS-1678'
let s:d[0x28E2]='BRAILLE PATTERN DOTS-2678'
let s:d[0x28E3]='BRAILLE PATTERN DOTS-12678'
let s:d[0x28E4]='BRAILLE PATTERN DOTS-3678'
let s:d[0x28E5]='BRAILLE PATTERN DOTS-13678'
let s:d[0x28E6]='BRAILLE PATTERN DOTS-23678'
let s:d[0x28E7]='BRAILLE PATTERN DOTS-123678'
let s:d[0x28E8]='BRAILLE PATTERN DOTS-4678'
let s:d[0x28E9]='BRAILLE PATTERN DOTS-14678'
let s:d[0x28EA]='BRAILLE PATTERN DOTS-24678'
let s:d[0x28EB]='BRAILLE PATTERN DOTS-124678'
let s:d[0x28EC]='BRAILLE PATTERN DOTS-34678'
let s:d[0x28ED]='BRAILLE PATTERN DOTS-134678'
let s:d[0x28EE]='BRAILLE PATTERN DOTS-234678'
let s:d[0x28EF]='BRAILLE PATTERN DOTS-1234678'
let s:d[0x28F0]='BRAILLE PATTERN DOTS-5678'
let s:d[0x28F1]='BRAILLE PATTERN DOTS-15678'
let s:d[0x28F2]='BRAILLE PATTERN DOTS-25678'
let s:d[0x28F3]='BRAILLE PATTERN DOTS-125678'
let s:d[0x28F4]='BRAILLE PATTERN DOTS-35678'
let s:d[0x28F5]='BRAILLE PATTERN DOTS-135678'
let s:d[0x28F6]='BRAILLE PATTERN DOTS-235678'
let s:d[0x28F7]='BRAILLE PATTERN DOTS-1235678'
let s:d[0x28F8]='BRAILLE PATTERN DOTS-45678'
let s:d[0x28F9]='BRAILLE PATTERN DOTS-145678'
let s:d[0x28FA]='BRAILLE PATTERN DOTS-245678'
let s:d[0x28FB]='BRAILLE PATTERN DOTS-1245678'
let s:d[0x28FC]='BRAILLE PATTERN DOTS-345678'
let s:d[0x28FD]='BRAILLE PATTERN DOTS-1345678'
let s:d[0x28FE]='BRAILLE PATTERN DOTS-2345678'
let s:d[0x28FF]='BRAILLE PATTERN DOTS-12345678'
let s:d[0x2900]='RIGHTWARDS TWO-HEADED ARROW WITH VERTICAL STROKE'
let s:d[0x2901]='RIGHTWARDS TWO-HEADED ARROW WITH DOUBLE VERTICAL STROKE'
let s:d[0x2902]='LEFTWARDS DOUBLE ARROW WITH VERTICAL STROKE'
let s:d[0x2903]='RIGHTWARDS DOUBLE ARROW WITH VERTICAL STROKE'
let s:d[0x2904]='LEFT RIGHT DOUBLE ARROW WITH VERTICAL STROKE'
let s:d[0x2905]='RIGHTWARDS TWO-HEADED ARROW FROM BAR'
let s:d[0x2906]='LEFTWARDS DOUBLE ARROW FROM BAR'
let s:d[0x2907]='RIGHTWARDS DOUBLE ARROW FROM BAR'
let s:d[0x2908]='DOWNWARDS ARROW WITH HORIZONTAL STROKE'
let s:d[0x2909]='UPWARDS ARROW WITH HORIZONTAL STROKE'
let s:d[0x290A]='UPWARDS TRIPLE ARROW'
let s:d[0x290B]='DOWNWARDS TRIPLE ARROW'
let s:d[0x290C]='LEFTWARDS DOUBLE DASH ARROW'
let s:d[0x290D]='RIGHTWARDS DOUBLE DASH ARROW'
let s:d[0x290E]='LEFTWARDS TRIPLE DASH ARROW'
let s:d[0x290F]='RIGHTWARDS TRIPLE DASH ARROW'
let s:d[0x2910]='RIGHTWARDS TWO-HEADED TRIPLE DASH ARROW'
let s:d[0x2911]='RIGHTWARDS ARROW WITH DOTTED STEM'
let s:d[0x2912]='UPWARDS ARROW TO BAR'
let s:d[0x2913]='DOWNWARDS ARROW TO BAR'
let s:d[0x2914]='RIGHTWARDS ARROW WITH TAIL WITH VERTICAL STROKE'
let s:d[0x2915]='RIGHTWARDS ARROW WITH TAIL WITH DOUBLE VERTICAL STROKE'
let s:d[0x2916]='RIGHTWARDS TWO-HEADED ARROW WITH TAIL'
let s:d[0x2917]='RIGHTWARDS TWO-HEADED ARROW WITH TAIL WITH VERTICAL STROKE'
let s:d[0x2918]='RIGHTWARDS TWO-HEADED ARROW WITH TAIL WITH DOUBLE VERTICAL STROKE'
let s:d[0x2919]='LEFTWARDS ARROW-TAIL'
let s:d[0x291A]='RIGHTWARDS ARROW-TAIL'
let s:d[0x291B]='LEFTWARDS DOUBLE ARROW-TAIL'
let s:d[0x291C]='RIGHTWARDS DOUBLE ARROW-TAIL'
let s:d[0x291D]='LEFTWARDS ARROW TO BLACK DIAMOND'
let s:d[0x291E]='RIGHTWARDS ARROW TO BLACK DIAMOND'
let s:d[0x291F]='LEFTWARDS ARROW FROM BAR TO BLACK DIAMOND'
let s:d[0x2920]='RIGHTWARDS ARROW FROM BAR TO BLACK DIAMOND'
let s:d[0x2921]='NORTH WEST AND SOUTH EAST ARROW'
let s:d[0x2922]='NORTH EAST AND SOUTH WEST ARROW'
let s:d[0x2923]='NORTH WEST ARROW WITH HOOK'
let s:d[0x2924]='NORTH EAST ARROW WITH HOOK'
let s:d[0x2925]='SOUTH EAST ARROW WITH HOOK'
let s:d[0x2926]='SOUTH WEST ARROW WITH HOOK'
let s:d[0x2927]='NORTH WEST ARROW AND NORTH EAST ARROW'
let s:d[0x2928]='NORTH EAST ARROW AND SOUTH EAST ARROW'
let s:d[0x2929]='SOUTH EAST ARROW AND SOUTH WEST ARROW'
let s:d[0x292A]='SOUTH WEST ARROW AND NORTH WEST ARROW'
let s:d[0x292B]='RISING DIAGONAL CROSSING FALLING DIAGONAL'
let s:d[0x292C]='FALLING DIAGONAL CROSSING RISING DIAGONAL'
let s:d[0x292D]='SOUTH EAST ARROW CROSSING NORTH EAST ARROW'
let s:d[0x292E]='NORTH EAST ARROW CROSSING SOUTH EAST ARROW'
let s:d[0x292F]='FALLING DIAGONAL CROSSING NORTH EAST ARROW'
let s:d[0x2930]='RISING DIAGONAL CROSSING SOUTH EAST ARROW'
let s:d[0x2931]='NORTH EAST ARROW CROSSING NORTH WEST ARROW'
let s:d[0x2932]='NORTH WEST ARROW CROSSING NORTH EAST ARROW'
let s:d[0x2933]='WAVE ARROW POINTING DIRECTLY RIGHT'
let s:d[0x2934]='ARROW POINTING RIGHTWARDS THEN CURVING UPWARDS'
let s:d[0x2935]='ARROW POINTING RIGHTWARDS THEN CURVING DOWNWARDS'
let s:d[0x2936]='ARROW POINTING DOWNWARDS THEN CURVING LEFTWARDS'
let s:d[0x2937]='ARROW POINTING DOWNWARDS THEN CURVING RIGHTWARDS'
let s:d[0x2938]='RIGHT-SIDE ARC CLOCKWISE ARROW'
let s:d[0x2939]='LEFT-SIDE ARC ANTICLOCKWISE ARROW'
let s:d[0x293A]='TOP ARC ANTICLOCKWISE ARROW'
let s:d[0x293B]='BOTTOM ARC ANTICLOCKWISE ARROW'
let s:d[0x293C]='TOP ARC CLOCKWISE ARROW WITH MINUS'
let s:d[0x293D]='TOP ARC ANTICLOCKWISE ARROW WITH PLUS'
let s:d[0x293E]='LOWER RIGHT SEMICIRCULAR CLOCKWISE ARROW'
let s:d[0x293F]='LOWER LEFT SEMICIRCULAR ANTICLOCKWISE ARROW'
let s:d[0x2940]='ANTICLOCKWISE CLOSED CIRCLE ARROW'
let s:d[0x2941]='CLOCKWISE CLOSED CIRCLE ARROW'
let s:d[0x2942]='RIGHTWARDS ARROW ABOVE SHORT LEFTWARDS ARROW'
let s:d[0x2943]='LEFTWARDS ARROW ABOVE SHORT RIGHTWARDS ARROW'
let s:d[0x2944]='SHORT RIGHTWARDS ARROW ABOVE LEFTWARDS ARROW'
let s:d[0x2945]='RIGHTWARDS ARROW WITH PLUS BELOW'
let s:d[0x2946]='LEFTWARDS ARROW WITH PLUS BELOW'
let s:d[0x2947]='RIGHTWARDS ARROW THROUGH X'
let s:d[0x2948]='LEFT RIGHT ARROW THROUGH SMALL CIRCLE'
let s:d[0x2949]='UPWARDS TWO-HEADED ARROW FROM SMALL CIRCLE'
let s:d[0x294A]='LEFT BARB UP RIGHT BARB DOWN HARPOON'
let s:d[0x294B]='LEFT BARB DOWN RIGHT BARB UP HARPOON'
let s:d[0x294C]='UP BARB RIGHT DOWN BARB LEFT HARPOON'
let s:d[0x294D]='UP BARB LEFT DOWN BARB RIGHT HARPOON'
let s:d[0x294E]='LEFT BARB UP RIGHT BARB UP HARPOON'
let s:d[0x294F]='UP BARB RIGHT DOWN BARB RIGHT HARPOON'
let s:d[0x2950]='LEFT BARB DOWN RIGHT BARB DOWN HARPOON'
let s:d[0x2951]='UP BARB LEFT DOWN BARB LEFT HARPOON'
let s:d[0x2952]='LEFTWARDS HARPOON WITH BARB UP TO BAR'
let s:d[0x2953]='RIGHTWARDS HARPOON WITH BARB UP TO BAR'
let s:d[0x2954]='UPWARDS HARPOON WITH BARB RIGHT TO BAR'
let s:d[0x2955]='DOWNWARDS HARPOON WITH BARB RIGHT TO BAR'
let s:d[0x2956]='LEFTWARDS HARPOON WITH BARB DOWN TO BAR'
let s:d[0x2957]='RIGHTWARDS HARPOON WITH BARB DOWN TO BAR'
let s:d[0x2958]='UPWARDS HARPOON WITH BARB LEFT TO BAR'
let s:d[0x2959]='DOWNWARDS HARPOON WITH BARB LEFT TO BAR'
let s:d[0x295A]='LEFTWARDS HARPOON WITH BARB UP FROM BAR'
let s:d[0x295B]='RIGHTWARDS HARPOON WITH BARB UP FROM BAR'
let s:d[0x295C]='UPWARDS HARPOON WITH BARB RIGHT FROM BAR'
let s:d[0x295D]='DOWNWARDS HARPOON WITH BARB RIGHT FROM BAR'
let s:d[0x295E]='LEFTWARDS HARPOON WITH BARB DOWN FROM BAR'
let s:d[0x295F]='RIGHTWARDS HARPOON WITH BARB DOWN FROM BAR'
let s:d[0x2960]='UPWARDS HARPOON WITH BARB LEFT FROM BAR'
let s:d[0x2961]='DOWNWARDS HARPOON WITH BARB LEFT FROM BAR'
let s:d[0x2962]='LEFTWARDS HARPOON WITH BARB UP ABOVE LEFTWARDS HARPOON WITH BARB DOWN'
let s:d[0x2963]='UPWARDS HARPOON WITH BARB LEFT BESIDE UPWARDS HARPOON WITH BARB RIGHT'
let s:d[0x2964]='RIGHTWARDS HARPOON WITH BARB UP ABOVE RIGHTWARDS HARPOON WITH BARB DOWN'
let s:d[0x2965]='DOWNWARDS HARPOON WITH BARB LEFT BESIDE DOWNWARDS HARPOON WITH BARB RIGHT'
let s:d[0x2966]='LEFTWARDS HARPOON WITH BARB UP ABOVE RIGHTWARDS HARPOON WITH BARB UP'
let s:d[0x2967]='LEFTWARDS HARPOON WITH BARB DOWN ABOVE RIGHTWARDS HARPOON WITH BARB DOWN'
let s:d[0x2968]='RIGHTWARDS HARPOON WITH BARB UP ABOVE LEFTWARDS HARPOON WITH BARB UP'
let s:d[0x2969]='RIGHTWARDS HARPOON WITH BARB DOWN ABOVE LEFTWARDS HARPOON WITH BARB DOWN'
let s:d[0x296A]='LEFTWARDS HARPOON WITH BARB UP ABOVE LONG DASH'
let s:d[0x296B]='LEFTWARDS HARPOON WITH BARB DOWN BELOW LONG DASH'
let s:d[0x296C]='RIGHTWARDS HARPOON WITH BARB UP ABOVE LONG DASH'
let s:d[0x296D]='RIGHTWARDS HARPOON WITH BARB DOWN BELOW LONG DASH'
let s:d[0x296E]='UPWARDS HARPOON WITH BARB LEFT BESIDE DOWNWARDS HARPOON WITH BARB RIGHT'
let s:d[0x296F]='DOWNWARDS HARPOON WITH BARB LEFT BESIDE UPWARDS HARPOON WITH BARB RIGHT'
let s:d[0x2970]='RIGHT DOUBLE ARROW WITH ROUNDED HEAD'
let s:d[0x2971]='EQUALS SIGN ABOVE RIGHTWARDS ARROW'
let s:d[0x2972]='TILDE OPERATOR ABOVE RIGHTWARDS ARROW'
let s:d[0x2973]='LEFTWARDS ARROW ABOVE TILDE OPERATOR'
let s:d[0x2974]='RIGHTWARDS ARROW ABOVE TILDE OPERATOR'
let s:d[0x2975]='RIGHTWARDS ARROW ABOVE ALMOST EQUAL TO'
let s:d[0x2976]='LESS-THAN ABOVE LEFTWARDS ARROW'
let s:d[0x2977]='LEFTWARDS ARROW THROUGH LESS-THAN'
let s:d[0x2978]='GREATER-THAN ABOVE RIGHTWARDS ARROW'
let s:d[0x2979]='SUBSET ABOVE RIGHTWARDS ARROW'
let s:d[0x297A]='LEFTWARDS ARROW THROUGH SUBSET'
let s:d[0x297B]='SUPERSET ABOVE LEFTWARDS ARROW'
let s:d[0x297C]='LEFT FISH TAIL'
let s:d[0x297D]='RIGHT FISH TAIL'
let s:d[0x297E]='UP FISH TAIL'
let s:d[0x297F]='DOWN FISH TAIL'
let s:d[0x2980]='TRIPLE VERTICAL BAR DELIMITER'
let s:d[0x2981]='Z NOTATION SPOT'
let s:d[0x2982]='Z NOTATION TYPE COLON'
let s:d[0x2983]='LEFT WHITE CURLY BRACKET'
let s:d[0x2984]='RIGHT WHITE CURLY BRACKET'
let s:d[0x2985]='LEFT WHITE PARENTHESIS'
let s:d[0x2986]='RIGHT WHITE PARENTHESIS'
let s:d[0x2987]='Z NOTATION LEFT IMAGE BRACKET'
let s:d[0x2988]='Z NOTATION RIGHT IMAGE BRACKET'
let s:d[0x2989]='Z NOTATION LEFT BINDING BRACKET'
let s:d[0x298A]='Z NOTATION RIGHT BINDING BRACKET'
let s:d[0x298B]='LEFT SQUARE BRACKET WITH UNDERBAR'
let s:d[0x298C]='RIGHT SQUARE BRACKET WITH UNDERBAR'
let s:d[0x298D]='LEFT SQUARE BRACKET WITH TICK IN TOP CORNER'
let s:d[0x298E]='RIGHT SQUARE BRACKET WITH TICK IN BOTTOM CORNER'
let s:d[0x298F]='LEFT SQUARE BRACKET WITH TICK IN BOTTOM CORNER'
let s:d[0x2990]='RIGHT SQUARE BRACKET WITH TICK IN TOP CORNER'
let s:d[0x2991]='LEFT ANGLE BRACKET WITH DOT'
let s:d[0x2992]='RIGHT ANGLE BRACKET WITH DOT'
let s:d[0x2993]='LEFT ARC LESS-THAN BRACKET'
let s:d[0x2994]='RIGHT ARC GREATER-THAN BRACKET'
let s:d[0x2995]='DOUBLE LEFT ARC GREATER-THAN BRACKET'
let s:d[0x2996]='DOUBLE RIGHT ARC LESS-THAN BRACKET'
let s:d[0x2997]='LEFT BLACK TORTOISE SHELL BRACKET'
let s:d[0x2998]='RIGHT BLACK TORTOISE SHELL BRACKET'
let s:d[0x2999]='DOTTED FENCE'
let s:d[0x299A]='VERTICAL ZIGZAG LINE'
let s:d[0x299B]='MEASURED ANGLE OPENING LEFT'
let s:d[0x299C]='RIGHT ANGLE VARIANT WITH SQUARE'
let s:d[0x299D]='MEASURED RIGHT ANGLE WITH DOT'
let s:d[0x299E]='ANGLE WITH S INSIDE'
let s:d[0x299F]='ACUTE ANGLE'
let s:d[0x29A0]='SPHERICAL ANGLE OPENING LEFT'
let s:d[0x29A1]='SPHERICAL ANGLE OPENING UP'
let s:d[0x29A2]='TURNED ANGLE'
let s:d[0x29A3]='REVERSED ANGLE'
let s:d[0x29A4]='ANGLE WITH UNDERBAR'
let s:d[0x29A5]='REVERSED ANGLE WITH UNDERBAR'
let s:d[0x29A6]='OBLIQUE ANGLE OPENING UP'
let s:d[0x29A7]='OBLIQUE ANGLE OPENING DOWN'
let s:d[0x29A8]='MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING UP AND RIGHT'
let s:d[0x29A9]='MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING UP AND LEFT'
let s:d[0x29AA]='MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING DOWN AND RIGHT'
let s:d[0x29AB]='MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING DOWN AND LEFT'
let s:d[0x29AC]='MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING RIGHT AND UP'
let s:d[0x29AD]='MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING LEFT AND UP'
let s:d[0x29AE]='MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING RIGHT AND DOWN'
let s:d[0x29AF]='MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING LEFT AND DOWN'
let s:d[0x29B0]='REVERSED EMPTY SET'
let s:d[0x29B1]='EMPTY SET WITH OVERBAR'
let s:d[0x29B2]='EMPTY SET WITH SMALL CIRCLE ABOVE'
let s:d[0x29B3]='EMPTY SET WITH RIGHT ARROW ABOVE'
let s:d[0x29B4]='EMPTY SET WITH LEFT ARROW ABOVE'
let s:d[0x29B5]='CIRCLE WITH HORIZONTAL BAR'
let s:d[0x29B6]='CIRCLED VERTICAL BAR'
let s:d[0x29B7]='CIRCLED PARALLEL'
let s:d[0x29B8]='CIRCLED REVERSE SOLIDUS'
let s:d[0x29B9]='CIRCLED PERPENDICULAR'
let s:d[0x29BA]='CIRCLE DIVIDED BY HORIZONTAL BAR AND TOP HALF DIVIDED BY VERTICAL BAR'
let s:d[0x29BB]='CIRCLE WITH SUPERIMPOSED X'
let s:d[0x29BC]='CIRCLED ANTICLOCKWISE-ROTATED DIVISION SIGN'
let s:d[0x29BD]='UP ARROW THROUGH CIRCLE'
let s:d[0x29BE]='CIRCLED WHITE BULLET'
let s:d[0x29BF]='CIRCLED BULLET'
let s:d[0x29C0]='CIRCLED LESS-THAN'
let s:d[0x29C1]='CIRCLED GREATER-THAN'
let s:d[0x29C2]='CIRCLE WITH SMALL CIRCLE TO THE RIGHT'
let s:d[0x29C3]='CIRCLE WITH TWO HORIZONTAL STROKES TO THE RIGHT'
let s:d[0x29C4]='SQUARED RISING DIAGONAL SLASH'
let s:d[0x29C5]='SQUARED FALLING DIAGONAL SLASH'
let s:d[0x29C6]='SQUARED ASTERISK'
let s:d[0x29C7]='SQUARED SMALL CIRCLE'
let s:d[0x29C8]='SQUARED SQUARE'
let s:d[0x29C9]='TWO JOINED SQUARES'
let s:d[0x29CA]='TRIANGLE WITH DOT ABOVE'
let s:d[0x29CB]='TRIANGLE WITH UNDERBAR'
let s:d[0x29CC]='S IN TRIANGLE'
let s:d[0x29CD]='TRIANGLE WITH SERIFS AT BOTTOM'
let s:d[0x29CE]='RIGHT TRIANGLE ABOVE LEFT TRIANGLE'
let s:d[0x29CF]='LEFT TRIANGLE BESIDE VERTICAL BAR'
let s:d[0x29D0]='VERTICAL BAR BESIDE RIGHT TRIANGLE'
let s:d[0x29D1]='BOWTIE WITH LEFT HALF BLACK'
let s:d[0x29D2]='BOWTIE WITH RIGHT HALF BLACK'
let s:d[0x29D3]='BLACK BOWTIE'
let s:d[0x29D4]='TIMES WITH LEFT HALF BLACK'
let s:d[0x29D5]='TIMES WITH RIGHT HALF BLACK'
let s:d[0x29D6]='WHITE HOURGLASS'
let s:d[0x29D7]='BLACK HOURGLASS'
let s:d[0x29D8]='LEFT WIGGLY FENCE'
let s:d[0x29D9]='RIGHT WIGGLY FENCE'
let s:d[0x29DA]='LEFT DOUBLE WIGGLY FENCE'
let s:d[0x29DB]='RIGHT DOUBLE WIGGLY FENCE'
let s:d[0x29DC]='INCOMPLETE INFINITY'
let s:d[0x29DD]='TIE OVER INFINITY'
let s:d[0x29DE]='INFINITY NEGATED WITH VERTICAL BAR'
let s:d[0x29DF]='DOUBLE-ENDED MULTIMAP'
let s:d[0x29E0]='SQUARE WITH CONTOURED OUTLINE'
let s:d[0x29E1]='INCREASES AS'
let s:d[0x29E2]='SHUFFLE PRODUCT'
let s:d[0x29E3]='EQUALS SIGN AND SLANTED PARALLEL'
let s:d[0x29E4]='EQUALS SIGN AND SLANTED PARALLEL WITH TILDE ABOVE'
let s:d[0x29E5]='IDENTICAL TO AND SLANTED PARALLEL'
let s:d[0x29E6]='GLEICH STARK'
let s:d[0x29E7]='THERMODYNAMIC'
let s:d[0x29E8]='DOWN-POINTING TRIANGLE WITH LEFT HALF BLACK'
let s:d[0x29E9]='DOWN-POINTING TRIANGLE WITH RIGHT HALF BLACK'
let s:d[0x29EA]='BLACK DIAMOND WITH DOWN ARROW'
let s:d[0x29EB]='BLACK LOZENGE'
let s:d[0x29EC]='WHITE CIRCLE WITH DOWN ARROW'
let s:d[0x29ED]='BLACK CIRCLE WITH DOWN ARROW'
let s:d[0x29EE]='ERROR-BARRED WHITE SQUARE'
let s:d[0x29EF]='ERROR-BARRED BLACK SQUARE'
let s:d[0x29F0]='ERROR-BARRED WHITE DIAMOND'
let s:d[0x29F1]='ERROR-BARRED BLACK DIAMOND'
let s:d[0x29F2]='ERROR-BARRED WHITE CIRCLE'
let s:d[0x29F3]='ERROR-BARRED BLACK CIRCLE'
let s:d[0x29F4]='RULE-DELAYED'
let s:d[0x29F5]='REVERSE SOLIDUS OPERATOR'
let s:d[0x29F6]='SOLIDUS WITH OVERBAR'
let s:d[0x29F7]='REVERSE SOLIDUS WITH HORIZONTAL STROKE'
let s:d[0x29F8]='BIG SOLIDUS'
let s:d[0x29F9]='BIG REVERSE SOLIDUS'
let s:d[0x29FA]='DOUBLE PLUS'
let s:d[0x29FB]='TRIPLE PLUS'
let s:d[0x29FC]='LEFT-POINTING CURVED ANGLE BRACKET'
let s:d[0x29FD]='RIGHT-POINTING CURVED ANGLE BRACKET'
let s:d[0x29FE]='TINY'
let s:d[0x29FF]='MINY'
let s:d[0x2A00]='N-ARY CIRCLED DOT OPERATOR'
let s:d[0x2A01]='N-ARY CIRCLED PLUS OPERATOR'
let s:d[0x2A02]='N-ARY CIRCLED TIMES OPERATOR'
let s:d[0x2A03]='N-ARY UNION OPERATOR WITH DOT'
let s:d[0x2A04]='N-ARY UNION OPERATOR WITH PLUS'
let s:d[0x2A05]='N-ARY SQUARE INTERSECTION OPERATOR'
let s:d[0x2A06]='N-ARY SQUARE UNION OPERATOR'
let s:d[0x2A07]='TWO LOGICAL AND OPERATOR'
let s:d[0x2A08]='TWO LOGICAL OR OPERATOR'
let s:d[0x2A09]='N-ARY TIMES OPERATOR'
let s:d[0x2A0A]='MODULO TWO SUM'
let s:d[0x2A0B]='SUMMATION WITH INTEGRAL'
let s:d[0x2A0C]='QUADRUPLE INTEGRAL OPERATOR'
let s:d[0x2A0D]='FINITE PART INTEGRAL'
let s:d[0x2A0E]='INTEGRAL WITH DOUBLE STROKE'
let s:d[0x2A0F]='INTEGRAL AVERAGE WITH SLASH'
let s:d[0x2A10]='CIRCULATION FUNCTION'
let s:d[0x2A11]='ANTICLOCKWISE INTEGRATION'
let s:d[0x2A12]='LINE INTEGRATION WITH RECTANGULAR PATH AROUND POLE'
let s:d[0x2A13]='LINE INTEGRATION WITH SEMICIRCULAR PATH AROUND POLE'
let s:d[0x2A14]='LINE INTEGRATION NOT INCLUDING THE POLE'
let s:d[0x2A15]='INTEGRAL AROUND A POINT OPERATOR'
let s:d[0x2A16]='QUATERNION INTEGRAL OPERATOR'
let s:d[0x2A17]='INTEGRAL WITH LEFTWARDS ARROW WITH HOOK'
let s:d[0x2A18]='INTEGRAL WITH TIMES SIGN'
let s:d[0x2A19]='INTEGRAL WITH INTERSECTION'
let s:d[0x2A1A]='INTEGRAL WITH UNION'
let s:d[0x2A1B]='INTEGRAL WITH OVERBAR'
let s:d[0x2A1C]='INTEGRAL WITH UNDERBAR'
let s:d[0x2A1D]='JOIN'
let s:d[0x2A1E]='LARGE LEFT TRIANGLE OPERATOR'
let s:d[0x2A1F]='Z NOTATION SCHEMA COMPOSITION'
let s:d[0x2A20]='Z NOTATION SCHEMA PIPING'
let s:d[0x2A21]='Z NOTATION SCHEMA PROJECTION'
let s:d[0x2A22]='PLUS SIGN WITH SMALL CIRCLE ABOVE'
let s:d[0x2A23]='PLUS SIGN WITH CIRCUMFLEX ACCENT ABOVE'
let s:d[0x2A24]='PLUS SIGN WITH TILDE ABOVE'
let s:d[0x2A25]='PLUS SIGN WITH DOT BELOW'
let s:d[0x2A26]='PLUS SIGN WITH TILDE BELOW'
let s:d[0x2A27]='PLUS SIGN WITH SUBSCRIPT TWO'
let s:d[0x2A28]='PLUS SIGN WITH BLACK TRIANGLE'
let s:d[0x2A29]='MINUS SIGN WITH COMMA ABOVE'
let s:d[0x2A2A]='MINUS SIGN WITH DOT BELOW'
let s:d[0x2A2B]='MINUS SIGN WITH FALLING DOTS'
let s:d[0x2A2C]='MINUS SIGN WITH RISING DOTS'
let s:d[0x2A2D]='PLUS SIGN IN LEFT HALF CIRCLE'
let s:d[0x2A2E]='PLUS SIGN IN RIGHT HALF CIRCLE'
let s:d[0x2A2F]='VECTOR OR CROSS PRODUCT'
let s:d[0x2A30]='MULTIPLICATION SIGN WITH DOT ABOVE'
let s:d[0x2A31]='MULTIPLICATION SIGN WITH UNDERBAR'
let s:d[0x2A32]='SEMIDIRECT PRODUCT WITH BOTTOM CLOSED'
let s:d[0x2A33]='SMASH PRODUCT'
let s:d[0x2A34]='MULTIPLICATION SIGN IN LEFT HALF CIRCLE'
let s:d[0x2A35]='MULTIPLICATION SIGN IN RIGHT HALF CIRCLE'
let s:d[0x2A36]='CIRCLED MULTIPLICATION SIGN WITH CIRCUMFLEX ACCENT'
let s:d[0x2A37]='MULTIPLICATION SIGN IN DOUBLE CIRCLE'
let s:d[0x2A38]='CIRCLED DIVISION SIGN'
let s:d[0x2A39]='PLUS SIGN IN TRIANGLE'
let s:d[0x2A3A]='MINUS SIGN IN TRIANGLE'
let s:d[0x2A3B]='MULTIPLICATION SIGN IN TRIANGLE'
let s:d[0x2A3C]='INTERIOR PRODUCT'
let s:d[0x2A3D]='RIGHTHAND INTERIOR PRODUCT'
let s:d[0x2A3E]='Z NOTATION RELATIONAL COMPOSITION'
let s:d[0x2A3F]='AMALGAMATION OR COPRODUCT'
let s:d[0x2A40]='INTERSECTION WITH DOT'
let s:d[0x2A41]='UNION WITH MINUS SIGN'
let s:d[0x2A42]='UNION WITH OVERBAR'
let s:d[0x2A43]='INTERSECTION WITH OVERBAR'
let s:d[0x2A44]='INTERSECTION WITH LOGICAL AND'
let s:d[0x2A45]='UNION WITH LOGICAL OR'
let s:d[0x2A46]='UNION ABOVE INTERSECTION'
let s:d[0x2A47]='INTERSECTION ABOVE UNION'
let s:d[0x2A48]='UNION ABOVE BAR ABOVE INTERSECTION'
let s:d[0x2A49]='INTERSECTION ABOVE BAR ABOVE UNION'
let s:d[0x2A4A]='UNION BESIDE AND JOINED WITH UNION'
let s:d[0x2A4B]='INTERSECTION BESIDE AND JOINED WITH INTERSECTION'
let s:d[0x2A4C]='CLOSED UNION WITH SERIFS'
let s:d[0x2A4D]='CLOSED INTERSECTION WITH SERIFS'
let s:d[0x2A4E]='DOUBLE SQUARE INTERSECTION'
let s:d[0x2A4F]='DOUBLE SQUARE UNION'
let s:d[0x2A50]='CLOSED UNION WITH SERIFS AND SMASH PRODUCT'
let s:d[0x2A51]='LOGICAL AND WITH DOT ABOVE'
let s:d[0x2A52]='LOGICAL OR WITH DOT ABOVE'
let s:d[0x2A53]='DOUBLE LOGICAL AND'
let s:d[0x2A54]='DOUBLE LOGICAL OR'
let s:d[0x2A55]='TWO INTERSECTING LOGICAL AND'
let s:d[0x2A56]='TWO INTERSECTING LOGICAL OR'
let s:d[0x2A57]='SLOPING LARGE OR'
let s:d[0x2A58]='SLOPING LARGE AND'
let s:d[0x2A59]='LOGICAL OR OVERLAPPING LOGICAL AND'
let s:d[0x2A5A]='LOGICAL AND WITH MIDDLE STEM'
let s:d[0x2A5B]='LOGICAL OR WITH MIDDLE STEM'
let s:d[0x2A5C]='LOGICAL AND WITH HORIZONTAL DASH'
let s:d[0x2A5D]='LOGICAL OR WITH HORIZONTAL DASH'
let s:d[0x2A5E]='LOGICAL AND WITH DOUBLE OVERBAR'
let s:d[0x2A5F]='LOGICAL AND WITH UNDERBAR'
let s:d[0x2A60]='LOGICAL AND WITH DOUBLE UNDERBAR'
let s:d[0x2A61]='SMALL VEE WITH UNDERBAR'
let s:d[0x2A62]='LOGICAL OR WITH DOUBLE OVERBAR'
let s:d[0x2A63]='LOGICAL OR WITH DOUBLE UNDERBAR'
let s:d[0x2A64]='Z NOTATION DOMAIN ANTIRESTRICTION'
let s:d[0x2A65]='Z NOTATION RANGE ANTIRESTRICTION'
let s:d[0x2A66]='EQUALS SIGN WITH DOT BELOW'
let s:d[0x2A67]='IDENTICAL WITH DOT ABOVE'
let s:d[0x2A68]='TRIPLE HORIZONTAL BAR WITH DOUBLE VERTICAL STROKE'
let s:d[0x2A69]='TRIPLE HORIZONTAL BAR WITH TRIPLE VERTICAL STROKE'
let s:d[0x2A6A]='TILDE OPERATOR WITH DOT ABOVE'
let s:d[0x2A6B]='TILDE OPERATOR WITH RISING DOTS'
let s:d[0x2A6C]='SIMILAR MINUS SIMILAR'
let s:d[0x2A6D]='CONGRUENT WITH DOT ABOVE'
let s:d[0x2A6E]='EQUALS WITH ASTERISK'
let s:d[0x2A6F]='ALMOST EQUAL TO WITH CIRCUMFLEX ACCENT'
let s:d[0x2A70]='APPROXIMATELY EQUAL OR EQUAL TO'
let s:d[0x2A71]='EQUALS SIGN ABOVE PLUS SIGN'
let s:d[0x2A72]='PLUS SIGN ABOVE EQUALS SIGN'
let s:d[0x2A73]='EQUALS SIGN ABOVE TILDE OPERATOR'
let s:d[0x2A74]='DOUBLE COLON EQUAL'
let s:d[0x2A75]='TWO CONSECUTIVE EQUALS SIGNS'
let s:d[0x2A76]='THREE CONSECUTIVE EQUALS SIGNS'
let s:d[0x2A77]='EQUALS SIGN WITH TWO DOTS ABOVE AND TWO DOTS BELOW'
let s:d[0x2A78]='EQUIVALENT WITH FOUR DOTS ABOVE'
let s:d[0x2A79]='LESS-THAN WITH CIRCLE INSIDE'
let s:d[0x2A7A]='GREATER-THAN WITH CIRCLE INSIDE'
let s:d[0x2A7B]='LESS-THAN WITH QUESTION MARK ABOVE'
let s:d[0x2A7C]='GREATER-THAN WITH QUESTION MARK ABOVE'
let s:d[0x2A7D]='LESS-THAN OR SLANTED EQUAL TO'
let s:d[0x2A7E]='GREATER-THAN OR SLANTED EQUAL TO'
let s:d[0x2A7F]='LESS-THAN OR SLANTED EQUAL TO WITH DOT INSIDE'
let s:d[0x2A80]='GREATER-THAN OR SLANTED EQUAL TO WITH DOT INSIDE'
let s:d[0x2A81]='LESS-THAN OR SLANTED EQUAL TO WITH DOT ABOVE'
let s:d[0x2A82]='GREATER-THAN OR SLANTED EQUAL TO WITH DOT ABOVE'
let s:d[0x2A83]='LESS-THAN OR SLANTED EQUAL TO WITH DOT ABOVE RIGHT'
let s:d[0x2A84]='GREATER-THAN OR SLANTED EQUAL TO WITH DOT ABOVE LEFT'
let s:d[0x2A85]='LESS-THAN OR APPROXIMATE'
let s:d[0x2A86]='GREATER-THAN OR APPROXIMATE'
let s:d[0x2A87]='LESS-THAN AND SINGLE-LINE NOT EQUAL TO'
let s:d[0x2A88]='GREATER-THAN AND SINGLE-LINE NOT EQUAL TO'
let s:d[0x2A89]='LESS-THAN AND NOT APPROXIMATE'
let s:d[0x2A8A]='GREATER-THAN AND NOT APPROXIMATE'
let s:d[0x2A8B]='LESS-THAN ABOVE DOUBLE-LINE EQUAL ABOVE GREATER-THAN'
let s:d[0x2A8C]='GREATER-THAN ABOVE DOUBLE-LINE EQUAL ABOVE LESS-THAN'
let s:d[0x2A8D]='LESS-THAN ABOVE SIMILAR OR EQUAL'
let s:d[0x2A8E]='GREATER-THAN ABOVE SIMILAR OR EQUAL'
let s:d[0x2A8F]='LESS-THAN ABOVE SIMILAR ABOVE GREATER-THAN'
let s:d[0x2A90]='GREATER-THAN ABOVE SIMILAR ABOVE LESS-THAN'
let s:d[0x2A91]='LESS-THAN ABOVE GREATER-THAN ABOVE DOUBLE-LINE EQUAL'
let s:d[0x2A92]='GREATER-THAN ABOVE LESS-THAN ABOVE DOUBLE-LINE EQUAL'
let s:d[0x2A93]='LESS-THAN ABOVE SLANTED EQUAL ABOVE GREATER-THAN ABOVE SLANTED EQUAL'
let s:d[0x2A94]='GREATER-THAN ABOVE SLANTED EQUAL ABOVE LESS-THAN ABOVE SLANTED EQUAL'
let s:d[0x2A95]='SLANTED EQUAL TO OR LESS-THAN'
let s:d[0x2A96]='SLANTED EQUAL TO OR GREATER-THAN'
let s:d[0x2A97]='SLANTED EQUAL TO OR LESS-THAN WITH DOT INSIDE'
let s:d[0x2A98]='SLANTED EQUAL TO OR GREATER-THAN WITH DOT INSIDE'
let s:d[0x2A99]='DOUBLE-LINE EQUAL TO OR LESS-THAN'
let s:d[0x2A9A]='DOUBLE-LINE EQUAL TO OR GREATER-THAN'
let s:d[0x2A9B]='DOUBLE-LINE SLANTED EQUAL TO OR LESS-THAN'
let s:d[0x2A9C]='DOUBLE-LINE SLANTED EQUAL TO OR GREATER-THAN'
let s:d[0x2A9D]='SIMILAR OR LESS-THAN'
let s:d[0x2A9E]='SIMILAR OR GREATER-THAN'
let s:d[0x2A9F]='SIMILAR ABOVE LESS-THAN ABOVE EQUALS SIGN'
let s:d[0x2AA0]='SIMILAR ABOVE GREATER-THAN ABOVE EQUALS SIGN'
let s:d[0x2AA1]='DOUBLE NESTED LESS-THAN'
let s:d[0x2AA2]='DOUBLE NESTED GREATER-THAN'
let s:d[0x2AA3]='DOUBLE NESTED LESS-THAN WITH UNDERBAR'
let s:d[0x2AA4]='GREATER-THAN OVERLAPPING LESS-THAN'
let s:d[0x2AA5]='GREATER-THAN BESIDE LESS-THAN'
let s:d[0x2AA6]='LESS-THAN CLOSED BY CURVE'
let s:d[0x2AA7]='GREATER-THAN CLOSED BY CURVE'
let s:d[0x2AA8]='LESS-THAN CLOSED BY CURVE ABOVE SLANTED EQUAL'
let s:d[0x2AA9]='GREATER-THAN CLOSED BY CURVE ABOVE SLANTED EQUAL'
let s:d[0x2AAA]='SMALLER THAN'
let s:d[0x2AAB]='LARGER THAN'
let s:d[0x2AAC]='SMALLER THAN OR EQUAL TO'
let s:d[0x2AAD]='LARGER THAN OR EQUAL TO'
let s:d[0x2AAE]='EQUALS SIGN WITH BUMPY ABOVE'
let s:d[0x2AAF]='PRECEDES ABOVE SINGLE-LINE EQUALS SIGN'
let s:d[0x2AB0]='SUCCEEDS ABOVE SINGLE-LINE EQUALS SIGN'
let s:d[0x2AB1]='PRECEDES ABOVE SINGLE-LINE NOT EQUAL TO'
let s:d[0x2AB2]='SUCCEEDS ABOVE SINGLE-LINE NOT EQUAL TO'
let s:d[0x2AB3]='PRECEDES ABOVE EQUALS SIGN'
let s:d[0x2AB4]='SUCCEEDS ABOVE EQUALS SIGN'
let s:d[0x2AB5]='PRECEDES ABOVE NOT EQUAL TO'
let s:d[0x2AB6]='SUCCEEDS ABOVE NOT EQUAL TO'
let s:d[0x2AB7]='PRECEDES ABOVE ALMOST EQUAL TO'
let s:d[0x2AB8]='SUCCEEDS ABOVE ALMOST EQUAL TO'
let s:d[0x2AB9]='PRECEDES ABOVE NOT ALMOST EQUAL TO'
let s:d[0x2ABA]='SUCCEEDS ABOVE NOT ALMOST EQUAL TO'
let s:d[0x2ABB]='DOUBLE PRECEDES'
let s:d[0x2ABC]='DOUBLE SUCCEEDS'
let s:d[0x2ABD]='SUBSET WITH DOT'
let s:d[0x2ABE]='SUPERSET WITH DOT'
let s:d[0x2ABF]='SUBSET WITH PLUS SIGN BELOW'
let s:d[0x2AC0]='SUPERSET WITH PLUS SIGN BELOW'
let s:d[0x2AC1]='SUBSET WITH MULTIPLICATION SIGN BELOW'
let s:d[0x2AC2]='SUPERSET WITH MULTIPLICATION SIGN BELOW'
let s:d[0x2AC3]='SUBSET OF OR EQUAL TO WITH DOT ABOVE'
let s:d[0x2AC4]='SUPERSET OF OR EQUAL TO WITH DOT ABOVE'
let s:d[0x2AC5]='SUBSET OF ABOVE EQUALS SIGN'
let s:d[0x2AC6]='SUPERSET OF ABOVE EQUALS SIGN'
let s:d[0x2AC7]='SUBSET OF ABOVE TILDE OPERATOR'
let s:d[0x2AC8]='SUPERSET OF ABOVE TILDE OPERATOR'
let s:d[0x2AC9]='SUBSET OF ABOVE ALMOST EQUAL TO'
let s:d[0x2ACA]='SUPERSET OF ABOVE ALMOST EQUAL TO'
let s:d[0x2ACB]='SUBSET OF ABOVE NOT EQUAL TO'
let s:d[0x2ACC]='SUPERSET OF ABOVE NOT EQUAL TO'
let s:d[0x2ACD]='SQUARE LEFT OPEN BOX OPERATOR'
let s:d[0x2ACE]='SQUARE RIGHT OPEN BOX OPERATOR'
let s:d[0x2ACF]='CLOSED SUBSET'
let s:d[0x2AD0]='CLOSED SUPERSET'
let s:d[0x2AD1]='CLOSED SUBSET OR EQUAL TO'
let s:d[0x2AD2]='CLOSED SUPERSET OR EQUAL TO'
let s:d[0x2AD3]='SUBSET ABOVE SUPERSET'
let s:d[0x2AD4]='SUPERSET ABOVE SUBSET'
let s:d[0x2AD5]='SUBSET ABOVE SUBSET'
let s:d[0x2AD6]='SUPERSET ABOVE SUPERSET'
let s:d[0x2AD7]='SUPERSET BESIDE SUBSET'
let s:d[0x2AD8]='SUPERSET BESIDE AND JOINED BY DASH WITH SUBSET'
let s:d[0x2AD9]='ELEMENT OF OPENING DOWNWARDS'
let s:d[0x2ADA]='PITCHFORK WITH TEE TOP'
let s:d[0x2ADB]='TRANSVERSAL INTERSECTION'
let s:d[0x2ADC]='FORKING'
let s:d[0x2ADD]='NONFORKING'
let s:d[0x2ADE]='SHORT LEFT TACK'
let s:d[0x2ADF]='SHORT DOWN TACK'
let s:d[0x2AE0]='SHORT UP TACK'
let s:d[0x2AE1]='PERPENDICULAR WITH S'
let s:d[0x2AE2]='VERTICAL BAR TRIPLE RIGHT TURNSTILE'
let s:d[0x2AE3]='DOUBLE VERTICAL BAR LEFT TURNSTILE'
let s:d[0x2AE4]='VERTICAL BAR DOUBLE LEFT TURNSTILE'
let s:d[0x2AE5]='DOUBLE VERTICAL BAR DOUBLE LEFT TURNSTILE'
let s:d[0x2AE6]='LONG DASH FROM LEFT MEMBER OF DOUBLE VERTICAL'
let s:d[0x2AE7]='SHORT DOWN TACK WITH OVERBAR'
let s:d[0x2AE8]='SHORT UP TACK WITH UNDERBAR'
let s:d[0x2AE9]='SHORT UP TACK ABOVE SHORT DOWN TACK'
let s:d[0x2AEA]='DOUBLE DOWN TACK'
let s:d[0x2AEB]='DOUBLE UP TACK'
let s:d[0x2AEC]='DOUBLE STROKE NOT SIGN'
let s:d[0x2AED]='REVERSED DOUBLE STROKE NOT SIGN'
let s:d[0x2AEE]='DOES NOT DIVIDE WITH REVERSED NEGATION SLASH'
let s:d[0x2AEF]='VERTICAL LINE WITH CIRCLE ABOVE'
let s:d[0x2AF0]='VERTICAL LINE WITH CIRCLE BELOW'
let s:d[0x2AF1]='DOWN TACK WITH CIRCLE BELOW'
let s:d[0x2AF2]='PARALLEL WITH HORIZONTAL STROKE'
let s:d[0x2AF3]='PARALLEL WITH TILDE OPERATOR'
let s:d[0x2AF4]='TRIPLE VERTICAL BAR BINARY RELATION'
let s:d[0x2AF5]='TRIPLE VERTICAL BAR WITH HORIZONTAL STROKE'
let s:d[0x2AF6]='TRIPLE COLON OPERATOR'
let s:d[0x2AF7]='TRIPLE NESTED LESS-THAN'
let s:d[0x2AF8]='TRIPLE NESTED GREATER-THAN'
let s:d[0x2AF9]='DOUBLE-LINE SLANTED LESS-THAN OR EQUAL TO'
let s:d[0x2AFA]='DOUBLE-LINE SLANTED GREATER-THAN OR EQUAL TO'
let s:d[0x2AFB]='TRIPLE SOLIDUS BINARY RELATION'
let s:d[0x2AFC]='LARGE TRIPLE VERTICAL BAR OPERATOR'
let s:d[0x2AFD]='DOUBLE SOLIDUS OPERATOR'
let s:d[0x2AFE]='WHITE VERTICAL BAR'
let s:d[0x2AFF]='N-ARY WHITE VERTICAL BAR'
let s:d[0x2B00]='NORTH EAST WHITE ARROW'
let s:d[0x2B01]='NORTH WEST WHITE ARROW'
let s:d[0x2B02]='SOUTH EAST WHITE ARROW'
let s:d[0x2B03]='SOUTH WEST WHITE ARROW'
let s:d[0x2B04]='LEFT RIGHT WHITE ARROW'
let s:d[0x2B05]='LEFTWARDS BLACK ARROW'
let s:d[0x2B06]='UPWARDS BLACK ARROW'
let s:d[0x2B07]='DOWNWARDS BLACK ARROW'
let s:d[0x2B08]='NORTH EAST BLACK ARROW'
let s:d[0x2B09]='NORTH WEST BLACK ARROW'
let s:d[0x2B0A]='SOUTH EAST BLACK ARROW'
let s:d[0x2B0B]='SOUTH WEST BLACK ARROW'
let s:d[0x2B0C]='LEFT RIGHT BLACK ARROW'
let s:d[0x2B0D]='UP DOWN BLACK ARROW'
let s:d[0x2B0E]='RIGHTWARDS ARROW WITH TIP DOWNWARDS'
let s:d[0x2B0F]='RIGHTWARDS ARROW WITH TIP UPWARDS'
let s:d[0x2B10]='LEFTWARDS ARROW WITH TIP DOWNWARDS'
let s:d[0x2B11]='LEFTWARDS ARROW WITH TIP UPWARDS'
let s:d[0x2B12]='SQUARE WITH TOP HALF BLACK'
let s:d[0x2B13]='SQUARE WITH BOTTOM HALF BLACK'
let s:d[0x2B14]='SQUARE WITH UPPER RIGHT DIAGONAL HALF BLACK'
let s:d[0x2B15]='SQUARE WITH LOWER LEFT DIAGONAL HALF BLACK'
let s:d[0x2B16]='DIAMOND WITH LEFT HALF BLACK'
let s:d[0x2B17]='DIAMOND WITH RIGHT HALF BLACK'
let s:d[0x2B18]='DIAMOND WITH TOP HALF BLACK'
let s:d[0x2B19]='DIAMOND WITH BOTTOM HALF BLACK'
let s:d[0x2B1A]='DOTTED SQUARE'
let s:d[0x2B1B]='BLACK LARGE SQUARE'
let s:d[0x2B1C]='WHITE LARGE SQUARE'
let s:d[0x2B1D]='BLACK VERY SMALL SQUARE'
let s:d[0x2B1E]='WHITE VERY SMALL SQUARE'
let s:d[0x2B1F]='BLACK PENTAGON'
let s:d[0x2B20]='WHITE PENTAGON'
let s:d[0x2B21]='WHITE HEXAGON'
let s:d[0x2B22]='BLACK HEXAGON'
let s:d[0x2B23]='HORIZONTAL BLACK HEXAGON'
let s:d[0x2B24]='BLACK LARGE CIRCLE'
let s:d[0x2B25]='BLACK MEDIUM DIAMOND'
let s:d[0x2B26]='WHITE MEDIUM DIAMOND'
let s:d[0x2B27]='BLACK MEDIUM LOZENGE'
let s:d[0x2B28]='WHITE MEDIUM LOZENGE'
let s:d[0x2B29]='BLACK SMALL DIAMOND'
let s:d[0x2B2A]='BLACK SMALL LOZENGE'
let s:d[0x2B2B]='WHITE SMALL LOZENGE'
let s:d[0x2B2C]='BLACK HORIZONTAL ELLIPSE'
let s:d[0x2B2D]='WHITE HORIZONTAL ELLIPSE'
let s:d[0x2B2E]='BLACK VERTICAL ELLIPSE'
let s:d[0x2B2F]='WHITE VERTICAL ELLIPSE'
let s:d[0x2B30]='LEFT ARROW WITH SMALL CIRCLE'
let s:d[0x2B31]='THREE LEFTWARDS ARROWS'
let s:d[0x2B32]='LEFT ARROW WITH CIRCLED PLUS'
let s:d[0x2B33]='LONG LEFTWARDS SQUIGGLE ARROW'
let s:d[0x2B34]='LEFTWARDS TWO-HEADED ARROW WITH VERTICAL STROKE'
let s:d[0x2B35]='LEFTWARDS TWO-HEADED ARROW WITH DOUBLE VERTICAL STROKE'
let s:d[0x2B36]='LEFTWARDS TWO-HEADED ARROW FROM BAR'
let s:d[0x2B37]='LEFTWARDS TWO-HEADED TRIPLE DASH ARROW'
let s:d[0x2B38]='LEFTWARDS ARROW WITH DOTTED STEM'
let s:d[0x2B39]='LEFTWARDS ARROW WITH TAIL WITH VERTICAL STROKE'
let s:d[0x2B3A]='LEFTWARDS ARROW WITH TAIL WITH DOUBLE VERTICAL STROKE'
let s:d[0x2B3B]='LEFTWARDS TWO-HEADED ARROW WITH TAIL'
let s:d[0x2B3C]='LEFTWARDS TWO-HEADED ARROW WITH TAIL WITH VERTICAL STROKE'
let s:d[0x2B3D]='LEFTWARDS TWO-HEADED ARROW WITH TAIL WITH DOUBLE VERTICAL STROKE'
let s:d[0x2B3E]='LEFTWARDS ARROW THROUGH X'
let s:d[0x2B3F]='WAVE ARROW POINTING DIRECTLY LEFT'
let s:d[0x2B40]='EQUALS SIGN ABOVE LEFTWARDS ARROW'
let s:d[0x2B41]='REVERSE TILDE OPERATOR ABOVE LEFTWARDS ARROW'
let s:d[0x2B42]='LEFTWARDS ARROW ABOVE REVERSE ALMOST EQUAL TO'
let s:d[0x2B43]='RIGHTWARDS ARROW THROUGH GREATER-THAN'
let s:d[0x2B44]='RIGHTWARDS ARROW THROUGH SUPERSET'
let s:d[0x2B45]='LEFTWARDS QUADRUPLE ARROW'
let s:d[0x2B46]='RIGHTWARDS QUADRUPLE ARROW'
let s:d[0x2B47]='REVERSE TILDE OPERATOR ABOVE RIGHTWARDS ARROW'
let s:d[0x2B48]='RIGHTWARDS ARROW ABOVE REVERSE ALMOST EQUAL TO'
let s:d[0x2B49]='TILDE OPERATOR ABOVE LEFTWARDS ARROW'
let s:d[0x2B4A]='LEFTWARDS ARROW ABOVE ALMOST EQUAL TO'
let s:d[0x2B4B]='LEFTWARDS ARROW ABOVE REVERSE TILDE OPERATOR'
let s:d[0x2B4C]='RIGHTWARDS ARROW ABOVE REVERSE TILDE OPERATOR'
let s:d[0x2B50]='WHITE MEDIUM STAR'
let s:d[0x2B51]='BLACK SMALL STAR'
let s:d[0x2B52]='WHITE SMALL STAR'
let s:d[0x2B53]='BLACK RIGHT-POINTING PENTAGON'
let s:d[0x2B54]='WHITE RIGHT-POINTING PENTAGON'
let s:d[0x2B55]='HEAVY LARGE CIRCLE'
let s:d[0x2B56]='HEAVY OVAL WITH OVAL INSIDE'
let s:d[0x2B57]='HEAVY CIRCLE WITH CIRCLE INSIDE'
let s:d[0x2B58]='HEAVY CIRCLE'
let s:d[0x2B59]='HEAVY CIRCLED SALTIRE'
let s:d[0x2C00]='GLAGOLITIC CAPITAL LETTER AZU'
let s:d[0x2C01]='GLAGOLITIC CAPITAL LETTER BUKY'
let s:d[0x2C02]='GLAGOLITIC CAPITAL LETTER VEDE'
let s:d[0x2C03]='GLAGOLITIC CAPITAL LETTER GLAGOLI'
let s:d[0x2C04]='GLAGOLITIC CAPITAL LETTER DOBRO'
let s:d[0x2C05]='GLAGOLITIC CAPITAL LETTER YESTU'
let s:d[0x2C06]='GLAGOLITIC CAPITAL LETTER ZHIVETE'
let s:d[0x2C07]='GLAGOLITIC CAPITAL LETTER DZELO'
let s:d[0x2C08]='GLAGOLITIC CAPITAL LETTER ZEMLJA'
let s:d[0x2C09]='GLAGOLITIC CAPITAL LETTER IZHE'
let s:d[0x2C0A]='GLAGOLITIC CAPITAL LETTER INITIAL IZHE'
let s:d[0x2C0B]='GLAGOLITIC CAPITAL LETTER I'
let s:d[0x2C0C]='GLAGOLITIC CAPITAL LETTER DJERVI'
let s:d[0x2C0D]='GLAGOLITIC CAPITAL LETTER KAKO'
let s:d[0x2C0E]='GLAGOLITIC CAPITAL LETTER LJUDIJE'
let s:d[0x2C0F]='GLAGOLITIC CAPITAL LETTER MYSLITE'
let s:d[0x2C10]='GLAGOLITIC CAPITAL LETTER NASHI'
let s:d[0x2C11]='GLAGOLITIC CAPITAL LETTER ONU'
let s:d[0x2C12]='GLAGOLITIC CAPITAL LETTER POKOJI'
let s:d[0x2C13]='GLAGOLITIC CAPITAL LETTER RITSI'
let s:d[0x2C14]='GLAGOLITIC CAPITAL LETTER SLOVO'
let s:d[0x2C15]='GLAGOLITIC CAPITAL LETTER TVRIDO'
let s:d[0x2C16]='GLAGOLITIC CAPITAL LETTER UKU'
let s:d[0x2C17]='GLAGOLITIC CAPITAL LETTER FRITU'
let s:d[0x2C18]='GLAGOLITIC CAPITAL LETTER HERU'
let s:d[0x2C19]='GLAGOLITIC CAPITAL LETTER OTU'
let s:d[0x2C1A]='GLAGOLITIC CAPITAL LETTER PE'
let s:d[0x2C1B]='GLAGOLITIC CAPITAL LETTER SHTA'
let s:d[0x2C1C]='GLAGOLITIC CAPITAL LETTER TSI'
let s:d[0x2C1D]='GLAGOLITIC CAPITAL LETTER CHRIVI'
let s:d[0x2C1E]='GLAGOLITIC CAPITAL LETTER SHA'
let s:d[0x2C1F]='GLAGOLITIC CAPITAL LETTER YERU'
let s:d[0x2C20]='GLAGOLITIC CAPITAL LETTER YERI'
let s:d[0x2C21]='GLAGOLITIC CAPITAL LETTER YATI'
let s:d[0x2C22]='GLAGOLITIC CAPITAL LETTER SPIDERY HA'
let s:d[0x2C23]='GLAGOLITIC CAPITAL LETTER YU'
let s:d[0x2C24]='GLAGOLITIC CAPITAL LETTER SMALL YUS'
let s:d[0x2C25]='GLAGOLITIC CAPITAL LETTER SMALL YUS WITH TAIL'
let s:d[0x2C26]='GLAGOLITIC CAPITAL LETTER YO'
let s:d[0x2C27]='GLAGOLITIC CAPITAL LETTER IOTATED SMALL YUS'
let s:d[0x2C28]='GLAGOLITIC CAPITAL LETTER BIG YUS'
let s:d[0x2C29]='GLAGOLITIC CAPITAL LETTER IOTATED BIG YUS'
let s:d[0x2C2A]='GLAGOLITIC CAPITAL LETTER FITA'
let s:d[0x2C2B]='GLAGOLITIC CAPITAL LETTER IZHITSA'
let s:d[0x2C2C]='GLAGOLITIC CAPITAL LETTER SHTAPIC'
let s:d[0x2C2D]='GLAGOLITIC CAPITAL LETTER TROKUTASTI A'
let s:d[0x2C2E]='GLAGOLITIC CAPITAL LETTER LATINATE MYSLITE'
let s:d[0x2C30]='GLAGOLITIC SMALL LETTER AZU'
let s:d[0x2C31]='GLAGOLITIC SMALL LETTER BUKY'
let s:d[0x2C32]='GLAGOLITIC SMALL LETTER VEDE'
let s:d[0x2C33]='GLAGOLITIC SMALL LETTER GLAGOLI'
let s:d[0x2C34]='GLAGOLITIC SMALL LETTER DOBRO'
let s:d[0x2C35]='GLAGOLITIC SMALL LETTER YESTU'
let s:d[0x2C36]='GLAGOLITIC SMALL LETTER ZHIVETE'
let s:d[0x2C37]='GLAGOLITIC SMALL LETTER DZELO'
let s:d[0x2C38]='GLAGOLITIC SMALL LETTER ZEMLJA'
let s:d[0x2C39]='GLAGOLITIC SMALL LETTER IZHE'
let s:d[0x2C3A]='GLAGOLITIC SMALL LETTER INITIAL IZHE'
let s:d[0x2C3B]='GLAGOLITIC SMALL LETTER I'
let s:d[0x2C3C]='GLAGOLITIC SMALL LETTER DJERVI'
let s:d[0x2C3D]='GLAGOLITIC SMALL LETTER KAKO'
let s:d[0x2C3E]='GLAGOLITIC SMALL LETTER LJUDIJE'
let s:d[0x2C3F]='GLAGOLITIC SMALL LETTER MYSLITE'
let s:d[0x2C40]='GLAGOLITIC SMALL LETTER NASHI'
let s:d[0x2C41]='GLAGOLITIC SMALL LETTER ONU'
let s:d[0x2C42]='GLAGOLITIC SMALL LETTER POKOJI'
let s:d[0x2C43]='GLAGOLITIC SMALL LETTER RITSI'
let s:d[0x2C44]='GLAGOLITIC SMALL LETTER SLOVO'
let s:d[0x2C45]='GLAGOLITIC SMALL LETTER TVRIDO'
let s:d[0x2C46]='GLAGOLITIC SMALL LETTER UKU'
let s:d[0x2C47]='GLAGOLITIC SMALL LETTER FRITU'
let s:d[0x2C48]='GLAGOLITIC SMALL LETTER HERU'
let s:d[0x2C49]='GLAGOLITIC SMALL LETTER OTU'
let s:d[0x2C4A]='GLAGOLITIC SMALL LETTER PE'
let s:d[0x2C4B]='GLAGOLITIC SMALL LETTER SHTA'
let s:d[0x2C4C]='GLAGOLITIC SMALL LETTER TSI'
let s:d[0x2C4D]='GLAGOLITIC SMALL LETTER CHRIVI'
let s:d[0x2C4E]='GLAGOLITIC SMALL LETTER SHA'
let s:d[0x2C4F]='GLAGOLITIC SMALL LETTER YERU'
let s:d[0x2C50]='GLAGOLITIC SMALL LETTER YERI'
let s:d[0x2C51]='GLAGOLITIC SMALL LETTER YATI'
let s:d[0x2C52]='GLAGOLITIC SMALL LETTER SPIDERY HA'
let s:d[0x2C53]='GLAGOLITIC SMALL LETTER YU'
let s:d[0x2C54]='GLAGOLITIC SMALL LETTER SMALL YUS'
let s:d[0x2C55]='GLAGOLITIC SMALL LETTER SMALL YUS WITH TAIL'
let s:d[0x2C56]='GLAGOLITIC SMALL LETTER YO'
let s:d[0x2C57]='GLAGOLITIC SMALL LETTER IOTATED SMALL YUS'
let s:d[0x2C58]='GLAGOLITIC SMALL LETTER BIG YUS'
let s:d[0x2C59]='GLAGOLITIC SMALL LETTER IOTATED BIG YUS'
let s:d[0x2C5A]='GLAGOLITIC SMALL LETTER FITA'
let s:d[0x2C5B]='GLAGOLITIC SMALL LETTER IZHITSA'
let s:d[0x2C5C]='GLAGOLITIC SMALL LETTER SHTAPIC'
let s:d[0x2C5D]='GLAGOLITIC SMALL LETTER TROKUTASTI A'
let s:d[0x2C5E]='GLAGOLITIC SMALL LETTER LATINATE MYSLITE'
let s:d[0x2C60]='LATIN CAPITAL LETTER L WITH DOUBLE BAR'
let s:d[0x2C61]='LATIN SMALL LETTER L WITH DOUBLE BAR'
let s:d[0x2C62]='LATIN CAPITAL LETTER L WITH MIDDLE TILDE'
let s:d[0x2C63]='LATIN CAPITAL LETTER P WITH STROKE'
let s:d[0x2C64]='LATIN CAPITAL LETTER R WITH TAIL'
let s:d[0x2C65]='LATIN SMALL LETTER A WITH STROKE'
let s:d[0x2C66]='LATIN SMALL LETTER T WITH DIAGONAL STROKE'
let s:d[0x2C67]='LATIN CAPITAL LETTER H WITH DESCENDER'
let s:d[0x2C68]='LATIN SMALL LETTER H WITH DESCENDER'
let s:d[0x2C69]='LATIN CAPITAL LETTER K WITH DESCENDER'
let s:d[0x2C6A]='LATIN SMALL LETTER K WITH DESCENDER'
let s:d[0x2C6B]='LATIN CAPITAL LETTER Z WITH DESCENDER'
let s:d[0x2C6C]='LATIN SMALL LETTER Z WITH DESCENDER'
let s:d[0x2C6D]='LATIN CAPITAL LETTER ALPHA'
let s:d[0x2C6E]='LATIN CAPITAL LETTER M WITH HOOK'
let s:d[0x2C6F]='LATIN CAPITAL LETTER TURNED A'
let s:d[0x2C70]='LATIN CAPITAL LETTER TURNED ALPHA'
let s:d[0x2C71]='LATIN SMALL LETTER V WITH RIGHT HOOK'
let s:d[0x2C72]='LATIN CAPITAL LETTER W WITH HOOK'
let s:d[0x2C73]='LATIN SMALL LETTER W WITH HOOK'
let s:d[0x2C74]='LATIN SMALL LETTER V WITH CURL'
let s:d[0x2C75]='LATIN CAPITAL LETTER HALF H'
let s:d[0x2C76]='LATIN SMALL LETTER HALF H'
let s:d[0x2C77]='LATIN SMALL LETTER TAILLESS PHI'
let s:d[0x2C78]='LATIN SMALL LETTER E WITH NOTCH'
let s:d[0x2C79]='LATIN SMALL LETTER TURNED R WITH TAIL'
let s:d[0x2C7A]='LATIN SMALL LETTER O WITH LOW RING INSIDE'
let s:d[0x2C7B]='LATIN LETTER SMALL CAPITAL TURNED E'
let s:d[0x2C7C]='LATIN SUBSCRIPT SMALL LETTER J'
let s:d[0x2C7D]='MODIFIER LETTER CAPITAL V'
let s:d[0x2C7E]='LATIN CAPITAL LETTER S WITH SWASH TAIL'
let s:d[0x2C7F]='LATIN CAPITAL LETTER Z WITH SWASH TAIL'
let s:d[0x2C80]='COPTIC CAPITAL LETTER ALFA'
let s:d[0x2C81]='COPTIC SMALL LETTER ALFA'
let s:d[0x2C82]='COPTIC CAPITAL LETTER VIDA'
let s:d[0x2C83]='COPTIC SMALL LETTER VIDA'
let s:d[0x2C84]='COPTIC CAPITAL LETTER GAMMA'
let s:d[0x2C85]='COPTIC SMALL LETTER GAMMA'
let s:d[0x2C86]='COPTIC CAPITAL LETTER DALDA'
let s:d[0x2C87]='COPTIC SMALL LETTER DALDA'
let s:d[0x2C88]='COPTIC CAPITAL LETTER EIE'
let s:d[0x2C89]='COPTIC SMALL LETTER EIE'
let s:d[0x2C8A]='COPTIC CAPITAL LETTER SOU'
let s:d[0x2C8B]='COPTIC SMALL LETTER SOU'
let s:d[0x2C8C]='COPTIC CAPITAL LETTER ZATA'
let s:d[0x2C8D]='COPTIC SMALL LETTER ZATA'
let s:d[0x2C8E]='COPTIC CAPITAL LETTER HATE'
let s:d[0x2C8F]='COPTIC SMALL LETTER HATE'
let s:d[0x2C90]='COPTIC CAPITAL LETTER THETHE'
let s:d[0x2C91]='COPTIC SMALL LETTER THETHE'
let s:d[0x2C92]='COPTIC CAPITAL LETTER IAUDA'
let s:d[0x2C93]='COPTIC SMALL LETTER IAUDA'
let s:d[0x2C94]='COPTIC CAPITAL LETTER KAPA'
let s:d[0x2C95]='COPTIC SMALL LETTER KAPA'
let s:d[0x2C96]='COPTIC CAPITAL LETTER LAULA'
let s:d[0x2C97]='COPTIC SMALL LETTER LAULA'
let s:d[0x2C98]='COPTIC CAPITAL LETTER MI'
let s:d[0x2C99]='COPTIC SMALL LETTER MI'
let s:d[0x2C9A]='COPTIC CAPITAL LETTER NI'
let s:d[0x2C9B]='COPTIC SMALL LETTER NI'
let s:d[0x2C9C]='COPTIC CAPITAL LETTER KSI'
let s:d[0x2C9D]='COPTIC SMALL LETTER KSI'
let s:d[0x2C9E]='COPTIC CAPITAL LETTER O'
let s:d[0x2C9F]='COPTIC SMALL LETTER O'
let s:d[0x2CA0]='COPTIC CAPITAL LETTER PI'
let s:d[0x2CA1]='COPTIC SMALL LETTER PI'
let s:d[0x2CA2]='COPTIC CAPITAL LETTER RO'
let s:d[0x2CA3]='COPTIC SMALL LETTER RO'
let s:d[0x2CA4]='COPTIC CAPITAL LETTER SIMA'
let s:d[0x2CA5]='COPTIC SMALL LETTER SIMA'
let s:d[0x2CA6]='COPTIC CAPITAL LETTER TAU'
let s:d[0x2CA7]='COPTIC SMALL LETTER TAU'
let s:d[0x2CA8]='COPTIC CAPITAL LETTER UA'
let s:d[0x2CA9]='COPTIC SMALL LETTER UA'
let s:d[0x2CAA]='COPTIC CAPITAL LETTER FI'
let s:d[0x2CAB]='COPTIC SMALL LETTER FI'
let s:d[0x2CAC]='COPTIC CAPITAL LETTER KHI'
let s:d[0x2CAD]='COPTIC SMALL LETTER KHI'
let s:d[0x2CAE]='COPTIC CAPITAL LETTER PSI'
let s:d[0x2CAF]='COPTIC SMALL LETTER PSI'
let s:d[0x2CB0]='COPTIC CAPITAL LETTER OOU'
let s:d[0x2CB1]='COPTIC SMALL LETTER OOU'
let s:d[0x2CB2]='COPTIC CAPITAL LETTER DIALECT-P ALEF'
let s:d[0x2CB3]='COPTIC SMALL LETTER DIALECT-P ALEF'
let s:d[0x2CB4]='COPTIC CAPITAL LETTER OLD COPTIC AIN'
let s:d[0x2CB5]='COPTIC SMALL LETTER OLD COPTIC AIN'
let s:d[0x2CB6]='COPTIC CAPITAL LETTER CRYPTOGRAMMIC EIE'
let s:d[0x2CB7]='COPTIC SMALL LETTER CRYPTOGRAMMIC EIE'
let s:d[0x2CB8]='COPTIC CAPITAL LETTER DIALECT-P KAPA'
let s:d[0x2CB9]='COPTIC SMALL LETTER DIALECT-P KAPA'
let s:d[0x2CBA]='COPTIC CAPITAL LETTER DIALECT-P NI'
let s:d[0x2CBB]='COPTIC SMALL LETTER DIALECT-P NI'
let s:d[0x2CBC]='COPTIC CAPITAL LETTER CRYPTOGRAMMIC NI'
let s:d[0x2CBD]='COPTIC SMALL LETTER CRYPTOGRAMMIC NI'
let s:d[0x2CBE]='COPTIC CAPITAL LETTER OLD COPTIC OOU'
let s:d[0x2CBF]='COPTIC SMALL LETTER OLD COPTIC OOU'
let s:d[0x2CC0]='COPTIC CAPITAL LETTER SAMPI'
let s:d[0x2CC1]='COPTIC SMALL LETTER SAMPI'
let s:d[0x2CC2]='COPTIC CAPITAL LETTER CROSSED SHEI'
let s:d[0x2CC3]='COPTIC SMALL LETTER CROSSED SHEI'
let s:d[0x2CC4]='COPTIC CAPITAL LETTER OLD COPTIC SHEI'
let s:d[0x2CC5]='COPTIC SMALL LETTER OLD COPTIC SHEI'
let s:d[0x2CC6]='COPTIC CAPITAL LETTER OLD COPTIC ESH'
let s:d[0x2CC7]='COPTIC SMALL LETTER OLD COPTIC ESH'
let s:d[0x2CC8]='COPTIC CAPITAL LETTER AKHMIMIC KHEI'
let s:d[0x2CC9]='COPTIC SMALL LETTER AKHMIMIC KHEI'
let s:d[0x2CCA]='COPTIC CAPITAL LETTER DIALECT-P HORI'
let s:d[0x2CCB]='COPTIC SMALL LETTER DIALECT-P HORI'
let s:d[0x2CCC]='COPTIC CAPITAL LETTER OLD COPTIC HORI'
let s:d[0x2CCD]='COPTIC SMALL LETTER OLD COPTIC HORI'
let s:d[0x2CCE]='COPTIC CAPITAL LETTER OLD COPTIC HA'
let s:d[0x2CCF]='COPTIC SMALL LETTER OLD COPTIC HA'
let s:d[0x2CD0]='COPTIC CAPITAL LETTER L-SHAPED HA'
let s:d[0x2CD1]='COPTIC SMALL LETTER L-SHAPED HA'
let s:d[0x2CD2]='COPTIC CAPITAL LETTER OLD COPTIC HEI'
let s:d[0x2CD3]='COPTIC SMALL LETTER OLD COPTIC HEI'
let s:d[0x2CD4]='COPTIC CAPITAL LETTER OLD COPTIC HAT'
let s:d[0x2CD5]='COPTIC SMALL LETTER OLD COPTIC HAT'
let s:d[0x2CD6]='COPTIC CAPITAL LETTER OLD COPTIC GANGIA'
let s:d[0x2CD7]='COPTIC SMALL LETTER OLD COPTIC GANGIA'
let s:d[0x2CD8]='COPTIC CAPITAL LETTER OLD COPTIC DJA'
let s:d[0x2CD9]='COPTIC SMALL LETTER OLD COPTIC DJA'
let s:d[0x2CDA]='COPTIC CAPITAL LETTER OLD COPTIC SHIMA'
let s:d[0x2CDB]='COPTIC SMALL LETTER OLD COPTIC SHIMA'
let s:d[0x2CDC]='COPTIC CAPITAL LETTER OLD NUBIAN SHIMA'
let s:d[0x2CDD]='COPTIC SMALL LETTER OLD NUBIAN SHIMA'
let s:d[0x2CDE]='COPTIC CAPITAL LETTER OLD NUBIAN NGI'
let s:d[0x2CDF]='COPTIC SMALL LETTER OLD NUBIAN NGI'
let s:d[0x2CE0]='COPTIC CAPITAL LETTER OLD NUBIAN NYI'
let s:d[0x2CE1]='COPTIC SMALL LETTER OLD NUBIAN NYI'
let s:d[0x2CE2]='COPTIC CAPITAL LETTER OLD NUBIAN WAU'
let s:d[0x2CE3]='COPTIC SMALL LETTER OLD NUBIAN WAU'
let s:d[0x2CE4]='COPTIC SYMBOL KAI'
let s:d[0x2CE5]='COPTIC SYMBOL MI RO'
let s:d[0x2CE6]='COPTIC SYMBOL PI RO'
let s:d[0x2CE7]='COPTIC SYMBOL STAUROS'
let s:d[0x2CE8]='COPTIC SYMBOL TAU RO'
let s:d[0x2CE9]='COPTIC SYMBOL KHI RO'
let s:d[0x2CEA]='COPTIC SYMBOL SHIMA SIMA'
let s:d[0x2CEB]='COPTIC CAPITAL LETTER CRYPTOGRAMMIC SHEI'
let s:d[0x2CEC]='COPTIC SMALL LETTER CRYPTOGRAMMIC SHEI'
let s:d[0x2CED]='COPTIC CAPITAL LETTER CRYPTOGRAMMIC GANGIA'
let s:d[0x2CEE]='COPTIC SMALL LETTER CRYPTOGRAMMIC GANGIA'
let s:d[0x2CEF]='COPTIC COMBINING NI ABOVE'
let s:d[0x2CF0]='COPTIC COMBINING SPIRITUS ASPER'
let s:d[0x2CF1]='COPTIC COMBINING SPIRITUS LENIS'
let s:d[0x2CF2]='COPTIC CAPITAL LETTER BOHAIRIC KHEI'
let s:d[0x2CF3]='COPTIC SMALL LETTER BOHAIRIC KHEI'
let s:d[0x2CF9]='COPTIC OLD NUBIAN FULL STOP'
let s:d[0x2CFA]='COPTIC OLD NUBIAN DIRECT QUESTION MARK'
let s:d[0x2CFB]='COPTIC OLD NUBIAN INDIRECT QUESTION MARK'
let s:d[0x2CFC]='COPTIC OLD NUBIAN VERSE DIVIDER'
let s:d[0x2CFD]='COPTIC FRACTION ONE HALF'
let s:d[0x2CFE]='COPTIC FULL STOP'
let s:d[0x2CFF]='COPTIC MORPHOLOGICAL DIVIDER'
let s:d[0x2D00]='GEORGIAN SMALL LETTER AN'
let s:d[0x2D01]='GEORGIAN SMALL LETTER BAN'
let s:d[0x2D02]='GEORGIAN SMALL LETTER GAN'
let s:d[0x2D03]='GEORGIAN SMALL LETTER DON'
let s:d[0x2D04]='GEORGIAN SMALL LETTER EN'
let s:d[0x2D05]='GEORGIAN SMALL LETTER VIN'
let s:d[0x2D06]='GEORGIAN SMALL LETTER ZEN'
let s:d[0x2D07]='GEORGIAN SMALL LETTER TAN'
let s:d[0x2D08]='GEORGIAN SMALL LETTER IN'
let s:d[0x2D09]='GEORGIAN SMALL LETTER KAN'
let s:d[0x2D0A]='GEORGIAN SMALL LETTER LAS'
let s:d[0x2D0B]='GEORGIAN SMALL LETTER MAN'
let s:d[0x2D0C]='GEORGIAN SMALL LETTER NAR'
let s:d[0x2D0D]='GEORGIAN SMALL LETTER ON'
let s:d[0x2D0E]='GEORGIAN SMALL LETTER PAR'
let s:d[0x2D0F]='GEORGIAN SMALL LETTER ZHAR'
let s:d[0x2D10]='GEORGIAN SMALL LETTER RAE'
let s:d[0x2D11]='GEORGIAN SMALL LETTER SAN'
let s:d[0x2D12]='GEORGIAN SMALL LETTER TAR'
let s:d[0x2D13]='GEORGIAN SMALL LETTER UN'
let s:d[0x2D14]='GEORGIAN SMALL LETTER PHAR'
let s:d[0x2D15]='GEORGIAN SMALL LETTER KHAR'
let s:d[0x2D16]='GEORGIAN SMALL LETTER GHAN'
let s:d[0x2D17]='GEORGIAN SMALL LETTER QAR'
let s:d[0x2D18]='GEORGIAN SMALL LETTER SHIN'
let s:d[0x2D19]='GEORGIAN SMALL LETTER CHIN'
let s:d[0x2D1A]='GEORGIAN SMALL LETTER CAN'
let s:d[0x2D1B]='GEORGIAN SMALL LETTER JIL'
let s:d[0x2D1C]='GEORGIAN SMALL LETTER CIL'
let s:d[0x2D1D]='GEORGIAN SMALL LETTER CHAR'
let s:d[0x2D1E]='GEORGIAN SMALL LETTER XAN'
let s:d[0x2D1F]='GEORGIAN SMALL LETTER JHAN'
let s:d[0x2D20]='GEORGIAN SMALL LETTER HAE'
let s:d[0x2D21]='GEORGIAN SMALL LETTER HE'
let s:d[0x2D22]='GEORGIAN SMALL LETTER HIE'
let s:d[0x2D23]='GEORGIAN SMALL LETTER WE'
let s:d[0x2D24]='GEORGIAN SMALL LETTER HAR'
let s:d[0x2D25]='GEORGIAN SMALL LETTER HOE'
let s:d[0x2D27]='GEORGIAN SMALL LETTER YN'
let s:d[0x2D2D]='GEORGIAN SMALL LETTER AEN'
let s:d[0x2D30]='TIFINAGH LETTER YA'
let s:d[0x2D31]='TIFINAGH LETTER YAB'
let s:d[0x2D32]='TIFINAGH LETTER YABH'
let s:d[0x2D33]='TIFINAGH LETTER YAG'
let s:d[0x2D34]='TIFINAGH LETTER YAGHH'
let s:d[0x2D35]='TIFINAGH LETTER BERBER ACADEMY YAJ'
let s:d[0x2D36]='TIFINAGH LETTER YAJ'
let s:d[0x2D37]='TIFINAGH LETTER YAD'
let s:d[0x2D38]='TIFINAGH LETTER YADH'
let s:d[0x2D39]='TIFINAGH LETTER YADD'
let s:d[0x2D3A]='TIFINAGH LETTER YADDH'
let s:d[0x2D3B]='TIFINAGH LETTER YEY'
let s:d[0x2D3C]='TIFINAGH LETTER YAF'
let s:d[0x2D3D]='TIFINAGH LETTER YAK'
let s:d[0x2D3E]='TIFINAGH LETTER TUAREG YAK'
let s:d[0x2D3F]='TIFINAGH LETTER YAKHH'
let s:d[0x2D40]='TIFINAGH LETTER YAH'
let s:d[0x2D41]='TIFINAGH LETTER BERBER ACADEMY YAH'
let s:d[0x2D42]='TIFINAGH LETTER TUAREG YAH'
let s:d[0x2D43]='TIFINAGH LETTER YAHH'
let s:d[0x2D44]='TIFINAGH LETTER YAA'
let s:d[0x2D45]='TIFINAGH LETTER YAKH'
let s:d[0x2D46]='TIFINAGH LETTER TUAREG YAKH'
let s:d[0x2D47]='TIFINAGH LETTER YAQ'
let s:d[0x2D48]='TIFINAGH LETTER TUAREG YAQ'
let s:d[0x2D49]='TIFINAGH LETTER YI'
let s:d[0x2D4A]='TIFINAGH LETTER YAZH'
let s:d[0x2D4B]='TIFINAGH LETTER AHAGGAR YAZH'
let s:d[0x2D4C]='TIFINAGH LETTER TUAREG YAZH'
let s:d[0x2D4D]='TIFINAGH LETTER YAL'
let s:d[0x2D4E]='TIFINAGH LETTER YAM'
let s:d[0x2D4F]='TIFINAGH LETTER YAN'
let s:d[0x2D50]='TIFINAGH LETTER TUAREG YAGN'
let s:d[0x2D51]='TIFINAGH LETTER TUAREG YANG'
let s:d[0x2D52]='TIFINAGH LETTER YAP'
let s:d[0x2D53]='TIFINAGH LETTER YU'
let s:d[0x2D54]='TIFINAGH LETTER YAR'
let s:d[0x2D55]='TIFINAGH LETTER YARR'
let s:d[0x2D56]='TIFINAGH LETTER YAGH'
let s:d[0x2D57]='TIFINAGH LETTER TUAREG YAGH'
let s:d[0x2D58]='TIFINAGH LETTER AYER YAGH'
let s:d[0x2D59]='TIFINAGH LETTER YAS'
let s:d[0x2D5A]='TIFINAGH LETTER YASS'
let s:d[0x2D5B]='TIFINAGH LETTER YASH'
let s:d[0x2D5C]='TIFINAGH LETTER YAT'
let s:d[0x2D5D]='TIFINAGH LETTER YATH'
let s:d[0x2D5E]='TIFINAGH LETTER YACH'
let s:d[0x2D5F]='TIFINAGH LETTER YATT'
let s:d[0x2D60]='TIFINAGH LETTER YAV'
let s:d[0x2D61]='TIFINAGH LETTER YAW'
let s:d[0x2D62]='TIFINAGH LETTER YAY'
let s:d[0x2D63]='TIFINAGH LETTER YAZ'
let s:d[0x2D64]='TIFINAGH LETTER TAWELLEMET YAZ'
let s:d[0x2D65]='TIFINAGH LETTER YAZZ'
let s:d[0x2D66]='TIFINAGH LETTER YE'
let s:d[0x2D67]='TIFINAGH LETTER YO'
let s:d[0x2D6F]='TIFINAGH MODIFIER LETTER LABIALIZATION MARK'
let s:d[0x2D70]='TIFINAGH SEPARATOR MARK'
let s:d[0x2D7F]='TIFINAGH CONSONANT JOINER'
let s:d[0x2D80]='ETHIOPIC SYLLABLE LOA'
let s:d[0x2D81]='ETHIOPIC SYLLABLE MOA'
let s:d[0x2D82]='ETHIOPIC SYLLABLE ROA'
let s:d[0x2D83]='ETHIOPIC SYLLABLE SOA'
let s:d[0x2D84]='ETHIOPIC SYLLABLE SHOA'
let s:d[0x2D85]='ETHIOPIC SYLLABLE BOA'
let s:d[0x2D86]='ETHIOPIC SYLLABLE TOA'
let s:d[0x2D87]='ETHIOPIC SYLLABLE COA'
let s:d[0x2D88]='ETHIOPIC SYLLABLE NOA'
let s:d[0x2D89]='ETHIOPIC SYLLABLE NYOA'
let s:d[0x2D8A]='ETHIOPIC SYLLABLE GLOTTAL OA'
let s:d[0x2D8B]='ETHIOPIC SYLLABLE ZOA'
let s:d[0x2D8C]='ETHIOPIC SYLLABLE DOA'
let s:d[0x2D8D]='ETHIOPIC SYLLABLE DDOA'
let s:d[0x2D8E]='ETHIOPIC SYLLABLE JOA'
let s:d[0x2D8F]='ETHIOPIC SYLLABLE THOA'
let s:d[0x2D90]='ETHIOPIC SYLLABLE CHOA'
let s:d[0x2D91]='ETHIOPIC SYLLABLE PHOA'
let s:d[0x2D92]='ETHIOPIC SYLLABLE POA'
let s:d[0x2D93]='ETHIOPIC SYLLABLE GGWA'
let s:d[0x2D94]='ETHIOPIC SYLLABLE GGWI'
let s:d[0x2D95]='ETHIOPIC SYLLABLE GGWEE'
let s:d[0x2D96]='ETHIOPIC SYLLABLE GGWE'
let s:d[0x2DA0]='ETHIOPIC SYLLABLE SSA'
let s:d[0x2DA1]='ETHIOPIC SYLLABLE SSU'
let s:d[0x2DA2]='ETHIOPIC SYLLABLE SSI'
let s:d[0x2DA3]='ETHIOPIC SYLLABLE SSAA'
let s:d[0x2DA4]='ETHIOPIC SYLLABLE SSEE'
let s:d[0x2DA5]='ETHIOPIC SYLLABLE SSE'
let s:d[0x2DA6]='ETHIOPIC SYLLABLE SSO'
let s:d[0x2DA8]='ETHIOPIC SYLLABLE CCA'
let s:d[0x2DA9]='ETHIOPIC SYLLABLE CCU'
let s:d[0x2DAA]='ETHIOPIC SYLLABLE CCI'
let s:d[0x2DAB]='ETHIOPIC SYLLABLE CCAA'
let s:d[0x2DAC]='ETHIOPIC SYLLABLE CCEE'
let s:d[0x2DAD]='ETHIOPIC SYLLABLE CCE'
let s:d[0x2DAE]='ETHIOPIC SYLLABLE CCO'
let s:d[0x2DB0]='ETHIOPIC SYLLABLE ZZA'
let s:d[0x2DB1]='ETHIOPIC SYLLABLE ZZU'
let s:d[0x2DB2]='ETHIOPIC SYLLABLE ZZI'
let s:d[0x2DB3]='ETHIOPIC SYLLABLE ZZAA'
let s:d[0x2DB4]='ETHIOPIC SYLLABLE ZZEE'
let s:d[0x2DB5]='ETHIOPIC SYLLABLE ZZE'
let s:d[0x2DB6]='ETHIOPIC SYLLABLE ZZO'
let s:d[0x2DB8]='ETHIOPIC SYLLABLE CCHA'
let s:d[0x2DB9]='ETHIOPIC SYLLABLE CCHU'
let s:d[0x2DBA]='ETHIOPIC SYLLABLE CCHI'
let s:d[0x2DBB]='ETHIOPIC SYLLABLE CCHAA'
let s:d[0x2DBC]='ETHIOPIC SYLLABLE CCHEE'
let s:d[0x2DBD]='ETHIOPIC SYLLABLE CCHE'
let s:d[0x2DBE]='ETHIOPIC SYLLABLE CCHO'
let s:d[0x2DC0]='ETHIOPIC SYLLABLE QYA'
let s:d[0x2DC1]='ETHIOPIC SYLLABLE QYU'
let s:d[0x2DC2]='ETHIOPIC SYLLABLE QYI'
let s:d[0x2DC3]='ETHIOPIC SYLLABLE QYAA'
let s:d[0x2DC4]='ETHIOPIC SYLLABLE QYEE'
let s:d[0x2DC5]='ETHIOPIC SYLLABLE QYE'
let s:d[0x2DC6]='ETHIOPIC SYLLABLE QYO'
let s:d[0x2DC8]='ETHIOPIC SYLLABLE KYA'
let s:d[0x2DC9]='ETHIOPIC SYLLABLE KYU'
let s:d[0x2DCA]='ETHIOPIC SYLLABLE KYI'
let s:d[0x2DCB]='ETHIOPIC SYLLABLE KYAA'
let s:d[0x2DCC]='ETHIOPIC SYLLABLE KYEE'
let s:d[0x2DCD]='ETHIOPIC SYLLABLE KYE'
let s:d[0x2DCE]='ETHIOPIC SYLLABLE KYO'
let s:d[0x2DD0]='ETHIOPIC SYLLABLE XYA'
let s:d[0x2DD1]='ETHIOPIC SYLLABLE XYU'
let s:d[0x2DD2]='ETHIOPIC SYLLABLE XYI'
let s:d[0x2DD3]='ETHIOPIC SYLLABLE XYAA'
let s:d[0x2DD4]='ETHIOPIC SYLLABLE XYEE'
let s:d[0x2DD5]='ETHIOPIC SYLLABLE XYE'
let s:d[0x2DD6]='ETHIOPIC SYLLABLE XYO'
let s:d[0x2DD8]='ETHIOPIC SYLLABLE GYA'
let s:d[0x2DD9]='ETHIOPIC SYLLABLE GYU'
let s:d[0x2DDA]='ETHIOPIC SYLLABLE GYI'
let s:d[0x2DDB]='ETHIOPIC SYLLABLE GYAA'
let s:d[0x2DDC]='ETHIOPIC SYLLABLE GYEE'
let s:d[0x2DDD]='ETHIOPIC SYLLABLE GYE'
let s:d[0x2DDE]='ETHIOPIC SYLLABLE GYO'
let s:d[0x2DE0]='COMBINING CYRILLIC LETTER BE'
let s:d[0x2DE1]='COMBINING CYRILLIC LETTER VE'
let s:d[0x2DE2]='COMBINING CYRILLIC LETTER GHE'
let s:d[0x2DE3]='COMBINING CYRILLIC LETTER DE'
let s:d[0x2DE4]='COMBINING CYRILLIC LETTER ZHE'
let s:d[0x2DE5]='COMBINING CYRILLIC LETTER ZE'
let s:d[0x2DE6]='COMBINING CYRILLIC LETTER KA'
let s:d[0x2DE7]='COMBINING CYRILLIC LETTER EL'
let s:d[0x2DE8]='COMBINING CYRILLIC LETTER EM'
let s:d[0x2DE9]='COMBINING CYRILLIC LETTER EN'
let s:d[0x2DEA]='COMBINING CYRILLIC LETTER O'
let s:d[0x2DEB]='COMBINING CYRILLIC LETTER PE'
let s:d[0x2DEC]='COMBINING CYRILLIC LETTER ER'
let s:d[0x2DED]='COMBINING CYRILLIC LETTER ES'
let s:d[0x2DEE]='COMBINING CYRILLIC LETTER TE'
let s:d[0x2DEF]='COMBINING CYRILLIC LETTER HA'
let s:d[0x2DF0]='COMBINING CYRILLIC LETTER TSE'
let s:d[0x2DF1]='COMBINING CYRILLIC LETTER CHE'
let s:d[0x2DF2]='COMBINING CYRILLIC LETTER SHA'
let s:d[0x2DF3]='COMBINING CYRILLIC LETTER SHCHA'
let s:d[0x2DF4]='COMBINING CYRILLIC LETTER FITA'
let s:d[0x2DF5]='COMBINING CYRILLIC LETTER ES-TE'
let s:d[0x2DF6]='COMBINING CYRILLIC LETTER A'
let s:d[0x2DF7]='COMBINING CYRILLIC LETTER IE'
let s:d[0x2DF8]='COMBINING CYRILLIC LETTER DJERV'
let s:d[0x2DF9]='COMBINING CYRILLIC LETTER MONOGRAPH UK'
let s:d[0x2DFA]='COMBINING CYRILLIC LETTER YAT'
let s:d[0x2DFB]='COMBINING CYRILLIC LETTER YU'
let s:d[0x2DFC]='COMBINING CYRILLIC LETTER IOTIFIED A'
let s:d[0x2DFD]='COMBINING CYRILLIC LETTER LITTLE YUS'
let s:d[0x2DFE]='COMBINING CYRILLIC LETTER BIG YUS'
let s:d[0x2DFF]='COMBINING CYRILLIC LETTER IOTIFIED BIG YUS'
let s:d[0x2E00]='RIGHT ANGLE SUBSTITUTION MARKER'
let s:d[0x2E01]='RIGHT ANGLE DOTTED SUBSTITUTION MARKER'
let s:d[0x2E02]='LEFT SUBSTITUTION BRACKET'
let s:d[0x2E03]='RIGHT SUBSTITUTION BRACKET'
let s:d[0x2E04]='LEFT DOTTED SUBSTITUTION BRACKET'
let s:d[0x2E05]='RIGHT DOTTED SUBSTITUTION BRACKET'
let s:d[0x2E06]='RAISED INTERPOLATION MARKER'
let s:d[0x2E07]='RAISED DOTTED INTERPOLATION MARKER'
let s:d[0x2E08]='DOTTED TRANSPOSITION MARKER'
let s:d[0x2E09]='LEFT TRANSPOSITION BRACKET'
let s:d[0x2E0A]='RIGHT TRANSPOSITION BRACKET'
let s:d[0x2E0B]='RAISED SQUARE'
let s:d[0x2E0C]='LEFT RAISED OMISSION BRACKET'
let s:d[0x2E0D]='RIGHT RAISED OMISSION BRACKET'
let s:d[0x2E0E]='EDITORIAL CORONIS'
let s:d[0x2E0F]='PARAGRAPHOS'
let s:d[0x2E10]='FORKED PARAGRAPHOS'
let s:d[0x2E11]='REVERSED FORKED PARAGRAPHOS'
let s:d[0x2E12]='HYPODIASTOLE'
let s:d[0x2E13]='DOTTED OBELOS'
let s:d[0x2E14]='DOWNWARDS ANCORA'
let s:d[0x2E15]='UPWARDS ANCORA'
let s:d[0x2E16]='DOTTED RIGHT-POINTING ANGLE'
let s:d[0x2E17]='DOUBLE OBLIQUE HYPHEN'
let s:d[0x2E18]='INVERTED INTERROBANG'
let s:d[0x2E19]='PALM BRANCH'
let s:d[0x2E1A]='HYPHEN WITH DIAERESIS'
let s:d[0x2E1B]='TILDE WITH RING ABOVE'
let s:d[0x2E1C]='LEFT LOW PARAPHRASE BRACKET'
let s:d[0x2E1D]='RIGHT LOW PARAPHRASE BRACKET'
let s:d[0x2E1E]='TILDE WITH DOT ABOVE'
let s:d[0x2E1F]='TILDE WITH DOT BELOW'
let s:d[0x2E20]='LEFT VERTICAL BAR WITH QUILL'
let s:d[0x2E21]='RIGHT VERTICAL BAR WITH QUILL'
let s:d[0x2E22]='TOP LEFT HALF BRACKET'
let s:d[0x2E23]='TOP RIGHT HALF BRACKET'
let s:d[0x2E24]='BOTTOM LEFT HALF BRACKET'
let s:d[0x2E25]='BOTTOM RIGHT HALF BRACKET'
let s:d[0x2E26]='LEFT SIDEWAYS U BRACKET'
let s:d[0x2E27]='RIGHT SIDEWAYS U BRACKET'
let s:d[0x2E28]='LEFT DOUBLE PARENTHESIS'
let s:d[0x2E29]='RIGHT DOUBLE PARENTHESIS'
let s:d[0x2E2A]='TWO DOTS OVER ONE DOT PUNCTUATION'
let s:d[0x2E2B]='ONE DOT OVER TWO DOTS PUNCTUATION'
let s:d[0x2E2C]='SQUARED FOUR DOT PUNCTUATION'
let s:d[0x2E2D]='FIVE DOT MARK'
let s:d[0x2E2E]='REVERSED QUESTION MARK'
let s:d[0x2E2F]='VERTICAL TILDE'
let s:d[0x2E30]='RING POINT'
let s:d[0x2E31]='WORD SEPARATOR MIDDLE DOT'
let s:d[0x2E32]='TURNED COMMA'
let s:d[0x2E33]='RAISED DOT'
let s:d[0x2E34]='RAISED COMMA'
let s:d[0x2E35]='TURNED SEMICOLON'
let s:d[0x2E36]='DAGGER WITH LEFT GUARD'
let s:d[0x2E37]='DAGGER WITH RIGHT GUARD'
let s:d[0x2E38]='TURNED DAGGER'
let s:d[0x2E39]='TOP HALF SECTION SIGN'
let s:d[0x2E3A]='TWO-EM DASH'
let s:d[0x2E3B]='THREE-EM DASH'
let s:d[0x2E80]='CJK RADICAL REPEAT'
let s:d[0x2E81]='CJK RADICAL CLIFF'
let s:d[0x2E82]='CJK RADICAL SECOND ONE'
let s:d[0x2E83]='CJK RADICAL SECOND TWO'
let s:d[0x2E84]='CJK RADICAL SECOND THREE'
let s:d[0x2E85]='CJK RADICAL PERSON'
let s:d[0x2E86]='CJK RADICAL BOX'
let s:d[0x2E87]='CJK RADICAL TABLE'
let s:d[0x2E88]='CJK RADICAL KNIFE ONE'
let s:d[0x2E89]='CJK RADICAL KNIFE TWO'
let s:d[0x2E8A]='CJK RADICAL DIVINATION'
let s:d[0x2E8B]='CJK RADICAL SEAL'
let s:d[0x2E8C]='CJK RADICAL SMALL ONE'
let s:d[0x2E8D]='CJK RADICAL SMALL TWO'
let s:d[0x2E8E]='CJK RADICAL LAME ONE'
let s:d[0x2E8F]='CJK RADICAL LAME TWO'
let s:d[0x2E90]='CJK RADICAL LAME THREE'
let s:d[0x2E91]='CJK RADICAL LAME FOUR'
let s:d[0x2E92]='CJK RADICAL SNAKE'
let s:d[0x2E93]='CJK RADICAL THREAD'
let s:d[0x2E94]='CJK RADICAL SNOUT ONE'
let s:d[0x2E95]='CJK RADICAL SNOUT TWO'
let s:d[0x2E96]='CJK RADICAL HEART ONE'
let s:d[0x2E97]='CJK RADICAL HEART TWO'
let s:d[0x2E98]='CJK RADICAL HAND'
let s:d[0x2E99]='CJK RADICAL RAP'
let s:d[0x2E9B]='CJK RADICAL CHOKE'
let s:d[0x2E9C]='CJK RADICAL SUN'
let s:d[0x2E9D]='CJK RADICAL MOON'
let s:d[0x2E9E]='CJK RADICAL DEATH'
let s:d[0x2E9F]='CJK RADICAL MOTHER'
let s:d[0x2EA0]='CJK RADICAL CIVILIAN'
let s:d[0x2EA1]='CJK RADICAL WATER ONE'
let s:d[0x2EA2]='CJK RADICAL WATER TWO'
let s:d[0x2EA3]='CJK RADICAL FIRE'
let s:d[0x2EA4]='CJK RADICAL PAW ONE'
let s:d[0x2EA5]='CJK RADICAL PAW TWO'
let s:d[0x2EA6]='CJK RADICAL SIMPLIFIED HALF TREE TRUNK'
let s:d[0x2EA7]='CJK RADICAL COW'
let s:d[0x2EA8]='CJK RADICAL DOG'
let s:d[0x2EA9]='CJK RADICAL JADE'
let s:d[0x2EAA]='CJK RADICAL BOLT OF CLOTH'
let s:d[0x2EAB]='CJK RADICAL EYE'
let s:d[0x2EAC]='CJK RADICAL SPIRIT ONE'
let s:d[0x2EAD]='CJK RADICAL SPIRIT TWO'
let s:d[0x2EAE]='CJK RADICAL BAMBOO'
let s:d[0x2EAF]='CJK RADICAL SILK'
let s:d[0x2EB0]='CJK RADICAL C-SIMPLIFIED SILK'
let s:d[0x2EB1]='CJK RADICAL NET ONE'
let s:d[0x2EB2]='CJK RADICAL NET TWO'
let s:d[0x2EB3]='CJK RADICAL NET THREE'
let s:d[0x2EB4]='CJK RADICAL NET FOUR'
let s:d[0x2EB5]='CJK RADICAL MESH'
let s:d[0x2EB6]='CJK RADICAL SHEEP'
let s:d[0x2EB7]='CJK RADICAL RAM'
let s:d[0x2EB8]='CJK RADICAL EWE'
let s:d[0x2EB9]='CJK RADICAL OLD'
let s:d[0x2EBA]='CJK RADICAL BRUSH ONE'
let s:d[0x2EBB]='CJK RADICAL BRUSH TWO'
let s:d[0x2EBC]='CJK RADICAL MEAT'
let s:d[0x2EBD]='CJK RADICAL MORTAR'
let s:d[0x2EBE]='CJK RADICAL GRASS ONE'
let s:d[0x2EBF]='CJK RADICAL GRASS TWO'
let s:d[0x2EC0]='CJK RADICAL GRASS THREE'
let s:d[0x2EC1]='CJK RADICAL TIGER'
let s:d[0x2EC2]='CJK RADICAL CLOTHES'
let s:d[0x2EC3]='CJK RADICAL WEST ONE'
let s:d[0x2EC4]='CJK RADICAL WEST TWO'
let s:d[0x2EC5]='CJK RADICAL C-SIMPLIFIED SEE'
let s:d[0x2EC6]='CJK RADICAL SIMPLIFIED HORN'
let s:d[0x2EC7]='CJK RADICAL HORN'
let s:d[0x2EC8]='CJK RADICAL C-SIMPLIFIED SPEECH'
let s:d[0x2EC9]='CJK RADICAL C-SIMPLIFIED SHELL'
let s:d[0x2ECA]='CJK RADICAL FOOT'
let s:d[0x2ECB]='CJK RADICAL C-SIMPLIFIED CART'
let s:d[0x2ECC]='CJK RADICAL SIMPLIFIED WALK'
let s:d[0x2ECD]='CJK RADICAL WALK ONE'
let s:d[0x2ECE]='CJK RADICAL WALK TWO'
let s:d[0x2ECF]='CJK RADICAL CITY'
let s:d[0x2ED0]='CJK RADICAL C-SIMPLIFIED GOLD'
let s:d[0x2ED1]='CJK RADICAL LONG ONE'
let s:d[0x2ED2]='CJK RADICAL LONG TWO'
let s:d[0x2ED3]='CJK RADICAL C-SIMPLIFIED LONG'
let s:d[0x2ED4]='CJK RADICAL C-SIMPLIFIED GATE'
let s:d[0x2ED5]='CJK RADICAL MOUND ONE'
let s:d[0x2ED6]='CJK RADICAL MOUND TWO'
let s:d[0x2ED7]='CJK RADICAL RAIN'
let s:d[0x2ED8]='CJK RADICAL BLUE'
let s:d[0x2ED9]='CJK RADICAL C-SIMPLIFIED TANNED LEATHER'
let s:d[0x2EDA]='CJK RADICAL C-SIMPLIFIED LEAF'
let s:d[0x2EDB]='CJK RADICAL C-SIMPLIFIED WIND'
let s:d[0x2EDC]='CJK RADICAL C-SIMPLIFIED FLY'
let s:d[0x2EDD]='CJK RADICAL EAT ONE'
let s:d[0x2EDE]='CJK RADICAL EAT TWO'
let s:d[0x2EDF]='CJK RADICAL EAT THREE'
let s:d[0x2EE0]='CJK RADICAL C-SIMPLIFIED EAT'
let s:d[0x2EE1]='CJK RADICAL HEAD'
let s:d[0x2EE2]='CJK RADICAL C-SIMPLIFIED HORSE'
let s:d[0x2EE3]='CJK RADICAL BONE'
let s:d[0x2EE4]='CJK RADICAL GHOST'
let s:d[0x2EE5]='CJK RADICAL C-SIMPLIFIED FISH'
let s:d[0x2EE6]='CJK RADICAL C-SIMPLIFIED BIRD'
let s:d[0x2EE7]='CJK RADICAL C-SIMPLIFIED SALT'
let s:d[0x2EE8]='CJK RADICAL SIMPLIFIED WHEAT'
let s:d[0x2EE9]='CJK RADICAL SIMPLIFIED YELLOW'
let s:d[0x2EEA]='CJK RADICAL C-SIMPLIFIED FROG'
let s:d[0x2EEB]='CJK RADICAL J-SIMPLIFIED EVEN'
let s:d[0x2EEC]='CJK RADICAL C-SIMPLIFIED EVEN'
let s:d[0x2EED]='CJK RADICAL J-SIMPLIFIED TOOTH'
let s:d[0x2EEE]='CJK RADICAL C-SIMPLIFIED TOOTH'
let s:d[0x2EEF]='CJK RADICAL J-SIMPLIFIED DRAGON'
let s:d[0x2EF0]='CJK RADICAL C-SIMPLIFIED DRAGON'
let s:d[0x2EF1]='CJK RADICAL TURTLE'
let s:d[0x2EF2]='CJK RADICAL J-SIMPLIFIED TURTLE'
let s:d[0x2EF3]='CJK RADICAL C-SIMPLIFIED TURTLE'
let s:d[0x2F00]='KANGXI RADICAL ONE'
let s:d[0x2F01]='KANGXI RADICAL LINE'
let s:d[0x2F02]='KANGXI RADICAL DOT'
let s:d[0x2F03]='KANGXI RADICAL SLASH'
let s:d[0x2F04]='KANGXI RADICAL SECOND'
let s:d[0x2F05]='KANGXI RADICAL HOOK'
let s:d[0x2F06]='KANGXI RADICAL TWO'
let s:d[0x2F07]='KANGXI RADICAL LID'
let s:d[0x2F08]='KANGXI RADICAL MAN'
let s:d[0x2F09]='KANGXI RADICAL LEGS'
let s:d[0x2F0A]='KANGXI RADICAL ENTER'
let s:d[0x2F0B]='KANGXI RADICAL EIGHT'
let s:d[0x2F0C]='KANGXI RADICAL DOWN BOX'
let s:d[0x2F0D]='KANGXI RADICAL COVER'
let s:d[0x2F0E]='KANGXI RADICAL ICE'
let s:d[0x2F0F]='KANGXI RADICAL TABLE'
let s:d[0x2F10]='KANGXI RADICAL OPEN BOX'
let s:d[0x2F11]='KANGXI RADICAL KNIFE'
let s:d[0x2F12]='KANGXI RADICAL POWER'
let s:d[0x2F13]='KANGXI RADICAL WRAP'
let s:d[0x2F14]='KANGXI RADICAL SPOON'
let s:d[0x2F15]='KANGXI RADICAL RIGHT OPEN BOX'
let s:d[0x2F16]='KANGXI RADICAL HIDING ENCLOSURE'
let s:d[0x2F17]='KANGXI RADICAL TEN'
let s:d[0x2F18]='KANGXI RADICAL DIVINATION'
let s:d[0x2F19]='KANGXI RADICAL SEAL'
let s:d[0x2F1A]='KANGXI RADICAL CLIFF'
let s:d[0x2F1B]='KANGXI RADICAL PRIVATE'
let s:d[0x2F1C]='KANGXI RADICAL AGAIN'
let s:d[0x2F1D]='KANGXI RADICAL MOUTH'
let s:d[0x2F1E]='KANGXI RADICAL ENCLOSURE'
let s:d[0x2F1F]='KANGXI RADICAL EARTH'
let s:d[0x2F20]='KANGXI RADICAL SCHOLAR'
let s:d[0x2F21]='KANGXI RADICAL GO'
let s:d[0x2F22]='KANGXI RADICAL GO SLOWLY'
let s:d[0x2F23]='KANGXI RADICAL EVENING'
let s:d[0x2F24]='KANGXI RADICAL BIG'
let s:d[0x2F25]='KANGXI RADICAL WOMAN'
let s:d[0x2F26]='KANGXI RADICAL CHILD'
let s:d[0x2F27]='KANGXI RADICAL ROOF'
let s:d[0x2F28]='KANGXI RADICAL INCH'
let s:d[0x2F29]='KANGXI RADICAL SMALL'
let s:d[0x2F2A]='KANGXI RADICAL LAME'
let s:d[0x2F2B]='KANGXI RADICAL CORPSE'
let s:d[0x2F2C]='KANGXI RADICAL SPROUT'
let s:d[0x2F2D]='KANGXI RADICAL MOUNTAIN'
let s:d[0x2F2E]='KANGXI RADICAL RIVER'
let s:d[0x2F2F]='KANGXI RADICAL WORK'
let s:d[0x2F30]='KANGXI RADICAL ONESELF'
let s:d[0x2F31]='KANGXI RADICAL TURBAN'
let s:d[0x2F32]='KANGXI RADICAL DRY'
let s:d[0x2F33]='KANGXI RADICAL SHORT THREAD'
let s:d[0x2F34]='KANGXI RADICAL DOTTED CLIFF'
let s:d[0x2F35]='KANGXI RADICAL LONG STRIDE'
let s:d[0x2F36]='KANGXI RADICAL TWO HANDS'
let s:d[0x2F37]='KANGXI RADICAL SHOOT'
let s:d[0x2F38]='KANGXI RADICAL BOW'
let s:d[0x2F39]='KANGXI RADICAL SNOUT'
let s:d[0x2F3A]='KANGXI RADICAL BRISTLE'
let s:d[0x2F3B]='KANGXI RADICAL STEP'
let s:d[0x2F3C]='KANGXI RADICAL HEART'
let s:d[0x2F3D]='KANGXI RADICAL HALBERD'
let s:d[0x2F3E]='KANGXI RADICAL DOOR'
let s:d[0x2F3F]='KANGXI RADICAL HAND'
let s:d[0x2F40]='KANGXI RADICAL BRANCH'
let s:d[0x2F41]='KANGXI RADICAL RAP'
let s:d[0x2F42]='KANGXI RADICAL SCRIPT'
let s:d[0x2F43]='KANGXI RADICAL DIPPER'
let s:d[0x2F44]='KANGXI RADICAL AXE'
let s:d[0x2F45]='KANGXI RADICAL SQUARE'
let s:d[0x2F46]='KANGXI RADICAL NOT'
let s:d[0x2F47]='KANGXI RADICAL SUN'
let s:d[0x2F48]='KANGXI RADICAL SAY'
let s:d[0x2F49]='KANGXI RADICAL MOON'
let s:d[0x2F4A]='KANGXI RADICAL TREE'
let s:d[0x2F4B]='KANGXI RADICAL LACK'
let s:d[0x2F4C]='KANGXI RADICAL STOP'
let s:d[0x2F4D]='KANGXI RADICAL DEATH'
let s:d[0x2F4E]='KANGXI RADICAL WEAPON'
let s:d[0x2F4F]='KANGXI RADICAL DO NOT'
let s:d[0x2F50]='KANGXI RADICAL COMPARE'
let s:d[0x2F51]='KANGXI RADICAL FUR'
let s:d[0x2F52]='KANGXI RADICAL CLAN'
let s:d[0x2F53]='KANGXI RADICAL STEAM'
let s:d[0x2F54]='KANGXI RADICAL WATER'
let s:d[0x2F55]='KANGXI RADICAL FIRE'
let s:d[0x2F56]='KANGXI RADICAL CLAW'
let s:d[0x2F57]='KANGXI RADICAL FATHER'
let s:d[0x2F58]='KANGXI RADICAL DOUBLE X'
let s:d[0x2F59]='KANGXI RADICAL HALF TREE TRUNK'
let s:d[0x2F5A]='KANGXI RADICAL SLICE'
let s:d[0x2F5B]='KANGXI RADICAL FANG'
let s:d[0x2F5C]='KANGXI RADICAL COW'
let s:d[0x2F5D]='KANGXI RADICAL DOG'
let s:d[0x2F5E]='KANGXI RADICAL PROFOUND'
let s:d[0x2F5F]='KANGXI RADICAL JADE'
let s:d[0x2F60]='KANGXI RADICAL MELON'
let s:d[0x2F61]='KANGXI RADICAL TILE'
let s:d[0x2F62]='KANGXI RADICAL SWEET'
let s:d[0x2F63]='KANGXI RADICAL LIFE'
let s:d[0x2F64]='KANGXI RADICAL USE'
let s:d[0x2F65]='KANGXI RADICAL FIELD'
let s:d[0x2F66]='KANGXI RADICAL BOLT OF CLOTH'
let s:d[0x2F67]='KANGXI RADICAL SICKNESS'
let s:d[0x2F68]='KANGXI RADICAL DOTTED TENT'
let s:d[0x2F69]='KANGXI RADICAL WHITE'
let s:d[0x2F6A]='KANGXI RADICAL SKIN'
let s:d[0x2F6B]='KANGXI RADICAL DISH'
let s:d[0x2F6C]='KANGXI RADICAL EYE'
let s:d[0x2F6D]='KANGXI RADICAL SPEAR'
let s:d[0x2F6E]='KANGXI RADICAL ARROW'
let s:d[0x2F6F]='KANGXI RADICAL STONE'
let s:d[0x2F70]='KANGXI RADICAL SPIRIT'
let s:d[0x2F71]='KANGXI RADICAL TRACK'
let s:d[0x2F72]='KANGXI RADICAL GRAIN'
let s:d[0x2F73]='KANGXI RADICAL CAVE'
let s:d[0x2F74]='KANGXI RADICAL STAND'
let s:d[0x2F75]='KANGXI RADICAL BAMBOO'
let s:d[0x2F76]='KANGXI RADICAL RICE'
let s:d[0x2F77]='KANGXI RADICAL SILK'
let s:d[0x2F78]='KANGXI RADICAL JAR'
let s:d[0x2F79]='KANGXI RADICAL NET'
let s:d[0x2F7A]='KANGXI RADICAL SHEEP'
let s:d[0x2F7B]='KANGXI RADICAL FEATHER'
let s:d[0x2F7C]='KANGXI RADICAL OLD'
let s:d[0x2F7D]='KANGXI RADICAL AND'
let s:d[0x2F7E]='KANGXI RADICAL PLOW'
let s:d[0x2F7F]='KANGXI RADICAL EAR'
let s:d[0x2F80]='KANGXI RADICAL BRUSH'
let s:d[0x2F81]='KANGXI RADICAL MEAT'
let s:d[0x2F82]='KANGXI RADICAL MINISTER'
let s:d[0x2F83]='KANGXI RADICAL SELF'
let s:d[0x2F84]='KANGXI RADICAL ARRIVE'
let s:d[0x2F85]='KANGXI RADICAL MORTAR'
let s:d[0x2F86]='KANGXI RADICAL TONGUE'
let s:d[0x2F87]='KANGXI RADICAL OPPOSE'
let s:d[0x2F88]='KANGXI RADICAL BOAT'
let s:d[0x2F89]='KANGXI RADICAL STOPPING'
let s:d[0x2F8A]='KANGXI RADICAL COLOR'
let s:d[0x2F8B]='KANGXI RADICAL GRASS'
let s:d[0x2F8C]='KANGXI RADICAL TIGER'
let s:d[0x2F8D]='KANGXI RADICAL INSECT'
let s:d[0x2F8E]='KANGXI RADICAL BLOOD'
let s:d[0x2F8F]='KANGXI RADICAL WALK ENCLOSURE'
let s:d[0x2F90]='KANGXI RADICAL CLOTHES'
let s:d[0x2F91]='KANGXI RADICAL WEST'
let s:d[0x2F92]='KANGXI RADICAL SEE'
let s:d[0x2F93]='KANGXI RADICAL HORN'
let s:d[0x2F94]='KANGXI RADICAL SPEECH'
let s:d[0x2F95]='KANGXI RADICAL VALLEY'
let s:d[0x2F96]='KANGXI RADICAL BEAN'
let s:d[0x2F97]='KANGXI RADICAL PIG'
let s:d[0x2F98]='KANGXI RADICAL BADGER'
let s:d[0x2F99]='KANGXI RADICAL SHELL'
let s:d[0x2F9A]='KANGXI RADICAL RED'
let s:d[0x2F9B]='KANGXI RADICAL RUN'
let s:d[0x2F9C]='KANGXI RADICAL FOOT'
let s:d[0x2F9D]='KANGXI RADICAL BODY'
let s:d[0x2F9E]='KANGXI RADICAL CART'
let s:d[0x2F9F]='KANGXI RADICAL BITTER'
let s:d[0x2FA0]='KANGXI RADICAL MORNING'
let s:d[0x2FA1]='KANGXI RADICAL WALK'
let s:d[0x2FA2]='KANGXI RADICAL CITY'
let s:d[0x2FA3]='KANGXI RADICAL WINE'
let s:d[0x2FA4]='KANGXI RADICAL DISTINGUISH'
let s:d[0x2FA5]='KANGXI RADICAL VILLAGE'
let s:d[0x2FA6]='KANGXI RADICAL GOLD'
let s:d[0x2FA7]='KANGXI RADICAL LONG'
let s:d[0x2FA8]='KANGXI RADICAL GATE'
let s:d[0x2FA9]='KANGXI RADICAL MOUND'
let s:d[0x2FAA]='KANGXI RADICAL SLAVE'
let s:d[0x2FAB]='KANGXI RADICAL SHORT TAILED BIRD'
let s:d[0x2FAC]='KANGXI RADICAL RAIN'
let s:d[0x2FAD]='KANGXI RADICAL BLUE'
let s:d[0x2FAE]='KANGXI RADICAL WRONG'
let s:d[0x2FAF]='KANGXI RADICAL FACE'
let s:d[0x2FB0]='KANGXI RADICAL LEATHER'
let s:d[0x2FB1]='KANGXI RADICAL TANNED LEATHER'
let s:d[0x2FB2]='KANGXI RADICAL LEEK'
let s:d[0x2FB3]='KANGXI RADICAL SOUND'
let s:d[0x2FB4]='KANGXI RADICAL LEAF'
let s:d[0x2FB5]='KANGXI RADICAL WIND'
let s:d[0x2FB6]='KANGXI RADICAL FLY'
let s:d[0x2FB7]='KANGXI RADICAL EAT'
let s:d[0x2FB8]='KANGXI RADICAL HEAD'
let s:d[0x2FB9]='KANGXI RADICAL FRAGRANT'
let s:d[0x2FBA]='KANGXI RADICAL HORSE'
let s:d[0x2FBB]='KANGXI RADICAL BONE'
let s:d[0x2FBC]='KANGXI RADICAL TALL'
let s:d[0x2FBD]='KANGXI RADICAL HAIR'
let s:d[0x2FBE]='KANGXI RADICAL FIGHT'
let s:d[0x2FBF]='KANGXI RADICAL SACRIFICIAL WINE'
let s:d[0x2FC0]='KANGXI RADICAL CAULDRON'
let s:d[0x2FC1]='KANGXI RADICAL GHOST'
let s:d[0x2FC2]='KANGXI RADICAL FISH'
let s:d[0x2FC3]='KANGXI RADICAL BIRD'
let s:d[0x2FC4]='KANGXI RADICAL SALT'
let s:d[0x2FC5]='KANGXI RADICAL DEER'
let s:d[0x2FC6]='KANGXI RADICAL WHEAT'
let s:d[0x2FC7]='KANGXI RADICAL HEMP'
let s:d[0x2FC8]='KANGXI RADICAL YELLOW'
let s:d[0x2FC9]='KANGXI RADICAL MILLET'
let s:d[0x2FCA]='KANGXI RADICAL BLACK'
let s:d[0x2FCB]='KANGXI RADICAL EMBROIDERY'
let s:d[0x2FCC]='KANGXI RADICAL FROG'
let s:d[0x2FCD]='KANGXI RADICAL TRIPOD'
let s:d[0x2FCE]='KANGXI RADICAL DRUM'
let s:d[0x2FCF]='KANGXI RADICAL RAT'
let s:d[0x2FD0]='KANGXI RADICAL NOSE'
let s:d[0x2FD1]='KANGXI RADICAL EVEN'
let s:d[0x2FD2]='KANGXI RADICAL TOOTH'
let s:d[0x2FD3]='KANGXI RADICAL DRAGON'
let s:d[0x2FD4]='KANGXI RADICAL TURTLE'
let s:d[0x2FD5]='KANGXI RADICAL FLUTE'
let s:d[0x2FF0]='IDEOGRAPHIC DESCRIPTION CHARACTER LEFT TO RIGHT'
let s:d[0x2FF1]='IDEOGRAPHIC DESCRIPTION CHARACTER ABOVE TO BELOW'
let s:d[0x2FF2]='IDEOGRAPHIC DESCRIPTION CHARACTER LEFT TO MIDDLE AND RIGHT'
let s:d[0x2FF3]='IDEOGRAPHIC DESCRIPTION CHARACTER ABOVE TO MIDDLE AND BELOW'
let s:d[0x2FF4]='IDEOGRAPHIC DESCRIPTION CHARACTER FULL SURROUND'
let s:d[0x2FF5]='IDEOGRAPHIC DESCRIPTION CHARACTER SURROUND FROM ABOVE'
let s:d[0x2FF6]='IDEOGRAPHIC DESCRIPTION CHARACTER SURROUND FROM BELOW'
let s:d[0x2FF7]='IDEOGRAPHIC DESCRIPTION CHARACTER SURROUND FROM LEFT'
let s:d[0x2FF8]='IDEOGRAPHIC DESCRIPTION CHARACTER SURROUND FROM UPPER LEFT'
let s:d[0x2FF9]='IDEOGRAPHIC DESCRIPTION CHARACTER SURROUND FROM UPPER RIGHT'
let s:d[0x2FFA]='IDEOGRAPHIC DESCRIPTION CHARACTER SURROUND FROM LOWER LEFT'
let s:d[0x2FFB]='IDEOGRAPHIC DESCRIPTION CHARACTER OVERLAID'
let s:d[0x3000]='IDEOGRAPHIC SPACE'
let s:d[0x3001]='IDEOGRAPHIC COMMA'
let s:d[0x3002]='IDEOGRAPHIC FULL STOP'
let s:d[0x3003]='DITTO MARK'
let s:d[0x3004]='JAPANESE INDUSTRIAL STANDARD SYMBOL'
let s:d[0x3005]='IDEOGRAPHIC ITERATION MARK'
let s:d[0x3006]='IDEOGRAPHIC CLOSING MARK'
let s:d[0x3007]='IDEOGRAPHIC NUMBER ZERO'
let s:d[0x3008]='LEFT ANGLE BRACKET'
let s:d[0x3009]='RIGHT ANGLE BRACKET'
let s:d[0x300A]='LEFT DOUBLE ANGLE BRACKET'
let s:d[0x300B]='RIGHT DOUBLE ANGLE BRACKET'
let s:d[0x300C]='LEFT CORNER BRACKET'
let s:d[0x300D]='RIGHT CORNER BRACKET'
let s:d[0x300E]='LEFT WHITE CORNER BRACKET'
let s:d[0x300F]='RIGHT WHITE CORNER BRACKET'
let s:d[0x3010]='LEFT BLACK LENTICULAR BRACKET'
let s:d[0x3011]='RIGHT BLACK LENTICULAR BRACKET'
let s:d[0x3012]='POSTAL MARK'
let s:d[0x3013]='GETA MARK'
let s:d[0x3014]='LEFT TORTOISE SHELL BRACKET'
let s:d[0x3015]='RIGHT TORTOISE SHELL BRACKET'
let s:d[0x3016]='LEFT WHITE LENTICULAR BRACKET'
let s:d[0x3017]='RIGHT WHITE LENTICULAR BRACKET'
let s:d[0x3018]='LEFT WHITE TORTOISE SHELL BRACKET'
let s:d[0x3019]='RIGHT WHITE TORTOISE SHELL BRACKET'
let s:d[0x301A]='LEFT WHITE SQUARE BRACKET'
let s:d[0x301B]='RIGHT WHITE SQUARE BRACKET'
let s:d[0x301C]='WAVE DASH'
let s:d[0x301D]='REVERSED DOUBLE PRIME QUOTATION MARK'
let s:d[0x301E]='DOUBLE PRIME QUOTATION MARK'
let s:d[0x301F]='LOW DOUBLE PRIME QUOTATION MARK'
let s:d[0x3020]='POSTAL MARK FACE'
let s:d[0x3021]='HANGZHOU NUMERAL ONE'
let s:d[0x3022]='HANGZHOU NUMERAL TWO'
let s:d[0x3023]='HANGZHOU NUMERAL THREE'
let s:d[0x3024]='HANGZHOU NUMERAL FOUR'
let s:d[0x3025]='HANGZHOU NUMERAL FIVE'
let s:d[0x3026]='HANGZHOU NUMERAL SIX'
let s:d[0x3027]='HANGZHOU NUMERAL SEVEN'
let s:d[0x3028]='HANGZHOU NUMERAL EIGHT'
let s:d[0x3029]='HANGZHOU NUMERAL NINE'
let s:d[0x302A]='IDEOGRAPHIC LEVEL TONE MARK'
let s:d[0x302B]='IDEOGRAPHIC RISING TONE MARK'
let s:d[0x302C]='IDEOGRAPHIC DEPARTING TONE MARK'
let s:d[0x302D]='IDEOGRAPHIC ENTERING TONE MARK'
let s:d[0x302E]='HANGUL SINGLE DOT TONE MARK'
let s:d[0x302F]='HANGUL DOUBLE DOT TONE MARK'
let s:d[0x3030]='WAVY DASH'
let s:d[0x3031]='VERTICAL KANA REPEAT MARK'
let s:d[0x3032]='VERTICAL KANA REPEAT WITH VOICED SOUND MARK'
let s:d[0x3033]='VERTICAL KANA REPEAT MARK UPPER HALF'
let s:d[0x3034]='VERTICAL KANA REPEAT WITH VOICED SOUND MARK UPPER HALF'
let s:d[0x3035]='VERTICAL KANA REPEAT MARK LOWER HALF'
let s:d[0x3036]='CIRCLED POSTAL MARK'
let s:d[0x3037]='IDEOGRAPHIC TELEGRAPH LINE FEED SEPARATOR SYMBOL'
let s:d[0x3038]='HANGZHOU NUMERAL TEN'
let s:d[0x3039]='HANGZHOU NUMERAL TWENTY'
let s:d[0x303A]='HANGZHOU NUMERAL THIRTY'
let s:d[0x303B]='VERTICAL IDEOGRAPHIC ITERATION MARK'
let s:d[0x303C]='MASU MARK'
let s:d[0x303D]='PART ALTERNATION MARK'
let s:d[0x303E]='IDEOGRAPHIC VARIATION INDICATOR'
let s:d[0x303F]='IDEOGRAPHIC HALF FILL SPACE'
let s:d[0x3041]='HIRAGANA LETTER SMALL A'
let s:d[0x3042]='HIRAGANA LETTER A'
let s:d[0x3043]='HIRAGANA LETTER SMALL I'
let s:d[0x3044]='HIRAGANA LETTER I'
let s:d[0x3045]='HIRAGANA LETTER SMALL U'
let s:d[0x3046]='HIRAGANA LETTER U'
let s:d[0x3047]='HIRAGANA LETTER SMALL E'
let s:d[0x3048]='HIRAGANA LETTER E'
let s:d[0x3049]='HIRAGANA LETTER SMALL O'
let s:d[0x304A]='HIRAGANA LETTER O'
let s:d[0x304B]='HIRAGANA LETTER KA'
let s:d[0x304C]='HIRAGANA LETTER GA'
let s:d[0x304D]='HIRAGANA LETTER KI'
let s:d[0x304E]='HIRAGANA LETTER GI'
let s:d[0x304F]='HIRAGANA LETTER KU'
let s:d[0x3050]='HIRAGANA LETTER GU'
let s:d[0x3051]='HIRAGANA LETTER KE'
let s:d[0x3052]='HIRAGANA LETTER GE'
let s:d[0x3053]='HIRAGANA LETTER KO'
let s:d[0x3054]='HIRAGANA LETTER GO'
let s:d[0x3055]='HIRAGANA LETTER SA'
let s:d[0x3056]='HIRAGANA LETTER ZA'
let s:d[0x3057]='HIRAGANA LETTER SI'
let s:d[0x3058]='HIRAGANA LETTER ZI'
let s:d[0x3059]='HIRAGANA LETTER SU'
let s:d[0x305A]='HIRAGANA LETTER ZU'
let s:d[0x305B]='HIRAGANA LETTER SE'
let s:d[0x305C]='HIRAGANA LETTER ZE'
let s:d[0x305D]='HIRAGANA LETTER SO'
let s:d[0x305E]='HIRAGANA LETTER ZO'
let s:d[0x305F]='HIRAGANA LETTER TA'
let s:d[0x3060]='HIRAGANA LETTER DA'
let s:d[0x3061]='HIRAGANA LETTER TI'
let s:d[0x3062]='HIRAGANA LETTER DI'
let s:d[0x3063]='HIRAGANA LETTER SMALL TU'
let s:d[0x3064]='HIRAGANA LETTER TU'
let s:d[0x3065]='HIRAGANA LETTER DU'
let s:d[0x3066]='HIRAGANA LETTER TE'
let s:d[0x3067]='HIRAGANA LETTER DE'
let s:d[0x3068]='HIRAGANA LETTER TO'
let s:d[0x3069]='HIRAGANA LETTER DO'
let s:d[0x306A]='HIRAGANA LETTER NA'
let s:d[0x306B]='HIRAGANA LETTER NI'
let s:d[0x306C]='HIRAGANA LETTER NU'
let s:d[0x306D]='HIRAGANA LETTER NE'
let s:d[0x306E]='HIRAGANA LETTER NO'
let s:d[0x306F]='HIRAGANA LETTER HA'
let s:d[0x3070]='HIRAGANA LETTER BA'
let s:d[0x3071]='HIRAGANA LETTER PA'
let s:d[0x3072]='HIRAGANA LETTER HI'
let s:d[0x3073]='HIRAGANA LETTER BI'
let s:d[0x3074]='HIRAGANA LETTER PI'
let s:d[0x3075]='HIRAGANA LETTER HU'
let s:d[0x3076]='HIRAGANA LETTER BU'
let s:d[0x3077]='HIRAGANA LETTER PU'
let s:d[0x3078]='HIRAGANA LETTER HE'
let s:d[0x3079]='HIRAGANA LETTER BE'
let s:d[0x307A]='HIRAGANA LETTER PE'
let s:d[0x307B]='HIRAGANA LETTER HO'
let s:d[0x307C]='HIRAGANA LETTER BO'
let s:d[0x307D]='HIRAGANA LETTER PO'
let s:d[0x307E]='HIRAGANA LETTER MA'
let s:d[0x307F]='HIRAGANA LETTER MI'
let s:d[0x3080]='HIRAGANA LETTER MU'
let s:d[0x3081]='HIRAGANA LETTER ME'
let s:d[0x3082]='HIRAGANA LETTER MO'
let s:d[0x3083]='HIRAGANA LETTER SMALL YA'
let s:d[0x3084]='HIRAGANA LETTER YA'
let s:d[0x3085]='HIRAGANA LETTER SMALL YU'
let s:d[0x3086]='HIRAGANA LETTER YU'
let s:d[0x3087]='HIRAGANA LETTER SMALL YO'
let s:d[0x3088]='HIRAGANA LETTER YO'
let s:d[0x3089]='HIRAGANA LETTER RA'
let s:d[0x308A]='HIRAGANA LETTER RI'
let s:d[0x308B]='HIRAGANA LETTER RU'
let s:d[0x308C]='HIRAGANA LETTER RE'
let s:d[0x308D]='HIRAGANA LETTER RO'
let s:d[0x308E]='HIRAGANA LETTER SMALL WA'
let s:d[0x308F]='HIRAGANA LETTER WA'
let s:d[0x3090]='HIRAGANA LETTER WI'
let s:d[0x3091]='HIRAGANA LETTER WE'
let s:d[0x3092]='HIRAGANA LETTER WO'
let s:d[0x3093]='HIRAGANA LETTER N'
let s:d[0x3094]='HIRAGANA LETTER VU'
let s:d[0x3095]='HIRAGANA LETTER SMALL KA'
let s:d[0x3096]='HIRAGANA LETTER SMALL KE'
let s:d[0x3099]='COMBINING KATAKANA-HIRAGANA VOICED SOUND MARK'
let s:d[0x309A]='COMBINING KATAKANA-HIRAGANA SEMI-VOICED SOUND MARK'
let s:d[0x309B]='KATAKANA-HIRAGANA VOICED SOUND MARK'
let s:d[0x309C]='KATAKANA-HIRAGANA SEMI-VOICED SOUND MARK'
let s:d[0x309D]='HIRAGANA ITERATION MARK'
let s:d[0x309E]='HIRAGANA VOICED ITERATION MARK'
let s:d[0x309F]='HIRAGANA DIGRAPH YORI'
let s:d[0x30A0]='KATAKANA-HIRAGANA DOUBLE HYPHEN'
let s:d[0x30A1]='KATAKANA LETTER SMALL A'
let s:d[0x30A2]='KATAKANA LETTER A'
let s:d[0x30A3]='KATAKANA LETTER SMALL I'
let s:d[0x30A4]='KATAKANA LETTER I'
let s:d[0x30A5]='KATAKANA LETTER SMALL U'
let s:d[0x30A6]='KATAKANA LETTER U'
let s:d[0x30A7]='KATAKANA LETTER SMALL E'
let s:d[0x30A8]='KATAKANA LETTER E'
let s:d[0x30A9]='KATAKANA LETTER SMALL O'
let s:d[0x30AA]='KATAKANA LETTER O'
let s:d[0x30AB]='KATAKANA LETTER KA'
let s:d[0x30AC]='KATAKANA LETTER GA'
let s:d[0x30AD]='KATAKANA LETTER KI'
let s:d[0x30AE]='KATAKANA LETTER GI'
let s:d[0x30AF]='KATAKANA LETTER KU'
let s:d[0x30B0]='KATAKANA LETTER GU'
let s:d[0x30B1]='KATAKANA LETTER KE'
let s:d[0x30B2]='KATAKANA LETTER GE'
let s:d[0x30B3]='KATAKANA LETTER KO'
let s:d[0x30B4]='KATAKANA LETTER GO'
let s:d[0x30B5]='KATAKANA LETTER SA'
let s:d[0x30B6]='KATAKANA LETTER ZA'
let s:d[0x30B7]='KATAKANA LETTER SI'
let s:d[0x30B8]='KATAKANA LETTER ZI'
let s:d[0x30B9]='KATAKANA LETTER SU'
let s:d[0x30BA]='KATAKANA LETTER ZU'
let s:d[0x30BB]='KATAKANA LETTER SE'
let s:d[0x30BC]='KATAKANA LETTER ZE'
let s:d[0x30BD]='KATAKANA LETTER SO'
let s:d[0x30BE]='KATAKANA LETTER ZO'
let s:d[0x30BF]='KATAKANA LETTER TA'
let s:d[0x30C0]='KATAKANA LETTER DA'
let s:d[0x30C1]='KATAKANA LETTER TI'
let s:d[0x30C2]='KATAKANA LETTER DI'
let s:d[0x30C3]='KATAKANA LETTER SMALL TU'
let s:d[0x30C4]='KATAKANA LETTER TU'
let s:d[0x30C5]='KATAKANA LETTER DU'
let s:d[0x30C6]='KATAKANA LETTER TE'
let s:d[0x30C7]='KATAKANA LETTER DE'
let s:d[0x30C8]='KATAKANA LETTER TO'
let s:d[0x30C9]='KATAKANA LETTER DO'
let s:d[0x30CA]='KATAKANA LETTER NA'
let s:d[0x30CB]='KATAKANA LETTER NI'
let s:d[0x30CC]='KATAKANA LETTER NU'
let s:d[0x30CD]='KATAKANA LETTER NE'
let s:d[0x30CE]='KATAKANA LETTER NO'
let s:d[0x30CF]='KATAKANA LETTER HA'
let s:d[0x30D0]='KATAKANA LETTER BA'
let s:d[0x30D1]='KATAKANA LETTER PA'
let s:d[0x30D2]='KATAKANA LETTER HI'
let s:d[0x30D3]='KATAKANA LETTER BI'
let s:d[0x30D4]='KATAKANA LETTER PI'
let s:d[0x30D5]='KATAKANA LETTER HU'
let s:d[0x30D6]='KATAKANA LETTER BU'
let s:d[0x30D7]='KATAKANA LETTER PU'
let s:d[0x30D8]='KATAKANA LETTER HE'
let s:d[0x30D9]='KATAKANA LETTER BE'
let s:d[0x30DA]='KATAKANA LETTER PE'
let s:d[0x30DB]='KATAKANA LETTER HO'
let s:d[0x30DC]='KATAKANA LETTER BO'
let s:d[0x30DD]='KATAKANA LETTER PO'
let s:d[0x30DE]='KATAKANA LETTER MA'
let s:d[0x30DF]='KATAKANA LETTER MI'
let s:d[0x30E0]='KATAKANA LETTER MU'
let s:d[0x30E1]='KATAKANA LETTER ME'
let s:d[0x30E2]='KATAKANA LETTER MO'
let s:d[0x30E3]='KATAKANA LETTER SMALL YA'
let s:d[0x30E4]='KATAKANA LETTER YA'
let s:d[0x30E5]='KATAKANA LETTER SMALL YU'
let s:d[0x30E6]='KATAKANA LETTER YU'
let s:d[0x30E7]='KATAKANA LETTER SMALL YO'
let s:d[0x30E8]='KATAKANA LETTER YO'
let s:d[0x30E9]='KATAKANA LETTER RA'
let s:d[0x30EA]='KATAKANA LETTER RI'
let s:d[0x30EB]='KATAKANA LETTER RU'
let s:d[0x30EC]='KATAKANA LETTER RE'
let s:d[0x30ED]='KATAKANA LETTER RO'
let s:d[0x30EE]='KATAKANA LETTER SMALL WA'
let s:d[0x30EF]='KATAKANA LETTER WA'
let s:d[0x30F0]='KATAKANA LETTER WI'
let s:d[0x30F1]='KATAKANA LETTER WE'
let s:d[0x30F2]='KATAKANA LETTER WO'
let s:d[0x30F3]='KATAKANA LETTER N'
let s:d[0x30F4]='KATAKANA LETTER VU'
let s:d[0x30F5]='KATAKANA LETTER SMALL KA'
let s:d[0x30F6]='KATAKANA LETTER SMALL KE'
let s:d[0x30F7]='KATAKANA LETTER VA'
let s:d[0x30F8]='KATAKANA LETTER VI'
let s:d[0x30F9]='KATAKANA LETTER VE'
let s:d[0x30FA]='KATAKANA LETTER VO'
let s:d[0x30FB]='KATAKANA MIDDLE DOT'
let s:d[0x30FC]='KATAKANA-HIRAGANA PROLONGED SOUND MARK'
let s:d[0x30FD]='KATAKANA ITERATION MARK'
let s:d[0x30FE]='KATAKANA VOICED ITERATION MARK'
let s:d[0x30FF]='KATAKANA DIGRAPH KOTO'
let s:d[0x3105]='BOPOMOFO LETTER B'
let s:d[0x3106]='BOPOMOFO LETTER P'
let s:d[0x3107]='BOPOMOFO LETTER M'
let s:d[0x3108]='BOPOMOFO LETTER F'
let s:d[0x3109]='BOPOMOFO LETTER D'
let s:d[0x310A]='BOPOMOFO LETTER T'
let s:d[0x310B]='BOPOMOFO LETTER N'
let s:d[0x310C]='BOPOMOFO LETTER L'
let s:d[0x310D]='BOPOMOFO LETTER G'
let s:d[0x310E]='BOPOMOFO LETTER K'
let s:d[0x310F]='BOPOMOFO LETTER H'
let s:d[0x3110]='BOPOMOFO LETTER J'
let s:d[0x3111]='BOPOMOFO LETTER Q'
let s:d[0x3112]='BOPOMOFO LETTER X'
let s:d[0x3113]='BOPOMOFO LETTER ZH'
let s:d[0x3114]='BOPOMOFO LETTER CH'
let s:d[0x3115]='BOPOMOFO LETTER SH'
let s:d[0x3116]='BOPOMOFO LETTER R'
let s:d[0x3117]='BOPOMOFO LETTER Z'
let s:d[0x3118]='BOPOMOFO LETTER C'
let s:d[0x3119]='BOPOMOFO LETTER S'
let s:d[0x311A]='BOPOMOFO LETTER A'
let s:d[0x311B]='BOPOMOFO LETTER O'
let s:d[0x311C]='BOPOMOFO LETTER E'
let s:d[0x311D]='BOPOMOFO LETTER EH'
let s:d[0x311E]='BOPOMOFO LETTER AI'
let s:d[0x311F]='BOPOMOFO LETTER EI'
let s:d[0x3120]='BOPOMOFO LETTER AU'
let s:d[0x3121]='BOPOMOFO LETTER OU'
let s:d[0x3122]='BOPOMOFO LETTER AN'
let s:d[0x3123]='BOPOMOFO LETTER EN'
let s:d[0x3124]='BOPOMOFO LETTER ANG'
let s:d[0x3125]='BOPOMOFO LETTER ENG'
let s:d[0x3126]='BOPOMOFO LETTER ER'
let s:d[0x3127]='BOPOMOFO LETTER I'
let s:d[0x3128]='BOPOMOFO LETTER U'
let s:d[0x3129]='BOPOMOFO LETTER IU'
let s:d[0x312A]='BOPOMOFO LETTER V'
let s:d[0x312B]='BOPOMOFO LETTER NG'
let s:d[0x312C]='BOPOMOFO LETTER GN'
let s:d[0x312D]='BOPOMOFO LETTER IH'
let s:d[0x3131]='HANGUL LETTER KIYEOK'
let s:d[0x3132]='HANGUL LETTER SSANGKIYEOK'
let s:d[0x3133]='HANGUL LETTER KIYEOK-SIOS'
let s:d[0x3134]='HANGUL LETTER NIEUN'
let s:d[0x3135]='HANGUL LETTER NIEUN-CIEUC'
let s:d[0x3136]='HANGUL LETTER NIEUN-HIEUH'
let s:d[0x3137]='HANGUL LETTER TIKEUT'
let s:d[0x3138]='HANGUL LETTER SSANGTIKEUT'
let s:d[0x3139]='HANGUL LETTER RIEUL'
let s:d[0x313A]='HANGUL LETTER RIEUL-KIYEOK'
let s:d[0x313B]='HANGUL LETTER RIEUL-MIEUM'
let s:d[0x313C]='HANGUL LETTER RIEUL-PIEUP'
let s:d[0x313D]='HANGUL LETTER RIEUL-SIOS'
let s:d[0x313E]='HANGUL LETTER RIEUL-THIEUTH'
let s:d[0x313F]='HANGUL LETTER RIEUL-PHIEUPH'
let s:d[0x3140]='HANGUL LETTER RIEUL-HIEUH'
let s:d[0x3141]='HANGUL LETTER MIEUM'
let s:d[0x3142]='HANGUL LETTER PIEUP'
let s:d[0x3143]='HANGUL LETTER SSANGPIEUP'
let s:d[0x3144]='HANGUL LETTER PIEUP-SIOS'
let s:d[0x3145]='HANGUL LETTER SIOS'
let s:d[0x3146]='HANGUL LETTER SSANGSIOS'
let s:d[0x3147]='HANGUL LETTER IEUNG'
let s:d[0x3148]='HANGUL LETTER CIEUC'
let s:d[0x3149]='HANGUL LETTER SSANGCIEUC'
let s:d[0x314A]='HANGUL LETTER CHIEUCH'
let s:d[0x314B]='HANGUL LETTER KHIEUKH'
let s:d[0x314C]='HANGUL LETTER THIEUTH'
let s:d[0x314D]='HANGUL LETTER PHIEUPH'
let s:d[0x314E]='HANGUL LETTER HIEUH'
let s:d[0x314F]='HANGUL LETTER A'
let s:d[0x3150]='HANGUL LETTER AE'
let s:d[0x3151]='HANGUL LETTER YA'
let s:d[0x3152]='HANGUL LETTER YAE'
let s:d[0x3153]='HANGUL LETTER EO'
let s:d[0x3154]='HANGUL LETTER E'
let s:d[0x3155]='HANGUL LETTER YEO'
let s:d[0x3156]='HANGUL LETTER YE'
let s:d[0x3157]='HANGUL LETTER O'
let s:d[0x3158]='HANGUL LETTER WA'
let s:d[0x3159]='HANGUL LETTER WAE'
let s:d[0x315A]='HANGUL LETTER OE'
let s:d[0x315B]='HANGUL LETTER YO'
let s:d[0x315C]='HANGUL LETTER U'
let s:d[0x315D]='HANGUL LETTER WEO'
let s:d[0x315E]='HANGUL LETTER WE'
let s:d[0x315F]='HANGUL LETTER WI'
let s:d[0x3160]='HANGUL LETTER YU'
let s:d[0x3161]='HANGUL LETTER EU'
let s:d[0x3162]='HANGUL LETTER YI'
let s:d[0x3163]='HANGUL LETTER I'
let s:d[0x3164]='HANGUL FILLER'
let s:d[0x3165]='HANGUL LETTER SSANGNIEUN'
let s:d[0x3166]='HANGUL LETTER NIEUN-TIKEUT'
let s:d[0x3167]='HANGUL LETTER NIEUN-SIOS'
let s:d[0x3168]='HANGUL LETTER NIEUN-PANSIOS'
let s:d[0x3169]='HANGUL LETTER RIEUL-KIYEOK-SIOS'
let s:d[0x316A]='HANGUL LETTER RIEUL-TIKEUT'
let s:d[0x316B]='HANGUL LETTER RIEUL-PIEUP-SIOS'
let s:d[0x316C]='HANGUL LETTER RIEUL-PANSIOS'
let s:d[0x316D]='HANGUL LETTER RIEUL-YEORINHIEUH'
let s:d[0x316E]='HANGUL LETTER MIEUM-PIEUP'
let s:d[0x316F]='HANGUL LETTER MIEUM-SIOS'
let s:d[0x3170]='HANGUL LETTER MIEUM-PANSIOS'
let s:d[0x3171]='HANGUL LETTER KAPYEOUNMIEUM'
let s:d[0x3172]='HANGUL LETTER PIEUP-KIYEOK'
let s:d[0x3173]='HANGUL LETTER PIEUP-TIKEUT'
let s:d[0x3174]='HANGUL LETTER PIEUP-SIOS-KIYEOK'
let s:d[0x3175]='HANGUL LETTER PIEUP-SIOS-TIKEUT'
let s:d[0x3176]='HANGUL LETTER PIEUP-CIEUC'
let s:d[0x3177]='HANGUL LETTER PIEUP-THIEUTH'
let s:d[0x3178]='HANGUL LETTER KAPYEOUNPIEUP'
let s:d[0x3179]='HANGUL LETTER KAPYEOUNSSANGPIEUP'
let s:d[0x317A]='HANGUL LETTER SIOS-KIYEOK'
let s:d[0x317B]='HANGUL LETTER SIOS-NIEUN'
let s:d[0x317C]='HANGUL LETTER SIOS-TIKEUT'
let s:d[0x317D]='HANGUL LETTER SIOS-PIEUP'
let s:d[0x317E]='HANGUL LETTER SIOS-CIEUC'
let s:d[0x317F]='HANGUL LETTER PANSIOS'
let s:d[0x3180]='HANGUL LETTER SSANGIEUNG'
let s:d[0x3181]='HANGUL LETTER YESIEUNG'
let s:d[0x3182]='HANGUL LETTER YESIEUNG-SIOS'
let s:d[0x3183]='HANGUL LETTER YESIEUNG-PANSIOS'
let s:d[0x3184]='HANGUL LETTER KAPYEOUNPHIEUPH'
let s:d[0x3185]='HANGUL LETTER SSANGHIEUH'
let s:d[0x3186]='HANGUL LETTER YEORINHIEUH'
let s:d[0x3187]='HANGUL LETTER YO-YA'
let s:d[0x3188]='HANGUL LETTER YO-YAE'
let s:d[0x3189]='HANGUL LETTER YO-I'
let s:d[0x318A]='HANGUL LETTER YU-YEO'
let s:d[0x318B]='HANGUL LETTER YU-YE'
let s:d[0x318C]='HANGUL LETTER YU-I'
let s:d[0x318D]='HANGUL LETTER ARAEA'
let s:d[0x318E]='HANGUL LETTER ARAEAE'
let s:d[0x3190]='IDEOGRAPHIC ANNOTATION LINKING MARK'
let s:d[0x3191]='IDEOGRAPHIC ANNOTATION REVERSE MARK'
let s:d[0x3192]='IDEOGRAPHIC ANNOTATION ONE MARK'
let s:d[0x3193]='IDEOGRAPHIC ANNOTATION TWO MARK'
let s:d[0x3194]='IDEOGRAPHIC ANNOTATION THREE MARK'
let s:d[0x3195]='IDEOGRAPHIC ANNOTATION FOUR MARK'
let s:d[0x3196]='IDEOGRAPHIC ANNOTATION TOP MARK'
let s:d[0x3197]='IDEOGRAPHIC ANNOTATION MIDDLE MARK'
let s:d[0x3198]='IDEOGRAPHIC ANNOTATION BOTTOM MARK'
let s:d[0x3199]='IDEOGRAPHIC ANNOTATION FIRST MARK'
let s:d[0x319A]='IDEOGRAPHIC ANNOTATION SECOND MARK'
let s:d[0x319B]='IDEOGRAPHIC ANNOTATION THIRD MARK'
let s:d[0x319C]='IDEOGRAPHIC ANNOTATION FOURTH MARK'
let s:d[0x319D]='IDEOGRAPHIC ANNOTATION HEAVEN MARK'
let s:d[0x319E]='IDEOGRAPHIC ANNOTATION EARTH MARK'
let s:d[0x319F]='IDEOGRAPHIC ANNOTATION MAN MARK'
let s:d[0x31A0]='BOPOMOFO LETTER BU'
let s:d[0x31A1]='BOPOMOFO LETTER ZI'
let s:d[0x31A2]='BOPOMOFO LETTER JI'
let s:d[0x31A3]='BOPOMOFO LETTER GU'
let s:d[0x31A4]='BOPOMOFO LETTER EE'
let s:d[0x31A5]='BOPOMOFO LETTER ENN'
let s:d[0x31A6]='BOPOMOFO LETTER OO'
let s:d[0x31A7]='BOPOMOFO LETTER ONN'
let s:d[0x31A8]='BOPOMOFO LETTER IR'
let s:d[0x31A9]='BOPOMOFO LETTER ANN'
let s:d[0x31AA]='BOPOMOFO LETTER INN'
let s:d[0x31AB]='BOPOMOFO LETTER UNN'
let s:d[0x31AC]='BOPOMOFO LETTER IM'
let s:d[0x31AD]='BOPOMOFO LETTER NGG'
let s:d[0x31AE]='BOPOMOFO LETTER AINN'
let s:d[0x31AF]='BOPOMOFO LETTER AUNN'
let s:d[0x31B0]='BOPOMOFO LETTER AM'
let s:d[0x31B1]='BOPOMOFO LETTER OM'
let s:d[0x31B2]='BOPOMOFO LETTER ONG'
let s:d[0x31B3]='BOPOMOFO LETTER INNN'
let s:d[0x31B4]='BOPOMOFO FINAL LETTER P'
let s:d[0x31B5]='BOPOMOFO FINAL LETTER T'
let s:d[0x31B6]='BOPOMOFO FINAL LETTER K'
let s:d[0x31B7]='BOPOMOFO FINAL LETTER H'
let s:d[0x31B8]='BOPOMOFO LETTER GH'
let s:d[0x31B9]='BOPOMOFO LETTER LH'
let s:d[0x31BA]='BOPOMOFO LETTER ZY'
let s:d[0x31C0]='CJK STROKE T'
let s:d[0x31C1]='CJK STROKE WG'
let s:d[0x31C2]='CJK STROKE XG'
let s:d[0x31C3]='CJK STROKE BXG'
let s:d[0x31C4]='CJK STROKE SW'
let s:d[0x31C5]='CJK STROKE HZZ'
let s:d[0x31C6]='CJK STROKE HZG'
let s:d[0x31C7]='CJK STROKE HP'
let s:d[0x31C8]='CJK STROKE HZWG'
let s:d[0x31C9]='CJK STROKE SZWG'
let s:d[0x31CA]='CJK STROKE HZT'
let s:d[0x31CB]='CJK STROKE HZZP'
let s:d[0x31CC]='CJK STROKE HPWG'
let s:d[0x31CD]='CJK STROKE HZW'
let s:d[0x31CE]='CJK STROKE HZZZ'
let s:d[0x31CF]='CJK STROKE N'
let s:d[0x31D0]='CJK STROKE H'
let s:d[0x31D1]='CJK STROKE S'
let s:d[0x31D2]='CJK STROKE P'
let s:d[0x31D3]='CJK STROKE SP'
let s:d[0x31D4]='CJK STROKE D'
let s:d[0x31D5]='CJK STROKE HZ'
let s:d[0x31D6]='CJK STROKE HG'
let s:d[0x31D7]='CJK STROKE SZ'
let s:d[0x31D8]='CJK STROKE SWZ'
let s:d[0x31D9]='CJK STROKE ST'
let s:d[0x31DA]='CJK STROKE SG'
let s:d[0x31DB]='CJK STROKE PD'
let s:d[0x31DC]='CJK STROKE PZ'
let s:d[0x31DD]='CJK STROKE TN'
let s:d[0x31DE]='CJK STROKE SZZ'
let s:d[0x31DF]='CJK STROKE SWG'
let s:d[0x31E0]='CJK STROKE HXWG'
let s:d[0x31E1]='CJK STROKE HZZZG'
let s:d[0x31E2]='CJK STROKE PG'
let s:d[0x31E3]='CJK STROKE Q'
let s:d[0x31F0]='KATAKANA LETTER SMALL KU'
let s:d[0x31F1]='KATAKANA LETTER SMALL SI'
let s:d[0x31F2]='KATAKANA LETTER SMALL SU'
let s:d[0x31F3]='KATAKANA LETTER SMALL TO'
let s:d[0x31F4]='KATAKANA LETTER SMALL NU'
let s:d[0x31F5]='KATAKANA LETTER SMALL HA'
let s:d[0x31F6]='KATAKANA LETTER SMALL HI'
let s:d[0x31F7]='KATAKANA LETTER SMALL HU'
let s:d[0x31F8]='KATAKANA LETTER SMALL HE'
let s:d[0x31F9]='KATAKANA LETTER SMALL HO'
let s:d[0x31FA]='KATAKANA LETTER SMALL MU'
let s:d[0x31FB]='KATAKANA LETTER SMALL RA'
let s:d[0x31FC]='KATAKANA LETTER SMALL RI'
let s:d[0x31FD]='KATAKANA LETTER SMALL RU'
let s:d[0x31FE]='KATAKANA LETTER SMALL RE'
let s:d[0x31FF]='KATAKANA LETTER SMALL RO'
let s:d[0x3200]='PARENTHESIZED HANGUL KIYEOK'
let s:d[0x3201]='PARENTHESIZED HANGUL NIEUN'
let s:d[0x3202]='PARENTHESIZED HANGUL TIKEUT'
let s:d[0x3203]='PARENTHESIZED HANGUL RIEUL'
let s:d[0x3204]='PARENTHESIZED HANGUL MIEUM'
let s:d[0x3205]='PARENTHESIZED HANGUL PIEUP'
let s:d[0x3206]='PARENTHESIZED HANGUL SIOS'
let s:d[0x3207]='PARENTHESIZED HANGUL IEUNG'
let s:d[0x3208]='PARENTHESIZED HANGUL CIEUC'
let s:d[0x3209]='PARENTHESIZED HANGUL CHIEUCH'
let s:d[0x320A]='PARENTHESIZED HANGUL KHIEUKH'
let s:d[0x320B]='PARENTHESIZED HANGUL THIEUTH'
let s:d[0x320C]='PARENTHESIZED HANGUL PHIEUPH'
let s:d[0x320D]='PARENTHESIZED HANGUL HIEUH'
let s:d[0x320E]='PARENTHESIZED HANGUL KIYEOK A'
let s:d[0x320F]='PARENTHESIZED HANGUL NIEUN A'
let s:d[0x3210]='PARENTHESIZED HANGUL TIKEUT A'
let s:d[0x3211]='PARENTHESIZED HANGUL RIEUL A'
let s:d[0x3212]='PARENTHESIZED HANGUL MIEUM A'
let s:d[0x3213]='PARENTHESIZED HANGUL PIEUP A'
let s:d[0x3214]='PARENTHESIZED HANGUL SIOS A'
let s:d[0x3215]='PARENTHESIZED HANGUL IEUNG A'
let s:d[0x3216]='PARENTHESIZED HANGUL CIEUC A'
let s:d[0x3217]='PARENTHESIZED HANGUL CHIEUCH A'
let s:d[0x3218]='PARENTHESIZED HANGUL KHIEUKH A'
let s:d[0x3219]='PARENTHESIZED HANGUL THIEUTH A'
let s:d[0x321A]='PARENTHESIZED HANGUL PHIEUPH A'
let s:d[0x321B]='PARENTHESIZED HANGUL HIEUH A'
let s:d[0x321C]='PARENTHESIZED HANGUL CIEUC U'
let s:d[0x321D]='PARENTHESIZED KOREAN CHARACTER OJEON'
let s:d[0x321E]='PARENTHESIZED KOREAN CHARACTER O HU'
let s:d[0x3220]='PARENTHESIZED IDEOGRAPH ONE'
let s:d[0x3221]='PARENTHESIZED IDEOGRAPH TWO'
let s:d[0x3222]='PARENTHESIZED IDEOGRAPH THREE'
let s:d[0x3223]='PARENTHESIZED IDEOGRAPH FOUR'
let s:d[0x3224]='PARENTHESIZED IDEOGRAPH FIVE'
let s:d[0x3225]='PARENTHESIZED IDEOGRAPH SIX'
let s:d[0x3226]='PARENTHESIZED IDEOGRAPH SEVEN'
let s:d[0x3227]='PARENTHESIZED IDEOGRAPH EIGHT'
let s:d[0x3228]='PARENTHESIZED IDEOGRAPH NINE'
let s:d[0x3229]='PARENTHESIZED IDEOGRAPH TEN'
let s:d[0x322A]='PARENTHESIZED IDEOGRAPH MOON'
let s:d[0x322B]='PARENTHESIZED IDEOGRAPH FIRE'
let s:d[0x322C]='PARENTHESIZED IDEOGRAPH WATER'
let s:d[0x322D]='PARENTHESIZED IDEOGRAPH WOOD'
let s:d[0x322E]='PARENTHESIZED IDEOGRAPH METAL'
let s:d[0x322F]='PARENTHESIZED IDEOGRAPH EARTH'
let s:d[0x3230]='PARENTHESIZED IDEOGRAPH SUN'
let s:d[0x3231]='PARENTHESIZED IDEOGRAPH STOCK'
let s:d[0x3232]='PARENTHESIZED IDEOGRAPH HAVE'
let s:d[0x3233]='PARENTHESIZED IDEOGRAPH SOCIETY'
let s:d[0x3234]='PARENTHESIZED IDEOGRAPH NAME'
let s:d[0x3235]='PARENTHESIZED IDEOGRAPH SPECIAL'
let s:d[0x3236]='PARENTHESIZED IDEOGRAPH FINANCIAL'
let s:d[0x3237]='PARENTHESIZED IDEOGRAPH CONGRATULATION'
let s:d[0x3238]='PARENTHESIZED IDEOGRAPH LABOR'
let s:d[0x3239]='PARENTHESIZED IDEOGRAPH REPRESENT'
let s:d[0x323A]='PARENTHESIZED IDEOGRAPH CALL'
let s:d[0x323B]='PARENTHESIZED IDEOGRAPH STUDY'
let s:d[0x323C]='PARENTHESIZED IDEOGRAPH SUPERVISE'
let s:d[0x323D]='PARENTHESIZED IDEOGRAPH ENTERPRISE'
let s:d[0x323E]='PARENTHESIZED IDEOGRAPH RESOURCE'
let s:d[0x323F]='PARENTHESIZED IDEOGRAPH ALLIANCE'
let s:d[0x3240]='PARENTHESIZED IDEOGRAPH FESTIVAL'
let s:d[0x3241]='PARENTHESIZED IDEOGRAPH REST'
let s:d[0x3242]='PARENTHESIZED IDEOGRAPH SELF'
let s:d[0x3243]='PARENTHESIZED IDEOGRAPH REACH'
let s:d[0x3244]='CIRCLED IDEOGRAPH QUESTION'
let s:d[0x3245]='CIRCLED IDEOGRAPH KINDERGARTEN'
let s:d[0x3246]='CIRCLED IDEOGRAPH SCHOOL'
let s:d[0x3247]='CIRCLED IDEOGRAPH KOTO'
let s:d[0x3248]='CIRCLED NUMBER TEN ON BLACK SQUARE'
let s:d[0x3249]='CIRCLED NUMBER TWENTY ON BLACK SQUARE'
let s:d[0x324A]='CIRCLED NUMBER THIRTY ON BLACK SQUARE'
let s:d[0x324B]='CIRCLED NUMBER FORTY ON BLACK SQUARE'
let s:d[0x324C]='CIRCLED NUMBER FIFTY ON BLACK SQUARE'
let s:d[0x324D]='CIRCLED NUMBER SIXTY ON BLACK SQUARE'
let s:d[0x324E]='CIRCLED NUMBER SEVENTY ON BLACK SQUARE'
let s:d[0x324F]='CIRCLED NUMBER EIGHTY ON BLACK SQUARE'
let s:d[0x3250]='PARTNERSHIP SIGN'
let s:d[0x3251]='CIRCLED NUMBER TWENTY ONE'
let s:d[0x3252]='CIRCLED NUMBER TWENTY TWO'
let s:d[0x3253]='CIRCLED NUMBER TWENTY THREE'
let s:d[0x3254]='CIRCLED NUMBER TWENTY FOUR'
let s:d[0x3255]='CIRCLED NUMBER TWENTY FIVE'
let s:d[0x3256]='CIRCLED NUMBER TWENTY SIX'
let s:d[0x3257]='CIRCLED NUMBER TWENTY SEVEN'
let s:d[0x3258]='CIRCLED NUMBER TWENTY EIGHT'
let s:d[0x3259]='CIRCLED NUMBER TWENTY NINE'
let s:d[0x325A]='CIRCLED NUMBER THIRTY'
let s:d[0x325B]='CIRCLED NUMBER THIRTY ONE'
let s:d[0x325C]='CIRCLED NUMBER THIRTY TWO'
let s:d[0x325D]='CIRCLED NUMBER THIRTY THREE'
let s:d[0x325E]='CIRCLED NUMBER THIRTY FOUR'
let s:d[0x325F]='CIRCLED NUMBER THIRTY FIVE'
let s:d[0x3260]='CIRCLED HANGUL KIYEOK'
let s:d[0x3261]='CIRCLED HANGUL NIEUN'
let s:d[0x3262]='CIRCLED HANGUL TIKEUT'
let s:d[0x3263]='CIRCLED HANGUL RIEUL'
let s:d[0x3264]='CIRCLED HANGUL MIEUM'
let s:d[0x3265]='CIRCLED HANGUL PIEUP'
let s:d[0x3266]='CIRCLED HANGUL SIOS'
let s:d[0x3267]='CIRCLED HANGUL IEUNG'
let s:d[0x3268]='CIRCLED HANGUL CIEUC'
let s:d[0x3269]='CIRCLED HANGUL CHIEUCH'
let s:d[0x326A]='CIRCLED HANGUL KHIEUKH'
let s:d[0x326B]='CIRCLED HANGUL THIEUTH'
let s:d[0x326C]='CIRCLED HANGUL PHIEUPH'
let s:d[0x326D]='CIRCLED HANGUL HIEUH'
let s:d[0x326E]='CIRCLED HANGUL KIYEOK A'
let s:d[0x326F]='CIRCLED HANGUL NIEUN A'
let s:d[0x3270]='CIRCLED HANGUL TIKEUT A'
let s:d[0x3271]='CIRCLED HANGUL RIEUL A'
let s:d[0x3272]='CIRCLED HANGUL MIEUM A'
let s:d[0x3273]='CIRCLED HANGUL PIEUP A'
let s:d[0x3274]='CIRCLED HANGUL SIOS A'
let s:d[0x3275]='CIRCLED HANGUL IEUNG A'
let s:d[0x3276]='CIRCLED HANGUL CIEUC A'
let s:d[0x3277]='CIRCLED HANGUL CHIEUCH A'
let s:d[0x3278]='CIRCLED HANGUL KHIEUKH A'
let s:d[0x3279]='CIRCLED HANGUL THIEUTH A'
let s:d[0x327A]='CIRCLED HANGUL PHIEUPH A'
let s:d[0x327B]='CIRCLED HANGUL HIEUH A'
let s:d[0x327C]='CIRCLED KOREAN CHARACTER CHAMKO'
let s:d[0x327D]='CIRCLED KOREAN CHARACTER JUEUI'
let s:d[0x327E]='CIRCLED HANGUL IEUNG U'
let s:d[0x327F]='KOREAN STANDARD SYMBOL'
let s:d[0x3280]='CIRCLED IDEOGRAPH ONE'
let s:d[0x3281]='CIRCLED IDEOGRAPH TWO'
let s:d[0x3282]='CIRCLED IDEOGRAPH THREE'
let s:d[0x3283]='CIRCLED IDEOGRAPH FOUR'
let s:d[0x3284]='CIRCLED IDEOGRAPH FIVE'
let s:d[0x3285]='CIRCLED IDEOGRAPH SIX'
let s:d[0x3286]='CIRCLED IDEOGRAPH SEVEN'
let s:d[0x3287]='CIRCLED IDEOGRAPH EIGHT'
let s:d[0x3288]='CIRCLED IDEOGRAPH NINE'
let s:d[0x3289]='CIRCLED IDEOGRAPH TEN'
let s:d[0x328A]='CIRCLED IDEOGRAPH MOON'
let s:d[0x328B]='CIRCLED IDEOGRAPH FIRE'
let s:d[0x328C]='CIRCLED IDEOGRAPH WATER'
let s:d[0x328D]='CIRCLED IDEOGRAPH WOOD'
let s:d[0x328E]='CIRCLED IDEOGRAPH METAL'
let s:d[0x328F]='CIRCLED IDEOGRAPH EARTH'
let s:d[0x3290]='CIRCLED IDEOGRAPH SUN'
let s:d[0x3291]='CIRCLED IDEOGRAPH STOCK'
let s:d[0x3292]='CIRCLED IDEOGRAPH HAVE'
let s:d[0x3293]='CIRCLED IDEOGRAPH SOCIETY'
let s:d[0x3294]='CIRCLED IDEOGRAPH NAME'
let s:d[0x3295]='CIRCLED IDEOGRAPH SPECIAL'
let s:d[0x3296]='CIRCLED IDEOGRAPH FINANCIAL'
let s:d[0x3297]='CIRCLED IDEOGRAPH CONGRATULATION'
let s:d[0x3298]='CIRCLED IDEOGRAPH LABOR'
let s:d[0x3299]='CIRCLED IDEOGRAPH SECRET'
let s:d[0x329A]='CIRCLED IDEOGRAPH MALE'
let s:d[0x329B]='CIRCLED IDEOGRAPH FEMALE'
let s:d[0x329C]='CIRCLED IDEOGRAPH SUITABLE'
let s:d[0x329D]='CIRCLED IDEOGRAPH EXCELLENT'
let s:d[0x329E]='CIRCLED IDEOGRAPH PRINT'
let s:d[0x329F]='CIRCLED IDEOGRAPH ATTENTION'
let s:d[0x32A0]='CIRCLED IDEOGRAPH ITEM'
let s:d[0x32A1]='CIRCLED IDEOGRAPH REST'
let s:d[0x32A2]='CIRCLED IDEOGRAPH COPY'
let s:d[0x32A3]='CIRCLED IDEOGRAPH CORRECT'
let s:d[0x32A4]='CIRCLED IDEOGRAPH HIGH'
let s:d[0x32A5]='CIRCLED IDEOGRAPH CENTRE'
let s:d[0x32A6]='CIRCLED IDEOGRAPH LOW'
let s:d[0x32A7]='CIRCLED IDEOGRAPH LEFT'
let s:d[0x32A8]='CIRCLED IDEOGRAPH RIGHT'
let s:d[0x32A9]='CIRCLED IDEOGRAPH MEDICINE'
let s:d[0x32AA]='CIRCLED IDEOGRAPH RELIGION'
let s:d[0x32AB]='CIRCLED IDEOGRAPH STUDY'
let s:d[0x32AC]='CIRCLED IDEOGRAPH SUPERVISE'
let s:d[0x32AD]='CIRCLED IDEOGRAPH ENTERPRISE'
let s:d[0x32AE]='CIRCLED IDEOGRAPH RESOURCE'
let s:d[0x32AF]='CIRCLED IDEOGRAPH ALLIANCE'
let s:d[0x32B0]='CIRCLED IDEOGRAPH NIGHT'
let s:d[0x32B1]='CIRCLED NUMBER THIRTY SIX'
let s:d[0x32B2]='CIRCLED NUMBER THIRTY SEVEN'
let s:d[0x32B3]='CIRCLED NUMBER THIRTY EIGHT'
let s:d[0x32B4]='CIRCLED NUMBER THIRTY NINE'
let s:d[0x32B5]='CIRCLED NUMBER FORTY'
let s:d[0x32B6]='CIRCLED NUMBER FORTY ONE'
let s:d[0x32B7]='CIRCLED NUMBER FORTY TWO'
let s:d[0x32B8]='CIRCLED NUMBER FORTY THREE'
let s:d[0x32B9]='CIRCLED NUMBER FORTY FOUR'
let s:d[0x32BA]='CIRCLED NUMBER FORTY FIVE'
let s:d[0x32BB]='CIRCLED NUMBER FORTY SIX'
let s:d[0x32BC]='CIRCLED NUMBER FORTY SEVEN'
let s:d[0x32BD]='CIRCLED NUMBER FORTY EIGHT'
let s:d[0x32BE]='CIRCLED NUMBER FORTY NINE'
let s:d[0x32BF]='CIRCLED NUMBER FIFTY'
let s:d[0x32C0]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR JANUARY'
let s:d[0x32C1]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR FEBRUARY'
let s:d[0x32C2]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR MARCH'
let s:d[0x32C3]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR APRIL'
let s:d[0x32C4]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR MAY'
let s:d[0x32C5]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR JUNE'
let s:d[0x32C6]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR JULY'
let s:d[0x32C7]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR AUGUST'
let s:d[0x32C8]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR SEPTEMBER'
let s:d[0x32C9]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR OCTOBER'
let s:d[0x32CA]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR NOVEMBER'
let s:d[0x32CB]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR DECEMBER'
let s:d[0x32CC]='SQUARE HG'
let s:d[0x32CD]='SQUARE ERG'
let s:d[0x32CE]='SQUARE EV'
let s:d[0x32CF]='LIMITED LIABILITY SIGN'
let s:d[0x32D0]='CIRCLED KATAKANA A'
let s:d[0x32D1]='CIRCLED KATAKANA I'
let s:d[0x32D2]='CIRCLED KATAKANA U'
let s:d[0x32D3]='CIRCLED KATAKANA E'
let s:d[0x32D4]='CIRCLED KATAKANA O'
let s:d[0x32D5]='CIRCLED KATAKANA KA'
let s:d[0x32D6]='CIRCLED KATAKANA KI'
let s:d[0x32D7]='CIRCLED KATAKANA KU'
let s:d[0x32D8]='CIRCLED KATAKANA KE'
let s:d[0x32D9]='CIRCLED KATAKANA KO'
let s:d[0x32DA]='CIRCLED KATAKANA SA'
let s:d[0x32DB]='CIRCLED KATAKANA SI'
let s:d[0x32DC]='CIRCLED KATAKANA SU'
let s:d[0x32DD]='CIRCLED KATAKANA SE'
let s:d[0x32DE]='CIRCLED KATAKANA SO'
let s:d[0x32DF]='CIRCLED KATAKANA TA'
let s:d[0x32E0]='CIRCLED KATAKANA TI'
let s:d[0x32E1]='CIRCLED KATAKANA TU'
let s:d[0x32E2]='CIRCLED KATAKANA TE'
let s:d[0x32E3]='CIRCLED KATAKANA TO'
let s:d[0x32E4]='CIRCLED KATAKANA NA'
let s:d[0x32E5]='CIRCLED KATAKANA NI'
let s:d[0x32E6]='CIRCLED KATAKANA NU'
let s:d[0x32E7]='CIRCLED KATAKANA NE'
let s:d[0x32E8]='CIRCLED KATAKANA NO'
let s:d[0x32E9]='CIRCLED KATAKANA HA'
let s:d[0x32EA]='CIRCLED KATAKANA HI'
let s:d[0x32EB]='CIRCLED KATAKANA HU'
let s:d[0x32EC]='CIRCLED KATAKANA HE'
let s:d[0x32ED]='CIRCLED KATAKANA HO'
let s:d[0x32EE]='CIRCLED KATAKANA MA'
let s:d[0x32EF]='CIRCLED KATAKANA MI'
let s:d[0x32F0]='CIRCLED KATAKANA MU'
let s:d[0x32F1]='CIRCLED KATAKANA ME'
let s:d[0x32F2]='CIRCLED KATAKANA MO'
let s:d[0x32F3]='CIRCLED KATAKANA YA'
let s:d[0x32F4]='CIRCLED KATAKANA YU'
let s:d[0x32F5]='CIRCLED KATAKANA YO'
let s:d[0x32F6]='CIRCLED KATAKANA RA'
let s:d[0x32F7]='CIRCLED KATAKANA RI'
let s:d[0x32F8]='CIRCLED KATAKANA RU'
let s:d[0x32F9]='CIRCLED KATAKANA RE'
let s:d[0x32FA]='CIRCLED KATAKANA RO'
let s:d[0x32FB]='CIRCLED KATAKANA WA'
let s:d[0x32FC]='CIRCLED KATAKANA WI'
let s:d[0x32FD]='CIRCLED KATAKANA WE'
let s:d[0x32FE]='CIRCLED KATAKANA WO'
let s:d[0x3300]='SQUARE APAATO'
let s:d[0x3301]='SQUARE ARUHUA'
let s:d[0x3302]='SQUARE ANPEA'
let s:d[0x3303]='SQUARE AARU'
let s:d[0x3304]='SQUARE ININGU'
let s:d[0x3305]='SQUARE INTI'
let s:d[0x3306]='SQUARE UON'
let s:d[0x3307]='SQUARE ESUKUUDO'
let s:d[0x3308]='SQUARE EEKAA'
let s:d[0x3309]='SQUARE ONSU'
let s:d[0x330A]='SQUARE OOMU'
let s:d[0x330B]='SQUARE KAIRI'
let s:d[0x330C]='SQUARE KARATTO'
let s:d[0x330D]='SQUARE KARORII'
let s:d[0x330E]='SQUARE GARON'
let s:d[0x330F]='SQUARE GANMA'
let s:d[0x3310]='SQUARE GIGA'
let s:d[0x3311]='SQUARE GINII'
let s:d[0x3312]='SQUARE KYURII'
let s:d[0x3313]='SQUARE GIRUDAA'
let s:d[0x3314]='SQUARE KIRO'
let s:d[0x3315]='SQUARE KIROGURAMU'
let s:d[0x3316]='SQUARE KIROMEETORU'
let s:d[0x3317]='SQUARE KIROWATTO'
let s:d[0x3318]='SQUARE GURAMU'
let s:d[0x3319]='SQUARE GURAMUTON'
let s:d[0x331A]='SQUARE KURUZEIRO'
let s:d[0x331B]='SQUARE KUROONE'
let s:d[0x331C]='SQUARE KEESU'
let s:d[0x331D]='SQUARE KORUNA'
let s:d[0x331E]='SQUARE KOOPO'
let s:d[0x331F]='SQUARE SAIKURU'
let s:d[0x3320]='SQUARE SANTIIMU'
let s:d[0x3321]='SQUARE SIRINGU'
let s:d[0x3322]='SQUARE SENTI'
let s:d[0x3323]='SQUARE SENTO'
let s:d[0x3324]='SQUARE DAASU'
let s:d[0x3325]='SQUARE DESI'
let s:d[0x3326]='SQUARE DORU'
let s:d[0x3327]='SQUARE TON'
let s:d[0x3328]='SQUARE NANO'
let s:d[0x3329]='SQUARE NOTTO'
let s:d[0x332A]='SQUARE HAITU'
let s:d[0x332B]='SQUARE PAASENTO'
let s:d[0x332C]='SQUARE PAATU'
let s:d[0x332D]='SQUARE BAARERU'
let s:d[0x332E]='SQUARE PIASUTORU'
let s:d[0x332F]='SQUARE PIKURU'
let s:d[0x3330]='SQUARE PIKO'
let s:d[0x3331]='SQUARE BIRU'
let s:d[0x3332]='SQUARE HUARADDO'
let s:d[0x3333]='SQUARE HUIITO'
let s:d[0x3334]='SQUARE BUSSYERU'
let s:d[0x3335]='SQUARE HURAN'
let s:d[0x3336]='SQUARE HEKUTAARU'
let s:d[0x3337]='SQUARE PESO'
let s:d[0x3338]='SQUARE PENIHI'
let s:d[0x3339]='SQUARE HERUTU'
let s:d[0x333A]='SQUARE PENSU'
let s:d[0x333B]='SQUARE PEEZI'
let s:d[0x333C]='SQUARE BEETA'
let s:d[0x333D]='SQUARE POINTO'
let s:d[0x333E]='SQUARE BORUTO'
let s:d[0x333F]='SQUARE HON'
let s:d[0x3340]='SQUARE PONDO'
let s:d[0x3341]='SQUARE HOORU'
let s:d[0x3342]='SQUARE HOON'
let s:d[0x3343]='SQUARE MAIKURO'
let s:d[0x3344]='SQUARE MAIRU'
let s:d[0x3345]='SQUARE MAHHA'
let s:d[0x3346]='SQUARE MARUKU'
let s:d[0x3347]='SQUARE MANSYON'
let s:d[0x3348]='SQUARE MIKURON'
let s:d[0x3349]='SQUARE MIRI'
let s:d[0x334A]='SQUARE MIRIBAARU'
let s:d[0x334B]='SQUARE MEGA'
let s:d[0x334C]='SQUARE MEGATON'
let s:d[0x334D]='SQUARE MEETORU'
let s:d[0x334E]='SQUARE YAADO'
let s:d[0x334F]='SQUARE YAARU'
let s:d[0x3350]='SQUARE YUAN'
let s:d[0x3351]='SQUARE RITTORU'
let s:d[0x3352]='SQUARE RIRA'
let s:d[0x3353]='SQUARE RUPII'
let s:d[0x3354]='SQUARE RUUBURU'
let s:d[0x3355]='SQUARE REMU'
let s:d[0x3356]='SQUARE RENTOGEN'
let s:d[0x3357]='SQUARE WATTO'
let s:d[0x3358]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR ZERO'
let s:d[0x3359]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR ONE'
let s:d[0x335A]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWO'
let s:d[0x335B]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR THREE'
let s:d[0x335C]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR FOUR'
let s:d[0x335D]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR FIVE'
let s:d[0x335E]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR SIX'
let s:d[0x335F]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR SEVEN'
let s:d[0x3360]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR EIGHT'
let s:d[0x3361]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR NINE'
let s:d[0x3362]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TEN'
let s:d[0x3363]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR ELEVEN'
let s:d[0x3364]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWELVE'
let s:d[0x3365]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR THIRTEEN'
let s:d[0x3366]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR FOURTEEN'
let s:d[0x3367]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR FIFTEEN'
let s:d[0x3368]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR SIXTEEN'
let s:d[0x3369]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR SEVENTEEN'
let s:d[0x336A]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR EIGHTEEN'
let s:d[0x336B]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR NINETEEN'
let s:d[0x336C]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWENTY'
let s:d[0x336D]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWENTY-ONE'
let s:d[0x336E]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWENTY-TWO'
let s:d[0x336F]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWENTY-THREE'
let s:d[0x3370]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWENTY-FOUR'
let s:d[0x3371]='SQUARE HPA'
let s:d[0x3372]='SQUARE DA'
let s:d[0x3373]='SQUARE AU'
let s:d[0x3374]='SQUARE BAR'
let s:d[0x3375]='SQUARE OV'
let s:d[0x3376]='SQUARE PC'
let s:d[0x3377]='SQUARE DM'
let s:d[0x3378]='SQUARE DM SQUARED'
let s:d[0x3379]='SQUARE DM CUBED'
let s:d[0x337A]='SQUARE IU'
let s:d[0x337B]='SQUARE ERA NAME HEISEI'
let s:d[0x337C]='SQUARE ERA NAME SYOUWA'
let s:d[0x337D]='SQUARE ERA NAME TAISYOU'
let s:d[0x337E]='SQUARE ERA NAME MEIZI'
let s:d[0x337F]='SQUARE CORPORATION'
let s:d[0x3380]='SQUARE PA AMPS'
let s:d[0x3381]='SQUARE NA'
let s:d[0x3382]='SQUARE MU A'
let s:d[0x3383]='SQUARE MA'
let s:d[0x3384]='SQUARE KA'
let s:d[0x3385]='SQUARE KB'
let s:d[0x3386]='SQUARE MB'
let s:d[0x3387]='SQUARE GB'
let s:d[0x3388]='SQUARE CAL'
let s:d[0x3389]='SQUARE KCAL'
let s:d[0x338A]='SQUARE PF'
let s:d[0x338B]='SQUARE NF'
let s:d[0x338C]='SQUARE MU F'
let s:d[0x338D]='SQUARE MU G'
let s:d[0x338E]='SQUARE MG'
let s:d[0x338F]='SQUARE KG'
let s:d[0x3390]='SQUARE HZ'
let s:d[0x3391]='SQUARE KHZ'
let s:d[0x3392]='SQUARE MHZ'
let s:d[0x3393]='SQUARE GHZ'
let s:d[0x3394]='SQUARE THZ'
let s:d[0x3395]='SQUARE MU L'
let s:d[0x3396]='SQUARE ML'
let s:d[0x3397]='SQUARE DL'
let s:d[0x3398]='SQUARE KL'
let s:d[0x3399]='SQUARE FM'
let s:d[0x339A]='SQUARE NM'
let s:d[0x339B]='SQUARE MU M'
let s:d[0x339C]='SQUARE MM'
let s:d[0x339D]='SQUARE CM'
let s:d[0x339E]='SQUARE KM'
let s:d[0x339F]='SQUARE MM SQUARED'
let s:d[0x33A0]='SQUARE CM SQUARED'
let s:d[0x33A1]='SQUARE M SQUARED'
let s:d[0x33A2]='SQUARE KM SQUARED'
let s:d[0x33A3]='SQUARE MM CUBED'
let s:d[0x33A4]='SQUARE CM CUBED'
let s:d[0x33A5]='SQUARE M CUBED'
let s:d[0x33A6]='SQUARE KM CUBED'
let s:d[0x33A7]='SQUARE M OVER S'
let s:d[0x33A8]='SQUARE M OVER S SQUARED'
let s:d[0x33A9]='SQUARE PA'
let s:d[0x33AA]='SQUARE KPA'
let s:d[0x33AB]='SQUARE MPA'
let s:d[0x33AC]='SQUARE GPA'
let s:d[0x33AD]='SQUARE RAD'
let s:d[0x33AE]='SQUARE RAD OVER S'
let s:d[0x33AF]='SQUARE RAD OVER S SQUARED'
let s:d[0x33B0]='SQUARE PS'
let s:d[0x33B1]='SQUARE NS'
let s:d[0x33B2]='SQUARE MU S'
let s:d[0x33B3]='SQUARE MS'
let s:d[0x33B4]='SQUARE PV'
let s:d[0x33B5]='SQUARE NV'
let s:d[0x33B6]='SQUARE MU V'
let s:d[0x33B7]='SQUARE MV'
let s:d[0x33B8]='SQUARE KV'
let s:d[0x33B9]='SQUARE MV MEGA'
let s:d[0x33BA]='SQUARE PW'
let s:d[0x33BB]='SQUARE NW'
let s:d[0x33BC]='SQUARE MU W'
let s:d[0x33BD]='SQUARE MW'
let s:d[0x33BE]='SQUARE KW'
let s:d[0x33BF]='SQUARE MW MEGA'
let s:d[0x33C0]='SQUARE K OHM'
let s:d[0x33C1]='SQUARE M OHM'
let s:d[0x33C2]='SQUARE AM'
let s:d[0x33C3]='SQUARE BQ'
let s:d[0x33C4]='SQUARE CC'
let s:d[0x33C5]='SQUARE CD'
let s:d[0x33C6]='SQUARE C OVER KG'
let s:d[0x33C7]='SQUARE CO'
let s:d[0x33C8]='SQUARE DB'
let s:d[0x33C9]='SQUARE GY'
let s:d[0x33CA]='SQUARE HA'
let s:d[0x33CB]='SQUARE HP'
let s:d[0x33CC]='SQUARE IN'
let s:d[0x33CD]='SQUARE KK'
let s:d[0x33CE]='SQUARE KM CAPITAL'
let s:d[0x33CF]='SQUARE KT'
let s:d[0x33D0]='SQUARE LM'
let s:d[0x33D1]='SQUARE LN'
let s:d[0x33D2]='SQUARE LOG'
let s:d[0x33D3]='SQUARE LX'
let s:d[0x33D4]='SQUARE MB SMALL'
let s:d[0x33D5]='SQUARE MIL'
let s:d[0x33D6]='SQUARE MOL'
let s:d[0x33D7]='SQUARE PH'
let s:d[0x33D8]='SQUARE PM'
let s:d[0x33D9]='SQUARE PPM'
let s:d[0x33DA]='SQUARE PR'
let s:d[0x33DB]='SQUARE SR'
let s:d[0x33DC]='SQUARE SV'
let s:d[0x33DD]='SQUARE WB'
let s:d[0x33DE]='SQUARE V OVER M'
let s:d[0x33DF]='SQUARE A OVER M'
let s:d[0x33E0]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY ONE'
let s:d[0x33E1]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWO'
let s:d[0x33E2]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY THREE'
let s:d[0x33E3]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY FOUR'
let s:d[0x33E4]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY FIVE'
let s:d[0x33E5]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY SIX'
let s:d[0x33E6]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY SEVEN'
let s:d[0x33E7]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY EIGHT'
let s:d[0x33E8]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY NINE'
let s:d[0x33E9]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TEN'
let s:d[0x33EA]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY ELEVEN'
let s:d[0x33EB]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWELVE'
let s:d[0x33EC]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY THIRTEEN'
let s:d[0x33ED]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY FOURTEEN'
let s:d[0x33EE]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY FIFTEEN'
let s:d[0x33EF]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY SIXTEEN'
let s:d[0x33F0]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY SEVENTEEN'
let s:d[0x33F1]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY EIGHTEEN'
let s:d[0x33F2]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY NINETEEN'
let s:d[0x33F3]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY'
let s:d[0x33F4]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-ONE'
let s:d[0x33F5]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-TWO'
let s:d[0x33F6]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-THREE'
let s:d[0x33F7]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-FOUR'
let s:d[0x33F8]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-FIVE'
let s:d[0x33F9]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-SIX'
let s:d[0x33FA]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-SEVEN'
let s:d[0x33FB]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-EIGHT'
let s:d[0x33FC]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-NINE'
let s:d[0x33FD]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY THIRTY'
let s:d[0x33FE]='IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY THIRTY-ONE'
let s:d[0x33FF]='SQUARE GAL'
let s:d[0x4DC0]='HEXAGRAM FOR THE CREATIVE HEAVEN'
let s:d[0x4DC1]='HEXAGRAM FOR THE RECEPTIVE EARTH'
let s:d[0x4DC2]='HEXAGRAM FOR DIFFICULTY AT THE BEGINNING'
let s:d[0x4DC3]='HEXAGRAM FOR YOUTHFUL FOLLY'
let s:d[0x4DC4]='HEXAGRAM FOR WAITING'
let s:d[0x4DC5]='HEXAGRAM FOR CONFLICT'
let s:d[0x4DC6]='HEXAGRAM FOR THE ARMY'
let s:d[0x4DC7]='HEXAGRAM FOR HOLDING TOGETHER'
let s:d[0x4DC8]='HEXAGRAM FOR SMALL TAMING'
let s:d[0x4DC9]='HEXAGRAM FOR TREADING'
let s:d[0x4DCA]='HEXAGRAM FOR PEACE'
let s:d[0x4DCB]='HEXAGRAM FOR STANDSTILL'
let s:d[0x4DCC]='HEXAGRAM FOR FELLOWSHIP'
let s:d[0x4DCD]='HEXAGRAM FOR GREAT POSSESSION'
let s:d[0x4DCE]='HEXAGRAM FOR MODESTY'
let s:d[0x4DCF]='HEXAGRAM FOR ENTHUSIASM'
let s:d[0x4DD0]='HEXAGRAM FOR FOLLOWING'
let s:d[0x4DD1]='HEXAGRAM FOR WORK ON THE DECAYED'
let s:d[0x4DD2]='HEXAGRAM FOR APPROACH'
let s:d[0x4DD3]='HEXAGRAM FOR CONTEMPLATION'
let s:d[0x4DD4]='HEXAGRAM FOR BITING THROUGH'
let s:d[0x4DD5]='HEXAGRAM FOR GRACE'
let s:d[0x4DD6]='HEXAGRAM FOR SPLITTING APART'
let s:d[0x4DD7]='HEXAGRAM FOR RETURN'
let s:d[0x4DD8]='HEXAGRAM FOR INNOCENCE'
let s:d[0x4DD9]='HEXAGRAM FOR GREAT TAMING'
let s:d[0x4DDA]='HEXAGRAM FOR MOUTH CORNERS'
let s:d[0x4DDB]='HEXAGRAM FOR GREAT PREPONDERANCE'
let s:d[0x4DDC]='HEXAGRAM FOR THE ABYSMAL WATER'
let s:d[0x4DDD]='HEXAGRAM FOR THE CLINGING FIRE'
let s:d[0x4DDE]='HEXAGRAM FOR INFLUENCE'
let s:d[0x4DDF]='HEXAGRAM FOR DURATION'
let s:d[0x4DE0]='HEXAGRAM FOR RETREAT'
let s:d[0x4DE1]='HEXAGRAM FOR GREAT POWER'
let s:d[0x4DE2]='HEXAGRAM FOR PROGRESS'
let s:d[0x4DE3]='HEXAGRAM FOR DARKENING OF THE LIGHT'
let s:d[0x4DE4]='HEXAGRAM FOR THE FAMILY'
let s:d[0x4DE5]='HEXAGRAM FOR OPPOSITION'
let s:d[0x4DE6]='HEXAGRAM FOR OBSTRUCTION'
let s:d[0x4DE7]='HEXAGRAM FOR DELIVERANCE'
let s:d[0x4DE8]='HEXAGRAM FOR DECREASE'
let s:d[0x4DE9]='HEXAGRAM FOR INCREASE'
let s:d[0x4DEA]='HEXAGRAM FOR BREAKTHROUGH'
let s:d[0x4DEB]='HEXAGRAM FOR COMING TO MEET'
let s:d[0x4DEC]='HEXAGRAM FOR GATHERING TOGETHER'
let s:d[0x4DED]='HEXAGRAM FOR PUSHING UPWARD'
let s:d[0x4DEE]='HEXAGRAM FOR OPPRESSION'
let s:d[0x4DEF]='HEXAGRAM FOR THE WELL'
let s:d[0x4DF0]='HEXAGRAM FOR REVOLUTION'
let s:d[0x4DF1]='HEXAGRAM FOR THE CAULDRON'
let s:d[0x4DF2]='HEXAGRAM FOR THE AROUSING THUNDER'
let s:d[0x4DF3]='HEXAGRAM FOR THE KEEPING STILL MOUNTAIN'
let s:d[0x4DF4]='HEXAGRAM FOR DEVELOPMENT'
let s:d[0x4DF5]='HEXAGRAM FOR THE MARRYING MAIDEN'
let s:d[0x4DF6]='HEXAGRAM FOR ABUNDANCE'
let s:d[0x4DF7]='HEXAGRAM FOR THE WANDERER'
let s:d[0x4DF8]='HEXAGRAM FOR THE GENTLE WIND'
let s:d[0x4DF9]='HEXAGRAM FOR THE JOYOUS LAKE'
let s:d[0x4DFA]='HEXAGRAM FOR DISPERSION'
let s:d[0x4DFB]='HEXAGRAM FOR LIMITATION'
let s:d[0x4DFC]='HEXAGRAM FOR INNER TRUTH'
let s:d[0x4DFD]='HEXAGRAM FOR SMALL PREPONDERANCE'
let s:d[0x4DFE]='HEXAGRAM FOR AFTER COMPLETION'
let s:d[0x4DFF]='HEXAGRAM FOR BEFORE COMPLETION'
let s:d[0xA000]='YI SYLLABLE IT'
let s:d[0xA001]='YI SYLLABLE IX'
let s:d[0xA002]='YI SYLLABLE I'
let s:d[0xA003]='YI SYLLABLE IP'
let s:d[0xA004]='YI SYLLABLE IET'
let s:d[0xA005]='YI SYLLABLE IEX'
let s:d[0xA006]='YI SYLLABLE IE'
let s:d[0xA007]='YI SYLLABLE IEP'
let s:d[0xA008]='YI SYLLABLE AT'
let s:d[0xA009]='YI SYLLABLE AX'
let s:d[0xA00A]='YI SYLLABLE A'
let s:d[0xA00B]='YI SYLLABLE AP'
let s:d[0xA00C]='YI SYLLABLE UOX'
let s:d[0xA00D]='YI SYLLABLE UO'
let s:d[0xA00E]='YI SYLLABLE UOP'
let s:d[0xA00F]='YI SYLLABLE OT'
let s:d[0xA010]='YI SYLLABLE OX'
let s:d[0xA011]='YI SYLLABLE O'
let s:d[0xA012]='YI SYLLABLE OP'
let s:d[0xA013]='YI SYLLABLE EX'
let s:d[0xA014]='YI SYLLABLE E'
let s:d[0xA015]='YI SYLLABLE WU'
let s:d[0xA016]='YI SYLLABLE BIT'
let s:d[0xA017]='YI SYLLABLE BIX'
let s:d[0xA018]='YI SYLLABLE BI'
let s:d[0xA019]='YI SYLLABLE BIP'
let s:d[0xA01A]='YI SYLLABLE BIET'
let s:d[0xA01B]='YI SYLLABLE BIEX'
let s:d[0xA01C]='YI SYLLABLE BIE'
let s:d[0xA01D]='YI SYLLABLE BIEP'
let s:d[0xA01E]='YI SYLLABLE BAT'
let s:d[0xA01F]='YI SYLLABLE BAX'
let s:d[0xA020]='YI SYLLABLE BA'
let s:d[0xA021]='YI SYLLABLE BAP'
let s:d[0xA022]='YI SYLLABLE BUOX'
let s:d[0xA023]='YI SYLLABLE BUO'
let s:d[0xA024]='YI SYLLABLE BUOP'
let s:d[0xA025]='YI SYLLABLE BOT'
let s:d[0xA026]='YI SYLLABLE BOX'
let s:d[0xA027]='YI SYLLABLE BO'
let s:d[0xA028]='YI SYLLABLE BOP'
let s:d[0xA029]='YI SYLLABLE BEX'
let s:d[0xA02A]='YI SYLLABLE BE'
let s:d[0xA02B]='YI SYLLABLE BEP'
let s:d[0xA02C]='YI SYLLABLE BUT'
let s:d[0xA02D]='YI SYLLABLE BUX'
let s:d[0xA02E]='YI SYLLABLE BU'
let s:d[0xA02F]='YI SYLLABLE BUP'
let s:d[0xA030]='YI SYLLABLE BURX'
let s:d[0xA031]='YI SYLLABLE BUR'
let s:d[0xA032]='YI SYLLABLE BYT'
let s:d[0xA033]='YI SYLLABLE BYX'
let s:d[0xA034]='YI SYLLABLE BY'
let s:d[0xA035]='YI SYLLABLE BYP'
let s:d[0xA036]='YI SYLLABLE BYRX'
let s:d[0xA037]='YI SYLLABLE BYR'
let s:d[0xA038]='YI SYLLABLE PIT'
let s:d[0xA039]='YI SYLLABLE PIX'
let s:d[0xA03A]='YI SYLLABLE PI'
let s:d[0xA03B]='YI SYLLABLE PIP'
let s:d[0xA03C]='YI SYLLABLE PIEX'
let s:d[0xA03D]='YI SYLLABLE PIE'
let s:d[0xA03E]='YI SYLLABLE PIEP'
let s:d[0xA03F]='YI SYLLABLE PAT'
let s:d[0xA040]='YI SYLLABLE PAX'
let s:d[0xA041]='YI SYLLABLE PA'
let s:d[0xA042]='YI SYLLABLE PAP'
let s:d[0xA043]='YI SYLLABLE PUOX'
let s:d[0xA044]='YI SYLLABLE PUO'
let s:d[0xA045]='YI SYLLABLE PUOP'
let s:d[0xA046]='YI SYLLABLE POT'
let s:d[0xA047]='YI SYLLABLE POX'
let s:d[0xA048]='YI SYLLABLE PO'
let s:d[0xA049]='YI SYLLABLE POP'
let s:d[0xA04A]='YI SYLLABLE PUT'
let s:d[0xA04B]='YI SYLLABLE PUX'
let s:d[0xA04C]='YI SYLLABLE PU'
let s:d[0xA04D]='YI SYLLABLE PUP'
let s:d[0xA04E]='YI SYLLABLE PURX'
let s:d[0xA04F]='YI SYLLABLE PUR'
let s:d[0xA050]='YI SYLLABLE PYT'
let s:d[0xA051]='YI SYLLABLE PYX'
let s:d[0xA052]='YI SYLLABLE PY'
let s:d[0xA053]='YI SYLLABLE PYP'
let s:d[0xA054]='YI SYLLABLE PYRX'
let s:d[0xA055]='YI SYLLABLE PYR'
let s:d[0xA056]='YI SYLLABLE BBIT'
let s:d[0xA057]='YI SYLLABLE BBIX'
let s:d[0xA058]='YI SYLLABLE BBI'
let s:d[0xA059]='YI SYLLABLE BBIP'
let s:d[0xA05A]='YI SYLLABLE BBIET'
let s:d[0xA05B]='YI SYLLABLE BBIEX'
let s:d[0xA05C]='YI SYLLABLE BBIE'
let s:d[0xA05D]='YI SYLLABLE BBIEP'
let s:d[0xA05E]='YI SYLLABLE BBAT'
let s:d[0xA05F]='YI SYLLABLE BBAX'
let s:d[0xA060]='YI SYLLABLE BBA'
let s:d[0xA061]='YI SYLLABLE BBAP'
let s:d[0xA062]='YI SYLLABLE BBUOX'
let s:d[0xA063]='YI SYLLABLE BBUO'
let s:d[0xA064]='YI SYLLABLE BBUOP'
let s:d[0xA065]='YI SYLLABLE BBOT'
let s:d[0xA066]='YI SYLLABLE BBOX'
let s:d[0xA067]='YI SYLLABLE BBO'
let s:d[0xA068]='YI SYLLABLE BBOP'
let s:d[0xA069]='YI SYLLABLE BBEX'
let s:d[0xA06A]='YI SYLLABLE BBE'
let s:d[0xA06B]='YI SYLLABLE BBEP'
let s:d[0xA06C]='YI SYLLABLE BBUT'
let s:d[0xA06D]='YI SYLLABLE BBUX'
let s:d[0xA06E]='YI SYLLABLE BBU'
let s:d[0xA06F]='YI SYLLABLE BBUP'
let s:d[0xA070]='YI SYLLABLE BBURX'
let s:d[0xA071]='YI SYLLABLE BBUR'
let s:d[0xA072]='YI SYLLABLE BBYT'
let s:d[0xA073]='YI SYLLABLE BBYX'
let s:d[0xA074]='YI SYLLABLE BBY'
let s:d[0xA075]='YI SYLLABLE BBYP'
let s:d[0xA076]='YI SYLLABLE NBIT'
let s:d[0xA077]='YI SYLLABLE NBIX'
let s:d[0xA078]='YI SYLLABLE NBI'
let s:d[0xA079]='YI SYLLABLE NBIP'
let s:d[0xA07A]='YI SYLLABLE NBIEX'
let s:d[0xA07B]='YI SYLLABLE NBIE'
let s:d[0xA07C]='YI SYLLABLE NBIEP'
let s:d[0xA07D]='YI SYLLABLE NBAT'
let s:d[0xA07E]='YI SYLLABLE NBAX'
let s:d[0xA07F]='YI SYLLABLE NBA'
let s:d[0xA080]='YI SYLLABLE NBAP'
let s:d[0xA081]='YI SYLLABLE NBOT'
let s:d[0xA082]='YI SYLLABLE NBOX'
let s:d[0xA083]='YI SYLLABLE NBO'
let s:d[0xA084]='YI SYLLABLE NBOP'
let s:d[0xA085]='YI SYLLABLE NBUT'
let s:d[0xA086]='YI SYLLABLE NBUX'
let s:d[0xA087]='YI SYLLABLE NBU'
let s:d[0xA088]='YI SYLLABLE NBUP'
let s:d[0xA089]='YI SYLLABLE NBURX'
let s:d[0xA08A]='YI SYLLABLE NBUR'
let s:d[0xA08B]='YI SYLLABLE NBYT'
let s:d[0xA08C]='YI SYLLABLE NBYX'
let s:d[0xA08D]='YI SYLLABLE NBY'
let s:d[0xA08E]='YI SYLLABLE NBYP'
let s:d[0xA08F]='YI SYLLABLE NBYRX'
let s:d[0xA090]='YI SYLLABLE NBYR'
let s:d[0xA091]='YI SYLLABLE HMIT'
let s:d[0xA092]='YI SYLLABLE HMIX'
let s:d[0xA093]='YI SYLLABLE HMI'
let s:d[0xA094]='YI SYLLABLE HMIP'
let s:d[0xA095]='YI SYLLABLE HMIEX'
let s:d[0xA096]='YI SYLLABLE HMIE'
let s:d[0xA097]='YI SYLLABLE HMIEP'
let s:d[0xA098]='YI SYLLABLE HMAT'
let s:d[0xA099]='YI SYLLABLE HMAX'
let s:d[0xA09A]='YI SYLLABLE HMA'
let s:d[0xA09B]='YI SYLLABLE HMAP'
let s:d[0xA09C]='YI SYLLABLE HMUOX'
let s:d[0xA09D]='YI SYLLABLE HMUO'
let s:d[0xA09E]='YI SYLLABLE HMUOP'
let s:d[0xA09F]='YI SYLLABLE HMOT'
let s:d[0xA0A0]='YI SYLLABLE HMOX'
let s:d[0xA0A1]='YI SYLLABLE HMO'
let s:d[0xA0A2]='YI SYLLABLE HMOP'
let s:d[0xA0A3]='YI SYLLABLE HMUT'
let s:d[0xA0A4]='YI SYLLABLE HMUX'
let s:d[0xA0A5]='YI SYLLABLE HMU'
let s:d[0xA0A6]='YI SYLLABLE HMUP'
let s:d[0xA0A7]='YI SYLLABLE HMURX'
let s:d[0xA0A8]='YI SYLLABLE HMUR'
let s:d[0xA0A9]='YI SYLLABLE HMYX'
let s:d[0xA0AA]='YI SYLLABLE HMY'
let s:d[0xA0AB]='YI SYLLABLE HMYP'
let s:d[0xA0AC]='YI SYLLABLE HMYRX'
let s:d[0xA0AD]='YI SYLLABLE HMYR'
let s:d[0xA0AE]='YI SYLLABLE MIT'
let s:d[0xA0AF]='YI SYLLABLE MIX'
let s:d[0xA0B0]='YI SYLLABLE MI'
let s:d[0xA0B1]='YI SYLLABLE MIP'
let s:d[0xA0B2]='YI SYLLABLE MIEX'
let s:d[0xA0B3]='YI SYLLABLE MIE'
let s:d[0xA0B4]='YI SYLLABLE MIEP'
let s:d[0xA0B5]='YI SYLLABLE MAT'
let s:d[0xA0B6]='YI SYLLABLE MAX'
let s:d[0xA0B7]='YI SYLLABLE MA'
let s:d[0xA0B8]='YI SYLLABLE MAP'
let s:d[0xA0B9]='YI SYLLABLE MUOT'
let s:d[0xA0BA]='YI SYLLABLE MUOX'
let s:d[0xA0BB]='YI SYLLABLE MUO'
let s:d[0xA0BC]='YI SYLLABLE MUOP'
let s:d[0xA0BD]='YI SYLLABLE MOT'
let s:d[0xA0BE]='YI SYLLABLE MOX'
let s:d[0xA0BF]='YI SYLLABLE MO'
let s:d[0xA0C0]='YI SYLLABLE MOP'
let s:d[0xA0C1]='YI SYLLABLE MEX'
let s:d[0xA0C2]='YI SYLLABLE ME'
let s:d[0xA0C3]='YI SYLLABLE MUT'
let s:d[0xA0C4]='YI SYLLABLE MUX'
let s:d[0xA0C5]='YI SYLLABLE MU'
let s:d[0xA0C6]='YI SYLLABLE MUP'
let s:d[0xA0C7]='YI SYLLABLE MURX'
let s:d[0xA0C8]='YI SYLLABLE MUR'
let s:d[0xA0C9]='YI SYLLABLE MYT'
let s:d[0xA0CA]='YI SYLLABLE MYX'
let s:d[0xA0CB]='YI SYLLABLE MY'
let s:d[0xA0CC]='YI SYLLABLE MYP'
let s:d[0xA0CD]='YI SYLLABLE FIT'
let s:d[0xA0CE]='YI SYLLABLE FIX'
let s:d[0xA0CF]='YI SYLLABLE FI'
let s:d[0xA0D0]='YI SYLLABLE FIP'
let s:d[0xA0D1]='YI SYLLABLE FAT'
let s:d[0xA0D2]='YI SYLLABLE FAX'
let s:d[0xA0D3]='YI SYLLABLE FA'
let s:d[0xA0D4]='YI SYLLABLE FAP'
let s:d[0xA0D5]='YI SYLLABLE FOX'
let s:d[0xA0D6]='YI SYLLABLE FO'
let s:d[0xA0D7]='YI SYLLABLE FOP'
let s:d[0xA0D8]='YI SYLLABLE FUT'
let s:d[0xA0D9]='YI SYLLABLE FUX'
let s:d[0xA0DA]='YI SYLLABLE FU'
let s:d[0xA0DB]='YI SYLLABLE FUP'
let s:d[0xA0DC]='YI SYLLABLE FURX'
let s:d[0xA0DD]='YI SYLLABLE FUR'
let s:d[0xA0DE]='YI SYLLABLE FYT'
let s:d[0xA0DF]='YI SYLLABLE FYX'
let s:d[0xA0E0]='YI SYLLABLE FY'
let s:d[0xA0E1]='YI SYLLABLE FYP'
let s:d[0xA0E2]='YI SYLLABLE VIT'
let s:d[0xA0E3]='YI SYLLABLE VIX'
let s:d[0xA0E4]='YI SYLLABLE VI'
let s:d[0xA0E5]='YI SYLLABLE VIP'
let s:d[0xA0E6]='YI SYLLABLE VIET'
let s:d[0xA0E7]='YI SYLLABLE VIEX'
let s:d[0xA0E8]='YI SYLLABLE VIE'
let s:d[0xA0E9]='YI SYLLABLE VIEP'
let s:d[0xA0EA]='YI SYLLABLE VAT'
let s:d[0xA0EB]='YI SYLLABLE VAX'
let s:d[0xA0EC]='YI SYLLABLE VA'
let s:d[0xA0ED]='YI SYLLABLE VAP'
let s:d[0xA0EE]='YI SYLLABLE VOT'
let s:d[0xA0EF]='YI SYLLABLE VOX'
let s:d[0xA0F0]='YI SYLLABLE VO'
let s:d[0xA0F1]='YI SYLLABLE VOP'
let s:d[0xA0F2]='YI SYLLABLE VEX'
let s:d[0xA0F3]='YI SYLLABLE VEP'
let s:d[0xA0F4]='YI SYLLABLE VUT'
let s:d[0xA0F5]='YI SYLLABLE VUX'
let s:d[0xA0F6]='YI SYLLABLE VU'
let s:d[0xA0F7]='YI SYLLABLE VUP'
let s:d[0xA0F8]='YI SYLLABLE VURX'
let s:d[0xA0F9]='YI SYLLABLE VUR'
let s:d[0xA0FA]='YI SYLLABLE VYT'
let s:d[0xA0FB]='YI SYLLABLE VYX'
let s:d[0xA0FC]='YI SYLLABLE VY'
let s:d[0xA0FD]='YI SYLLABLE VYP'
let s:d[0xA0FE]='YI SYLLABLE VYRX'
let s:d[0xA0FF]='YI SYLLABLE VYR'
let s:d[0xA100]='YI SYLLABLE DIT'
let s:d[0xA101]='YI SYLLABLE DIX'
let s:d[0xA102]='YI SYLLABLE DI'
let s:d[0xA103]='YI SYLLABLE DIP'
let s:d[0xA104]='YI SYLLABLE DIEX'
let s:d[0xA105]='YI SYLLABLE DIE'
let s:d[0xA106]='YI SYLLABLE DIEP'
let s:d[0xA107]='YI SYLLABLE DAT'
let s:d[0xA108]='YI SYLLABLE DAX'
let s:d[0xA109]='YI SYLLABLE DA'
let s:d[0xA10A]='YI SYLLABLE DAP'
let s:d[0xA10B]='YI SYLLABLE DUOX'
let s:d[0xA10C]='YI SYLLABLE DUO'
let s:d[0xA10D]='YI SYLLABLE DOT'
let s:d[0xA10E]='YI SYLLABLE DOX'
let s:d[0xA10F]='YI SYLLABLE DO'
let s:d[0xA110]='YI SYLLABLE DOP'
let s:d[0xA111]='YI SYLLABLE DEX'
let s:d[0xA112]='YI SYLLABLE DE'
let s:d[0xA113]='YI SYLLABLE DEP'
let s:d[0xA114]='YI SYLLABLE DUT'
let s:d[0xA115]='YI SYLLABLE DUX'
let s:d[0xA116]='YI SYLLABLE DU'
let s:d[0xA117]='YI SYLLABLE DUP'
let s:d[0xA118]='YI SYLLABLE DURX'
let s:d[0xA119]='YI SYLLABLE DUR'
let s:d[0xA11A]='YI SYLLABLE TIT'
let s:d[0xA11B]='YI SYLLABLE TIX'
let s:d[0xA11C]='YI SYLLABLE TI'
let s:d[0xA11D]='YI SYLLABLE TIP'
let s:d[0xA11E]='YI SYLLABLE TIEX'
let s:d[0xA11F]='YI SYLLABLE TIE'
let s:d[0xA120]='YI SYLLABLE TIEP'
let s:d[0xA121]='YI SYLLABLE TAT'
let s:d[0xA122]='YI SYLLABLE TAX'
let s:d[0xA123]='YI SYLLABLE TA'
let s:d[0xA124]='YI SYLLABLE TAP'
let s:d[0xA125]='YI SYLLABLE TUOT'
let s:d[0xA126]='YI SYLLABLE TUOX'
let s:d[0xA127]='YI SYLLABLE TUO'
let s:d[0xA128]='YI SYLLABLE TUOP'
let s:d[0xA129]='YI SYLLABLE TOT'
let s:d[0xA12A]='YI SYLLABLE TOX'
let s:d[0xA12B]='YI SYLLABLE TO'
let s:d[0xA12C]='YI SYLLABLE TOP'
let s:d[0xA12D]='YI SYLLABLE TEX'
let s:d[0xA12E]='YI SYLLABLE TE'
let s:d[0xA12F]='YI SYLLABLE TEP'
let s:d[0xA130]='YI SYLLABLE TUT'
let s:d[0xA131]='YI SYLLABLE TUX'
let s:d[0xA132]='YI SYLLABLE TU'
let s:d[0xA133]='YI SYLLABLE TUP'
let s:d[0xA134]='YI SYLLABLE TURX'
let s:d[0xA135]='YI SYLLABLE TUR'
let s:d[0xA136]='YI SYLLABLE DDIT'
let s:d[0xA137]='YI SYLLABLE DDIX'
let s:d[0xA138]='YI SYLLABLE DDI'
let s:d[0xA139]='YI SYLLABLE DDIP'
let s:d[0xA13A]='YI SYLLABLE DDIEX'
let s:d[0xA13B]='YI SYLLABLE DDIE'
let s:d[0xA13C]='YI SYLLABLE DDIEP'
let s:d[0xA13D]='YI SYLLABLE DDAT'
let s:d[0xA13E]='YI SYLLABLE DDAX'
let s:d[0xA13F]='YI SYLLABLE DDA'
let s:d[0xA140]='YI SYLLABLE DDAP'
let s:d[0xA141]='YI SYLLABLE DDUOX'
let s:d[0xA142]='YI SYLLABLE DDUO'
let s:d[0xA143]='YI SYLLABLE DDUOP'
let s:d[0xA144]='YI SYLLABLE DDOT'
let s:d[0xA145]='YI SYLLABLE DDOX'
let s:d[0xA146]='YI SYLLABLE DDO'
let s:d[0xA147]='YI SYLLABLE DDOP'
let s:d[0xA148]='YI SYLLABLE DDEX'
let s:d[0xA149]='YI SYLLABLE DDE'
let s:d[0xA14A]='YI SYLLABLE DDEP'
let s:d[0xA14B]='YI SYLLABLE DDUT'
let s:d[0xA14C]='YI SYLLABLE DDUX'
let s:d[0xA14D]='YI SYLLABLE DDU'
let s:d[0xA14E]='YI SYLLABLE DDUP'
let s:d[0xA14F]='YI SYLLABLE DDURX'
let s:d[0xA150]='YI SYLLABLE DDUR'
let s:d[0xA151]='YI SYLLABLE NDIT'
let s:d[0xA152]='YI SYLLABLE NDIX'
let s:d[0xA153]='YI SYLLABLE NDI'
let s:d[0xA154]='YI SYLLABLE NDIP'
let s:d[0xA155]='YI SYLLABLE NDIEX'
let s:d[0xA156]='YI SYLLABLE NDIE'
let s:d[0xA157]='YI SYLLABLE NDAT'
let s:d[0xA158]='YI SYLLABLE NDAX'
let s:d[0xA159]='YI SYLLABLE NDA'
let s:d[0xA15A]='YI SYLLABLE NDAP'
let s:d[0xA15B]='YI SYLLABLE NDOT'
let s:d[0xA15C]='YI SYLLABLE NDOX'
let s:d[0xA15D]='YI SYLLABLE NDO'
let s:d[0xA15E]='YI SYLLABLE NDOP'
let s:d[0xA15F]='YI SYLLABLE NDEX'
let s:d[0xA160]='YI SYLLABLE NDE'
let s:d[0xA161]='YI SYLLABLE NDEP'
let s:d[0xA162]='YI SYLLABLE NDUT'
let s:d[0xA163]='YI SYLLABLE NDUX'
let s:d[0xA164]='YI SYLLABLE NDU'
let s:d[0xA165]='YI SYLLABLE NDUP'
let s:d[0xA166]='YI SYLLABLE NDURX'
let s:d[0xA167]='YI SYLLABLE NDUR'
let s:d[0xA168]='YI SYLLABLE HNIT'
let s:d[0xA169]='YI SYLLABLE HNIX'
let s:d[0xA16A]='YI SYLLABLE HNI'
let s:d[0xA16B]='YI SYLLABLE HNIP'
let s:d[0xA16C]='YI SYLLABLE HNIET'
let s:d[0xA16D]='YI SYLLABLE HNIEX'
let s:d[0xA16E]='YI SYLLABLE HNIE'
let s:d[0xA16F]='YI SYLLABLE HNIEP'
let s:d[0xA170]='YI SYLLABLE HNAT'
let s:d[0xA171]='YI SYLLABLE HNAX'
let s:d[0xA172]='YI SYLLABLE HNA'
let s:d[0xA173]='YI SYLLABLE HNAP'
let s:d[0xA174]='YI SYLLABLE HNUOX'
let s:d[0xA175]='YI SYLLABLE HNUO'
let s:d[0xA176]='YI SYLLABLE HNOT'
let s:d[0xA177]='YI SYLLABLE HNOX'
let s:d[0xA178]='YI SYLLABLE HNOP'
let s:d[0xA179]='YI SYLLABLE HNEX'
let s:d[0xA17A]='YI SYLLABLE HNE'
let s:d[0xA17B]='YI SYLLABLE HNEP'
let s:d[0xA17C]='YI SYLLABLE HNUT'
let s:d[0xA17D]='YI SYLLABLE NIT'
let s:d[0xA17E]='YI SYLLABLE NIX'
let s:d[0xA17F]='YI SYLLABLE NI'
let s:d[0xA180]='YI SYLLABLE NIP'
let s:d[0xA181]='YI SYLLABLE NIEX'
let s:d[0xA182]='YI SYLLABLE NIE'
let s:d[0xA183]='YI SYLLABLE NIEP'
let s:d[0xA184]='YI SYLLABLE NAX'
let s:d[0xA185]='YI SYLLABLE NA'
let s:d[0xA186]='YI SYLLABLE NAP'
let s:d[0xA187]='YI SYLLABLE NUOX'
let s:d[0xA188]='YI SYLLABLE NUO'
let s:d[0xA189]='YI SYLLABLE NUOP'
let s:d[0xA18A]='YI SYLLABLE NOT'
let s:d[0xA18B]='YI SYLLABLE NOX'
let s:d[0xA18C]='YI SYLLABLE NO'
let s:d[0xA18D]='YI SYLLABLE NOP'
let s:d[0xA18E]='YI SYLLABLE NEX'
let s:d[0xA18F]='YI SYLLABLE NE'
let s:d[0xA190]='YI SYLLABLE NEP'
let s:d[0xA191]='YI SYLLABLE NUT'
let s:d[0xA192]='YI SYLLABLE NUX'
let s:d[0xA193]='YI SYLLABLE NU'
let s:d[0xA194]='YI SYLLABLE NUP'
let s:d[0xA195]='YI SYLLABLE NURX'
let s:d[0xA196]='YI SYLLABLE NUR'
let s:d[0xA197]='YI SYLLABLE HLIT'
let s:d[0xA198]='YI SYLLABLE HLIX'
let s:d[0xA199]='YI SYLLABLE HLI'
let s:d[0xA19A]='YI SYLLABLE HLIP'
let s:d[0xA19B]='YI SYLLABLE HLIEX'
let s:d[0xA19C]='YI SYLLABLE HLIE'
let s:d[0xA19D]='YI SYLLABLE HLIEP'
let s:d[0xA19E]='YI SYLLABLE HLAT'
let s:d[0xA19F]='YI SYLLABLE HLAX'
let s:d[0xA1A0]='YI SYLLABLE HLA'
let s:d[0xA1A1]='YI SYLLABLE HLAP'
let s:d[0xA1A2]='YI SYLLABLE HLUOX'
let s:d[0xA1A3]='YI SYLLABLE HLUO'
let s:d[0xA1A4]='YI SYLLABLE HLUOP'
let s:d[0xA1A5]='YI SYLLABLE HLOX'
let s:d[0xA1A6]='YI SYLLABLE HLO'
let s:d[0xA1A7]='YI SYLLABLE HLOP'
let s:d[0xA1A8]='YI SYLLABLE HLEX'
let s:d[0xA1A9]='YI SYLLABLE HLE'
let s:d[0xA1AA]='YI SYLLABLE HLEP'
let s:d[0xA1AB]='YI SYLLABLE HLUT'
let s:d[0xA1AC]='YI SYLLABLE HLUX'
let s:d[0xA1AD]='YI SYLLABLE HLU'
let s:d[0xA1AE]='YI SYLLABLE HLUP'
let s:d[0xA1AF]='YI SYLLABLE HLURX'
let s:d[0xA1B0]='YI SYLLABLE HLUR'
let s:d[0xA1B1]='YI SYLLABLE HLYT'
let s:d[0xA1B2]='YI SYLLABLE HLYX'
let s:d[0xA1B3]='YI SYLLABLE HLY'
let s:d[0xA1B4]='YI SYLLABLE HLYP'
let s:d[0xA1B5]='YI SYLLABLE HLYRX'
let s:d[0xA1B6]='YI SYLLABLE HLYR'
let s:d[0xA1B7]='YI SYLLABLE LIT'
let s:d[0xA1B8]='YI SYLLABLE LIX'
let s:d[0xA1B9]='YI SYLLABLE LI'
let s:d[0xA1BA]='YI SYLLABLE LIP'
let s:d[0xA1BB]='YI SYLLABLE LIET'
let s:d[0xA1BC]='YI SYLLABLE LIEX'
let s:d[0xA1BD]='YI SYLLABLE LIE'
let s:d[0xA1BE]='YI SYLLABLE LIEP'
let s:d[0xA1BF]='YI SYLLABLE LAT'
let s:d[0xA1C0]='YI SYLLABLE LAX'
let s:d[0xA1C1]='YI SYLLABLE LA'
let s:d[0xA1C2]='YI SYLLABLE LAP'
let s:d[0xA1C3]='YI SYLLABLE LUOT'
let s:d[0xA1C4]='YI SYLLABLE LUOX'
let s:d[0xA1C5]='YI SYLLABLE LUO'
let s:d[0xA1C6]='YI SYLLABLE LUOP'
let s:d[0xA1C7]='YI SYLLABLE LOT'
let s:d[0xA1C8]='YI SYLLABLE LOX'
let s:d[0xA1C9]='YI SYLLABLE LO'
let s:d[0xA1CA]='YI SYLLABLE LOP'
let s:d[0xA1CB]='YI SYLLABLE LEX'
let s:d[0xA1CC]='YI SYLLABLE LE'
let s:d[0xA1CD]='YI SYLLABLE LEP'
let s:d[0xA1CE]='YI SYLLABLE LUT'
let s:d[0xA1CF]='YI SYLLABLE LUX'
let s:d[0xA1D0]='YI SYLLABLE LU'
let s:d[0xA1D1]='YI SYLLABLE LUP'
let s:d[0xA1D2]='YI SYLLABLE LURX'
let s:d[0xA1D3]='YI SYLLABLE LUR'
let s:d[0xA1D4]='YI SYLLABLE LYT'
let s:d[0xA1D5]='YI SYLLABLE LYX'
let s:d[0xA1D6]='YI SYLLABLE LY'
let s:d[0xA1D7]='YI SYLLABLE LYP'
let s:d[0xA1D8]='YI SYLLABLE LYRX'
let s:d[0xA1D9]='YI SYLLABLE LYR'
let s:d[0xA1DA]='YI SYLLABLE GIT'
let s:d[0xA1DB]='YI SYLLABLE GIX'
let s:d[0xA1DC]='YI SYLLABLE GI'
let s:d[0xA1DD]='YI SYLLABLE GIP'
let s:d[0xA1DE]='YI SYLLABLE GIET'
let s:d[0xA1DF]='YI SYLLABLE GIEX'
let s:d[0xA1E0]='YI SYLLABLE GIE'
let s:d[0xA1E1]='YI SYLLABLE GIEP'
let s:d[0xA1E2]='YI SYLLABLE GAT'
let s:d[0xA1E3]='YI SYLLABLE GAX'
let s:d[0xA1E4]='YI SYLLABLE GA'
let s:d[0xA1E5]='YI SYLLABLE GAP'
let s:d[0xA1E6]='YI SYLLABLE GUOT'
let s:d[0xA1E7]='YI SYLLABLE GUOX'
let s:d[0xA1E8]='YI SYLLABLE GUO'
let s:d[0xA1E9]='YI SYLLABLE GUOP'
let s:d[0xA1EA]='YI SYLLABLE GOT'
let s:d[0xA1EB]='YI SYLLABLE GOX'
let s:d[0xA1EC]='YI SYLLABLE GO'
let s:d[0xA1ED]='YI SYLLABLE GOP'
let s:d[0xA1EE]='YI SYLLABLE GET'
let s:d[0xA1EF]='YI SYLLABLE GEX'
let s:d[0xA1F0]='YI SYLLABLE GE'
let s:d[0xA1F1]='YI SYLLABLE GEP'
let s:d[0xA1F2]='YI SYLLABLE GUT'
let s:d[0xA1F3]='YI SYLLABLE GUX'
let s:d[0xA1F4]='YI SYLLABLE GU'
let s:d[0xA1F5]='YI SYLLABLE GUP'
let s:d[0xA1F6]='YI SYLLABLE GURX'
let s:d[0xA1F7]='YI SYLLABLE GUR'
let s:d[0xA1F8]='YI SYLLABLE KIT'
let s:d[0xA1F9]='YI SYLLABLE KIX'
let s:d[0xA1FA]='YI SYLLABLE KI'
let s:d[0xA1FB]='YI SYLLABLE KIP'
let s:d[0xA1FC]='YI SYLLABLE KIEX'
let s:d[0xA1FD]='YI SYLLABLE KIE'
let s:d[0xA1FE]='YI SYLLABLE KIEP'
let s:d[0xA1FF]='YI SYLLABLE KAT'
let s:d[0xA200]='YI SYLLABLE KAX'
let s:d[0xA201]='YI SYLLABLE KA'
let s:d[0xA202]='YI SYLLABLE KAP'
let s:d[0xA203]='YI SYLLABLE KUOX'
let s:d[0xA204]='YI SYLLABLE KUO'
let s:d[0xA205]='YI SYLLABLE KUOP'
let s:d[0xA206]='YI SYLLABLE KOT'
let s:d[0xA207]='YI SYLLABLE KOX'
let s:d[0xA208]='YI SYLLABLE KO'
let s:d[0xA209]='YI SYLLABLE KOP'
let s:d[0xA20A]='YI SYLLABLE KET'
let s:d[0xA20B]='YI SYLLABLE KEX'
let s:d[0xA20C]='YI SYLLABLE KE'
let s:d[0xA20D]='YI SYLLABLE KEP'
let s:d[0xA20E]='YI SYLLABLE KUT'
let s:d[0xA20F]='YI SYLLABLE KUX'
let s:d[0xA210]='YI SYLLABLE KU'
let s:d[0xA211]='YI SYLLABLE KUP'
let s:d[0xA212]='YI SYLLABLE KURX'
let s:d[0xA213]='YI SYLLABLE KUR'
let s:d[0xA214]='YI SYLLABLE GGIT'
let s:d[0xA215]='YI SYLLABLE GGIX'
let s:d[0xA216]='YI SYLLABLE GGI'
let s:d[0xA217]='YI SYLLABLE GGIEX'
let s:d[0xA218]='YI SYLLABLE GGIE'
let s:d[0xA219]='YI SYLLABLE GGIEP'
let s:d[0xA21A]='YI SYLLABLE GGAT'
let s:d[0xA21B]='YI SYLLABLE GGAX'
let s:d[0xA21C]='YI SYLLABLE GGA'
let s:d[0xA21D]='YI SYLLABLE GGAP'
let s:d[0xA21E]='YI SYLLABLE GGUOT'
let s:d[0xA21F]='YI SYLLABLE GGUOX'
let s:d[0xA220]='YI SYLLABLE GGUO'
let s:d[0xA221]='YI SYLLABLE GGUOP'
let s:d[0xA222]='YI SYLLABLE GGOT'
let s:d[0xA223]='YI SYLLABLE GGOX'
let s:d[0xA224]='YI SYLLABLE GGO'
let s:d[0xA225]='YI SYLLABLE GGOP'
let s:d[0xA226]='YI SYLLABLE GGET'
let s:d[0xA227]='YI SYLLABLE GGEX'
let s:d[0xA228]='YI SYLLABLE GGE'
let s:d[0xA229]='YI SYLLABLE GGEP'
let s:d[0xA22A]='YI SYLLABLE GGUT'
let s:d[0xA22B]='YI SYLLABLE GGUX'
let s:d[0xA22C]='YI SYLLABLE GGU'
let s:d[0xA22D]='YI SYLLABLE GGUP'
let s:d[0xA22E]='YI SYLLABLE GGURX'
let s:d[0xA22F]='YI SYLLABLE GGUR'
let s:d[0xA230]='YI SYLLABLE MGIEX'
let s:d[0xA231]='YI SYLLABLE MGIE'
let s:d[0xA232]='YI SYLLABLE MGAT'
let s:d[0xA233]='YI SYLLABLE MGAX'
let s:d[0xA234]='YI SYLLABLE MGA'
let s:d[0xA235]='YI SYLLABLE MGAP'
let s:d[0xA236]='YI SYLLABLE MGUOX'
let s:d[0xA237]='YI SYLLABLE MGUO'
let s:d[0xA238]='YI SYLLABLE MGUOP'
let s:d[0xA239]='YI SYLLABLE MGOT'
let s:d[0xA23A]='YI SYLLABLE MGOX'
let s:d[0xA23B]='YI SYLLABLE MGO'
let s:d[0xA23C]='YI SYLLABLE MGOP'
let s:d[0xA23D]='YI SYLLABLE MGEX'
let s:d[0xA23E]='YI SYLLABLE MGE'
let s:d[0xA23F]='YI SYLLABLE MGEP'
let s:d[0xA240]='YI SYLLABLE MGUT'
let s:d[0xA241]='YI SYLLABLE MGUX'
let s:d[0xA242]='YI SYLLABLE MGU'
let s:d[0xA243]='YI SYLLABLE MGUP'
let s:d[0xA244]='YI SYLLABLE MGURX'
let s:d[0xA245]='YI SYLLABLE MGUR'
let s:d[0xA246]='YI SYLLABLE HXIT'
let s:d[0xA247]='YI SYLLABLE HXIX'
let s:d[0xA248]='YI SYLLABLE HXI'
let s:d[0xA249]='YI SYLLABLE HXIP'
let s:d[0xA24A]='YI SYLLABLE HXIET'
let s:d[0xA24B]='YI SYLLABLE HXIEX'
let s:d[0xA24C]='YI SYLLABLE HXIE'
let s:d[0xA24D]='YI SYLLABLE HXIEP'
let s:d[0xA24E]='YI SYLLABLE HXAT'
let s:d[0xA24F]='YI SYLLABLE HXAX'
let s:d[0xA250]='YI SYLLABLE HXA'
let s:d[0xA251]='YI SYLLABLE HXAP'
let s:d[0xA252]='YI SYLLABLE HXUOT'
let s:d[0xA253]='YI SYLLABLE HXUOX'
let s:d[0xA254]='YI SYLLABLE HXUO'
let s:d[0xA255]='YI SYLLABLE HXUOP'
let s:d[0xA256]='YI SYLLABLE HXOT'
let s:d[0xA257]='YI SYLLABLE HXOX'
let s:d[0xA258]='YI SYLLABLE HXO'
let s:d[0xA259]='YI SYLLABLE HXOP'
let s:d[0xA25A]='YI SYLLABLE HXEX'
let s:d[0xA25B]='YI SYLLABLE HXE'
let s:d[0xA25C]='YI SYLLABLE HXEP'
let s:d[0xA25D]='YI SYLLABLE NGIEX'
let s:d[0xA25E]='YI SYLLABLE NGIE'
let s:d[0xA25F]='YI SYLLABLE NGIEP'
let s:d[0xA260]='YI SYLLABLE NGAT'
let s:d[0xA261]='YI SYLLABLE NGAX'
let s:d[0xA262]='YI SYLLABLE NGA'
let s:d[0xA263]='YI SYLLABLE NGAP'
let s:d[0xA264]='YI SYLLABLE NGUOT'
let s:d[0xA265]='YI SYLLABLE NGUOX'
let s:d[0xA266]='YI SYLLABLE NGUO'
let s:d[0xA267]='YI SYLLABLE NGOT'
let s:d[0xA268]='YI SYLLABLE NGOX'
let s:d[0xA269]='YI SYLLABLE NGO'
let s:d[0xA26A]='YI SYLLABLE NGOP'
let s:d[0xA26B]='YI SYLLABLE NGEX'
let s:d[0xA26C]='YI SYLLABLE NGE'
let s:d[0xA26D]='YI SYLLABLE NGEP'
let s:d[0xA26E]='YI SYLLABLE HIT'
let s:d[0xA26F]='YI SYLLABLE HIEX'
let s:d[0xA270]='YI SYLLABLE HIE'
let s:d[0xA271]='YI SYLLABLE HAT'
let s:d[0xA272]='YI SYLLABLE HAX'
let s:d[0xA273]='YI SYLLABLE HA'
let s:d[0xA274]='YI SYLLABLE HAP'
let s:d[0xA275]='YI SYLLABLE HUOT'
let s:d[0xA276]='YI SYLLABLE HUOX'
let s:d[0xA277]='YI SYLLABLE HUO'
let s:d[0xA278]='YI SYLLABLE HUOP'
let s:d[0xA279]='YI SYLLABLE HOT'
let s:d[0xA27A]='YI SYLLABLE HOX'
let s:d[0xA27B]='YI SYLLABLE HO'
let s:d[0xA27C]='YI SYLLABLE HOP'
let s:d[0xA27D]='YI SYLLABLE HEX'
let s:d[0xA27E]='YI SYLLABLE HE'
let s:d[0xA27F]='YI SYLLABLE HEP'
let s:d[0xA280]='YI SYLLABLE WAT'
let s:d[0xA281]='YI SYLLABLE WAX'
let s:d[0xA282]='YI SYLLABLE WA'
let s:d[0xA283]='YI SYLLABLE WAP'
let s:d[0xA284]='YI SYLLABLE WUOX'
let s:d[0xA285]='YI SYLLABLE WUO'
let s:d[0xA286]='YI SYLLABLE WUOP'
let s:d[0xA287]='YI SYLLABLE WOX'
let s:d[0xA288]='YI SYLLABLE WO'
let s:d[0xA289]='YI SYLLABLE WOP'
let s:d[0xA28A]='YI SYLLABLE WEX'
let s:d[0xA28B]='YI SYLLABLE WE'
let s:d[0xA28C]='YI SYLLABLE WEP'
let s:d[0xA28D]='YI SYLLABLE ZIT'
let s:d[0xA28E]='YI SYLLABLE ZIX'
let s:d[0xA28F]='YI SYLLABLE ZI'
let s:d[0xA290]='YI SYLLABLE ZIP'
let s:d[0xA291]='YI SYLLABLE ZIEX'
let s:d[0xA292]='YI SYLLABLE ZIE'
let s:d[0xA293]='YI SYLLABLE ZIEP'
let s:d[0xA294]='YI SYLLABLE ZAT'
let s:d[0xA295]='YI SYLLABLE ZAX'
let s:d[0xA296]='YI SYLLABLE ZA'
let s:d[0xA297]='YI SYLLABLE ZAP'
let s:d[0xA298]='YI SYLLABLE ZUOX'
let s:d[0xA299]='YI SYLLABLE ZUO'
let s:d[0xA29A]='YI SYLLABLE ZUOP'
let s:d[0xA29B]='YI SYLLABLE ZOT'
let s:d[0xA29C]='YI SYLLABLE ZOX'
let s:d[0xA29D]='YI SYLLABLE ZO'
let s:d[0xA29E]='YI SYLLABLE ZOP'
let s:d[0xA29F]='YI SYLLABLE ZEX'
let s:d[0xA2A0]='YI SYLLABLE ZE'
let s:d[0xA2A1]='YI SYLLABLE ZEP'
let s:d[0xA2A2]='YI SYLLABLE ZUT'
let s:d[0xA2A3]='YI SYLLABLE ZUX'
let s:d[0xA2A4]='YI SYLLABLE ZU'
let s:d[0xA2A5]='YI SYLLABLE ZUP'
let s:d[0xA2A6]='YI SYLLABLE ZURX'
let s:d[0xA2A7]='YI SYLLABLE ZUR'
let s:d[0xA2A8]='YI SYLLABLE ZYT'
let s:d[0xA2A9]='YI SYLLABLE ZYX'
let s:d[0xA2AA]='YI SYLLABLE ZY'
let s:d[0xA2AB]='YI SYLLABLE ZYP'
let s:d[0xA2AC]='YI SYLLABLE ZYRX'
let s:d[0xA2AD]='YI SYLLABLE ZYR'
let s:d[0xA2AE]='YI SYLLABLE CIT'
let s:d[0xA2AF]='YI SYLLABLE CIX'
let s:d[0xA2B0]='YI SYLLABLE CI'
let s:d[0xA2B1]='YI SYLLABLE CIP'
let s:d[0xA2B2]='YI SYLLABLE CIET'
let s:d[0xA2B3]='YI SYLLABLE CIEX'
let s:d[0xA2B4]='YI SYLLABLE CIE'
let s:d[0xA2B5]='YI SYLLABLE CIEP'
let s:d[0xA2B6]='YI SYLLABLE CAT'
let s:d[0xA2B7]='YI SYLLABLE CAX'
let s:d[0xA2B8]='YI SYLLABLE CA'
let s:d[0xA2B9]='YI SYLLABLE CAP'
let s:d[0xA2BA]='YI SYLLABLE CUOX'
let s:d[0xA2BB]='YI SYLLABLE CUO'
let s:d[0xA2BC]='YI SYLLABLE CUOP'
let s:d[0xA2BD]='YI SYLLABLE COT'
let s:d[0xA2BE]='YI SYLLABLE COX'
let s:d[0xA2BF]='YI SYLLABLE CO'
let s:d[0xA2C0]='YI SYLLABLE COP'
let s:d[0xA2C1]='YI SYLLABLE CEX'
let s:d[0xA2C2]='YI SYLLABLE CE'
let s:d[0xA2C3]='YI SYLLABLE CEP'
let s:d[0xA2C4]='YI SYLLABLE CUT'
let s:d[0xA2C5]='YI SYLLABLE CUX'
let s:d[0xA2C6]='YI SYLLABLE CU'
let s:d[0xA2C7]='YI SYLLABLE CUP'
let s:d[0xA2C8]='YI SYLLABLE CURX'
let s:d[0xA2C9]='YI SYLLABLE CUR'
let s:d[0xA2CA]='YI SYLLABLE CYT'
let s:d[0xA2CB]='YI SYLLABLE CYX'
let s:d[0xA2CC]='YI SYLLABLE CY'
let s:d[0xA2CD]='YI SYLLABLE CYP'
let s:d[0xA2CE]='YI SYLLABLE CYRX'
let s:d[0xA2CF]='YI SYLLABLE CYR'
let s:d[0xA2D0]='YI SYLLABLE ZZIT'
let s:d[0xA2D1]='YI SYLLABLE ZZIX'
let s:d[0xA2D2]='YI SYLLABLE ZZI'
let s:d[0xA2D3]='YI SYLLABLE ZZIP'
let s:d[0xA2D4]='YI SYLLABLE ZZIET'
let s:d[0xA2D5]='YI SYLLABLE ZZIEX'
let s:d[0xA2D6]='YI SYLLABLE ZZIE'
let s:d[0xA2D7]='YI SYLLABLE ZZIEP'
let s:d[0xA2D8]='YI SYLLABLE ZZAT'
let s:d[0xA2D9]='YI SYLLABLE ZZAX'
let s:d[0xA2DA]='YI SYLLABLE ZZA'
let s:d[0xA2DB]='YI SYLLABLE ZZAP'
let s:d[0xA2DC]='YI SYLLABLE ZZOX'
let s:d[0xA2DD]='YI SYLLABLE ZZO'
let s:d[0xA2DE]='YI SYLLABLE ZZOP'
let s:d[0xA2DF]='YI SYLLABLE ZZEX'
let s:d[0xA2E0]='YI SYLLABLE ZZE'
let s:d[0xA2E1]='YI SYLLABLE ZZEP'
let s:d[0xA2E2]='YI SYLLABLE ZZUX'
let s:d[0xA2E3]='YI SYLLABLE ZZU'
let s:d[0xA2E4]='YI SYLLABLE ZZUP'
let s:d[0xA2E5]='YI SYLLABLE ZZURX'
let s:d[0xA2E6]='YI SYLLABLE ZZUR'
let s:d[0xA2E7]='YI SYLLABLE ZZYT'
let s:d[0xA2E8]='YI SYLLABLE ZZYX'
let s:d[0xA2E9]='YI SYLLABLE ZZY'
let s:d[0xA2EA]='YI SYLLABLE ZZYP'
let s:d[0xA2EB]='YI SYLLABLE ZZYRX'
let s:d[0xA2EC]='YI SYLLABLE ZZYR'
let s:d[0xA2ED]='YI SYLLABLE NZIT'
let s:d[0xA2EE]='YI SYLLABLE NZIX'
let s:d[0xA2EF]='YI SYLLABLE NZI'
let s:d[0xA2F0]='YI SYLLABLE NZIP'
let s:d[0xA2F1]='YI SYLLABLE NZIEX'
let s:d[0xA2F2]='YI SYLLABLE NZIE'
let s:d[0xA2F3]='YI SYLLABLE NZIEP'
let s:d[0xA2F4]='YI SYLLABLE NZAT'
let s:d[0xA2F5]='YI SYLLABLE NZAX'
let s:d[0xA2F6]='YI SYLLABLE NZA'
let s:d[0xA2F7]='YI SYLLABLE NZAP'
let s:d[0xA2F8]='YI SYLLABLE NZUOX'
let s:d[0xA2F9]='YI SYLLABLE NZUO'
let s:d[0xA2FA]='YI SYLLABLE NZOX'
let s:d[0xA2FB]='YI SYLLABLE NZOP'
let s:d[0xA2FC]='YI SYLLABLE NZEX'
let s:d[0xA2FD]='YI SYLLABLE NZE'
let s:d[0xA2FE]='YI SYLLABLE NZUX'
let s:d[0xA2FF]='YI SYLLABLE NZU'
let s:d[0xA300]='YI SYLLABLE NZUP'
let s:d[0xA301]='YI SYLLABLE NZURX'
let s:d[0xA302]='YI SYLLABLE NZUR'
let s:d[0xA303]='YI SYLLABLE NZYT'
let s:d[0xA304]='YI SYLLABLE NZYX'
let s:d[0xA305]='YI SYLLABLE NZY'
let s:d[0xA306]='YI SYLLABLE NZYP'
let s:d[0xA307]='YI SYLLABLE NZYRX'
let s:d[0xA308]='YI SYLLABLE NZYR'
let s:d[0xA309]='YI SYLLABLE SIT'
let s:d[0xA30A]='YI SYLLABLE SIX'
let s:d[0xA30B]='YI SYLLABLE SI'
let s:d[0xA30C]='YI SYLLABLE SIP'
let s:d[0xA30D]='YI SYLLABLE SIEX'
let s:d[0xA30E]='YI SYLLABLE SIE'
let s:d[0xA30F]='YI SYLLABLE SIEP'
let s:d[0xA310]='YI SYLLABLE SAT'
let s:d[0xA311]='YI SYLLABLE SAX'
let s:d[0xA312]='YI SYLLABLE SA'
let s:d[0xA313]='YI SYLLABLE SAP'
let s:d[0xA314]='YI SYLLABLE SUOX'
let s:d[0xA315]='YI SYLLABLE SUO'
let s:d[0xA316]='YI SYLLABLE SUOP'
let s:d[0xA317]='YI SYLLABLE SOT'
let s:d[0xA318]='YI SYLLABLE SOX'
let s:d[0xA319]='YI SYLLABLE SO'
let s:d[0xA31A]='YI SYLLABLE SOP'
let s:d[0xA31B]='YI SYLLABLE SEX'
let s:d[0xA31C]='YI SYLLABLE SE'
let s:d[0xA31D]='YI SYLLABLE SEP'
let s:d[0xA31E]='YI SYLLABLE SUT'
let s:d[0xA31F]='YI SYLLABLE SUX'
let s:d[0xA320]='YI SYLLABLE SU'
let s:d[0xA321]='YI SYLLABLE SUP'
let s:d[0xA322]='YI SYLLABLE SURX'
let s:d[0xA323]='YI SYLLABLE SUR'
let s:d[0xA324]='YI SYLLABLE SYT'
let s:d[0xA325]='YI SYLLABLE SYX'
let s:d[0xA326]='YI SYLLABLE SY'
let s:d[0xA327]='YI SYLLABLE SYP'
let s:d[0xA328]='YI SYLLABLE SYRX'
let s:d[0xA329]='YI SYLLABLE SYR'
let s:d[0xA32A]='YI SYLLABLE SSIT'
let s:d[0xA32B]='YI SYLLABLE SSIX'
let s:d[0xA32C]='YI SYLLABLE SSI'
let s:d[0xA32D]='YI SYLLABLE SSIP'
let s:d[0xA32E]='YI SYLLABLE SSIEX'
let s:d[0xA32F]='YI SYLLABLE SSIE'
let s:d[0xA330]='YI SYLLABLE SSIEP'
let s:d[0xA331]='YI SYLLABLE SSAT'
let s:d[0xA332]='YI SYLLABLE SSAX'
let s:d[0xA333]='YI SYLLABLE SSA'
let s:d[0xA334]='YI SYLLABLE SSAP'
let s:d[0xA335]='YI SYLLABLE SSOT'
let s:d[0xA336]='YI SYLLABLE SSOX'
let s:d[0xA337]='YI SYLLABLE SSO'
let s:d[0xA338]='YI SYLLABLE SSOP'
let s:d[0xA339]='YI SYLLABLE SSEX'
let s:d[0xA33A]='YI SYLLABLE SSE'
let s:d[0xA33B]='YI SYLLABLE SSEP'
let s:d[0xA33C]='YI SYLLABLE SSUT'
let s:d[0xA33D]='YI SYLLABLE SSUX'
let s:d[0xA33E]='YI SYLLABLE SSU'
let s:d[0xA33F]='YI SYLLABLE SSUP'
let s:d[0xA340]='YI SYLLABLE SSYT'
let s:d[0xA341]='YI SYLLABLE SSYX'
let s:d[0xA342]='YI SYLLABLE SSY'
let s:d[0xA343]='YI SYLLABLE SSYP'
let s:d[0xA344]='YI SYLLABLE SSYRX'
let s:d[0xA345]='YI SYLLABLE SSYR'
let s:d[0xA346]='YI SYLLABLE ZHAT'
let s:d[0xA347]='YI SYLLABLE ZHAX'
let s:d[0xA348]='YI SYLLABLE ZHA'
let s:d[0xA349]='YI SYLLABLE ZHAP'
let s:d[0xA34A]='YI SYLLABLE ZHUOX'
let s:d[0xA34B]='YI SYLLABLE ZHUO'
let s:d[0xA34C]='YI SYLLABLE ZHUOP'
let s:d[0xA34D]='YI SYLLABLE ZHOT'
let s:d[0xA34E]='YI SYLLABLE ZHOX'
let s:d[0xA34F]='YI SYLLABLE ZHO'
let s:d[0xA350]='YI SYLLABLE ZHOP'
let s:d[0xA351]='YI SYLLABLE ZHET'
let s:d[0xA352]='YI SYLLABLE ZHEX'
let s:d[0xA353]='YI SYLLABLE ZHE'
let s:d[0xA354]='YI SYLLABLE ZHEP'
let s:d[0xA355]='YI SYLLABLE ZHUT'
let s:d[0xA356]='YI SYLLABLE ZHUX'
let s:d[0xA357]='YI SYLLABLE ZHU'
let s:d[0xA358]='YI SYLLABLE ZHUP'
let s:d[0xA359]='YI SYLLABLE ZHURX'
let s:d[0xA35A]='YI SYLLABLE ZHUR'
let s:d[0xA35B]='YI SYLLABLE ZHYT'
let s:d[0xA35C]='YI SYLLABLE ZHYX'
let s:d[0xA35D]='YI SYLLABLE ZHY'
let s:d[0xA35E]='YI SYLLABLE ZHYP'
let s:d[0xA35F]='YI SYLLABLE ZHYRX'
let s:d[0xA360]='YI SYLLABLE ZHYR'
let s:d[0xA361]='YI SYLLABLE CHAT'
let s:d[0xA362]='YI SYLLABLE CHAX'
let s:d[0xA363]='YI SYLLABLE CHA'
let s:d[0xA364]='YI SYLLABLE CHAP'
let s:d[0xA365]='YI SYLLABLE CHUOT'
let s:d[0xA366]='YI SYLLABLE CHUOX'
let s:d[0xA367]='YI SYLLABLE CHUO'
let s:d[0xA368]='YI SYLLABLE CHUOP'
let s:d[0xA369]='YI SYLLABLE CHOT'
let s:d[0xA36A]='YI SYLLABLE CHOX'
let s:d[0xA36B]='YI SYLLABLE CHO'
let s:d[0xA36C]='YI SYLLABLE CHOP'
let s:d[0xA36D]='YI SYLLABLE CHET'
let s:d[0xA36E]='YI SYLLABLE CHEX'
let s:d[0xA36F]='YI SYLLABLE CHE'
let s:d[0xA370]='YI SYLLABLE CHEP'
let s:d[0xA371]='YI SYLLABLE CHUX'
let s:d[0xA372]='YI SYLLABLE CHU'
let s:d[0xA373]='YI SYLLABLE CHUP'
let s:d[0xA374]='YI SYLLABLE CHURX'
let s:d[0xA375]='YI SYLLABLE CHUR'
let s:d[0xA376]='YI SYLLABLE CHYT'
let s:d[0xA377]='YI SYLLABLE CHYX'
let s:d[0xA378]='YI SYLLABLE CHY'
let s:d[0xA379]='YI SYLLABLE CHYP'
let s:d[0xA37A]='YI SYLLABLE CHYRX'
let s:d[0xA37B]='YI SYLLABLE CHYR'
let s:d[0xA37C]='YI SYLLABLE RRAX'
let s:d[0xA37D]='YI SYLLABLE RRA'
let s:d[0xA37E]='YI SYLLABLE RRUOX'
let s:d[0xA37F]='YI SYLLABLE RRUO'
let s:d[0xA380]='YI SYLLABLE RROT'
let s:d[0xA381]='YI SYLLABLE RROX'
let s:d[0xA382]='YI SYLLABLE RRO'
let s:d[0xA383]='YI SYLLABLE RROP'
let s:d[0xA384]='YI SYLLABLE RRET'
let s:d[0xA385]='YI SYLLABLE RREX'
let s:d[0xA386]='YI SYLLABLE RRE'
let s:d[0xA387]='YI SYLLABLE RREP'
let s:d[0xA388]='YI SYLLABLE RRUT'
let s:d[0xA389]='YI SYLLABLE RRUX'
let s:d[0xA38A]='YI SYLLABLE RRU'
let s:d[0xA38B]='YI SYLLABLE RRUP'
let s:d[0xA38C]='YI SYLLABLE RRURX'
let s:d[0xA38D]='YI SYLLABLE RRUR'
let s:d[0xA38E]='YI SYLLABLE RRYT'
let s:d[0xA38F]='YI SYLLABLE RRYX'
let s:d[0xA390]='YI SYLLABLE RRY'
let s:d[0xA391]='YI SYLLABLE RRYP'
let s:d[0xA392]='YI SYLLABLE RRYRX'
let s:d[0xA393]='YI SYLLABLE RRYR'
let s:d[0xA394]='YI SYLLABLE NRAT'
let s:d[0xA395]='YI SYLLABLE NRAX'
let s:d[0xA396]='YI SYLLABLE NRA'
let s:d[0xA397]='YI SYLLABLE NRAP'
let s:d[0xA398]='YI SYLLABLE NROX'
let s:d[0xA399]='YI SYLLABLE NRO'
let s:d[0xA39A]='YI SYLLABLE NROP'
let s:d[0xA39B]='YI SYLLABLE NRET'
let s:d[0xA39C]='YI SYLLABLE NREX'
let s:d[0xA39D]='YI SYLLABLE NRE'
let s:d[0xA39E]='YI SYLLABLE NREP'
let s:d[0xA39F]='YI SYLLABLE NRUT'
let s:d[0xA3A0]='YI SYLLABLE NRUX'
let s:d[0xA3A1]='YI SYLLABLE NRU'
let s:d[0xA3A2]='YI SYLLABLE NRUP'
let s:d[0xA3A3]='YI SYLLABLE NRURX'
let s:d[0xA3A4]='YI SYLLABLE NRUR'
let s:d[0xA3A5]='YI SYLLABLE NRYT'
let s:d[0xA3A6]='YI SYLLABLE NRYX'
let s:d[0xA3A7]='YI SYLLABLE NRY'
let s:d[0xA3A8]='YI SYLLABLE NRYP'
let s:d[0xA3A9]='YI SYLLABLE NRYRX'
let s:d[0xA3AA]='YI SYLLABLE NRYR'
let s:d[0xA3AB]='YI SYLLABLE SHAT'
let s:d[0xA3AC]='YI SYLLABLE SHAX'
let s:d[0xA3AD]='YI SYLLABLE SHA'
let s:d[0xA3AE]='YI SYLLABLE SHAP'
let s:d[0xA3AF]='YI SYLLABLE SHUOX'
let s:d[0xA3B0]='YI SYLLABLE SHUO'
let s:d[0xA3B1]='YI SYLLABLE SHUOP'
let s:d[0xA3B2]='YI SYLLABLE SHOT'
let s:d[0xA3B3]='YI SYLLABLE SHOX'
let s:d[0xA3B4]='YI SYLLABLE SHO'
let s:d[0xA3B5]='YI SYLLABLE SHOP'
let s:d[0xA3B6]='YI SYLLABLE SHET'
let s:d[0xA3B7]='YI SYLLABLE SHEX'
let s:d[0xA3B8]='YI SYLLABLE SHE'
let s:d[0xA3B9]='YI SYLLABLE SHEP'
let s:d[0xA3BA]='YI SYLLABLE SHUT'
let s:d[0xA3BB]='YI SYLLABLE SHUX'
let s:d[0xA3BC]='YI SYLLABLE SHU'
let s:d[0xA3BD]='YI SYLLABLE SHUP'
let s:d[0xA3BE]='YI SYLLABLE SHURX'
let s:d[0xA3BF]='YI SYLLABLE SHUR'
let s:d[0xA3C0]='YI SYLLABLE SHYT'
let s:d[0xA3C1]='YI SYLLABLE SHYX'
let s:d[0xA3C2]='YI SYLLABLE SHY'
let s:d[0xA3C3]='YI SYLLABLE SHYP'
let s:d[0xA3C4]='YI SYLLABLE SHYRX'
let s:d[0xA3C5]='YI SYLLABLE SHYR'
let s:d[0xA3C6]='YI SYLLABLE RAT'
let s:d[0xA3C7]='YI SYLLABLE RAX'
let s:d[0xA3C8]='YI SYLLABLE RA'
let s:d[0xA3C9]='YI SYLLABLE RAP'
let s:d[0xA3CA]='YI SYLLABLE RUOX'
let s:d[0xA3CB]='YI SYLLABLE RUO'
let s:d[0xA3CC]='YI SYLLABLE RUOP'
let s:d[0xA3CD]='YI SYLLABLE ROT'
let s:d[0xA3CE]='YI SYLLABLE ROX'
let s:d[0xA3CF]='YI SYLLABLE RO'
let s:d[0xA3D0]='YI SYLLABLE ROP'
let s:d[0xA3D1]='YI SYLLABLE REX'
let s:d[0xA3D2]='YI SYLLABLE RE'
let s:d[0xA3D3]='YI SYLLABLE REP'
let s:d[0xA3D4]='YI SYLLABLE RUT'
let s:d[0xA3D5]='YI SYLLABLE RUX'
let s:d[0xA3D6]='YI SYLLABLE RU'
let s:d[0xA3D7]='YI SYLLABLE RUP'
let s:d[0xA3D8]='YI SYLLABLE RURX'
let s:d[0xA3D9]='YI SYLLABLE RUR'
let s:d[0xA3DA]='YI SYLLABLE RYT'
let s:d[0xA3DB]='YI SYLLABLE RYX'
let s:d[0xA3DC]='YI SYLLABLE RY'
let s:d[0xA3DD]='YI SYLLABLE RYP'
let s:d[0xA3DE]='YI SYLLABLE RYRX'
let s:d[0xA3DF]='YI SYLLABLE RYR'
let s:d[0xA3E0]='YI SYLLABLE JIT'
let s:d[0xA3E1]='YI SYLLABLE JIX'
let s:d[0xA3E2]='YI SYLLABLE JI'
let s:d[0xA3E3]='YI SYLLABLE JIP'
let s:d[0xA3E4]='YI SYLLABLE JIET'
let s:d[0xA3E5]='YI SYLLABLE JIEX'
let s:d[0xA3E6]='YI SYLLABLE JIE'
let s:d[0xA3E7]='YI SYLLABLE JIEP'
let s:d[0xA3E8]='YI SYLLABLE JUOT'
let s:d[0xA3E9]='YI SYLLABLE JUOX'
let s:d[0xA3EA]='YI SYLLABLE JUO'
let s:d[0xA3EB]='YI SYLLABLE JUOP'
let s:d[0xA3EC]='YI SYLLABLE JOT'
let s:d[0xA3ED]='YI SYLLABLE JOX'
let s:d[0xA3EE]='YI SYLLABLE JO'
let s:d[0xA3EF]='YI SYLLABLE JOP'
let s:d[0xA3F0]='YI SYLLABLE JUT'
let s:d[0xA3F1]='YI SYLLABLE JUX'
let s:d[0xA3F2]='YI SYLLABLE JU'
let s:d[0xA3F3]='YI SYLLABLE JUP'
let s:d[0xA3F4]='YI SYLLABLE JURX'
let s:d[0xA3F5]='YI SYLLABLE JUR'
let s:d[0xA3F6]='YI SYLLABLE JYT'
let s:d[0xA3F7]='YI SYLLABLE JYX'
let s:d[0xA3F8]='YI SYLLABLE JY'
let s:d[0xA3F9]='YI SYLLABLE JYP'
let s:d[0xA3FA]='YI SYLLABLE JYRX'
let s:d[0xA3FB]='YI SYLLABLE JYR'
let s:d[0xA3FC]='YI SYLLABLE QIT'
let s:d[0xA3FD]='YI SYLLABLE QIX'
let s:d[0xA3FE]='YI SYLLABLE QI'
let s:d[0xA3FF]='YI SYLLABLE QIP'
let s:d[0xA400]='YI SYLLABLE QIET'
let s:d[0xA401]='YI SYLLABLE QIEX'
let s:d[0xA402]='YI SYLLABLE QIE'
let s:d[0xA403]='YI SYLLABLE QIEP'
let s:d[0xA404]='YI SYLLABLE QUOT'
let s:d[0xA405]='YI SYLLABLE QUOX'
let s:d[0xA406]='YI SYLLABLE QUO'
let s:d[0xA407]='YI SYLLABLE QUOP'
let s:d[0xA408]='YI SYLLABLE QOT'
let s:d[0xA409]='YI SYLLABLE QOX'
let s:d[0xA40A]='YI SYLLABLE QO'
let s:d[0xA40B]='YI SYLLABLE QOP'
let s:d[0xA40C]='YI SYLLABLE QUT'
let s:d[0xA40D]='YI SYLLABLE QUX'
let s:d[0xA40E]='YI SYLLABLE QU'
let s:d[0xA40F]='YI SYLLABLE QUP'
let s:d[0xA410]='YI SYLLABLE QURX'
let s:d[0xA411]='YI SYLLABLE QUR'
let s:d[0xA412]='YI SYLLABLE QYT'
let s:d[0xA413]='YI SYLLABLE QYX'
let s:d[0xA414]='YI SYLLABLE QY'
let s:d[0xA415]='YI SYLLABLE QYP'
let s:d[0xA416]='YI SYLLABLE QYRX'
let s:d[0xA417]='YI SYLLABLE QYR'
let s:d[0xA418]='YI SYLLABLE JJIT'
let s:d[0xA419]='YI SYLLABLE JJIX'
let s:d[0xA41A]='YI SYLLABLE JJI'
let s:d[0xA41B]='YI SYLLABLE JJIP'
let s:d[0xA41C]='YI SYLLABLE JJIET'
let s:d[0xA41D]='YI SYLLABLE JJIEX'
let s:d[0xA41E]='YI SYLLABLE JJIE'
let s:d[0xA41F]='YI SYLLABLE JJIEP'
let s:d[0xA420]='YI SYLLABLE JJUOX'
let s:d[0xA421]='YI SYLLABLE JJUO'
let s:d[0xA422]='YI SYLLABLE JJUOP'
let s:d[0xA423]='YI SYLLABLE JJOT'
let s:d[0xA424]='YI SYLLABLE JJOX'
let s:d[0xA425]='YI SYLLABLE JJO'
let s:d[0xA426]='YI SYLLABLE JJOP'
let s:d[0xA427]='YI SYLLABLE JJUT'
let s:d[0xA428]='YI SYLLABLE JJUX'
let s:d[0xA429]='YI SYLLABLE JJU'
let s:d[0xA42A]='YI SYLLABLE JJUP'
let s:d[0xA42B]='YI SYLLABLE JJURX'
let s:d[0xA42C]='YI SYLLABLE JJUR'
let s:d[0xA42D]='YI SYLLABLE JJYT'
let s:d[0xA42E]='YI SYLLABLE JJYX'
let s:d[0xA42F]='YI SYLLABLE JJY'
let s:d[0xA430]='YI SYLLABLE JJYP'
let s:d[0xA431]='YI SYLLABLE NJIT'
let s:d[0xA432]='YI SYLLABLE NJIX'
let s:d[0xA433]='YI SYLLABLE NJI'
let s:d[0xA434]='YI SYLLABLE NJIP'
let s:d[0xA435]='YI SYLLABLE NJIET'
let s:d[0xA436]='YI SYLLABLE NJIEX'
let s:d[0xA437]='YI SYLLABLE NJIE'
let s:d[0xA438]='YI SYLLABLE NJIEP'
let s:d[0xA439]='YI SYLLABLE NJUOX'
let s:d[0xA43A]='YI SYLLABLE NJUO'
let s:d[0xA43B]='YI SYLLABLE NJOT'
let s:d[0xA43C]='YI SYLLABLE NJOX'
let s:d[0xA43D]='YI SYLLABLE NJO'
let s:d[0xA43E]='YI SYLLABLE NJOP'
let s:d[0xA43F]='YI SYLLABLE NJUX'
let s:d[0xA440]='YI SYLLABLE NJU'
let s:d[0xA441]='YI SYLLABLE NJUP'
let s:d[0xA442]='YI SYLLABLE NJURX'
let s:d[0xA443]='YI SYLLABLE NJUR'
let s:d[0xA444]='YI SYLLABLE NJYT'
let s:d[0xA445]='YI SYLLABLE NJYX'
let s:d[0xA446]='YI SYLLABLE NJY'
let s:d[0xA447]='YI SYLLABLE NJYP'
let s:d[0xA448]='YI SYLLABLE NJYRX'
let s:d[0xA449]='YI SYLLABLE NJYR'
let s:d[0xA44A]='YI SYLLABLE NYIT'
let s:d[0xA44B]='YI SYLLABLE NYIX'
let s:d[0xA44C]='YI SYLLABLE NYI'
let s:d[0xA44D]='YI SYLLABLE NYIP'
let s:d[0xA44E]='YI SYLLABLE NYIET'
let s:d[0xA44F]='YI SYLLABLE NYIEX'
let s:d[0xA450]='YI SYLLABLE NYIE'
let s:d[0xA451]='YI SYLLABLE NYIEP'
let s:d[0xA452]='YI SYLLABLE NYUOX'
let s:d[0xA453]='YI SYLLABLE NYUO'
let s:d[0xA454]='YI SYLLABLE NYUOP'
let s:d[0xA455]='YI SYLLABLE NYOT'
let s:d[0xA456]='YI SYLLABLE NYOX'
let s:d[0xA457]='YI SYLLABLE NYO'
let s:d[0xA458]='YI SYLLABLE NYOP'
let s:d[0xA459]='YI SYLLABLE NYUT'
let s:d[0xA45A]='YI SYLLABLE NYUX'
let s:d[0xA45B]='YI SYLLABLE NYU'
let s:d[0xA45C]='YI SYLLABLE NYUP'
let s:d[0xA45D]='YI SYLLABLE XIT'
let s:d[0xA45E]='YI SYLLABLE XIX'
let s:d[0xA45F]='YI SYLLABLE XI'
let s:d[0xA460]='YI SYLLABLE XIP'
let s:d[0xA461]='YI SYLLABLE XIET'
let s:d[0xA462]='YI SYLLABLE XIEX'
let s:d[0xA463]='YI SYLLABLE XIE'
let s:d[0xA464]='YI SYLLABLE XIEP'
let s:d[0xA465]='YI SYLLABLE XUOX'
let s:d[0xA466]='YI SYLLABLE XUO'
let s:d[0xA467]='YI SYLLABLE XOT'
let s:d[0xA468]='YI SYLLABLE XOX'
let s:d[0xA469]='YI SYLLABLE XO'
let s:d[0xA46A]='YI SYLLABLE XOP'
let s:d[0xA46B]='YI SYLLABLE XYT'
let s:d[0xA46C]='YI SYLLABLE XYX'
let s:d[0xA46D]='YI SYLLABLE XY'
let s:d[0xA46E]='YI SYLLABLE XYP'
let s:d[0xA46F]='YI SYLLABLE XYRX'
let s:d[0xA470]='YI SYLLABLE XYR'
let s:d[0xA471]='YI SYLLABLE YIT'
let s:d[0xA472]='YI SYLLABLE YIX'
let s:d[0xA473]='YI SYLLABLE YI'
let s:d[0xA474]='YI SYLLABLE YIP'
let s:d[0xA475]='YI SYLLABLE YIET'
let s:d[0xA476]='YI SYLLABLE YIEX'
let s:d[0xA477]='YI SYLLABLE YIE'
let s:d[0xA478]='YI SYLLABLE YIEP'
let s:d[0xA479]='YI SYLLABLE YUOT'
let s:d[0xA47A]='YI SYLLABLE YUOX'
let s:d[0xA47B]='YI SYLLABLE YUO'
let s:d[0xA47C]='YI SYLLABLE YUOP'
let s:d[0xA47D]='YI SYLLABLE YOT'
let s:d[0xA47E]='YI SYLLABLE YOX'
let s:d[0xA47F]='YI SYLLABLE YO'
let s:d[0xA480]='YI SYLLABLE YOP'
let s:d[0xA481]='YI SYLLABLE YUT'
let s:d[0xA482]='YI SYLLABLE YUX'
let s:d[0xA483]='YI SYLLABLE YU'
let s:d[0xA484]='YI SYLLABLE YUP'
let s:d[0xA485]='YI SYLLABLE YURX'
let s:d[0xA486]='YI SYLLABLE YUR'
let s:d[0xA487]='YI SYLLABLE YYT'
let s:d[0xA488]='YI SYLLABLE YYX'
let s:d[0xA489]='YI SYLLABLE YY'
let s:d[0xA48A]='YI SYLLABLE YYP'
let s:d[0xA48B]='YI SYLLABLE YYRX'
let s:d[0xA48C]='YI SYLLABLE YYR'
let s:d[0xA490]='YI RADICAL QOT'
let s:d[0xA491]='YI RADICAL LI'
let s:d[0xA492]='YI RADICAL KIT'
let s:d[0xA493]='YI RADICAL NYIP'
let s:d[0xA494]='YI RADICAL CYP'
let s:d[0xA495]='YI RADICAL SSI'
let s:d[0xA496]='YI RADICAL GGOP'
let s:d[0xA497]='YI RADICAL GEP'
let s:d[0xA498]='YI RADICAL MI'
let s:d[0xA499]='YI RADICAL HXIT'
let s:d[0xA49A]='YI RADICAL LYR'
let s:d[0xA49B]='YI RADICAL BBUT'
let s:d[0xA49C]='YI RADICAL MOP'
let s:d[0xA49D]='YI RADICAL YO'
let s:d[0xA49E]='YI RADICAL PUT'
let s:d[0xA49F]='YI RADICAL HXUO'
let s:d[0xA4A0]='YI RADICAL TAT'
let s:d[0xA4A1]='YI RADICAL GA'
let s:d[0xA4A2]='YI RADICAL ZUP'
let s:d[0xA4A3]='YI RADICAL CYT'
let s:d[0xA4A4]='YI RADICAL DDUR'
let s:d[0xA4A5]='YI RADICAL BUR'
let s:d[0xA4A6]='YI RADICAL GGUO'
let s:d[0xA4A7]='YI RADICAL NYOP'
let s:d[0xA4A8]='YI RADICAL TU'
let s:d[0xA4A9]='YI RADICAL OP'
let s:d[0xA4AA]='YI RADICAL JJUT'
let s:d[0xA4AB]='YI RADICAL ZOT'
let s:d[0xA4AC]='YI RADICAL PYT'
let s:d[0xA4AD]='YI RADICAL HMO'
let s:d[0xA4AE]='YI RADICAL YIT'
let s:d[0xA4AF]='YI RADICAL VUR'
let s:d[0xA4B0]='YI RADICAL SHY'
let s:d[0xA4B1]='YI RADICAL VEP'
let s:d[0xA4B2]='YI RADICAL ZA'
let s:d[0xA4B3]='YI RADICAL JO'
let s:d[0xA4B4]='YI RADICAL NZUP'
let s:d[0xA4B5]='YI RADICAL JJY'
let s:d[0xA4B6]='YI RADICAL GOT'
let s:d[0xA4B7]='YI RADICAL JJIE'
let s:d[0xA4B8]='YI RADICAL WO'
let s:d[0xA4B9]='YI RADICAL DU'
let s:d[0xA4BA]='YI RADICAL SHUR'
let s:d[0xA4BB]='YI RADICAL LIE'
let s:d[0xA4BC]='YI RADICAL CY'
let s:d[0xA4BD]='YI RADICAL CUOP'
let s:d[0xA4BE]='YI RADICAL CIP'
let s:d[0xA4BF]='YI RADICAL HXOP'
let s:d[0xA4C0]='YI RADICAL SHAT'
let s:d[0xA4C1]='YI RADICAL ZUR'
let s:d[0xA4C2]='YI RADICAL SHOP'
let s:d[0xA4C3]='YI RADICAL CHE'
let s:d[0xA4C4]='YI RADICAL ZZIET'
let s:d[0xA4C5]='YI RADICAL NBIE'
let s:d[0xA4C6]='YI RADICAL KE'
let s:d[0xA4D0]='LISU LETTER BA'
let s:d[0xA4D1]='LISU LETTER PA'
let s:d[0xA4D2]='LISU LETTER PHA'
let s:d[0xA4D3]='LISU LETTER DA'
let s:d[0xA4D4]='LISU LETTER TA'
let s:d[0xA4D5]='LISU LETTER THA'
let s:d[0xA4D6]='LISU LETTER GA'
let s:d[0xA4D7]='LISU LETTER KA'
let s:d[0xA4D8]='LISU LETTER KHA'
let s:d[0xA4D9]='LISU LETTER JA'
let s:d[0xA4DA]='LISU LETTER CA'
let s:d[0xA4DB]='LISU LETTER CHA'
let s:d[0xA4DC]='LISU LETTER DZA'
let s:d[0xA4DD]='LISU LETTER TSA'
let s:d[0xA4DE]='LISU LETTER TSHA'
let s:d[0xA4DF]='LISU LETTER MA'
let s:d[0xA4E0]='LISU LETTER NA'
let s:d[0xA4E1]='LISU LETTER LA'
let s:d[0xA4E2]='LISU LETTER SA'
let s:d[0xA4E3]='LISU LETTER ZHA'
let s:d[0xA4E4]='LISU LETTER ZA'
let s:d[0xA4E5]='LISU LETTER NGA'
let s:d[0xA4E6]='LISU LETTER HA'
let s:d[0xA4E7]='LISU LETTER XA'
let s:d[0xA4E8]='LISU LETTER HHA'
let s:d[0xA4E9]='LISU LETTER FA'
let s:d[0xA4EA]='LISU LETTER WA'
let s:d[0xA4EB]='LISU LETTER SHA'
let s:d[0xA4EC]='LISU LETTER YA'
let s:d[0xA4ED]='LISU LETTER GHA'
let s:d[0xA4EE]='LISU LETTER A'
let s:d[0xA4EF]='LISU LETTER AE'
let s:d[0xA4F0]='LISU LETTER E'
let s:d[0xA4F1]='LISU LETTER EU'
let s:d[0xA4F2]='LISU LETTER I'
let s:d[0xA4F3]='LISU LETTER O'
let s:d[0xA4F4]='LISU LETTER U'
let s:d[0xA4F5]='LISU LETTER UE'
let s:d[0xA4F6]='LISU LETTER UH'
let s:d[0xA4F7]='LISU LETTER OE'
let s:d[0xA4F8]='LISU LETTER TONE MYA TI'
let s:d[0xA4F9]='LISU LETTER TONE NA PO'
let s:d[0xA4FA]='LISU LETTER TONE MYA CYA'
let s:d[0xA4FB]='LISU LETTER TONE MYA BO'
let s:d[0xA4FC]='LISU LETTER TONE MYA NA'
let s:d[0xA4FD]='LISU LETTER TONE MYA JEU'
let s:d[0xA4FE]='LISU PUNCTUATION COMMA'
let s:d[0xA4FF]='LISU PUNCTUATION FULL STOP'
let s:d[0xA500]='VAI SYLLABLE EE'
let s:d[0xA501]='VAI SYLLABLE EEN'
let s:d[0xA502]='VAI SYLLABLE HEE'
let s:d[0xA503]='VAI SYLLABLE WEE'
let s:d[0xA504]='VAI SYLLABLE WEEN'
let s:d[0xA505]='VAI SYLLABLE PEE'
let s:d[0xA506]='VAI SYLLABLE BHEE'
let s:d[0xA507]='VAI SYLLABLE BEE'
let s:d[0xA508]='VAI SYLLABLE MBEE'
let s:d[0xA509]='VAI SYLLABLE KPEE'
let s:d[0xA50A]='VAI SYLLABLE MGBEE'
let s:d[0xA50B]='VAI SYLLABLE GBEE'
let s:d[0xA50C]='VAI SYLLABLE FEE'
let s:d[0xA50D]='VAI SYLLABLE VEE'
let s:d[0xA50E]='VAI SYLLABLE TEE'
let s:d[0xA50F]='VAI SYLLABLE THEE'
let s:d[0xA510]='VAI SYLLABLE DHEE'
let s:d[0xA511]='VAI SYLLABLE DHHEE'
let s:d[0xA512]='VAI SYLLABLE LEE'
let s:d[0xA513]='VAI SYLLABLE REE'
let s:d[0xA514]='VAI SYLLABLE DEE'
let s:d[0xA515]='VAI SYLLABLE NDEE'
let s:d[0xA516]='VAI SYLLABLE SEE'
let s:d[0xA517]='VAI SYLLABLE SHEE'
let s:d[0xA518]='VAI SYLLABLE ZEE'
let s:d[0xA519]='VAI SYLLABLE ZHEE'
let s:d[0xA51A]='VAI SYLLABLE CEE'
let s:d[0xA51B]='VAI SYLLABLE JEE'
let s:d[0xA51C]='VAI SYLLABLE NJEE'
let s:d[0xA51D]='VAI SYLLABLE YEE'
let s:d[0xA51E]='VAI SYLLABLE KEE'
let s:d[0xA51F]='VAI SYLLABLE NGGEE'
let s:d[0xA520]='VAI SYLLABLE GEE'
let s:d[0xA521]='VAI SYLLABLE MEE'
let s:d[0xA522]='VAI SYLLABLE NEE'
let s:d[0xA523]='VAI SYLLABLE NYEE'
let s:d[0xA524]='VAI SYLLABLE I'
let s:d[0xA525]='VAI SYLLABLE IN'
let s:d[0xA526]='VAI SYLLABLE HI'
let s:d[0xA527]='VAI SYLLABLE HIN'
let s:d[0xA528]='VAI SYLLABLE WI'
let s:d[0xA529]='VAI SYLLABLE WIN'
let s:d[0xA52A]='VAI SYLLABLE PI'
let s:d[0xA52B]='VAI SYLLABLE BHI'
let s:d[0xA52C]='VAI SYLLABLE BI'
let s:d[0xA52D]='VAI SYLLABLE MBI'
let s:d[0xA52E]='VAI SYLLABLE KPI'
let s:d[0xA52F]='VAI SYLLABLE MGBI'
let s:d[0xA530]='VAI SYLLABLE GBI'
let s:d[0xA531]='VAI SYLLABLE FI'
let s:d[0xA532]='VAI SYLLABLE VI'
let s:d[0xA533]='VAI SYLLABLE TI'
let s:d[0xA534]='VAI SYLLABLE THI'
let s:d[0xA535]='VAI SYLLABLE DHI'
let s:d[0xA536]='VAI SYLLABLE DHHI'
let s:d[0xA537]='VAI SYLLABLE LI'
let s:d[0xA538]='VAI SYLLABLE RI'
let s:d[0xA539]='VAI SYLLABLE DI'
let s:d[0xA53A]='VAI SYLLABLE NDI'
let s:d[0xA53B]='VAI SYLLABLE SI'
let s:d[0xA53C]='VAI SYLLABLE SHI'
let s:d[0xA53D]='VAI SYLLABLE ZI'
let s:d[0xA53E]='VAI SYLLABLE ZHI'
let s:d[0xA53F]='VAI SYLLABLE CI'
let s:d[0xA540]='VAI SYLLABLE JI'
let s:d[0xA541]='VAI SYLLABLE NJI'
let s:d[0xA542]='VAI SYLLABLE YI'
let s:d[0xA543]='VAI SYLLABLE KI'
let s:d[0xA544]='VAI SYLLABLE NGGI'
let s:d[0xA545]='VAI SYLLABLE GI'
let s:d[0xA546]='VAI SYLLABLE MI'
let s:d[0xA547]='VAI SYLLABLE NI'
let s:d[0xA548]='VAI SYLLABLE NYI'
let s:d[0xA549]='VAI SYLLABLE A'
let s:d[0xA54A]='VAI SYLLABLE AN'
let s:d[0xA54B]='VAI SYLLABLE NGAN'
let s:d[0xA54C]='VAI SYLLABLE HA'
let s:d[0xA54D]='VAI SYLLABLE HAN'
let s:d[0xA54E]='VAI SYLLABLE WA'
let s:d[0xA54F]='VAI SYLLABLE WAN'
let s:d[0xA550]='VAI SYLLABLE PA'
let s:d[0xA551]='VAI SYLLABLE BHA'
let s:d[0xA552]='VAI SYLLABLE BA'
let s:d[0xA553]='VAI SYLLABLE MBA'
let s:d[0xA554]='VAI SYLLABLE KPA'
let s:d[0xA555]='VAI SYLLABLE KPAN'
let s:d[0xA556]='VAI SYLLABLE MGBA'
let s:d[0xA557]='VAI SYLLABLE GBA'
let s:d[0xA558]='VAI SYLLABLE FA'
let s:d[0xA559]='VAI SYLLABLE VA'
let s:d[0xA55A]='VAI SYLLABLE TA'
let s:d[0xA55B]='VAI SYLLABLE THA'
let s:d[0xA55C]='VAI SYLLABLE DHA'
let s:d[0xA55D]='VAI SYLLABLE DHHA'
let s:d[0xA55E]='VAI SYLLABLE LA'
let s:d[0xA55F]='VAI SYLLABLE RA'
let s:d[0xA560]='VAI SYLLABLE DA'
let s:d[0xA561]='VAI SYLLABLE NDA'
let s:d[0xA562]='VAI SYLLABLE SA'
let s:d[0xA563]='VAI SYLLABLE SHA'
let s:d[0xA564]='VAI SYLLABLE ZA'
let s:d[0xA565]='VAI SYLLABLE ZHA'
let s:d[0xA566]='VAI SYLLABLE CA'
let s:d[0xA567]='VAI SYLLABLE JA'
let s:d[0xA568]='VAI SYLLABLE NJA'
let s:d[0xA569]='VAI SYLLABLE YA'
let s:d[0xA56A]='VAI SYLLABLE KA'
let s:d[0xA56B]='VAI SYLLABLE KAN'
let s:d[0xA56C]='VAI SYLLABLE NGGA'
let s:d[0xA56D]='VAI SYLLABLE GA'
let s:d[0xA56E]='VAI SYLLABLE MA'
let s:d[0xA56F]='VAI SYLLABLE NA'
let s:d[0xA570]='VAI SYLLABLE NYA'
let s:d[0xA571]='VAI SYLLABLE OO'
let s:d[0xA572]='VAI SYLLABLE OON'
let s:d[0xA573]='VAI SYLLABLE HOO'
let s:d[0xA574]='VAI SYLLABLE WOO'
let s:d[0xA575]='VAI SYLLABLE WOON'
let s:d[0xA576]='VAI SYLLABLE POO'
let s:d[0xA577]='VAI SYLLABLE BHOO'
let s:d[0xA578]='VAI SYLLABLE BOO'
let s:d[0xA579]='VAI SYLLABLE MBOO'
let s:d[0xA57A]='VAI SYLLABLE KPOO'
let s:d[0xA57B]='VAI SYLLABLE MGBOO'
let s:d[0xA57C]='VAI SYLLABLE GBOO'
let s:d[0xA57D]='VAI SYLLABLE FOO'
let s:d[0xA57E]='VAI SYLLABLE VOO'
let s:d[0xA57F]='VAI SYLLABLE TOO'
let s:d[0xA580]='VAI SYLLABLE THOO'
let s:d[0xA581]='VAI SYLLABLE DHOO'
let s:d[0xA582]='VAI SYLLABLE DHHOO'
let s:d[0xA583]='VAI SYLLABLE LOO'
let s:d[0xA584]='VAI SYLLABLE ROO'
let s:d[0xA585]='VAI SYLLABLE DOO'
let s:d[0xA586]='VAI SYLLABLE NDOO'
let s:d[0xA587]='VAI SYLLABLE SOO'
let s:d[0xA588]='VAI SYLLABLE SHOO'
let s:d[0xA589]='VAI SYLLABLE ZOO'
let s:d[0xA58A]='VAI SYLLABLE ZHOO'
let s:d[0xA58B]='VAI SYLLABLE COO'
let s:d[0xA58C]='VAI SYLLABLE JOO'
let s:d[0xA58D]='VAI SYLLABLE NJOO'
let s:d[0xA58E]='VAI SYLLABLE YOO'
let s:d[0xA58F]='VAI SYLLABLE KOO'
let s:d[0xA590]='VAI SYLLABLE NGGOO'
let s:d[0xA591]='VAI SYLLABLE GOO'
let s:d[0xA592]='VAI SYLLABLE MOO'
let s:d[0xA593]='VAI SYLLABLE NOO'
let s:d[0xA594]='VAI SYLLABLE NYOO'
let s:d[0xA595]='VAI SYLLABLE U'
let s:d[0xA596]='VAI SYLLABLE UN'
let s:d[0xA597]='VAI SYLLABLE HU'
let s:d[0xA598]='VAI SYLLABLE HUN'
let s:d[0xA599]='VAI SYLLABLE WU'
let s:d[0xA59A]='VAI SYLLABLE WUN'
let s:d[0xA59B]='VAI SYLLABLE PU'
let s:d[0xA59C]='VAI SYLLABLE BHU'
let s:d[0xA59D]='VAI SYLLABLE BU'
let s:d[0xA59E]='VAI SYLLABLE MBU'
let s:d[0xA59F]='VAI SYLLABLE KPU'
let s:d[0xA5A0]='VAI SYLLABLE MGBU'
let s:d[0xA5A1]='VAI SYLLABLE GBU'
let s:d[0xA5A2]='VAI SYLLABLE FU'
let s:d[0xA5A3]='VAI SYLLABLE VU'
let s:d[0xA5A4]='VAI SYLLABLE TU'
let s:d[0xA5A5]='VAI SYLLABLE THU'
let s:d[0xA5A6]='VAI SYLLABLE DHU'
let s:d[0xA5A7]='VAI SYLLABLE DHHU'
let s:d[0xA5A8]='VAI SYLLABLE LU'
let s:d[0xA5A9]='VAI SYLLABLE RU'
let s:d[0xA5AA]='VAI SYLLABLE DU'
let s:d[0xA5AB]='VAI SYLLABLE NDU'
let s:d[0xA5AC]='VAI SYLLABLE SU'
let s:d[0xA5AD]='VAI SYLLABLE SHU'
let s:d[0xA5AE]='VAI SYLLABLE ZU'
let s:d[0xA5AF]='VAI SYLLABLE ZHU'
let s:d[0xA5B0]='VAI SYLLABLE CU'
let s:d[0xA5B1]='VAI SYLLABLE JU'
let s:d[0xA5B2]='VAI SYLLABLE NJU'
let s:d[0xA5B3]='VAI SYLLABLE YU'
let s:d[0xA5B4]='VAI SYLLABLE KU'
let s:d[0xA5B5]='VAI SYLLABLE NGGU'
let s:d[0xA5B6]='VAI SYLLABLE GU'
let s:d[0xA5B7]='VAI SYLLABLE MU'
let s:d[0xA5B8]='VAI SYLLABLE NU'
let s:d[0xA5B9]='VAI SYLLABLE NYU'
let s:d[0xA5BA]='VAI SYLLABLE O'
let s:d[0xA5BB]='VAI SYLLABLE ON'
let s:d[0xA5BC]='VAI SYLLABLE NGON'
let s:d[0xA5BD]='VAI SYLLABLE HO'
let s:d[0xA5BE]='VAI SYLLABLE HON'
let s:d[0xA5BF]='VAI SYLLABLE WO'
let s:d[0xA5C0]='VAI SYLLABLE WON'
let s:d[0xA5C1]='VAI SYLLABLE PO'
let s:d[0xA5C2]='VAI SYLLABLE BHO'
let s:d[0xA5C3]='VAI SYLLABLE BO'
let s:d[0xA5C4]='VAI SYLLABLE MBO'
let s:d[0xA5C5]='VAI SYLLABLE KPO'
let s:d[0xA5C6]='VAI SYLLABLE MGBO'
let s:d[0xA5C7]='VAI SYLLABLE GBO'
let s:d[0xA5C8]='VAI SYLLABLE GBON'
let s:d[0xA5C9]='VAI SYLLABLE FO'
let s:d[0xA5CA]='VAI SYLLABLE VO'
let s:d[0xA5CB]='VAI SYLLABLE TO'
let s:d[0xA5CC]='VAI SYLLABLE THO'
let s:d[0xA5CD]='VAI SYLLABLE DHO'
let s:d[0xA5CE]='VAI SYLLABLE DHHO'
let s:d[0xA5CF]='VAI SYLLABLE LO'
let s:d[0xA5D0]='VAI SYLLABLE RO'
let s:d[0xA5D1]='VAI SYLLABLE DO'
let s:d[0xA5D2]='VAI SYLLABLE NDO'
let s:d[0xA5D3]='VAI SYLLABLE SO'
let s:d[0xA5D4]='VAI SYLLABLE SHO'
let s:d[0xA5D5]='VAI SYLLABLE ZO'
let s:d[0xA5D6]='VAI SYLLABLE ZHO'
let s:d[0xA5D7]='VAI SYLLABLE CO'
let s:d[0xA5D8]='VAI SYLLABLE JO'
let s:d[0xA5D9]='VAI SYLLABLE NJO'
let s:d[0xA5DA]='VAI SYLLABLE YO'
let s:d[0xA5DB]='VAI SYLLABLE KO'
let s:d[0xA5DC]='VAI SYLLABLE NGGO'
let s:d[0xA5DD]='VAI SYLLABLE GO'
let s:d[0xA5DE]='VAI SYLLABLE MO'
let s:d[0xA5DF]='VAI SYLLABLE NO'
let s:d[0xA5E0]='VAI SYLLABLE NYO'
let s:d[0xA5E1]='VAI SYLLABLE E'
let s:d[0xA5E2]='VAI SYLLABLE EN'
let s:d[0xA5E3]='VAI SYLLABLE NGEN'
let s:d[0xA5E4]='VAI SYLLABLE HE'
let s:d[0xA5E5]='VAI SYLLABLE HEN'
let s:d[0xA5E6]='VAI SYLLABLE WE'
let s:d[0xA5E7]='VAI SYLLABLE WEN'
let s:d[0xA5E8]='VAI SYLLABLE PE'
let s:d[0xA5E9]='VAI SYLLABLE BHE'
let s:d[0xA5EA]='VAI SYLLABLE BE'
let s:d[0xA5EB]='VAI SYLLABLE MBE'
let s:d[0xA5EC]='VAI SYLLABLE KPE'
let s:d[0xA5ED]='VAI SYLLABLE KPEN'
let s:d[0xA5EE]='VAI SYLLABLE MGBE'
let s:d[0xA5EF]='VAI SYLLABLE GBE'
let s:d[0xA5F0]='VAI SYLLABLE GBEN'
let s:d[0xA5F1]='VAI SYLLABLE FE'
let s:d[0xA5F2]='VAI SYLLABLE VE'
let s:d[0xA5F3]='VAI SYLLABLE TE'
let s:d[0xA5F4]='VAI SYLLABLE THE'
let s:d[0xA5F5]='VAI SYLLABLE DHE'
let s:d[0xA5F6]='VAI SYLLABLE DHHE'
let s:d[0xA5F7]='VAI SYLLABLE LE'
let s:d[0xA5F8]='VAI SYLLABLE RE'
let s:d[0xA5F9]='VAI SYLLABLE DE'
let s:d[0xA5FA]='VAI SYLLABLE NDE'
let s:d[0xA5FB]='VAI SYLLABLE SE'
let s:d[0xA5FC]='VAI SYLLABLE SHE'
let s:d[0xA5FD]='VAI SYLLABLE ZE'
let s:d[0xA5FE]='VAI SYLLABLE ZHE'
let s:d[0xA5FF]='VAI SYLLABLE CE'
let s:d[0xA600]='VAI SYLLABLE JE'
let s:d[0xA601]='VAI SYLLABLE NJE'
let s:d[0xA602]='VAI SYLLABLE YE'
let s:d[0xA603]='VAI SYLLABLE KE'
let s:d[0xA604]='VAI SYLLABLE NGGE'
let s:d[0xA605]='VAI SYLLABLE NGGEN'
let s:d[0xA606]='VAI SYLLABLE GE'
let s:d[0xA607]='VAI SYLLABLE GEN'
let s:d[0xA608]='VAI SYLLABLE ME'
let s:d[0xA609]='VAI SYLLABLE NE'
let s:d[0xA60A]='VAI SYLLABLE NYE'
let s:d[0xA60B]='VAI SYLLABLE NG'
let s:d[0xA60C]='VAI SYLLABLE LENGTHENER'
let s:d[0xA60D]='VAI COMMA'
let s:d[0xA60E]='VAI FULL STOP'
let s:d[0xA60F]='VAI QUESTION MARK'
let s:d[0xA610]='VAI SYLLABLE NDOLE FA'
let s:d[0xA611]='VAI SYLLABLE NDOLE KA'
let s:d[0xA612]='VAI SYLLABLE NDOLE SOO'
let s:d[0xA613]='VAI SYMBOL FEENG'
let s:d[0xA614]='VAI SYMBOL KEENG'
let s:d[0xA615]='VAI SYMBOL TING'
let s:d[0xA616]='VAI SYMBOL NII'
let s:d[0xA617]='VAI SYMBOL BANG'
let s:d[0xA618]='VAI SYMBOL FAA'
let s:d[0xA619]='VAI SYMBOL TAA'
let s:d[0xA61A]='VAI SYMBOL DANG'
let s:d[0xA61B]='VAI SYMBOL DOONG'
let s:d[0xA61C]='VAI SYMBOL KUNG'
let s:d[0xA61D]='VAI SYMBOL TONG'
let s:d[0xA61E]='VAI SYMBOL DO-O'
let s:d[0xA61F]='VAI SYMBOL JONG'
let s:d[0xA620]='VAI DIGIT ZERO'
let s:d[0xA621]='VAI DIGIT ONE'
let s:d[0xA622]='VAI DIGIT TWO'
let s:d[0xA623]='VAI DIGIT THREE'
let s:d[0xA624]='VAI DIGIT FOUR'
let s:d[0xA625]='VAI DIGIT FIVE'
let s:d[0xA626]='VAI DIGIT SIX'
let s:d[0xA627]='VAI DIGIT SEVEN'
let s:d[0xA628]='VAI DIGIT EIGHT'
let s:d[0xA629]='VAI DIGIT NINE'
let s:d[0xA62A]='VAI SYLLABLE NDOLE MA'
let s:d[0xA62B]='VAI SYLLABLE NDOLE DO'
let s:d[0xA640]='CYRILLIC CAPITAL LETTER ZEMLYA'
let s:d[0xA641]='CYRILLIC SMALL LETTER ZEMLYA'
let s:d[0xA642]='CYRILLIC CAPITAL LETTER DZELO'
let s:d[0xA643]='CYRILLIC SMALL LETTER DZELO'
let s:d[0xA644]='CYRILLIC CAPITAL LETTER REVERSED DZE'
let s:d[0xA645]='CYRILLIC SMALL LETTER REVERSED DZE'
let s:d[0xA646]='CYRILLIC CAPITAL LETTER IOTA'
let s:d[0xA647]='CYRILLIC SMALL LETTER IOTA'
let s:d[0xA648]='CYRILLIC CAPITAL LETTER DJERV'
let s:d[0xA649]='CYRILLIC SMALL LETTER DJERV'
let s:d[0xA64A]='CYRILLIC CAPITAL LETTER MONOGRAPH UK'
let s:d[0xA64B]='CYRILLIC SMALL LETTER MONOGRAPH UK'
let s:d[0xA64C]='CYRILLIC CAPITAL LETTER BROAD OMEGA'
let s:d[0xA64D]='CYRILLIC SMALL LETTER BROAD OMEGA'
let s:d[0xA64E]='CYRILLIC CAPITAL LETTER NEUTRAL YER'
let s:d[0xA64F]='CYRILLIC SMALL LETTER NEUTRAL YER'
let s:d[0xA650]='CYRILLIC CAPITAL LETTER YERU WITH BACK YER'
let s:d[0xA651]='CYRILLIC SMALL LETTER YERU WITH BACK YER'
let s:d[0xA652]='CYRILLIC CAPITAL LETTER IOTIFIED YAT'
let s:d[0xA653]='CYRILLIC SMALL LETTER IOTIFIED YAT'
let s:d[0xA654]='CYRILLIC CAPITAL LETTER REVERSED YU'
let s:d[0xA655]='CYRILLIC SMALL LETTER REVERSED YU'
let s:d[0xA656]='CYRILLIC CAPITAL LETTER IOTIFIED A'
let s:d[0xA657]='CYRILLIC SMALL LETTER IOTIFIED A'
let s:d[0xA658]='CYRILLIC CAPITAL LETTER CLOSED LITTLE YUS'
let s:d[0xA659]='CYRILLIC SMALL LETTER CLOSED LITTLE YUS'
let s:d[0xA65A]='CYRILLIC CAPITAL LETTER BLENDED YUS'
let s:d[0xA65B]='CYRILLIC SMALL LETTER BLENDED YUS'
let s:d[0xA65C]='CYRILLIC CAPITAL LETTER IOTIFIED CLOSED LITTLE YUS'
let s:d[0xA65D]='CYRILLIC SMALL LETTER IOTIFIED CLOSED LITTLE YUS'
let s:d[0xA65E]='CYRILLIC CAPITAL LETTER YN'
let s:d[0xA65F]='CYRILLIC SMALL LETTER YN'
let s:d[0xA660]='CYRILLIC CAPITAL LETTER REVERSED TSE'
let s:d[0xA661]='CYRILLIC SMALL LETTER REVERSED TSE'
let s:d[0xA662]='CYRILLIC CAPITAL LETTER SOFT DE'
let s:d[0xA663]='CYRILLIC SMALL LETTER SOFT DE'
let s:d[0xA664]='CYRILLIC CAPITAL LETTER SOFT EL'
let s:d[0xA665]='CYRILLIC SMALL LETTER SOFT EL'
let s:d[0xA666]='CYRILLIC CAPITAL LETTER SOFT EM'
let s:d[0xA667]='CYRILLIC SMALL LETTER SOFT EM'
let s:d[0xA668]='CYRILLIC CAPITAL LETTER MONOCULAR O'
let s:d[0xA669]='CYRILLIC SMALL LETTER MONOCULAR O'
let s:d[0xA66A]='CYRILLIC CAPITAL LETTER BINOCULAR O'
let s:d[0xA66B]='CYRILLIC SMALL LETTER BINOCULAR O'
let s:d[0xA66C]='CYRILLIC CAPITAL LETTER DOUBLE MONOCULAR O'
let s:d[0xA66D]='CYRILLIC SMALL LETTER DOUBLE MONOCULAR O'
let s:d[0xA66E]='CYRILLIC LETTER MULTIOCULAR O'
let s:d[0xA66F]='COMBINING CYRILLIC VZMET'
let s:d[0xA670]='COMBINING CYRILLIC TEN MILLIONS SIGN'
let s:d[0xA671]='COMBINING CYRILLIC HUNDRED MILLIONS SIGN'
let s:d[0xA672]='COMBINING CYRILLIC THOUSAND MILLIONS SIGN'
let s:d[0xA673]='SLAVONIC ASTERISK'
let s:d[0xA674]='COMBINING CYRILLIC LETTER UKRAINIAN IE'
let s:d[0xA675]='COMBINING CYRILLIC LETTER I'
let s:d[0xA676]='COMBINING CYRILLIC LETTER YI'
let s:d[0xA677]='COMBINING CYRILLIC LETTER U'
let s:d[0xA678]='COMBINING CYRILLIC LETTER HARD SIGN'
let s:d[0xA679]='COMBINING CYRILLIC LETTER YERU'
let s:d[0xA67A]='COMBINING CYRILLIC LETTER SOFT SIGN'
let s:d[0xA67B]='COMBINING CYRILLIC LETTER OMEGA'
let s:d[0xA67C]='COMBINING CYRILLIC KAVYKA'
let s:d[0xA67D]='COMBINING CYRILLIC PAYEROK'
let s:d[0xA67E]='CYRILLIC KAVYKA'
let s:d[0xA67F]='CYRILLIC PAYEROK'
let s:d[0xA680]='CYRILLIC CAPITAL LETTER DWE'
let s:d[0xA681]='CYRILLIC SMALL LETTER DWE'
let s:d[0xA682]='CYRILLIC CAPITAL LETTER DZWE'
let s:d[0xA683]='CYRILLIC SMALL LETTER DZWE'
let s:d[0xA684]='CYRILLIC CAPITAL LETTER ZHWE'
let s:d[0xA685]='CYRILLIC SMALL LETTER ZHWE'
let s:d[0xA686]='CYRILLIC CAPITAL LETTER CCHE'
let s:d[0xA687]='CYRILLIC SMALL LETTER CCHE'
let s:d[0xA688]='CYRILLIC CAPITAL LETTER DZZE'
let s:d[0xA689]='CYRILLIC SMALL LETTER DZZE'
let s:d[0xA68A]='CYRILLIC CAPITAL LETTER TE WITH MIDDLE HOOK'
let s:d[0xA68B]='CYRILLIC SMALL LETTER TE WITH MIDDLE HOOK'
let s:d[0xA68C]='CYRILLIC CAPITAL LETTER TWE'
let s:d[0xA68D]='CYRILLIC SMALL LETTER TWE'
let s:d[0xA68E]='CYRILLIC CAPITAL LETTER TSWE'
let s:d[0xA68F]='CYRILLIC SMALL LETTER TSWE'
let s:d[0xA690]='CYRILLIC CAPITAL LETTER TSSE'
let s:d[0xA691]='CYRILLIC SMALL LETTER TSSE'
let s:d[0xA692]='CYRILLIC CAPITAL LETTER TCHE'
let s:d[0xA693]='CYRILLIC SMALL LETTER TCHE'
let s:d[0xA694]='CYRILLIC CAPITAL LETTER HWE'
let s:d[0xA695]='CYRILLIC SMALL LETTER HWE'
let s:d[0xA696]='CYRILLIC CAPITAL LETTER SHWE'
let s:d[0xA697]='CYRILLIC SMALL LETTER SHWE'
let s:d[0xA69F]='COMBINING CYRILLIC LETTER IOTIFIED E'
let s:d[0xA6A0]='BAMUM LETTER A'
let s:d[0xA6A1]='BAMUM LETTER KA'
let s:d[0xA6A2]='BAMUM LETTER U'
let s:d[0xA6A3]='BAMUM LETTER KU'
let s:d[0xA6A4]='BAMUM LETTER EE'
let s:d[0xA6A5]='BAMUM LETTER REE'
let s:d[0xA6A6]='BAMUM LETTER TAE'
let s:d[0xA6A7]='BAMUM LETTER O'
let s:d[0xA6A8]='BAMUM LETTER NYI'
let s:d[0xA6A9]='BAMUM LETTER I'
let s:d[0xA6AA]='BAMUM LETTER LA'
let s:d[0xA6AB]='BAMUM LETTER PA'
let s:d[0xA6AC]='BAMUM LETTER RII'
let s:d[0xA6AD]='BAMUM LETTER RIEE'
let s:d[0xA6AE]='BAMUM LETTER LEEEE'
let s:d[0xA6AF]='BAMUM LETTER MEEEE'
let s:d[0xA6B0]='BAMUM LETTER TAA'
let s:d[0xA6B1]='BAMUM LETTER NDAA'
let s:d[0xA6B2]='BAMUM LETTER NJAEM'
let s:d[0xA6B3]='BAMUM LETTER M'
let s:d[0xA6B4]='BAMUM LETTER SUU'
let s:d[0xA6B5]='BAMUM LETTER MU'
let s:d[0xA6B6]='BAMUM LETTER SHII'
let s:d[0xA6B7]='BAMUM LETTER SI'
let s:d[0xA6B8]='BAMUM LETTER SHEUX'
let s:d[0xA6B9]='BAMUM LETTER SEUX'
let s:d[0xA6BA]='BAMUM LETTER KYEE'
let s:d[0xA6BB]='BAMUM LETTER KET'
let s:d[0xA6BC]='BAMUM LETTER NUAE'
let s:d[0xA6BD]='BAMUM LETTER NU'
let s:d[0xA6BE]='BAMUM LETTER NJUAE'
let s:d[0xA6BF]='BAMUM LETTER YOQ'
let s:d[0xA6C0]='BAMUM LETTER SHU'
let s:d[0xA6C1]='BAMUM LETTER YUQ'
let s:d[0xA6C2]='BAMUM LETTER YA'
let s:d[0xA6C3]='BAMUM LETTER NSHA'
let s:d[0xA6C4]='BAMUM LETTER KEUX'
let s:d[0xA6C5]='BAMUM LETTER PEUX'
let s:d[0xA6C6]='BAMUM LETTER NJEE'
let s:d[0xA6C7]='BAMUM LETTER NTEE'
let s:d[0xA6C8]='BAMUM LETTER PUE'
let s:d[0xA6C9]='BAMUM LETTER WUE'
let s:d[0xA6CA]='BAMUM LETTER PEE'
let s:d[0xA6CB]='BAMUM LETTER FEE'
let s:d[0xA6CC]='BAMUM LETTER RU'
let s:d[0xA6CD]='BAMUM LETTER LU'
let s:d[0xA6CE]='BAMUM LETTER MI'
let s:d[0xA6CF]='BAMUM LETTER NI'
let s:d[0xA6D0]='BAMUM LETTER REUX'
let s:d[0xA6D1]='BAMUM LETTER RAE'
let s:d[0xA6D2]='BAMUM LETTER KEN'
let s:d[0xA6D3]='BAMUM LETTER NGKWAEN'
let s:d[0xA6D4]='BAMUM LETTER NGGA'
let s:d[0xA6D5]='BAMUM LETTER NGA'
let s:d[0xA6D6]='BAMUM LETTER SHO'
let s:d[0xA6D7]='BAMUM LETTER PUAE'
let s:d[0xA6D8]='BAMUM LETTER FU'
let s:d[0xA6D9]='BAMUM LETTER FOM'
let s:d[0xA6DA]='BAMUM LETTER WA'
let s:d[0xA6DB]='BAMUM LETTER NA'
let s:d[0xA6DC]='BAMUM LETTER LI'
let s:d[0xA6DD]='BAMUM LETTER PI'
let s:d[0xA6DE]='BAMUM LETTER LOQ'
let s:d[0xA6DF]='BAMUM LETTER KO'
let s:d[0xA6E0]='BAMUM LETTER MBEN'
let s:d[0xA6E1]='BAMUM LETTER REN'
let s:d[0xA6E2]='BAMUM LETTER MEN'
let s:d[0xA6E3]='BAMUM LETTER MA'
let s:d[0xA6E4]='BAMUM LETTER TI'
let s:d[0xA6E5]='BAMUM LETTER KI'
let s:d[0xA6E6]='BAMUM LETTER MO'
let s:d[0xA6E7]='BAMUM LETTER MBAA'
let s:d[0xA6E8]='BAMUM LETTER TET'
let s:d[0xA6E9]='BAMUM LETTER KPA'
let s:d[0xA6EA]='BAMUM LETTER TEN'
let s:d[0xA6EB]='BAMUM LETTER NTUU'
let s:d[0xA6EC]='BAMUM LETTER SAMBA'
let s:d[0xA6ED]='BAMUM LETTER FAAMAE'
let s:d[0xA6EE]='BAMUM LETTER KOVUU'
let s:d[0xA6EF]='BAMUM LETTER KOGHOM'
let s:d[0xA6F0]='BAMUM COMBINING MARK KOQNDON'
let s:d[0xA6F1]='BAMUM COMBINING MARK TUKWENTIS'
let s:d[0xA6F2]='BAMUM NJAEMLI'
let s:d[0xA6F3]='BAMUM FULL STOP'
let s:d[0xA6F4]='BAMUM COLON'
let s:d[0xA6F5]='BAMUM COMMA'
let s:d[0xA6F6]='BAMUM SEMICOLON'
let s:d[0xA6F7]='BAMUM QUESTION MARK'
let s:d[0xA700]='MODIFIER LETTER CHINESE TONE YIN PING'
let s:d[0xA701]='MODIFIER LETTER CHINESE TONE YANG PING'
let s:d[0xA702]='MODIFIER LETTER CHINESE TONE YIN SHANG'
let s:d[0xA703]='MODIFIER LETTER CHINESE TONE YANG SHANG'
let s:d[0xA704]='MODIFIER LETTER CHINESE TONE YIN QU'
let s:d[0xA705]='MODIFIER LETTER CHINESE TONE YANG QU'
let s:d[0xA706]='MODIFIER LETTER CHINESE TONE YIN RU'
let s:d[0xA707]='MODIFIER LETTER CHINESE TONE YANG RU'
let s:d[0xA708]='MODIFIER LETTER EXTRA-HIGH DOTTED TONE BAR'
let s:d[0xA709]='MODIFIER LETTER HIGH DOTTED TONE BAR'
let s:d[0xA70A]='MODIFIER LETTER MID DOTTED TONE BAR'
let s:d[0xA70B]='MODIFIER LETTER LOW DOTTED TONE BAR'
let s:d[0xA70C]='MODIFIER LETTER EXTRA-LOW DOTTED TONE BAR'
let s:d[0xA70D]='MODIFIER LETTER EXTRA-HIGH DOTTED LEFT-STEM TONE BAR'
let s:d[0xA70E]='MODIFIER LETTER HIGH DOTTED LEFT-STEM TONE BAR'
let s:d[0xA70F]='MODIFIER LETTER MID DOTTED LEFT-STEM TONE BAR'
let s:d[0xA710]='MODIFIER LETTER LOW DOTTED LEFT-STEM TONE BAR'
let s:d[0xA711]='MODIFIER LETTER EXTRA-LOW DOTTED LEFT-STEM TONE BAR'
let s:d[0xA712]='MODIFIER LETTER EXTRA-HIGH LEFT-STEM TONE BAR'
let s:d[0xA713]='MODIFIER LETTER HIGH LEFT-STEM TONE BAR'
let s:d[0xA714]='MODIFIER LETTER MID LEFT-STEM TONE BAR'
let s:d[0xA715]='MODIFIER LETTER LOW LEFT-STEM TONE BAR'
let s:d[0xA716]='MODIFIER LETTER EXTRA-LOW LEFT-STEM TONE BAR'
let s:d[0xA717]='MODIFIER LETTER DOT VERTICAL BAR'
let s:d[0xA718]='MODIFIER LETTER DOT SLASH'
let s:d[0xA719]='MODIFIER LETTER DOT HORIZONTAL BAR'
let s:d[0xA71A]='MODIFIER LETTER LOWER RIGHT CORNER ANGLE'
let s:d[0xA71B]='MODIFIER LETTER RAISED UP ARROW'
let s:d[0xA71C]='MODIFIER LETTER RAISED DOWN ARROW'
let s:d[0xA71D]='MODIFIER LETTER RAISED EXCLAMATION MARK'
let s:d[0xA71E]='MODIFIER LETTER RAISED INVERTED EXCLAMATION MARK'
let s:d[0xA71F]='MODIFIER LETTER LOW INVERTED EXCLAMATION MARK'
let s:d[0xA720]='MODIFIER LETTER STRESS AND HIGH TONE'
let s:d[0xA721]='MODIFIER LETTER STRESS AND LOW TONE'
let s:d[0xA722]='LATIN CAPITAL LETTER EGYPTOLOGICAL ALEF'
let s:d[0xA723]='LATIN SMALL LETTER EGYPTOLOGICAL ALEF'
let s:d[0xA724]='LATIN CAPITAL LETTER EGYPTOLOGICAL AIN'
let s:d[0xA725]='LATIN SMALL LETTER EGYPTOLOGICAL AIN'
let s:d[0xA726]='LATIN CAPITAL LETTER HENG'
let s:d[0xA727]='LATIN SMALL LETTER HENG'
let s:d[0xA728]='LATIN CAPITAL LETTER TZ'
let s:d[0xA729]='LATIN SMALL LETTER TZ'
let s:d[0xA72A]='LATIN CAPITAL LETTER TRESILLO'
let s:d[0xA72B]='LATIN SMALL LETTER TRESILLO'
let s:d[0xA72C]='LATIN CAPITAL LETTER CUATRILLO'
let s:d[0xA72D]='LATIN SMALL LETTER CUATRILLO'
let s:d[0xA72E]='LATIN CAPITAL LETTER CUATRILLO WITH COMMA'
let s:d[0xA72F]='LATIN SMALL LETTER CUATRILLO WITH COMMA'
let s:d[0xA730]='LATIN LETTER SMALL CAPITAL F'
let s:d[0xA731]='LATIN LETTER SMALL CAPITAL S'
let s:d[0xA732]='LATIN CAPITAL LETTER AA'
let s:d[0xA733]='LATIN SMALL LETTER AA'
let s:d[0xA734]='LATIN CAPITAL LETTER AO'
let s:d[0xA735]='LATIN SMALL LETTER AO'
let s:d[0xA736]='LATIN CAPITAL LETTER AU'
let s:d[0xA737]='LATIN SMALL LETTER AU'
let s:d[0xA738]='LATIN CAPITAL LETTER AV'
let s:d[0xA739]='LATIN SMALL LETTER AV'
let s:d[0xA73A]='LATIN CAPITAL LETTER AV WITH HORIZONTAL BAR'
let s:d[0xA73B]='LATIN SMALL LETTER AV WITH HORIZONTAL BAR'
let s:d[0xA73C]='LATIN CAPITAL LETTER AY'
let s:d[0xA73D]='LATIN SMALL LETTER AY'
let s:d[0xA73E]='LATIN CAPITAL LETTER REVERSED C WITH DOT'
let s:d[0xA73F]='LATIN SMALL LETTER REVERSED C WITH DOT'
let s:d[0xA740]='LATIN CAPITAL LETTER K WITH STROKE'
let s:d[0xA741]='LATIN SMALL LETTER K WITH STROKE'
let s:d[0xA742]='LATIN CAPITAL LETTER K WITH DIAGONAL STROKE'
let s:d[0xA743]='LATIN SMALL LETTER K WITH DIAGONAL STROKE'
let s:d[0xA744]='LATIN CAPITAL LETTER K WITH STROKE AND DIAGONAL STROKE'
let s:d[0xA745]='LATIN SMALL LETTER K WITH STROKE AND DIAGONAL STROKE'
let s:d[0xA746]='LATIN CAPITAL LETTER BROKEN L'
let s:d[0xA747]='LATIN SMALL LETTER BROKEN L'
let s:d[0xA748]='LATIN CAPITAL LETTER L WITH HIGH STROKE'
let s:d[0xA749]='LATIN SMALL LETTER L WITH HIGH STROKE'
let s:d[0xA74A]='LATIN CAPITAL LETTER O WITH LONG STROKE OVERLAY'
let s:d[0xA74B]='LATIN SMALL LETTER O WITH LONG STROKE OVERLAY'
let s:d[0xA74C]='LATIN CAPITAL LETTER O WITH LOOP'
let s:d[0xA74D]='LATIN SMALL LETTER O WITH LOOP'
let s:d[0xA74E]='LATIN CAPITAL LETTER OO'
let s:d[0xA74F]='LATIN SMALL LETTER OO'
let s:d[0xA750]='LATIN CAPITAL LETTER P WITH STROKE THROUGH DESCENDER'
let s:d[0xA751]='LATIN SMALL LETTER P WITH STROKE THROUGH DESCENDER'
let s:d[0xA752]='LATIN CAPITAL LETTER P WITH FLOURISH'
let s:d[0xA753]='LATIN SMALL LETTER P WITH FLOURISH'
let s:d[0xA754]='LATIN CAPITAL LETTER P WITH SQUIRREL TAIL'
let s:d[0xA755]='LATIN SMALL LETTER P WITH SQUIRREL TAIL'
let s:d[0xA756]='LATIN CAPITAL LETTER Q WITH STROKE THROUGH DESCENDER'
let s:d[0xA757]='LATIN SMALL LETTER Q WITH STROKE THROUGH DESCENDER'
let s:d[0xA758]='LATIN CAPITAL LETTER Q WITH DIAGONAL STROKE'
let s:d[0xA759]='LATIN SMALL LETTER Q WITH DIAGONAL STROKE'
let s:d[0xA75A]='LATIN CAPITAL LETTER R ROTUNDA'
let s:d[0xA75B]='LATIN SMALL LETTER R ROTUNDA'
let s:d[0xA75C]='LATIN CAPITAL LETTER RUM ROTUNDA'
let s:d[0xA75D]='LATIN SMALL LETTER RUM ROTUNDA'
let s:d[0xA75E]='LATIN CAPITAL LETTER V WITH DIAGONAL STROKE'
let s:d[0xA75F]='LATIN SMALL LETTER V WITH DIAGONAL STROKE'
let s:d[0xA760]='LATIN CAPITAL LETTER VY'
let s:d[0xA761]='LATIN SMALL LETTER VY'
let s:d[0xA762]='LATIN CAPITAL LETTER VISIGOTHIC Z'
let s:d[0xA763]='LATIN SMALL LETTER VISIGOTHIC Z'
let s:d[0xA764]='LATIN CAPITAL LETTER THORN WITH STROKE'
let s:d[0xA765]='LATIN SMALL LETTER THORN WITH STROKE'
let s:d[0xA766]='LATIN CAPITAL LETTER THORN WITH STROKE THROUGH DESCENDER'
let s:d[0xA767]='LATIN SMALL LETTER THORN WITH STROKE THROUGH DESCENDER'
let s:d[0xA768]='LATIN CAPITAL LETTER VEND'
let s:d[0xA769]='LATIN SMALL LETTER VEND'
let s:d[0xA76A]='LATIN CAPITAL LETTER ET'
let s:d[0xA76B]='LATIN SMALL LETTER ET'
let s:d[0xA76C]='LATIN CAPITAL LETTER IS'
let s:d[0xA76D]='LATIN SMALL LETTER IS'
let s:d[0xA76E]='LATIN CAPITAL LETTER CON'
let s:d[0xA76F]='LATIN SMALL LETTER CON'
let s:d[0xA770]='MODIFIER LETTER US'
let s:d[0xA771]='LATIN SMALL LETTER DUM'
let s:d[0xA772]='LATIN SMALL LETTER LUM'
let s:d[0xA773]='LATIN SMALL LETTER MUM'
let s:d[0xA774]='LATIN SMALL LETTER NUM'
let s:d[0xA775]='LATIN SMALL LETTER RUM'
let s:d[0xA776]='LATIN LETTER SMALL CAPITAL RUM'
let s:d[0xA777]='LATIN SMALL LETTER TUM'
let s:d[0xA778]='LATIN SMALL LETTER UM'
let s:d[0xA779]='LATIN CAPITAL LETTER INSULAR D'
let s:d[0xA77A]='LATIN SMALL LETTER INSULAR D'
let s:d[0xA77B]='LATIN CAPITAL LETTER INSULAR F'
let s:d[0xA77C]='LATIN SMALL LETTER INSULAR F'
let s:d[0xA77D]='LATIN CAPITAL LETTER INSULAR G'
let s:d[0xA77E]='LATIN CAPITAL LETTER TURNED INSULAR G'
let s:d[0xA77F]='LATIN SMALL LETTER TURNED INSULAR G'
let s:d[0xA780]='LATIN CAPITAL LETTER TURNED L'
let s:d[0xA781]='LATIN SMALL LETTER TURNED L'
let s:d[0xA782]='LATIN CAPITAL LETTER INSULAR R'
let s:d[0xA783]='LATIN SMALL LETTER INSULAR R'
let s:d[0xA784]='LATIN CAPITAL LETTER INSULAR S'
let s:d[0xA785]='LATIN SMALL LETTER INSULAR S'
let s:d[0xA786]='LATIN CAPITAL LETTER INSULAR T'
let s:d[0xA787]='LATIN SMALL LETTER INSULAR T'
let s:d[0xA788]='MODIFIER LETTER LOW CIRCUMFLEX ACCENT'
let s:d[0xA789]='MODIFIER LETTER COLON'
let s:d[0xA78A]='MODIFIER LETTER SHORT EQUALS SIGN'
let s:d[0xA78B]='LATIN CAPITAL LETTER SALTILLO'
let s:d[0xA78C]='LATIN SMALL LETTER SALTILLO'
let s:d[0xA78D]='LATIN CAPITAL LETTER TURNED H'
let s:d[0xA78E]='LATIN SMALL LETTER L WITH RETROFLEX HOOK AND BELT'
let s:d[0xA790]='LATIN CAPITAL LETTER N WITH DESCENDER'
let s:d[0xA791]='LATIN SMALL LETTER N WITH DESCENDER'
let s:d[0xA792]='LATIN CAPITAL LETTER C WITH BAR'
let s:d[0xA793]='LATIN SMALL LETTER C WITH BAR'
let s:d[0xA7A0]='LATIN CAPITAL LETTER G WITH OBLIQUE STROKE'
let s:d[0xA7A1]='LATIN SMALL LETTER G WITH OBLIQUE STROKE'
let s:d[0xA7A2]='LATIN CAPITAL LETTER K WITH OBLIQUE STROKE'
let s:d[0xA7A3]='LATIN SMALL LETTER K WITH OBLIQUE STROKE'
let s:d[0xA7A4]='LATIN CAPITAL LETTER N WITH OBLIQUE STROKE'
let s:d[0xA7A5]='LATIN SMALL LETTER N WITH OBLIQUE STROKE'
let s:d[0xA7A6]='LATIN CAPITAL LETTER R WITH OBLIQUE STROKE'
let s:d[0xA7A7]='LATIN SMALL LETTER R WITH OBLIQUE STROKE'
let s:d[0xA7A8]='LATIN CAPITAL LETTER S WITH OBLIQUE STROKE'
let s:d[0xA7A9]='LATIN SMALL LETTER S WITH OBLIQUE STROKE'
let s:d[0xA7AA]='LATIN CAPITAL LETTER H WITH HOOK'
let s:d[0xA7F8]='MODIFIER LETTER CAPITAL H WITH STROKE'
let s:d[0xA7F9]='MODIFIER LETTER SMALL LIGATURE OE'
let s:d[0xA7FA]='LATIN LETTER SMALL CAPITAL TURNED M'
let s:d[0xA7FB]='LATIN EPIGRAPHIC LETTER REVERSED F'
let s:d[0xA7FC]='LATIN EPIGRAPHIC LETTER REVERSED P'
let s:d[0xA7FD]='LATIN EPIGRAPHIC LETTER INVERTED M'
let s:d[0xA7FE]='LATIN EPIGRAPHIC LETTER I LONGA'
let s:d[0xA7FF]='LATIN EPIGRAPHIC LETTER ARCHAIC M'
let s:d[0xA800]='SYLOTI NAGRI LETTER A'
let s:d[0xA801]='SYLOTI NAGRI LETTER I'
let s:d[0xA802]='SYLOTI NAGRI SIGN DVISVARA'
let s:d[0xA803]='SYLOTI NAGRI LETTER U'
let s:d[0xA804]='SYLOTI NAGRI LETTER E'
let s:d[0xA805]='SYLOTI NAGRI LETTER O'
let s:d[0xA806]='SYLOTI NAGRI SIGN HASANTA'
let s:d[0xA807]='SYLOTI NAGRI LETTER KO'
let s:d[0xA808]='SYLOTI NAGRI LETTER KHO'
let s:d[0xA809]='SYLOTI NAGRI LETTER GO'
let s:d[0xA80A]='SYLOTI NAGRI LETTER GHO'
let s:d[0xA80B]='SYLOTI NAGRI SIGN ANUSVARA'
let s:d[0xA80C]='SYLOTI NAGRI LETTER CO'
let s:d[0xA80D]='SYLOTI NAGRI LETTER CHO'
let s:d[0xA80E]='SYLOTI NAGRI LETTER JO'
let s:d[0xA80F]='SYLOTI NAGRI LETTER JHO'
let s:d[0xA810]='SYLOTI NAGRI LETTER TTO'
let s:d[0xA811]='SYLOTI NAGRI LETTER TTHO'
let s:d[0xA812]='SYLOTI NAGRI LETTER DDO'
let s:d[0xA813]='SYLOTI NAGRI LETTER DDHO'
let s:d[0xA814]='SYLOTI NAGRI LETTER TO'
let s:d[0xA815]='SYLOTI NAGRI LETTER THO'
let s:d[0xA816]='SYLOTI NAGRI LETTER DO'
let s:d[0xA817]='SYLOTI NAGRI LETTER DHO'
let s:d[0xA818]='SYLOTI NAGRI LETTER NO'
let s:d[0xA819]='SYLOTI NAGRI LETTER PO'
let s:d[0xA81A]='SYLOTI NAGRI LETTER PHO'
let s:d[0xA81B]='SYLOTI NAGRI LETTER BO'
let s:d[0xA81C]='SYLOTI NAGRI LETTER BHO'
let s:d[0xA81D]='SYLOTI NAGRI LETTER MO'
let s:d[0xA81E]='SYLOTI NAGRI LETTER RO'
let s:d[0xA81F]='SYLOTI NAGRI LETTER LO'
let s:d[0xA820]='SYLOTI NAGRI LETTER RRO'
let s:d[0xA821]='SYLOTI NAGRI LETTER SO'
let s:d[0xA822]='SYLOTI NAGRI LETTER HO'
let s:d[0xA823]='SYLOTI NAGRI VOWEL SIGN A'
let s:d[0xA824]='SYLOTI NAGRI VOWEL SIGN I'
let s:d[0xA825]='SYLOTI NAGRI VOWEL SIGN U'
let s:d[0xA826]='SYLOTI NAGRI VOWEL SIGN E'
let s:d[0xA827]='SYLOTI NAGRI VOWEL SIGN OO'
let s:d[0xA828]='SYLOTI NAGRI POETRY MARK-1'
let s:d[0xA829]='SYLOTI NAGRI POETRY MARK-2'
let s:d[0xA82A]='SYLOTI NAGRI POETRY MARK-3'
let s:d[0xA82B]='SYLOTI NAGRI POETRY MARK-4'
let s:d[0xA830]='NORTH INDIC FRACTION ONE QUARTER'
let s:d[0xA831]='NORTH INDIC FRACTION ONE HALF'
let s:d[0xA832]='NORTH INDIC FRACTION THREE QUARTERS'
let s:d[0xA833]='NORTH INDIC FRACTION ONE SIXTEENTH'
let s:d[0xA834]='NORTH INDIC FRACTION ONE EIGHTH'
let s:d[0xA835]='NORTH INDIC FRACTION THREE SIXTEENTHS'
let s:d[0xA836]='NORTH INDIC QUARTER MARK'
let s:d[0xA837]='NORTH INDIC PLACEHOLDER MARK'
let s:d[0xA838]='NORTH INDIC RUPEE MARK'
let s:d[0xA839]='NORTH INDIC QUANTITY MARK'
let s:d[0xA840]='PHAGS-PA LETTER KA'
let s:d[0xA841]='PHAGS-PA LETTER KHA'
let s:d[0xA842]='PHAGS-PA LETTER GA'
let s:d[0xA843]='PHAGS-PA LETTER NGA'
let s:d[0xA844]='PHAGS-PA LETTER CA'
let s:d[0xA845]='PHAGS-PA LETTER CHA'
let s:d[0xA846]='PHAGS-PA LETTER JA'
let s:d[0xA847]='PHAGS-PA LETTER NYA'
let s:d[0xA848]='PHAGS-PA LETTER TA'
let s:d[0xA849]='PHAGS-PA LETTER THA'
let s:d[0xA84A]='PHAGS-PA LETTER DA'
let s:d[0xA84B]='PHAGS-PA LETTER NA'
let s:d[0xA84C]='PHAGS-PA LETTER PA'
let s:d[0xA84D]='PHAGS-PA LETTER PHA'
let s:d[0xA84E]='PHAGS-PA LETTER BA'
let s:d[0xA84F]='PHAGS-PA LETTER MA'
let s:d[0xA850]='PHAGS-PA LETTER TSA'
let s:d[0xA851]='PHAGS-PA LETTER TSHA'
let s:d[0xA852]='PHAGS-PA LETTER DZA'
let s:d[0xA853]='PHAGS-PA LETTER WA'
let s:d[0xA854]='PHAGS-PA LETTER ZHA'
let s:d[0xA855]='PHAGS-PA LETTER ZA'
let s:d[0xA856]='PHAGS-PA LETTER SMALL A'
let s:d[0xA857]='PHAGS-PA LETTER YA'
let s:d[0xA858]='PHAGS-PA LETTER RA'
let s:d[0xA859]='PHAGS-PA LETTER LA'
let s:d[0xA85A]='PHAGS-PA LETTER SHA'
let s:d[0xA85B]='PHAGS-PA LETTER SA'
let s:d[0xA85C]='PHAGS-PA LETTER HA'
let s:d[0xA85D]='PHAGS-PA LETTER A'
let s:d[0xA85E]='PHAGS-PA LETTER I'
let s:d[0xA85F]='PHAGS-PA LETTER U'
let s:d[0xA860]='PHAGS-PA LETTER E'
let s:d[0xA861]='PHAGS-PA LETTER O'
let s:d[0xA862]='PHAGS-PA LETTER QA'
let s:d[0xA863]='PHAGS-PA LETTER XA'
let s:d[0xA864]='PHAGS-PA LETTER FA'
let s:d[0xA865]='PHAGS-PA LETTER GGA'
let s:d[0xA866]='PHAGS-PA LETTER EE'
let s:d[0xA867]='PHAGS-PA SUBJOINED LETTER WA'
let s:d[0xA868]='PHAGS-PA SUBJOINED LETTER YA'
let s:d[0xA869]='PHAGS-PA LETTER TTA'
let s:d[0xA86A]='PHAGS-PA LETTER TTHA'
let s:d[0xA86B]='PHAGS-PA LETTER DDA'
let s:d[0xA86C]='PHAGS-PA LETTER NNA'
let s:d[0xA86D]='PHAGS-PA LETTER ALTERNATE YA'
let s:d[0xA86E]='PHAGS-PA LETTER VOICELESS SHA'
let s:d[0xA86F]='PHAGS-PA LETTER VOICED HA'
let s:d[0xA870]='PHAGS-PA LETTER ASPIRATED FA'
let s:d[0xA871]='PHAGS-PA SUBJOINED LETTER RA'
let s:d[0xA872]='PHAGS-PA SUPERFIXED LETTER RA'
let s:d[0xA873]='PHAGS-PA LETTER CANDRABINDU'
let s:d[0xA874]='PHAGS-PA SINGLE HEAD MARK'
let s:d[0xA875]='PHAGS-PA DOUBLE HEAD MARK'
let s:d[0xA876]='PHAGS-PA MARK SHAD'
let s:d[0xA877]='PHAGS-PA MARK DOUBLE SHAD'
let s:d[0xA880]='SAURASHTRA SIGN ANUSVARA'
let s:d[0xA881]='SAURASHTRA SIGN VISARGA'
let s:d[0xA882]='SAURASHTRA LETTER A'
let s:d[0xA883]='SAURASHTRA LETTER AA'
let s:d[0xA884]='SAURASHTRA LETTER I'
let s:d[0xA885]='SAURASHTRA LETTER II'
let s:d[0xA886]='SAURASHTRA LETTER U'
let s:d[0xA887]='SAURASHTRA LETTER UU'
let s:d[0xA888]='SAURASHTRA LETTER VOCALIC R'
let s:d[0xA889]='SAURASHTRA LETTER VOCALIC RR'
let s:d[0xA88A]='SAURASHTRA LETTER VOCALIC L'
let s:d[0xA88B]='SAURASHTRA LETTER VOCALIC LL'
let s:d[0xA88C]='SAURASHTRA LETTER E'
let s:d[0xA88D]='SAURASHTRA LETTER EE'
let s:d[0xA88E]='SAURASHTRA LETTER AI'
let s:d[0xA88F]='SAURASHTRA LETTER O'
let s:d[0xA890]='SAURASHTRA LETTER OO'
let s:d[0xA891]='SAURASHTRA LETTER AU'
let s:d[0xA892]='SAURASHTRA LETTER KA'
let s:d[0xA893]='SAURASHTRA LETTER KHA'
let s:d[0xA894]='SAURASHTRA LETTER GA'
let s:d[0xA895]='SAURASHTRA LETTER GHA'
let s:d[0xA896]='SAURASHTRA LETTER NGA'
let s:d[0xA897]='SAURASHTRA LETTER CA'
let s:d[0xA898]='SAURASHTRA LETTER CHA'
let s:d[0xA899]='SAURASHTRA LETTER JA'
let s:d[0xA89A]='SAURASHTRA LETTER JHA'
let s:d[0xA89B]='SAURASHTRA LETTER NYA'
let s:d[0xA89C]='SAURASHTRA LETTER TTA'
let s:d[0xA89D]='SAURASHTRA LETTER TTHA'
let s:d[0xA89E]='SAURASHTRA LETTER DDA'
let s:d[0xA89F]='SAURASHTRA LETTER DDHA'
let s:d[0xA8A0]='SAURASHTRA LETTER NNA'
let s:d[0xA8A1]='SAURASHTRA LETTER TA'
let s:d[0xA8A2]='SAURASHTRA LETTER THA'
let s:d[0xA8A3]='SAURASHTRA LETTER DA'
let s:d[0xA8A4]='SAURASHTRA LETTER DHA'
let s:d[0xA8A5]='SAURASHTRA LETTER NA'
let s:d[0xA8A6]='SAURASHTRA LETTER PA'
let s:d[0xA8A7]='SAURASHTRA LETTER PHA'
let s:d[0xA8A8]='SAURASHTRA LETTER BA'
let s:d[0xA8A9]='SAURASHTRA LETTER BHA'
let s:d[0xA8AA]='SAURASHTRA LETTER MA'
let s:d[0xA8AB]='SAURASHTRA LETTER YA'
let s:d[0xA8AC]='SAURASHTRA LETTER RA'
let s:d[0xA8AD]='SAURASHTRA LETTER LA'
let s:d[0xA8AE]='SAURASHTRA LETTER VA'
let s:d[0xA8AF]='SAURASHTRA LETTER SHA'
let s:d[0xA8B0]='SAURASHTRA LETTER SSA'
let s:d[0xA8B1]='SAURASHTRA LETTER SA'
let s:d[0xA8B2]='SAURASHTRA LETTER HA'
let s:d[0xA8B3]='SAURASHTRA LETTER LLA'
let s:d[0xA8B4]='SAURASHTRA CONSONANT SIGN HAARU'
let s:d[0xA8B5]='SAURASHTRA VOWEL SIGN AA'
let s:d[0xA8B6]='SAURASHTRA VOWEL SIGN I'
let s:d[0xA8B7]='SAURASHTRA VOWEL SIGN II'
let s:d[0xA8B8]='SAURASHTRA VOWEL SIGN U'
let s:d[0xA8B9]='SAURASHTRA VOWEL SIGN UU'
let s:d[0xA8BA]='SAURASHTRA VOWEL SIGN VOCALIC R'
let s:d[0xA8BB]='SAURASHTRA VOWEL SIGN VOCALIC RR'
let s:d[0xA8BC]='SAURASHTRA VOWEL SIGN VOCALIC L'
let s:d[0xA8BD]='SAURASHTRA VOWEL SIGN VOCALIC LL'
let s:d[0xA8BE]='SAURASHTRA VOWEL SIGN E'
let s:d[0xA8BF]='SAURASHTRA VOWEL SIGN EE'
let s:d[0xA8C0]='SAURASHTRA VOWEL SIGN AI'
let s:d[0xA8C1]='SAURASHTRA VOWEL SIGN O'
let s:d[0xA8C2]='SAURASHTRA VOWEL SIGN OO'
let s:d[0xA8C3]='SAURASHTRA VOWEL SIGN AU'
let s:d[0xA8C4]='SAURASHTRA SIGN VIRAMA'
let s:d[0xA8CE]='SAURASHTRA DANDA'
let s:d[0xA8CF]='SAURASHTRA DOUBLE DANDA'
let s:d[0xA8D0]='SAURASHTRA DIGIT ZERO'
let s:d[0xA8D1]='SAURASHTRA DIGIT ONE'
let s:d[0xA8D2]='SAURASHTRA DIGIT TWO'
let s:d[0xA8D3]='SAURASHTRA DIGIT THREE'
let s:d[0xA8D4]='SAURASHTRA DIGIT FOUR'
let s:d[0xA8D5]='SAURASHTRA DIGIT FIVE'
let s:d[0xA8D6]='SAURASHTRA DIGIT SIX'
let s:d[0xA8D7]='SAURASHTRA DIGIT SEVEN'
let s:d[0xA8D8]='SAURASHTRA DIGIT EIGHT'
let s:d[0xA8D9]='SAURASHTRA DIGIT NINE'
let s:d[0xA8E0]='COMBINING DEVANAGARI DIGIT ZERO'
let s:d[0xA8E1]='COMBINING DEVANAGARI DIGIT ONE'
let s:d[0xA8E2]='COMBINING DEVANAGARI DIGIT TWO'
let s:d[0xA8E3]='COMBINING DEVANAGARI DIGIT THREE'
let s:d[0xA8E4]='COMBINING DEVANAGARI DIGIT FOUR'
let s:d[0xA8E5]='COMBINING DEVANAGARI DIGIT FIVE'
let s:d[0xA8E6]='COMBINING DEVANAGARI DIGIT SIX'
let s:d[0xA8E7]='COMBINING DEVANAGARI DIGIT SEVEN'
let s:d[0xA8E8]='COMBINING DEVANAGARI DIGIT EIGHT'
let s:d[0xA8E9]='COMBINING DEVANAGARI DIGIT NINE'
let s:d[0xA8EA]='COMBINING DEVANAGARI LETTER A'
let s:d[0xA8EB]='COMBINING DEVANAGARI LETTER U'
let s:d[0xA8EC]='COMBINING DEVANAGARI LETTER KA'
let s:d[0xA8ED]='COMBINING DEVANAGARI LETTER NA'
let s:d[0xA8EE]='COMBINING DEVANAGARI LETTER PA'
let s:d[0xA8EF]='COMBINING DEVANAGARI LETTER RA'
let s:d[0xA8F0]='COMBINING DEVANAGARI LETTER VI'
let s:d[0xA8F1]='COMBINING DEVANAGARI SIGN AVAGRAHA'
let s:d[0xA8F2]='DEVANAGARI SIGN SPACING CANDRABINDU'
let s:d[0xA8F3]='DEVANAGARI SIGN CANDRABINDU VIRAMA'
let s:d[0xA8F4]='DEVANAGARI SIGN DOUBLE CANDRABINDU VIRAMA'
let s:d[0xA8F5]='DEVANAGARI SIGN CANDRABINDU TWO'
let s:d[0xA8F6]='DEVANAGARI SIGN CANDRABINDU THREE'
let s:d[0xA8F7]='DEVANAGARI SIGN CANDRABINDU AVAGRAHA'
let s:d[0xA8F8]='DEVANAGARI SIGN PUSHPIKA'
let s:d[0xA8F9]='DEVANAGARI GAP FILLER'
let s:d[0xA8FA]='DEVANAGARI CARET'
let s:d[0xA8FB]='DEVANAGARI HEADSTROKE'
let s:d[0xA900]='KAYAH LI DIGIT ZERO'
let s:d[0xA901]='KAYAH LI DIGIT ONE'
let s:d[0xA902]='KAYAH LI DIGIT TWO'
let s:d[0xA903]='KAYAH LI DIGIT THREE'
let s:d[0xA904]='KAYAH LI DIGIT FOUR'
let s:d[0xA905]='KAYAH LI DIGIT FIVE'
let s:d[0xA906]='KAYAH LI DIGIT SIX'
let s:d[0xA907]='KAYAH LI DIGIT SEVEN'
let s:d[0xA908]='KAYAH LI DIGIT EIGHT'
let s:d[0xA909]='KAYAH LI DIGIT NINE'
let s:d[0xA90A]='KAYAH LI LETTER KA'
let s:d[0xA90B]='KAYAH LI LETTER KHA'
let s:d[0xA90C]='KAYAH LI LETTER GA'
let s:d[0xA90D]='KAYAH LI LETTER NGA'
let s:d[0xA90E]='KAYAH LI LETTER SA'
let s:d[0xA90F]='KAYAH LI LETTER SHA'
let s:d[0xA910]='KAYAH LI LETTER ZA'
let s:d[0xA911]='KAYAH LI LETTER NYA'
let s:d[0xA912]='KAYAH LI LETTER TA'
let s:d[0xA913]='KAYAH LI LETTER HTA'
let s:d[0xA914]='KAYAH LI LETTER NA'
let s:d[0xA915]='KAYAH LI LETTER PA'
let s:d[0xA916]='KAYAH LI LETTER PHA'
let s:d[0xA917]='KAYAH LI LETTER MA'
let s:d[0xA918]='KAYAH LI LETTER DA'
let s:d[0xA919]='KAYAH LI LETTER BA'
let s:d[0xA91A]='KAYAH LI LETTER RA'
let s:d[0xA91B]='KAYAH LI LETTER YA'
let s:d[0xA91C]='KAYAH LI LETTER LA'
let s:d[0xA91D]='KAYAH LI LETTER WA'
let s:d[0xA91E]='KAYAH LI LETTER THA'
let s:d[0xA91F]='KAYAH LI LETTER HA'
let s:d[0xA920]='KAYAH LI LETTER VA'
let s:d[0xA921]='KAYAH LI LETTER CA'
let s:d[0xA922]='KAYAH LI LETTER A'
let s:d[0xA923]='KAYAH LI LETTER OE'
let s:d[0xA924]='KAYAH LI LETTER I'
let s:d[0xA925]='KAYAH LI LETTER OO'
let s:d[0xA926]='KAYAH LI VOWEL UE'
let s:d[0xA927]='KAYAH LI VOWEL E'
let s:d[0xA928]='KAYAH LI VOWEL U'
let s:d[0xA929]='KAYAH LI VOWEL EE'
let s:d[0xA92A]='KAYAH LI VOWEL O'
let s:d[0xA92B]='KAYAH LI TONE PLOPHU'
let s:d[0xA92C]='KAYAH LI TONE CALYA'
let s:d[0xA92D]='KAYAH LI TONE CALYA PLOPHU'
let s:d[0xA92E]='KAYAH LI SIGN CWI'
let s:d[0xA92F]='KAYAH LI SIGN SHYA'
let s:d[0xA930]='REJANG LETTER KA'
let s:d[0xA931]='REJANG LETTER GA'
let s:d[0xA932]='REJANG LETTER NGA'
let s:d[0xA933]='REJANG LETTER TA'
let s:d[0xA934]='REJANG LETTER DA'
let s:d[0xA935]='REJANG LETTER NA'
let s:d[0xA936]='REJANG LETTER PA'
let s:d[0xA937]='REJANG LETTER BA'
let s:d[0xA938]='REJANG LETTER MA'
let s:d[0xA939]='REJANG LETTER CA'
let s:d[0xA93A]='REJANG LETTER JA'
let s:d[0xA93B]='REJANG LETTER NYA'
let s:d[0xA93C]='REJANG LETTER SA'
let s:d[0xA93D]='REJANG LETTER RA'
let s:d[0xA93E]='REJANG LETTER LA'
let s:d[0xA93F]='REJANG LETTER YA'
let s:d[0xA940]='REJANG LETTER WA'
let s:d[0xA941]='REJANG LETTER HA'
let s:d[0xA942]='REJANG LETTER MBA'
let s:d[0xA943]='REJANG LETTER NGGA'
let s:d[0xA944]='REJANG LETTER NDA'
let s:d[0xA945]='REJANG LETTER NYJA'
let s:d[0xA946]='REJANG LETTER A'
let s:d[0xA947]='REJANG VOWEL SIGN I'
let s:d[0xA948]='REJANG VOWEL SIGN U'
let s:d[0xA949]='REJANG VOWEL SIGN E'
let s:d[0xA94A]='REJANG VOWEL SIGN AI'
let s:d[0xA94B]='REJANG VOWEL SIGN O'
let s:d[0xA94C]='REJANG VOWEL SIGN AU'
let s:d[0xA94D]='REJANG VOWEL SIGN EU'
let s:d[0xA94E]='REJANG VOWEL SIGN EA'
let s:d[0xA94F]='REJANG CONSONANT SIGN NG'
let s:d[0xA950]='REJANG CONSONANT SIGN N'
let s:d[0xA951]='REJANG CONSONANT SIGN R'
let s:d[0xA952]='REJANG CONSONANT SIGN H'
let s:d[0xA953]='REJANG VIRAMA'
let s:d[0xA95F]='REJANG SECTION MARK'
let s:d[0xA960]='HANGUL CHOSEONG TIKEUT-MIEUM'
let s:d[0xA961]='HANGUL CHOSEONG TIKEUT-PIEUP'
let s:d[0xA962]='HANGUL CHOSEONG TIKEUT-SIOS'
let s:d[0xA963]='HANGUL CHOSEONG TIKEUT-CIEUC'
let s:d[0xA964]='HANGUL CHOSEONG RIEUL-KIYEOK'
let s:d[0xA965]='HANGUL CHOSEONG RIEUL-SSANGKIYEOK'
let s:d[0xA966]='HANGUL CHOSEONG RIEUL-TIKEUT'
let s:d[0xA967]='HANGUL CHOSEONG RIEUL-SSANGTIKEUT'
let s:d[0xA968]='HANGUL CHOSEONG RIEUL-MIEUM'
let s:d[0xA969]='HANGUL CHOSEONG RIEUL-PIEUP'
let s:d[0xA96A]='HANGUL CHOSEONG RIEUL-SSANGPIEUP'
let s:d[0xA96B]='HANGUL CHOSEONG RIEUL-KAPYEOUNPIEUP'
let s:d[0xA96C]='HANGUL CHOSEONG RIEUL-SIOS'
let s:d[0xA96D]='HANGUL CHOSEONG RIEUL-CIEUC'
let s:d[0xA96E]='HANGUL CHOSEONG RIEUL-KHIEUKH'
let s:d[0xA96F]='HANGUL CHOSEONG MIEUM-KIYEOK'
let s:d[0xA970]='HANGUL CHOSEONG MIEUM-TIKEUT'
let s:d[0xA971]='HANGUL CHOSEONG MIEUM-SIOS'
let s:d[0xA972]='HANGUL CHOSEONG PIEUP-SIOS-THIEUTH'
let s:d[0xA973]='HANGUL CHOSEONG PIEUP-KHIEUKH'
let s:d[0xA974]='HANGUL CHOSEONG PIEUP-HIEUH'
let s:d[0xA975]='HANGUL CHOSEONG SSANGSIOS-PIEUP'
let s:d[0xA976]='HANGUL CHOSEONG IEUNG-RIEUL'
let s:d[0xA977]='HANGUL CHOSEONG IEUNG-HIEUH'
let s:d[0xA978]='HANGUL CHOSEONG SSANGCIEUC-HIEUH'
let s:d[0xA979]='HANGUL CHOSEONG SSANGTHIEUTH'
let s:d[0xA97A]='HANGUL CHOSEONG PHIEUPH-HIEUH'
let s:d[0xA97B]='HANGUL CHOSEONG HIEUH-SIOS'
let s:d[0xA97C]='HANGUL CHOSEONG SSANGYEORINHIEUH'
let s:d[0xA980]='JAVANESE SIGN PANYANGGA'
let s:d[0xA981]='JAVANESE SIGN CECAK'
let s:d[0xA982]='JAVANESE SIGN LAYAR'
let s:d[0xA983]='JAVANESE SIGN WIGNYAN'
let s:d[0xA984]='JAVANESE LETTER A'
let s:d[0xA985]='JAVANESE LETTER I KAWI'
let s:d[0xA986]='JAVANESE LETTER I'
let s:d[0xA987]='JAVANESE LETTER II'
let s:d[0xA988]='JAVANESE LETTER U'
let s:d[0xA989]='JAVANESE LETTER PA CEREK'
let s:d[0xA98A]='JAVANESE LETTER NGA LELET'
let s:d[0xA98B]='JAVANESE LETTER NGA LELET RASWADI'
let s:d[0xA98C]='JAVANESE LETTER E'
let s:d[0xA98D]='JAVANESE LETTER AI'
let s:d[0xA98E]='JAVANESE LETTER O'
let s:d[0xA98F]='JAVANESE LETTER KA'
let s:d[0xA990]='JAVANESE LETTER KA SASAK'
let s:d[0xA991]='JAVANESE LETTER KA MURDA'
let s:d[0xA992]='JAVANESE LETTER GA'
let s:d[0xA993]='JAVANESE LETTER GA MURDA'
let s:d[0xA994]='JAVANESE LETTER NGA'
let s:d[0xA995]='JAVANESE LETTER CA'
let s:d[0xA996]='JAVANESE LETTER CA MURDA'
let s:d[0xA997]='JAVANESE LETTER JA'
let s:d[0xA998]='JAVANESE LETTER NYA MURDA'
let s:d[0xA999]='JAVANESE LETTER JA MAHAPRANA'
let s:d[0xA99A]='JAVANESE LETTER NYA'
let s:d[0xA99B]='JAVANESE LETTER TTA'
let s:d[0xA99C]='JAVANESE LETTER TTA MAHAPRANA'
let s:d[0xA99D]='JAVANESE LETTER DDA'
let s:d[0xA99E]='JAVANESE LETTER DDA MAHAPRANA'
let s:d[0xA99F]='JAVANESE LETTER NA MURDA'
let s:d[0xA9A0]='JAVANESE LETTER TA'
let s:d[0xA9A1]='JAVANESE LETTER TA MURDA'
let s:d[0xA9A2]='JAVANESE LETTER DA'
let s:d[0xA9A3]='JAVANESE LETTER DA MAHAPRANA'
let s:d[0xA9A4]='JAVANESE LETTER NA'
let s:d[0xA9A5]='JAVANESE LETTER PA'
let s:d[0xA9A6]='JAVANESE LETTER PA MURDA'
let s:d[0xA9A7]='JAVANESE LETTER BA'
let s:d[0xA9A8]='JAVANESE LETTER BA MURDA'
let s:d[0xA9A9]='JAVANESE LETTER MA'
let s:d[0xA9AA]='JAVANESE LETTER YA'
let s:d[0xA9AB]='JAVANESE LETTER RA'
let s:d[0xA9AC]='JAVANESE LETTER RA AGUNG'
let s:d[0xA9AD]='JAVANESE LETTER LA'
let s:d[0xA9AE]='JAVANESE LETTER WA'
let s:d[0xA9AF]='JAVANESE LETTER SA MURDA'
let s:d[0xA9B0]='JAVANESE LETTER SA MAHAPRANA'
let s:d[0xA9B1]='JAVANESE LETTER SA'
let s:d[0xA9B2]='JAVANESE LETTER HA'
let s:d[0xA9B3]='JAVANESE SIGN CECAK TELU'
let s:d[0xA9B4]='JAVANESE VOWEL SIGN TARUNG'
let s:d[0xA9B5]='JAVANESE VOWEL SIGN TOLONG'
let s:d[0xA9B6]='JAVANESE VOWEL SIGN WULU'
let s:d[0xA9B7]='JAVANESE VOWEL SIGN WULU MELIK'
let s:d[0xA9B8]='JAVANESE VOWEL SIGN SUKU'
let s:d[0xA9B9]='JAVANESE VOWEL SIGN SUKU MENDUT'
let s:d[0xA9BA]='JAVANESE VOWEL SIGN TALING'
let s:d[0xA9BB]='JAVANESE VOWEL SIGN DIRGA MURE'
let s:d[0xA9BC]='JAVANESE VOWEL SIGN PEPET'
let s:d[0xA9BD]='JAVANESE CONSONANT SIGN KERET'
let s:d[0xA9BE]='JAVANESE CONSONANT SIGN PENGKAL'
let s:d[0xA9BF]='JAVANESE CONSONANT SIGN CAKRA'
let s:d[0xA9C0]='JAVANESE PANGKON'
let s:d[0xA9C1]='JAVANESE LEFT RERENGGAN'
let s:d[0xA9C2]='JAVANESE RIGHT RERENGGAN'
let s:d[0xA9C3]='JAVANESE PADA ANDAP'
let s:d[0xA9C4]='JAVANESE PADA MADYA'
let s:d[0xA9C5]='JAVANESE PADA LUHUR'
let s:d[0xA9C6]='JAVANESE PADA WINDU'
let s:d[0xA9C7]='JAVANESE PADA PANGKAT'
let s:d[0xA9C8]='JAVANESE PADA LINGSA'
let s:d[0xA9C9]='JAVANESE PADA LUNGSI'
let s:d[0xA9CA]='JAVANESE PADA ADEG'
let s:d[0xA9CB]='JAVANESE PADA ADEG ADEG'
let s:d[0xA9CC]='JAVANESE PADA PISELEH'
let s:d[0xA9CD]='JAVANESE TURNED PADA PISELEH'
let s:d[0xA9CF]='JAVANESE PANGRANGKEP'
let s:d[0xA9D0]='JAVANESE DIGIT ZERO'
let s:d[0xA9D1]='JAVANESE DIGIT ONE'
let s:d[0xA9D2]='JAVANESE DIGIT TWO'
let s:d[0xA9D3]='JAVANESE DIGIT THREE'
let s:d[0xA9D4]='JAVANESE DIGIT FOUR'
let s:d[0xA9D5]='JAVANESE DIGIT FIVE'
let s:d[0xA9D6]='JAVANESE DIGIT SIX'
let s:d[0xA9D7]='JAVANESE DIGIT SEVEN'
let s:d[0xA9D8]='JAVANESE DIGIT EIGHT'
let s:d[0xA9D9]='JAVANESE DIGIT NINE'
let s:d[0xA9DE]='JAVANESE PADA TIRTA TUMETES'
let s:d[0xA9DF]='JAVANESE PADA ISEN-ISEN'
let s:d[0xAA00]='CHAM LETTER A'
let s:d[0xAA01]='CHAM LETTER I'
let s:d[0xAA02]='CHAM LETTER U'
let s:d[0xAA03]='CHAM LETTER E'
let s:d[0xAA04]='CHAM LETTER AI'
let s:d[0xAA05]='CHAM LETTER O'
let s:d[0xAA06]='CHAM LETTER KA'
let s:d[0xAA07]='CHAM LETTER KHA'
let s:d[0xAA08]='CHAM LETTER GA'
let s:d[0xAA09]='CHAM LETTER GHA'
let s:d[0xAA0A]='CHAM LETTER NGUE'
let s:d[0xAA0B]='CHAM LETTER NGA'
let s:d[0xAA0C]='CHAM LETTER CHA'
let s:d[0xAA0D]='CHAM LETTER CHHA'
let s:d[0xAA0E]='CHAM LETTER JA'
let s:d[0xAA0F]='CHAM LETTER JHA'
let s:d[0xAA10]='CHAM LETTER NHUE'
let s:d[0xAA11]='CHAM LETTER NHA'
let s:d[0xAA12]='CHAM LETTER NHJA'
let s:d[0xAA13]='CHAM LETTER TA'
let s:d[0xAA14]='CHAM LETTER THA'
let s:d[0xAA15]='CHAM LETTER DA'
let s:d[0xAA16]='CHAM LETTER DHA'
let s:d[0xAA17]='CHAM LETTER NUE'
let s:d[0xAA18]='CHAM LETTER NA'
let s:d[0xAA19]='CHAM LETTER DDA'
let s:d[0xAA1A]='CHAM LETTER PA'
let s:d[0xAA1B]='CHAM LETTER PPA'
let s:d[0xAA1C]='CHAM LETTER PHA'
let s:d[0xAA1D]='CHAM LETTER BA'
let s:d[0xAA1E]='CHAM LETTER BHA'
let s:d[0xAA1F]='CHAM LETTER MUE'
let s:d[0xAA20]='CHAM LETTER MA'
let s:d[0xAA21]='CHAM LETTER BBA'
let s:d[0xAA22]='CHAM LETTER YA'
let s:d[0xAA23]='CHAM LETTER RA'
let s:d[0xAA24]='CHAM LETTER LA'
let s:d[0xAA25]='CHAM LETTER VA'
let s:d[0xAA26]='CHAM LETTER SSA'
let s:d[0xAA27]='CHAM LETTER SA'
let s:d[0xAA28]='CHAM LETTER HA'
let s:d[0xAA29]='CHAM VOWEL SIGN AA'
let s:d[0xAA2A]='CHAM VOWEL SIGN I'
let s:d[0xAA2B]='CHAM VOWEL SIGN II'
let s:d[0xAA2C]='CHAM VOWEL SIGN EI'
let s:d[0xAA2D]='CHAM VOWEL SIGN U'
let s:d[0xAA2E]='CHAM VOWEL SIGN OE'
let s:d[0xAA2F]='CHAM VOWEL SIGN O'
let s:d[0xAA30]='CHAM VOWEL SIGN AI'
let s:d[0xAA31]='CHAM VOWEL SIGN AU'
let s:d[0xAA32]='CHAM VOWEL SIGN UE'
let s:d[0xAA33]='CHAM CONSONANT SIGN YA'
let s:d[0xAA34]='CHAM CONSONANT SIGN RA'
let s:d[0xAA35]='CHAM CONSONANT SIGN LA'
let s:d[0xAA36]='CHAM CONSONANT SIGN WA'
let s:d[0xAA40]='CHAM LETTER FINAL K'
let s:d[0xAA41]='CHAM LETTER FINAL G'
let s:d[0xAA42]='CHAM LETTER FINAL NG'
let s:d[0xAA43]='CHAM CONSONANT SIGN FINAL NG'
let s:d[0xAA44]='CHAM LETTER FINAL CH'
let s:d[0xAA45]='CHAM LETTER FINAL T'
let s:d[0xAA46]='CHAM LETTER FINAL N'
let s:d[0xAA47]='CHAM LETTER FINAL P'
let s:d[0xAA48]='CHAM LETTER FINAL Y'
let s:d[0xAA49]='CHAM LETTER FINAL R'
let s:d[0xAA4A]='CHAM LETTER FINAL L'
let s:d[0xAA4B]='CHAM LETTER FINAL SS'
let s:d[0xAA4C]='CHAM CONSONANT SIGN FINAL M'
let s:d[0xAA4D]='CHAM CONSONANT SIGN FINAL H'
let s:d[0xAA50]='CHAM DIGIT ZERO'
let s:d[0xAA51]='CHAM DIGIT ONE'
let s:d[0xAA52]='CHAM DIGIT TWO'
let s:d[0xAA53]='CHAM DIGIT THREE'
let s:d[0xAA54]='CHAM DIGIT FOUR'
let s:d[0xAA55]='CHAM DIGIT FIVE'
let s:d[0xAA56]='CHAM DIGIT SIX'
let s:d[0xAA57]='CHAM DIGIT SEVEN'
let s:d[0xAA58]='CHAM DIGIT EIGHT'
let s:d[0xAA59]='CHAM DIGIT NINE'
let s:d[0xAA5C]='CHAM PUNCTUATION SPIRAL'
let s:d[0xAA5D]='CHAM PUNCTUATION DANDA'
let s:d[0xAA5E]='CHAM PUNCTUATION DOUBLE DANDA'
let s:d[0xAA5F]='CHAM PUNCTUATION TRIPLE DANDA'
let s:d[0xAA60]='MYANMAR LETTER KHAMTI GA'
let s:d[0xAA61]='MYANMAR LETTER KHAMTI CA'
let s:d[0xAA62]='MYANMAR LETTER KHAMTI CHA'
let s:d[0xAA63]='MYANMAR LETTER KHAMTI JA'
let s:d[0xAA64]='MYANMAR LETTER KHAMTI JHA'
let s:d[0xAA65]='MYANMAR LETTER KHAMTI NYA'
let s:d[0xAA66]='MYANMAR LETTER KHAMTI TTA'
let s:d[0xAA67]='MYANMAR LETTER KHAMTI TTHA'
let s:d[0xAA68]='MYANMAR LETTER KHAMTI DDA'
let s:d[0xAA69]='MYANMAR LETTER KHAMTI DDHA'
let s:d[0xAA6A]='MYANMAR LETTER KHAMTI DHA'
let s:d[0xAA6B]='MYANMAR LETTER KHAMTI NA'
let s:d[0xAA6C]='MYANMAR LETTER KHAMTI SA'
let s:d[0xAA6D]='MYANMAR LETTER KHAMTI HA'
let s:d[0xAA6E]='MYANMAR LETTER KHAMTI HHA'
let s:d[0xAA6F]='MYANMAR LETTER KHAMTI FA'
let s:d[0xAA70]='MYANMAR MODIFIER LETTER KHAMTI REDUPLICATION'
let s:d[0xAA71]='MYANMAR LETTER KHAMTI XA'
let s:d[0xAA72]='MYANMAR LETTER KHAMTI ZA'
let s:d[0xAA73]='MYANMAR LETTER KHAMTI RA'
let s:d[0xAA74]='MYANMAR LOGOGRAM KHAMTI OAY'
let s:d[0xAA75]='MYANMAR LOGOGRAM KHAMTI QN'
let s:d[0xAA76]='MYANMAR LOGOGRAM KHAMTI HM'
let s:d[0xAA77]='MYANMAR SYMBOL AITON EXCLAMATION'
let s:d[0xAA78]='MYANMAR SYMBOL AITON ONE'
let s:d[0xAA79]='MYANMAR SYMBOL AITON TWO'
let s:d[0xAA7A]='MYANMAR LETTER AITON RA'
let s:d[0xAA7B]='MYANMAR SIGN PAO KAREN TONE'
let s:d[0xAA80]='TAI VIET LETTER LOW KO'
let s:d[0xAA81]='TAI VIET LETTER HIGH KO'
let s:d[0xAA82]='TAI VIET LETTER LOW KHO'
let s:d[0xAA83]='TAI VIET LETTER HIGH KHO'
let s:d[0xAA84]='TAI VIET LETTER LOW KHHO'
let s:d[0xAA85]='TAI VIET LETTER HIGH KHHO'
let s:d[0xAA86]='TAI VIET LETTER LOW GO'
let s:d[0xAA87]='TAI VIET LETTER HIGH GO'
let s:d[0xAA88]='TAI VIET LETTER LOW NGO'
let s:d[0xAA89]='TAI VIET LETTER HIGH NGO'
let s:d[0xAA8A]='TAI VIET LETTER LOW CO'
let s:d[0xAA8B]='TAI VIET LETTER HIGH CO'
let s:d[0xAA8C]='TAI VIET LETTER LOW CHO'
let s:d[0xAA8D]='TAI VIET LETTER HIGH CHO'
let s:d[0xAA8E]='TAI VIET LETTER LOW SO'
let s:d[0xAA8F]='TAI VIET LETTER HIGH SO'
let s:d[0xAA90]='TAI VIET LETTER LOW NYO'
let s:d[0xAA91]='TAI VIET LETTER HIGH NYO'
let s:d[0xAA92]='TAI VIET LETTER LOW DO'
let s:d[0xAA93]='TAI VIET LETTER HIGH DO'
let s:d[0xAA94]='TAI VIET LETTER LOW TO'
let s:d[0xAA95]='TAI VIET LETTER HIGH TO'
let s:d[0xAA96]='TAI VIET LETTER LOW THO'
let s:d[0xAA97]='TAI VIET LETTER HIGH THO'
let s:d[0xAA98]='TAI VIET LETTER LOW NO'
let s:d[0xAA99]='TAI VIET LETTER HIGH NO'
let s:d[0xAA9A]='TAI VIET LETTER LOW BO'
let s:d[0xAA9B]='TAI VIET LETTER HIGH BO'
let s:d[0xAA9C]='TAI VIET LETTER LOW PO'
let s:d[0xAA9D]='TAI VIET LETTER HIGH PO'
let s:d[0xAA9E]='TAI VIET LETTER LOW PHO'
let s:d[0xAA9F]='TAI VIET LETTER HIGH PHO'
let s:d[0xAAA0]='TAI VIET LETTER LOW FO'
let s:d[0xAAA1]='TAI VIET LETTER HIGH FO'
let s:d[0xAAA2]='TAI VIET LETTER LOW MO'
let s:d[0xAAA3]='TAI VIET LETTER HIGH MO'
let s:d[0xAAA4]='TAI VIET LETTER LOW YO'
let s:d[0xAAA5]='TAI VIET LETTER HIGH YO'
let s:d[0xAAA6]='TAI VIET LETTER LOW RO'
let s:d[0xAAA7]='TAI VIET LETTER HIGH RO'
let s:d[0xAAA8]='TAI VIET LETTER LOW LO'
let s:d[0xAAA9]='TAI VIET LETTER HIGH LO'
let s:d[0xAAAA]='TAI VIET LETTER LOW VO'
let s:d[0xAAAB]='TAI VIET LETTER HIGH VO'
let s:d[0xAAAC]='TAI VIET LETTER LOW HO'
let s:d[0xAAAD]='TAI VIET LETTER HIGH HO'
let s:d[0xAAAE]='TAI VIET LETTER LOW O'
let s:d[0xAAAF]='TAI VIET LETTER HIGH O'
let s:d[0xAAB0]='TAI VIET MAI KANG'
let s:d[0xAAB1]='TAI VIET VOWEL AA'
let s:d[0xAAB2]='TAI VIET VOWEL I'
let s:d[0xAAB3]='TAI VIET VOWEL UE'
let s:d[0xAAB4]='TAI VIET VOWEL U'
let s:d[0xAAB5]='TAI VIET VOWEL E'
let s:d[0xAAB6]='TAI VIET VOWEL O'
let s:d[0xAAB7]='TAI VIET MAI KHIT'
let s:d[0xAAB8]='TAI VIET VOWEL IA'
let s:d[0xAAB9]='TAI VIET VOWEL UEA'
let s:d[0xAABA]='TAI VIET VOWEL UA'
let s:d[0xAABB]='TAI VIET VOWEL AUE'
let s:d[0xAABC]='TAI VIET VOWEL AY'
let s:d[0xAABD]='TAI VIET VOWEL AN'
let s:d[0xAABE]='TAI VIET VOWEL AM'
let s:d[0xAABF]='TAI VIET TONE MAI EK'
let s:d[0xAAC0]='TAI VIET TONE MAI NUENG'
let s:d[0xAAC1]='TAI VIET TONE MAI THO'
let s:d[0xAAC2]='TAI VIET TONE MAI SONG'
let s:d[0xAADB]='TAI VIET SYMBOL KON'
let s:d[0xAADC]='TAI VIET SYMBOL NUENG'
let s:d[0xAADD]='TAI VIET SYMBOL SAM'
let s:d[0xAADE]='TAI VIET SYMBOL HO HOI'
let s:d[0xAADF]='TAI VIET SYMBOL KOI KOI'
let s:d[0xAAE0]='MEETEI MAYEK LETTER E'
let s:d[0xAAE1]='MEETEI MAYEK LETTER O'
let s:d[0xAAE2]='MEETEI MAYEK LETTER CHA'
let s:d[0xAAE3]='MEETEI MAYEK LETTER NYA'
let s:d[0xAAE4]='MEETEI MAYEK LETTER TTA'
let s:d[0xAAE5]='MEETEI MAYEK LETTER TTHA'
let s:d[0xAAE6]='MEETEI MAYEK LETTER DDA'
let s:d[0xAAE7]='MEETEI MAYEK LETTER DDHA'
let s:d[0xAAE8]='MEETEI MAYEK LETTER NNA'
let s:d[0xAAE9]='MEETEI MAYEK LETTER SHA'
let s:d[0xAAEA]='MEETEI MAYEK LETTER SSA'
let s:d[0xAAEB]='MEETEI MAYEK VOWEL SIGN II'
let s:d[0xAAEC]='MEETEI MAYEK VOWEL SIGN UU'
let s:d[0xAAED]='MEETEI MAYEK VOWEL SIGN AAI'
let s:d[0xAAEE]='MEETEI MAYEK VOWEL SIGN AU'
let s:d[0xAAEF]='MEETEI MAYEK VOWEL SIGN AAU'
let s:d[0xAAF0]='MEETEI MAYEK CHEIKHAN'
let s:d[0xAAF1]='MEETEI MAYEK AHANG KHUDAM'
let s:d[0xAAF2]='MEETEI MAYEK ANJI'
let s:d[0xAAF3]='MEETEI MAYEK SYLLABLE REPETITION MARK'
let s:d[0xAAF4]='MEETEI MAYEK WORD REPETITION MARK'
let s:d[0xAAF5]='MEETEI MAYEK VOWEL SIGN VISARGA'
let s:d[0xAAF6]='MEETEI MAYEK VIRAMA'
let s:d[0xAB01]='ETHIOPIC SYLLABLE TTHU'
let s:d[0xAB02]='ETHIOPIC SYLLABLE TTHI'
let s:d[0xAB03]='ETHIOPIC SYLLABLE TTHAA'
let s:d[0xAB04]='ETHIOPIC SYLLABLE TTHEE'
let s:d[0xAB05]='ETHIOPIC SYLLABLE TTHE'
let s:d[0xAB06]='ETHIOPIC SYLLABLE TTHO'
let s:d[0xAB09]='ETHIOPIC SYLLABLE DDHU'
let s:d[0xAB0A]='ETHIOPIC SYLLABLE DDHI'
let s:d[0xAB0B]='ETHIOPIC SYLLABLE DDHAA'
let s:d[0xAB0C]='ETHIOPIC SYLLABLE DDHEE'
let s:d[0xAB0D]='ETHIOPIC SYLLABLE DDHE'
let s:d[0xAB0E]='ETHIOPIC SYLLABLE DDHO'
let s:d[0xAB11]='ETHIOPIC SYLLABLE DZU'
let s:d[0xAB12]='ETHIOPIC SYLLABLE DZI'
let s:d[0xAB13]='ETHIOPIC SYLLABLE DZAA'
let s:d[0xAB14]='ETHIOPIC SYLLABLE DZEE'
let s:d[0xAB15]='ETHIOPIC SYLLABLE DZE'
let s:d[0xAB16]='ETHIOPIC SYLLABLE DZO'
let s:d[0xAB20]='ETHIOPIC SYLLABLE CCHHA'
let s:d[0xAB21]='ETHIOPIC SYLLABLE CCHHU'
let s:d[0xAB22]='ETHIOPIC SYLLABLE CCHHI'
let s:d[0xAB23]='ETHIOPIC SYLLABLE CCHHAA'
let s:d[0xAB24]='ETHIOPIC SYLLABLE CCHHEE'
let s:d[0xAB25]='ETHIOPIC SYLLABLE CCHHE'
let s:d[0xAB26]='ETHIOPIC SYLLABLE CCHHO'
let s:d[0xAB28]='ETHIOPIC SYLLABLE BBA'
let s:d[0xAB29]='ETHIOPIC SYLLABLE BBU'
let s:d[0xAB2A]='ETHIOPIC SYLLABLE BBI'
let s:d[0xAB2B]='ETHIOPIC SYLLABLE BBAA'
let s:d[0xAB2C]='ETHIOPIC SYLLABLE BBEE'
let s:d[0xAB2D]='ETHIOPIC SYLLABLE BBE'
let s:d[0xAB2E]='ETHIOPIC SYLLABLE BBO'
let s:d[0xABC0]='MEETEI MAYEK LETTER KOK'
let s:d[0xABC1]='MEETEI MAYEK LETTER SAM'
let s:d[0xABC2]='MEETEI MAYEK LETTER LAI'
let s:d[0xABC3]='MEETEI MAYEK LETTER MIT'
let s:d[0xABC4]='MEETEI MAYEK LETTER PA'
let s:d[0xABC5]='MEETEI MAYEK LETTER NA'
let s:d[0xABC6]='MEETEI MAYEK LETTER CHIL'
let s:d[0xABC7]='MEETEI MAYEK LETTER TIL'
let s:d[0xABC8]='MEETEI MAYEK LETTER KHOU'
let s:d[0xABC9]='MEETEI MAYEK LETTER NGOU'
let s:d[0xABCA]='MEETEI MAYEK LETTER THOU'
let s:d[0xABCB]='MEETEI MAYEK LETTER WAI'
let s:d[0xABCC]='MEETEI MAYEK LETTER YANG'
let s:d[0xABCD]='MEETEI MAYEK LETTER HUK'
let s:d[0xABCE]='MEETEI MAYEK LETTER UN'
let s:d[0xABCF]='MEETEI MAYEK LETTER I'
let s:d[0xABD0]='MEETEI MAYEK LETTER PHAM'
let s:d[0xABD1]='MEETEI MAYEK LETTER ATIYA'
let s:d[0xABD2]='MEETEI MAYEK LETTER GOK'
let s:d[0xABD3]='MEETEI MAYEK LETTER JHAM'
let s:d[0xABD4]='MEETEI MAYEK LETTER RAI'
let s:d[0xABD5]='MEETEI MAYEK LETTER BA'
let s:d[0xABD6]='MEETEI MAYEK LETTER JIL'
let s:d[0xABD7]='MEETEI MAYEK LETTER DIL'
let s:d[0xABD8]='MEETEI MAYEK LETTER GHOU'
let s:d[0xABD9]='MEETEI MAYEK LETTER DHOU'
let s:d[0xABDA]='MEETEI MAYEK LETTER BHAM'
let s:d[0xABDB]='MEETEI MAYEK LETTER KOK LONSUM'
let s:d[0xABDC]='MEETEI MAYEK LETTER LAI LONSUM'
let s:d[0xABDD]='MEETEI MAYEK LETTER MIT LONSUM'
let s:d[0xABDE]='MEETEI MAYEK LETTER PA LONSUM'
let s:d[0xABDF]='MEETEI MAYEK LETTER NA LONSUM'
let s:d[0xABE0]='MEETEI MAYEK LETTER TIL LONSUM'
let s:d[0xABE1]='MEETEI MAYEK LETTER NGOU LONSUM'
let s:d[0xABE2]='MEETEI MAYEK LETTER I LONSUM'
let s:d[0xABE3]='MEETEI MAYEK VOWEL SIGN ONAP'
let s:d[0xABE4]='MEETEI MAYEK VOWEL SIGN INAP'
let s:d[0xABE5]='MEETEI MAYEK VOWEL SIGN ANAP'
let s:d[0xABE6]='MEETEI MAYEK VOWEL SIGN YENAP'
let s:d[0xABE7]='MEETEI MAYEK VOWEL SIGN SOUNAP'
let s:d[0xABE8]='MEETEI MAYEK VOWEL SIGN UNAP'
let s:d[0xABE9]='MEETEI MAYEK VOWEL SIGN CHEINAP'
let s:d[0xABEA]='MEETEI MAYEK VOWEL SIGN NUNG'
let s:d[0xABEB]='MEETEI MAYEK CHEIKHEI'
let s:d[0xABEC]='MEETEI MAYEK LUM IYEK'
let s:d[0xABED]='MEETEI MAYEK APUN IYEK'
let s:d[0xABF0]='MEETEI MAYEK DIGIT ZERO'
let s:d[0xABF1]='MEETEI MAYEK DIGIT ONE'
let s:d[0xABF2]='MEETEI MAYEK DIGIT TWO'
let s:d[0xABF3]='MEETEI MAYEK DIGIT THREE'
let s:d[0xABF4]='MEETEI MAYEK DIGIT FOUR'
let s:d[0xABF5]='MEETEI MAYEK DIGIT FIVE'
let s:d[0xABF6]='MEETEI MAYEK DIGIT SIX'
let s:d[0xABF7]='MEETEI MAYEK DIGIT SEVEN'
let s:d[0xABF8]='MEETEI MAYEK DIGIT EIGHT'
let s:d[0xABF9]='MEETEI MAYEK DIGIT NINE'
let s:d[0xD7B0]='HANGUL JUNGSEONG O-YEO'
let s:d[0xD7B1]='HANGUL JUNGSEONG O-O-I'
let s:d[0xD7B2]='HANGUL JUNGSEONG YO-A'
let s:d[0xD7B3]='HANGUL JUNGSEONG YO-AE'
let s:d[0xD7B4]='HANGUL JUNGSEONG YO-EO'
let s:d[0xD7B5]='HANGUL JUNGSEONG U-YEO'
let s:d[0xD7B6]='HANGUL JUNGSEONG U-I-I'
let s:d[0xD7B7]='HANGUL JUNGSEONG YU-AE'
let s:d[0xD7B8]='HANGUL JUNGSEONG YU-O'
let s:d[0xD7B9]='HANGUL JUNGSEONG EU-A'
let s:d[0xD7BA]='HANGUL JUNGSEONG EU-EO'
let s:d[0xD7BB]='HANGUL JUNGSEONG EU-E'
let s:d[0xD7BC]='HANGUL JUNGSEONG EU-O'
let s:d[0xD7BD]='HANGUL JUNGSEONG I-YA-O'
let s:d[0xD7BE]='HANGUL JUNGSEONG I-YAE'
let s:d[0xD7BF]='HANGUL JUNGSEONG I-YEO'
let s:d[0xD7C0]='HANGUL JUNGSEONG I-YE'
let s:d[0xD7C1]='HANGUL JUNGSEONG I-O-I'
let s:d[0xD7C2]='HANGUL JUNGSEONG I-YO'
let s:d[0xD7C3]='HANGUL JUNGSEONG I-YU'
let s:d[0xD7C4]='HANGUL JUNGSEONG I-I'
let s:d[0xD7C5]='HANGUL JUNGSEONG ARAEA-A'
let s:d[0xD7C6]='HANGUL JUNGSEONG ARAEA-E'
let s:d[0xD7CB]='HANGUL JONGSEONG NIEUN-RIEUL'
let s:d[0xD7CC]='HANGUL JONGSEONG NIEUN-CHIEUCH'
let s:d[0xD7CD]='HANGUL JONGSEONG SSANGTIKEUT'
let s:d[0xD7CE]='HANGUL JONGSEONG SSANGTIKEUT-PIEUP'
let s:d[0xD7CF]='HANGUL JONGSEONG TIKEUT-PIEUP'
let s:d[0xD7D0]='HANGUL JONGSEONG TIKEUT-SIOS'
let s:d[0xD7D1]='HANGUL JONGSEONG TIKEUT-SIOS-KIYEOK'
let s:d[0xD7D2]='HANGUL JONGSEONG TIKEUT-CIEUC'
let s:d[0xD7D3]='HANGUL JONGSEONG TIKEUT-CHIEUCH'
let s:d[0xD7D4]='HANGUL JONGSEONG TIKEUT-THIEUTH'
let s:d[0xD7D5]='HANGUL JONGSEONG RIEUL-SSANGKIYEOK'
let s:d[0xD7D6]='HANGUL JONGSEONG RIEUL-KIYEOK-HIEUH'
let s:d[0xD7D7]='HANGUL JONGSEONG SSANGRIEUL-KHIEUKH'
let s:d[0xD7D8]='HANGUL JONGSEONG RIEUL-MIEUM-HIEUH'
let s:d[0xD7D9]='HANGUL JONGSEONG RIEUL-PIEUP-TIKEUT'
let s:d[0xD7DA]='HANGUL JONGSEONG RIEUL-PIEUP-PHIEUPH'
let s:d[0xD7DB]='HANGUL JONGSEONG RIEUL-YESIEUNG'
let s:d[0xD7DC]='HANGUL JONGSEONG RIEUL-YEORINHIEUH-HIEUH'
let s:d[0xD7DD]='HANGUL JONGSEONG KAPYEOUNRIEUL'
let s:d[0xD7DE]='HANGUL JONGSEONG MIEUM-NIEUN'
let s:d[0xD7DF]='HANGUL JONGSEONG MIEUM-SSANGNIEUN'
let s:d[0xD7E0]='HANGUL JONGSEONG SSANGMIEUM'
let s:d[0xD7E1]='HANGUL JONGSEONG MIEUM-PIEUP-SIOS'
let s:d[0xD7E2]='HANGUL JONGSEONG MIEUM-CIEUC'
let s:d[0xD7E3]='HANGUL JONGSEONG PIEUP-TIKEUT'
let s:d[0xD7E4]='HANGUL JONGSEONG PIEUP-RIEUL-PHIEUPH'
let s:d[0xD7E5]='HANGUL JONGSEONG PIEUP-MIEUM'
let s:d[0xD7E6]='HANGUL JONGSEONG SSANGPIEUP'
let s:d[0xD7E7]='HANGUL JONGSEONG PIEUP-SIOS-TIKEUT'
let s:d[0xD7E8]='HANGUL JONGSEONG PIEUP-CIEUC'
let s:d[0xD7E9]='HANGUL JONGSEONG PIEUP-CHIEUCH'
let s:d[0xD7EA]='HANGUL JONGSEONG SIOS-MIEUM'
let s:d[0xD7EB]='HANGUL JONGSEONG SIOS-KAPYEOUNPIEUP'
let s:d[0xD7EC]='HANGUL JONGSEONG SSANGSIOS-KIYEOK'
let s:d[0xD7ED]='HANGUL JONGSEONG SSANGSIOS-TIKEUT'
let s:d[0xD7EE]='HANGUL JONGSEONG SIOS-PANSIOS'
let s:d[0xD7EF]='HANGUL JONGSEONG SIOS-CIEUC'
let s:d[0xD7F0]='HANGUL JONGSEONG SIOS-CHIEUCH'
let s:d[0xD7F1]='HANGUL JONGSEONG SIOS-THIEUTH'
let s:d[0xD7F2]='HANGUL JONGSEONG SIOS-HIEUH'
let s:d[0xD7F3]='HANGUL JONGSEONG PANSIOS-PIEUP'
let s:d[0xD7F4]='HANGUL JONGSEONG PANSIOS-KAPYEOUNPIEUP'
let s:d[0xD7F5]='HANGUL JONGSEONG YESIEUNG-MIEUM'
let s:d[0xD7F6]='HANGUL JONGSEONG YESIEUNG-HIEUH'
let s:d[0xD7F7]='HANGUL JONGSEONG CIEUC-PIEUP'
let s:d[0xD7F8]='HANGUL JONGSEONG CIEUC-SSANGPIEUP'
let s:d[0xD7F9]='HANGUL JONGSEONG SSANGCIEUC'
let s:d[0xD7FA]='HANGUL JONGSEONG PHIEUPH-SIOS'
let s:d[0xD7FB]='HANGUL JONGSEONG PHIEUPH-THIEUTH'
let s:d[0xF900]='CJK COMPATIBILITY IDEOGRAPH-F900'
let s:d[0xF901]='CJK COMPATIBILITY IDEOGRAPH-F901'
let s:d[0xF902]='CJK COMPATIBILITY IDEOGRAPH-F902'
let s:d[0xF903]='CJK COMPATIBILITY IDEOGRAPH-F903'
let s:d[0xF904]='CJK COMPATIBILITY IDEOGRAPH-F904'
let s:d[0xF905]='CJK COMPATIBILITY IDEOGRAPH-F905'
let s:d[0xF906]='CJK COMPATIBILITY IDEOGRAPH-F906'
let s:d[0xF907]='CJK COMPATIBILITY IDEOGRAPH-F907'
let s:d[0xF908]='CJK COMPATIBILITY IDEOGRAPH-F908'
let s:d[0xF909]='CJK COMPATIBILITY IDEOGRAPH-F909'
let s:d[0xF90A]='CJK COMPATIBILITY IDEOGRAPH-F90A'
let s:d[0xF90B]='CJK COMPATIBILITY IDEOGRAPH-F90B'
let s:d[0xF90C]='CJK COMPATIBILITY IDEOGRAPH-F90C'
let s:d[0xF90D]='CJK COMPATIBILITY IDEOGRAPH-F90D'
let s:d[0xF90E]='CJK COMPATIBILITY IDEOGRAPH-F90E'
let s:d[0xF90F]='CJK COMPATIBILITY IDEOGRAPH-F90F'
let s:d[0xF910]='CJK COMPATIBILITY IDEOGRAPH-F910'
let s:d[0xF911]='CJK COMPATIBILITY IDEOGRAPH-F911'
let s:d[0xF912]='CJK COMPATIBILITY IDEOGRAPH-F912'
let s:d[0xF913]='CJK COMPATIBILITY IDEOGRAPH-F913'
let s:d[0xF914]='CJK COMPATIBILITY IDEOGRAPH-F914'
let s:d[0xF915]='CJK COMPATIBILITY IDEOGRAPH-F915'
let s:d[0xF916]='CJK COMPATIBILITY IDEOGRAPH-F916'
let s:d[0xF917]='CJK COMPATIBILITY IDEOGRAPH-F917'
let s:d[0xF918]='CJK COMPATIBILITY IDEOGRAPH-F918'
let s:d[0xF919]='CJK COMPATIBILITY IDEOGRAPH-F919'
let s:d[0xF91A]='CJK COMPATIBILITY IDEOGRAPH-F91A'
let s:d[0xF91B]='CJK COMPATIBILITY IDEOGRAPH-F91B'
let s:d[0xF91C]='CJK COMPATIBILITY IDEOGRAPH-F91C'
let s:d[0xF91D]='CJK COMPATIBILITY IDEOGRAPH-F91D'
let s:d[0xF91E]='CJK COMPATIBILITY IDEOGRAPH-F91E'
let s:d[0xF91F]='CJK COMPATIBILITY IDEOGRAPH-F91F'
let s:d[0xF920]='CJK COMPATIBILITY IDEOGRAPH-F920'
let s:d[0xF921]='CJK COMPATIBILITY IDEOGRAPH-F921'
let s:d[0xF922]='CJK COMPATIBILITY IDEOGRAPH-F922'
let s:d[0xF923]='CJK COMPATIBILITY IDEOGRAPH-F923'
let s:d[0xF924]='CJK COMPATIBILITY IDEOGRAPH-F924'
let s:d[0xF925]='CJK COMPATIBILITY IDEOGRAPH-F925'
let s:d[0xF926]='CJK COMPATIBILITY IDEOGRAPH-F926'
let s:d[0xF927]='CJK COMPATIBILITY IDEOGRAPH-F927'
let s:d[0xF928]='CJK COMPATIBILITY IDEOGRAPH-F928'
let s:d[0xF929]='CJK COMPATIBILITY IDEOGRAPH-F929'
let s:d[0xF92A]='CJK COMPATIBILITY IDEOGRAPH-F92A'
let s:d[0xF92B]='CJK COMPATIBILITY IDEOGRAPH-F92B'
let s:d[0xF92C]='CJK COMPATIBILITY IDEOGRAPH-F92C'
let s:d[0xF92D]='CJK COMPATIBILITY IDEOGRAPH-F92D'
let s:d[0xF92E]='CJK COMPATIBILITY IDEOGRAPH-F92E'
let s:d[0xF92F]='CJK COMPATIBILITY IDEOGRAPH-F92F'
let s:d[0xF930]='CJK COMPATIBILITY IDEOGRAPH-F930'
let s:d[0xF931]='CJK COMPATIBILITY IDEOGRAPH-F931'
let s:d[0xF932]='CJK COMPATIBILITY IDEOGRAPH-F932'
let s:d[0xF933]='CJK COMPATIBILITY IDEOGRAPH-F933'
let s:d[0xF934]='CJK COMPATIBILITY IDEOGRAPH-F934'
let s:d[0xF935]='CJK COMPATIBILITY IDEOGRAPH-F935'
let s:d[0xF936]='CJK COMPATIBILITY IDEOGRAPH-F936'
let s:d[0xF937]='CJK COMPATIBILITY IDEOGRAPH-F937'
let s:d[0xF938]='CJK COMPATIBILITY IDEOGRAPH-F938'
let s:d[0xF939]='CJK COMPATIBILITY IDEOGRAPH-F939'
let s:d[0xF93A]='CJK COMPATIBILITY IDEOGRAPH-F93A'
let s:d[0xF93B]='CJK COMPATIBILITY IDEOGRAPH-F93B'
let s:d[0xF93C]='CJK COMPATIBILITY IDEOGRAPH-F93C'
let s:d[0xF93D]='CJK COMPATIBILITY IDEOGRAPH-F93D'
let s:d[0xF93E]='CJK COMPATIBILITY IDEOGRAPH-F93E'
let s:d[0xF93F]='CJK COMPATIBILITY IDEOGRAPH-F93F'
let s:d[0xF940]='CJK COMPATIBILITY IDEOGRAPH-F940'
let s:d[0xF941]='CJK COMPATIBILITY IDEOGRAPH-F941'
let s:d[0xF942]='CJK COMPATIBILITY IDEOGRAPH-F942'
let s:d[0xF943]='CJK COMPATIBILITY IDEOGRAPH-F943'
let s:d[0xF944]='CJK COMPATIBILITY IDEOGRAPH-F944'
let s:d[0xF945]='CJK COMPATIBILITY IDEOGRAPH-F945'
let s:d[0xF946]='CJK COMPATIBILITY IDEOGRAPH-F946'
let s:d[0xF947]='CJK COMPATIBILITY IDEOGRAPH-F947'
let s:d[0xF948]='CJK COMPATIBILITY IDEOGRAPH-F948'
let s:d[0xF949]='CJK COMPATIBILITY IDEOGRAPH-F949'
let s:d[0xF94A]='CJK COMPATIBILITY IDEOGRAPH-F94A'
let s:d[0xF94B]='CJK COMPATIBILITY IDEOGRAPH-F94B'
let s:d[0xF94C]='CJK COMPATIBILITY IDEOGRAPH-F94C'
let s:d[0xF94D]='CJK COMPATIBILITY IDEOGRAPH-F94D'
let s:d[0xF94E]='CJK COMPATIBILITY IDEOGRAPH-F94E'
let s:d[0xF94F]='CJK COMPATIBILITY IDEOGRAPH-F94F'
let s:d[0xF950]='CJK COMPATIBILITY IDEOGRAPH-F950'
let s:d[0xF951]='CJK COMPATIBILITY IDEOGRAPH-F951'
let s:d[0xF952]='CJK COMPATIBILITY IDEOGRAPH-F952'
let s:d[0xF953]='CJK COMPATIBILITY IDEOGRAPH-F953'
let s:d[0xF954]='CJK COMPATIBILITY IDEOGRAPH-F954'
let s:d[0xF955]='CJK COMPATIBILITY IDEOGRAPH-F955'
let s:d[0xF956]='CJK COMPATIBILITY IDEOGRAPH-F956'
let s:d[0xF957]='CJK COMPATIBILITY IDEOGRAPH-F957'
let s:d[0xF958]='CJK COMPATIBILITY IDEOGRAPH-F958'
let s:d[0xF959]='CJK COMPATIBILITY IDEOGRAPH-F959'
let s:d[0xF95A]='CJK COMPATIBILITY IDEOGRAPH-F95A'
let s:d[0xF95B]='CJK COMPATIBILITY IDEOGRAPH-F95B'
let s:d[0xF95C]='CJK COMPATIBILITY IDEOGRAPH-F95C'
let s:d[0xF95D]='CJK COMPATIBILITY IDEOGRAPH-F95D'
let s:d[0xF95E]='CJK COMPATIBILITY IDEOGRAPH-F95E'
let s:d[0xF95F]='CJK COMPATIBILITY IDEOGRAPH-F95F'
let s:d[0xF960]='CJK COMPATIBILITY IDEOGRAPH-F960'
let s:d[0xF961]='CJK COMPATIBILITY IDEOGRAPH-F961'
let s:d[0xF962]='CJK COMPATIBILITY IDEOGRAPH-F962'
let s:d[0xF963]='CJK COMPATIBILITY IDEOGRAPH-F963'
let s:d[0xF964]='CJK COMPATIBILITY IDEOGRAPH-F964'
let s:d[0xF965]='CJK COMPATIBILITY IDEOGRAPH-F965'
let s:d[0xF966]='CJK COMPATIBILITY IDEOGRAPH-F966'
let s:d[0xF967]='CJK COMPATIBILITY IDEOGRAPH-F967'
let s:d[0xF968]='CJK COMPATIBILITY IDEOGRAPH-F968'
let s:d[0xF969]='CJK COMPATIBILITY IDEOGRAPH-F969'
let s:d[0xF96A]='CJK COMPATIBILITY IDEOGRAPH-F96A'
let s:d[0xF96B]='CJK COMPATIBILITY IDEOGRAPH-F96B'
let s:d[0xF96C]='CJK COMPATIBILITY IDEOGRAPH-F96C'
let s:d[0xF96D]='CJK COMPATIBILITY IDEOGRAPH-F96D'
let s:d[0xF96E]='CJK COMPATIBILITY IDEOGRAPH-F96E'
let s:d[0xF96F]='CJK COMPATIBILITY IDEOGRAPH-F96F'
let s:d[0xF970]='CJK COMPATIBILITY IDEOGRAPH-F970'
let s:d[0xF971]='CJK COMPATIBILITY IDEOGRAPH-F971'
let s:d[0xF972]='CJK COMPATIBILITY IDEOGRAPH-F972'
let s:d[0xF973]='CJK COMPATIBILITY IDEOGRAPH-F973'
let s:d[0xF974]='CJK COMPATIBILITY IDEOGRAPH-F974'
let s:d[0xF975]='CJK COMPATIBILITY IDEOGRAPH-F975'
let s:d[0xF976]='CJK COMPATIBILITY IDEOGRAPH-F976'
let s:d[0xF977]='CJK COMPATIBILITY IDEOGRAPH-F977'
let s:d[0xF978]='CJK COMPATIBILITY IDEOGRAPH-F978'
let s:d[0xF979]='CJK COMPATIBILITY IDEOGRAPH-F979'
let s:d[0xF97A]='CJK COMPATIBILITY IDEOGRAPH-F97A'
let s:d[0xF97B]='CJK COMPATIBILITY IDEOGRAPH-F97B'
let s:d[0xF97C]='CJK COMPATIBILITY IDEOGRAPH-F97C'
let s:d[0xF97D]='CJK COMPATIBILITY IDEOGRAPH-F97D'
let s:d[0xF97E]='CJK COMPATIBILITY IDEOGRAPH-F97E'
let s:d[0xF97F]='CJK COMPATIBILITY IDEOGRAPH-F97F'
let s:d[0xF980]='CJK COMPATIBILITY IDEOGRAPH-F980'
let s:d[0xF981]='CJK COMPATIBILITY IDEOGRAPH-F981'
let s:d[0xF982]='CJK COMPATIBILITY IDEOGRAPH-F982'
let s:d[0xF983]='CJK COMPATIBILITY IDEOGRAPH-F983'
let s:d[0xF984]='CJK COMPATIBILITY IDEOGRAPH-F984'
let s:d[0xF985]='CJK COMPATIBILITY IDEOGRAPH-F985'
let s:d[0xF986]='CJK COMPATIBILITY IDEOGRAPH-F986'
let s:d[0xF987]='CJK COMPATIBILITY IDEOGRAPH-F987'
let s:d[0xF988]='CJK COMPATIBILITY IDEOGRAPH-F988'
let s:d[0xF989]='CJK COMPATIBILITY IDEOGRAPH-F989'
let s:d[0xF98A]='CJK COMPATIBILITY IDEOGRAPH-F98A'
let s:d[0xF98B]='CJK COMPATIBILITY IDEOGRAPH-F98B'
let s:d[0xF98C]='CJK COMPATIBILITY IDEOGRAPH-F98C'
let s:d[0xF98D]='CJK COMPATIBILITY IDEOGRAPH-F98D'
let s:d[0xF98E]='CJK COMPATIBILITY IDEOGRAPH-F98E'
let s:d[0xF98F]='CJK COMPATIBILITY IDEOGRAPH-F98F'
let s:d[0xF990]='CJK COMPATIBILITY IDEOGRAPH-F990'
let s:d[0xF991]='CJK COMPATIBILITY IDEOGRAPH-F991'
let s:d[0xF992]='CJK COMPATIBILITY IDEOGRAPH-F992'
let s:d[0xF993]='CJK COMPATIBILITY IDEOGRAPH-F993'
let s:d[0xF994]='CJK COMPATIBILITY IDEOGRAPH-F994'
let s:d[0xF995]='CJK COMPATIBILITY IDEOGRAPH-F995'
let s:d[0xF996]='CJK COMPATIBILITY IDEOGRAPH-F996'
let s:d[0xF997]='CJK COMPATIBILITY IDEOGRAPH-F997'
let s:d[0xF998]='CJK COMPATIBILITY IDEOGRAPH-F998'
let s:d[0xF999]='CJK COMPATIBILITY IDEOGRAPH-F999'
let s:d[0xF99A]='CJK COMPATIBILITY IDEOGRAPH-F99A'
let s:d[0xF99B]='CJK COMPATIBILITY IDEOGRAPH-F99B'
let s:d[0xF99C]='CJK COMPATIBILITY IDEOGRAPH-F99C'
let s:d[0xF99D]='CJK COMPATIBILITY IDEOGRAPH-F99D'
let s:d[0xF99E]='CJK COMPATIBILITY IDEOGRAPH-F99E'
let s:d[0xF99F]='CJK COMPATIBILITY IDEOGRAPH-F99F'
let s:d[0xF9A0]='CJK COMPATIBILITY IDEOGRAPH-F9A0'
let s:d[0xF9A1]='CJK COMPATIBILITY IDEOGRAPH-F9A1'
let s:d[0xF9A2]='CJK COMPATIBILITY IDEOGRAPH-F9A2'
let s:d[0xF9A3]='CJK COMPATIBILITY IDEOGRAPH-F9A3'
let s:d[0xF9A4]='CJK COMPATIBILITY IDEOGRAPH-F9A4'
let s:d[0xF9A5]='CJK COMPATIBILITY IDEOGRAPH-F9A5'
let s:d[0xF9A6]='CJK COMPATIBILITY IDEOGRAPH-F9A6'
let s:d[0xF9A7]='CJK COMPATIBILITY IDEOGRAPH-F9A7'
let s:d[0xF9A8]='CJK COMPATIBILITY IDEOGRAPH-F9A8'
let s:d[0xF9A9]='CJK COMPATIBILITY IDEOGRAPH-F9A9'
let s:d[0xF9AA]='CJK COMPATIBILITY IDEOGRAPH-F9AA'
let s:d[0xF9AB]='CJK COMPATIBILITY IDEOGRAPH-F9AB'
let s:d[0xF9AC]='CJK COMPATIBILITY IDEOGRAPH-F9AC'
let s:d[0xF9AD]='CJK COMPATIBILITY IDEOGRAPH-F9AD'
let s:d[0xF9AE]='CJK COMPATIBILITY IDEOGRAPH-F9AE'
let s:d[0xF9AF]='CJK COMPATIBILITY IDEOGRAPH-F9AF'
let s:d[0xF9B0]='CJK COMPATIBILITY IDEOGRAPH-F9B0'
let s:d[0xF9B1]='CJK COMPATIBILITY IDEOGRAPH-F9B1'
let s:d[0xF9B2]='CJK COMPATIBILITY IDEOGRAPH-F9B2'
let s:d[0xF9B3]='CJK COMPATIBILITY IDEOGRAPH-F9B3'
let s:d[0xF9B4]='CJK COMPATIBILITY IDEOGRAPH-F9B4'
let s:d[0xF9B5]='CJK COMPATIBILITY IDEOGRAPH-F9B5'
let s:d[0xF9B6]='CJK COMPATIBILITY IDEOGRAPH-F9B6'
let s:d[0xF9B7]='CJK COMPATIBILITY IDEOGRAPH-F9B7'
let s:d[0xF9B8]='CJK COMPATIBILITY IDEOGRAPH-F9B8'
let s:d[0xF9B9]='CJK COMPATIBILITY IDEOGRAPH-F9B9'
let s:d[0xF9BA]='CJK COMPATIBILITY IDEOGRAPH-F9BA'
let s:d[0xF9BB]='CJK COMPATIBILITY IDEOGRAPH-F9BB'
let s:d[0xF9BC]='CJK COMPATIBILITY IDEOGRAPH-F9BC'
let s:d[0xF9BD]='CJK COMPATIBILITY IDEOGRAPH-F9BD'
let s:d[0xF9BE]='CJK COMPATIBILITY IDEOGRAPH-F9BE'
let s:d[0xF9BF]='CJK COMPATIBILITY IDEOGRAPH-F9BF'
let s:d[0xF9C0]='CJK COMPATIBILITY IDEOGRAPH-F9C0'
let s:d[0xF9C1]='CJK COMPATIBILITY IDEOGRAPH-F9C1'
let s:d[0xF9C2]='CJK COMPATIBILITY IDEOGRAPH-F9C2'
let s:d[0xF9C3]='CJK COMPATIBILITY IDEOGRAPH-F9C3'
let s:d[0xF9C4]='CJK COMPATIBILITY IDEOGRAPH-F9C4'
let s:d[0xF9C5]='CJK COMPATIBILITY IDEOGRAPH-F9C5'
let s:d[0xF9C6]='CJK COMPATIBILITY IDEOGRAPH-F9C6'
let s:d[0xF9C7]='CJK COMPATIBILITY IDEOGRAPH-F9C7'
let s:d[0xF9C8]='CJK COMPATIBILITY IDEOGRAPH-F9C8'
let s:d[0xF9C9]='CJK COMPATIBILITY IDEOGRAPH-F9C9'
let s:d[0xF9CA]='CJK COMPATIBILITY IDEOGRAPH-F9CA'
let s:d[0xF9CB]='CJK COMPATIBILITY IDEOGRAPH-F9CB'
let s:d[0xF9CC]='CJK COMPATIBILITY IDEOGRAPH-F9CC'
let s:d[0xF9CD]='CJK COMPATIBILITY IDEOGRAPH-F9CD'
let s:d[0xF9CE]='CJK COMPATIBILITY IDEOGRAPH-F9CE'
let s:d[0xF9CF]='CJK COMPATIBILITY IDEOGRAPH-F9CF'
let s:d[0xF9D0]='CJK COMPATIBILITY IDEOGRAPH-F9D0'
let s:d[0xF9D1]='CJK COMPATIBILITY IDEOGRAPH-F9D1'
let s:d[0xF9D2]='CJK COMPATIBILITY IDEOGRAPH-F9D2'
let s:d[0xF9D3]='CJK COMPATIBILITY IDEOGRAPH-F9D3'
let s:d[0xF9D4]='CJK COMPATIBILITY IDEOGRAPH-F9D4'
let s:d[0xF9D5]='CJK COMPATIBILITY IDEOGRAPH-F9D5'
let s:d[0xF9D6]='CJK COMPATIBILITY IDEOGRAPH-F9D6'
let s:d[0xF9D7]='CJK COMPATIBILITY IDEOGRAPH-F9D7'
let s:d[0xF9D8]='CJK COMPATIBILITY IDEOGRAPH-F9D8'
let s:d[0xF9D9]='CJK COMPATIBILITY IDEOGRAPH-F9D9'
let s:d[0xF9DA]='CJK COMPATIBILITY IDEOGRAPH-F9DA'
let s:d[0xF9DB]='CJK COMPATIBILITY IDEOGRAPH-F9DB'
let s:d[0xF9DC]='CJK COMPATIBILITY IDEOGRAPH-F9DC'
let s:d[0xF9DD]='CJK COMPATIBILITY IDEOGRAPH-F9DD'
let s:d[0xF9DE]='CJK COMPATIBILITY IDEOGRAPH-F9DE'
let s:d[0xF9DF]='CJK COMPATIBILITY IDEOGRAPH-F9DF'
let s:d[0xF9E0]='CJK COMPATIBILITY IDEOGRAPH-F9E0'
let s:d[0xF9E1]='CJK COMPATIBILITY IDEOGRAPH-F9E1'
let s:d[0xF9E2]='CJK COMPATIBILITY IDEOGRAPH-F9E2'
let s:d[0xF9E3]='CJK COMPATIBILITY IDEOGRAPH-F9E3'
let s:d[0xF9E4]='CJK COMPATIBILITY IDEOGRAPH-F9E4'
let s:d[0xF9E5]='CJK COMPATIBILITY IDEOGRAPH-F9E5'
let s:d[0xF9E6]='CJK COMPATIBILITY IDEOGRAPH-F9E6'
let s:d[0xF9E7]='CJK COMPATIBILITY IDEOGRAPH-F9E7'
let s:d[0xF9E8]='CJK COMPATIBILITY IDEOGRAPH-F9E8'
let s:d[0xF9E9]='CJK COMPATIBILITY IDEOGRAPH-F9E9'
let s:d[0xF9EA]='CJK COMPATIBILITY IDEOGRAPH-F9EA'
let s:d[0xF9EB]='CJK COMPATIBILITY IDEOGRAPH-F9EB'
let s:d[0xF9EC]='CJK COMPATIBILITY IDEOGRAPH-F9EC'
let s:d[0xF9ED]='CJK COMPATIBILITY IDEOGRAPH-F9ED'
let s:d[0xF9EE]='CJK COMPATIBILITY IDEOGRAPH-F9EE'
let s:d[0xF9EF]='CJK COMPATIBILITY IDEOGRAPH-F9EF'
let s:d[0xF9F0]='CJK COMPATIBILITY IDEOGRAPH-F9F0'
let s:d[0xF9F1]='CJK COMPATIBILITY IDEOGRAPH-F9F1'
let s:d[0xF9F2]='CJK COMPATIBILITY IDEOGRAPH-F9F2'
let s:d[0xF9F3]='CJK COMPATIBILITY IDEOGRAPH-F9F3'
let s:d[0xF9F4]='CJK COMPATIBILITY IDEOGRAPH-F9F4'
let s:d[0xF9F5]='CJK COMPATIBILITY IDEOGRAPH-F9F5'
let s:d[0xF9F6]='CJK COMPATIBILITY IDEOGRAPH-F9F6'
let s:d[0xF9F7]='CJK COMPATIBILITY IDEOGRAPH-F9F7'
let s:d[0xF9F8]='CJK COMPATIBILITY IDEOGRAPH-F9F8'
let s:d[0xF9F9]='CJK COMPATIBILITY IDEOGRAPH-F9F9'
let s:d[0xF9FA]='CJK COMPATIBILITY IDEOGRAPH-F9FA'
let s:d[0xF9FB]='CJK COMPATIBILITY IDEOGRAPH-F9FB'
let s:d[0xF9FC]='CJK COMPATIBILITY IDEOGRAPH-F9FC'
let s:d[0xF9FD]='CJK COMPATIBILITY IDEOGRAPH-F9FD'
let s:d[0xF9FE]='CJK COMPATIBILITY IDEOGRAPH-F9FE'
let s:d[0xF9FF]='CJK COMPATIBILITY IDEOGRAPH-F9FF'
let s:d[0xFA00]='CJK COMPATIBILITY IDEOGRAPH-FA00'
let s:d[0xFA01]='CJK COMPATIBILITY IDEOGRAPH-FA01'
let s:d[0xFA02]='CJK COMPATIBILITY IDEOGRAPH-FA02'
let s:d[0xFA03]='CJK COMPATIBILITY IDEOGRAPH-FA03'
let s:d[0xFA04]='CJK COMPATIBILITY IDEOGRAPH-FA04'
let s:d[0xFA05]='CJK COMPATIBILITY IDEOGRAPH-FA05'
let s:d[0xFA06]='CJK COMPATIBILITY IDEOGRAPH-FA06'
let s:d[0xFA07]='CJK COMPATIBILITY IDEOGRAPH-FA07'
let s:d[0xFA08]='CJK COMPATIBILITY IDEOGRAPH-FA08'
let s:d[0xFA09]='CJK COMPATIBILITY IDEOGRAPH-FA09'
let s:d[0xFA0A]='CJK COMPATIBILITY IDEOGRAPH-FA0A'
let s:d[0xFA0B]='CJK COMPATIBILITY IDEOGRAPH-FA0B'
let s:d[0xFA0C]='CJK COMPATIBILITY IDEOGRAPH-FA0C'
let s:d[0xFA0D]='CJK COMPATIBILITY IDEOGRAPH-FA0D'
let s:d[0xFA0E]='CJK COMPATIBILITY IDEOGRAPH-FA0E'
let s:d[0xFA0F]='CJK COMPATIBILITY IDEOGRAPH-FA0F'
let s:d[0xFA10]='CJK COMPATIBILITY IDEOGRAPH-FA10'
let s:d[0xFA11]='CJK COMPATIBILITY IDEOGRAPH-FA11'
let s:d[0xFA12]='CJK COMPATIBILITY IDEOGRAPH-FA12'
let s:d[0xFA13]='CJK COMPATIBILITY IDEOGRAPH-FA13'
let s:d[0xFA14]='CJK COMPATIBILITY IDEOGRAPH-FA14'
let s:d[0xFA15]='CJK COMPATIBILITY IDEOGRAPH-FA15'
let s:d[0xFA16]='CJK COMPATIBILITY IDEOGRAPH-FA16'
let s:d[0xFA17]='CJK COMPATIBILITY IDEOGRAPH-FA17'
let s:d[0xFA18]='CJK COMPATIBILITY IDEOGRAPH-FA18'
let s:d[0xFA19]='CJK COMPATIBILITY IDEOGRAPH-FA19'
let s:d[0xFA1A]='CJK COMPATIBILITY IDEOGRAPH-FA1A'
let s:d[0xFA1B]='CJK COMPATIBILITY IDEOGRAPH-FA1B'
let s:d[0xFA1C]='CJK COMPATIBILITY IDEOGRAPH-FA1C'
let s:d[0xFA1D]='CJK COMPATIBILITY IDEOGRAPH-FA1D'
let s:d[0xFA1E]='CJK COMPATIBILITY IDEOGRAPH-FA1E'
let s:d[0xFA1F]='CJK COMPATIBILITY IDEOGRAPH-FA1F'
let s:d[0xFA20]='CJK COMPATIBILITY IDEOGRAPH-FA20'
let s:d[0xFA21]='CJK COMPATIBILITY IDEOGRAPH-FA21'
let s:d[0xFA22]='CJK COMPATIBILITY IDEOGRAPH-FA22'
let s:d[0xFA23]='CJK COMPATIBILITY IDEOGRAPH-FA23'
let s:d[0xFA24]='CJK COMPATIBILITY IDEOGRAPH-FA24'
let s:d[0xFA25]='CJK COMPATIBILITY IDEOGRAPH-FA25'
let s:d[0xFA26]='CJK COMPATIBILITY IDEOGRAPH-FA26'
let s:d[0xFA27]='CJK COMPATIBILITY IDEOGRAPH-FA27'
let s:d[0xFA28]='CJK COMPATIBILITY IDEOGRAPH-FA28'
let s:d[0xFA29]='CJK COMPATIBILITY IDEOGRAPH-FA29'
let s:d[0xFA2A]='CJK COMPATIBILITY IDEOGRAPH-FA2A'
let s:d[0xFA2B]='CJK COMPATIBILITY IDEOGRAPH-FA2B'
let s:d[0xFA2C]='CJK COMPATIBILITY IDEOGRAPH-FA2C'
let s:d[0xFA2D]='CJK COMPATIBILITY IDEOGRAPH-FA2D'
let s:d[0xFA2E]='CJK COMPATIBILITY IDEOGRAPH-FA2E'
let s:d[0xFA2F]='CJK COMPATIBILITY IDEOGRAPH-FA2F'
let s:d[0xFA30]='CJK COMPATIBILITY IDEOGRAPH-FA30'
let s:d[0xFA31]='CJK COMPATIBILITY IDEOGRAPH-FA31'
let s:d[0xFA32]='CJK COMPATIBILITY IDEOGRAPH-FA32'
let s:d[0xFA33]='CJK COMPATIBILITY IDEOGRAPH-FA33'
let s:d[0xFA34]='CJK COMPATIBILITY IDEOGRAPH-FA34'
let s:d[0xFA35]='CJK COMPATIBILITY IDEOGRAPH-FA35'
let s:d[0xFA36]='CJK COMPATIBILITY IDEOGRAPH-FA36'
let s:d[0xFA37]='CJK COMPATIBILITY IDEOGRAPH-FA37'
let s:d[0xFA38]='CJK COMPATIBILITY IDEOGRAPH-FA38'
let s:d[0xFA39]='CJK COMPATIBILITY IDEOGRAPH-FA39'
let s:d[0xFA3A]='CJK COMPATIBILITY IDEOGRAPH-FA3A'
let s:d[0xFA3B]='CJK COMPATIBILITY IDEOGRAPH-FA3B'
let s:d[0xFA3C]='CJK COMPATIBILITY IDEOGRAPH-FA3C'
let s:d[0xFA3D]='CJK COMPATIBILITY IDEOGRAPH-FA3D'
let s:d[0xFA3E]='CJK COMPATIBILITY IDEOGRAPH-FA3E'
let s:d[0xFA3F]='CJK COMPATIBILITY IDEOGRAPH-FA3F'
let s:d[0xFA40]='CJK COMPATIBILITY IDEOGRAPH-FA40'
let s:d[0xFA41]='CJK COMPATIBILITY IDEOGRAPH-FA41'
let s:d[0xFA42]='CJK COMPATIBILITY IDEOGRAPH-FA42'
let s:d[0xFA43]='CJK COMPATIBILITY IDEOGRAPH-FA43'
let s:d[0xFA44]='CJK COMPATIBILITY IDEOGRAPH-FA44'
let s:d[0xFA45]='CJK COMPATIBILITY IDEOGRAPH-FA45'
let s:d[0xFA46]='CJK COMPATIBILITY IDEOGRAPH-FA46'
let s:d[0xFA47]='CJK COMPATIBILITY IDEOGRAPH-FA47'
let s:d[0xFA48]='CJK COMPATIBILITY IDEOGRAPH-FA48'
let s:d[0xFA49]='CJK COMPATIBILITY IDEOGRAPH-FA49'
let s:d[0xFA4A]='CJK COMPATIBILITY IDEOGRAPH-FA4A'
let s:d[0xFA4B]='CJK COMPATIBILITY IDEOGRAPH-FA4B'
let s:d[0xFA4C]='CJK COMPATIBILITY IDEOGRAPH-FA4C'
let s:d[0xFA4D]='CJK COMPATIBILITY IDEOGRAPH-FA4D'
let s:d[0xFA4E]='CJK COMPATIBILITY IDEOGRAPH-FA4E'
let s:d[0xFA4F]='CJK COMPATIBILITY IDEOGRAPH-FA4F'
let s:d[0xFA50]='CJK COMPATIBILITY IDEOGRAPH-FA50'
let s:d[0xFA51]='CJK COMPATIBILITY IDEOGRAPH-FA51'
let s:d[0xFA52]='CJK COMPATIBILITY IDEOGRAPH-FA52'
let s:d[0xFA53]='CJK COMPATIBILITY IDEOGRAPH-FA53'
let s:d[0xFA54]='CJK COMPATIBILITY IDEOGRAPH-FA54'
let s:d[0xFA55]='CJK COMPATIBILITY IDEOGRAPH-FA55'
let s:d[0xFA56]='CJK COMPATIBILITY IDEOGRAPH-FA56'
let s:d[0xFA57]='CJK COMPATIBILITY IDEOGRAPH-FA57'
let s:d[0xFA58]='CJK COMPATIBILITY IDEOGRAPH-FA58'
let s:d[0xFA59]='CJK COMPATIBILITY IDEOGRAPH-FA59'
let s:d[0xFA5A]='CJK COMPATIBILITY IDEOGRAPH-FA5A'
let s:d[0xFA5B]='CJK COMPATIBILITY IDEOGRAPH-FA5B'
let s:d[0xFA5C]='CJK COMPATIBILITY IDEOGRAPH-FA5C'
let s:d[0xFA5D]='CJK COMPATIBILITY IDEOGRAPH-FA5D'
let s:d[0xFA5E]='CJK COMPATIBILITY IDEOGRAPH-FA5E'
let s:d[0xFA5F]='CJK COMPATIBILITY IDEOGRAPH-FA5F'
let s:d[0xFA60]='CJK COMPATIBILITY IDEOGRAPH-FA60'
let s:d[0xFA61]='CJK COMPATIBILITY IDEOGRAPH-FA61'
let s:d[0xFA62]='CJK COMPATIBILITY IDEOGRAPH-FA62'
let s:d[0xFA63]='CJK COMPATIBILITY IDEOGRAPH-FA63'
let s:d[0xFA64]='CJK COMPATIBILITY IDEOGRAPH-FA64'
let s:d[0xFA65]='CJK COMPATIBILITY IDEOGRAPH-FA65'
let s:d[0xFA66]='CJK COMPATIBILITY IDEOGRAPH-FA66'
let s:d[0xFA67]='CJK COMPATIBILITY IDEOGRAPH-FA67'
let s:d[0xFA68]='CJK COMPATIBILITY IDEOGRAPH-FA68'
let s:d[0xFA69]='CJK COMPATIBILITY IDEOGRAPH-FA69'
let s:d[0xFA6A]='CJK COMPATIBILITY IDEOGRAPH-FA6A'
let s:d[0xFA6B]='CJK COMPATIBILITY IDEOGRAPH-FA6B'
let s:d[0xFA6C]='CJK COMPATIBILITY IDEOGRAPH-FA6C'
let s:d[0xFA6D]='CJK COMPATIBILITY IDEOGRAPH-FA6D'
let s:d[0xFA70]='CJK COMPATIBILITY IDEOGRAPH-FA70'
let s:d[0xFA71]='CJK COMPATIBILITY IDEOGRAPH-FA71'
let s:d[0xFA72]='CJK COMPATIBILITY IDEOGRAPH-FA72'
let s:d[0xFA73]='CJK COMPATIBILITY IDEOGRAPH-FA73'
let s:d[0xFA74]='CJK COMPATIBILITY IDEOGRAPH-FA74'
let s:d[0xFA75]='CJK COMPATIBILITY IDEOGRAPH-FA75'
let s:d[0xFA76]='CJK COMPATIBILITY IDEOGRAPH-FA76'
let s:d[0xFA77]='CJK COMPATIBILITY IDEOGRAPH-FA77'
let s:d[0xFA78]='CJK COMPATIBILITY IDEOGRAPH-FA78'
let s:d[0xFA79]='CJK COMPATIBILITY IDEOGRAPH-FA79'
let s:d[0xFA7A]='CJK COMPATIBILITY IDEOGRAPH-FA7A'
let s:d[0xFA7B]='CJK COMPATIBILITY IDEOGRAPH-FA7B'
let s:d[0xFA7C]='CJK COMPATIBILITY IDEOGRAPH-FA7C'
let s:d[0xFA7D]='CJK COMPATIBILITY IDEOGRAPH-FA7D'
let s:d[0xFA7E]='CJK COMPATIBILITY IDEOGRAPH-FA7E'
let s:d[0xFA7F]='CJK COMPATIBILITY IDEOGRAPH-FA7F'
let s:d[0xFA80]='CJK COMPATIBILITY IDEOGRAPH-FA80'
let s:d[0xFA81]='CJK COMPATIBILITY IDEOGRAPH-FA81'
let s:d[0xFA82]='CJK COMPATIBILITY IDEOGRAPH-FA82'
let s:d[0xFA83]='CJK COMPATIBILITY IDEOGRAPH-FA83'
let s:d[0xFA84]='CJK COMPATIBILITY IDEOGRAPH-FA84'
let s:d[0xFA85]='CJK COMPATIBILITY IDEOGRAPH-FA85'
let s:d[0xFA86]='CJK COMPATIBILITY IDEOGRAPH-FA86'
let s:d[0xFA87]='CJK COMPATIBILITY IDEOGRAPH-FA87'
let s:d[0xFA88]='CJK COMPATIBILITY IDEOGRAPH-FA88'
let s:d[0xFA89]='CJK COMPATIBILITY IDEOGRAPH-FA89'
let s:d[0xFA8A]='CJK COMPATIBILITY IDEOGRAPH-FA8A'
let s:d[0xFA8B]='CJK COMPATIBILITY IDEOGRAPH-FA8B'
let s:d[0xFA8C]='CJK COMPATIBILITY IDEOGRAPH-FA8C'
let s:d[0xFA8D]='CJK COMPATIBILITY IDEOGRAPH-FA8D'
let s:d[0xFA8E]='CJK COMPATIBILITY IDEOGRAPH-FA8E'
let s:d[0xFA8F]='CJK COMPATIBILITY IDEOGRAPH-FA8F'
let s:d[0xFA90]='CJK COMPATIBILITY IDEOGRAPH-FA90'
let s:d[0xFA91]='CJK COMPATIBILITY IDEOGRAPH-FA91'
let s:d[0xFA92]='CJK COMPATIBILITY IDEOGRAPH-FA92'
let s:d[0xFA93]='CJK COMPATIBILITY IDEOGRAPH-FA93'
let s:d[0xFA94]='CJK COMPATIBILITY IDEOGRAPH-FA94'
let s:d[0xFA95]='CJK COMPATIBILITY IDEOGRAPH-FA95'
let s:d[0xFA96]='CJK COMPATIBILITY IDEOGRAPH-FA96'
let s:d[0xFA97]='CJK COMPATIBILITY IDEOGRAPH-FA97'
let s:d[0xFA98]='CJK COMPATIBILITY IDEOGRAPH-FA98'
let s:d[0xFA99]='CJK COMPATIBILITY IDEOGRAPH-FA99'
let s:d[0xFA9A]='CJK COMPATIBILITY IDEOGRAPH-FA9A'
let s:d[0xFA9B]='CJK COMPATIBILITY IDEOGRAPH-FA9B'
let s:d[0xFA9C]='CJK COMPATIBILITY IDEOGRAPH-FA9C'
let s:d[0xFA9D]='CJK COMPATIBILITY IDEOGRAPH-FA9D'
let s:d[0xFA9E]='CJK COMPATIBILITY IDEOGRAPH-FA9E'
let s:d[0xFA9F]='CJK COMPATIBILITY IDEOGRAPH-FA9F'
let s:d[0xFAA0]='CJK COMPATIBILITY IDEOGRAPH-FAA0'
let s:d[0xFAA1]='CJK COMPATIBILITY IDEOGRAPH-FAA1'
let s:d[0xFAA2]='CJK COMPATIBILITY IDEOGRAPH-FAA2'
let s:d[0xFAA3]='CJK COMPATIBILITY IDEOGRAPH-FAA3'
let s:d[0xFAA4]='CJK COMPATIBILITY IDEOGRAPH-FAA4'
let s:d[0xFAA5]='CJK COMPATIBILITY IDEOGRAPH-FAA5'
let s:d[0xFAA6]='CJK COMPATIBILITY IDEOGRAPH-FAA6'
let s:d[0xFAA7]='CJK COMPATIBILITY IDEOGRAPH-FAA7'
let s:d[0xFAA8]='CJK COMPATIBILITY IDEOGRAPH-FAA8'
let s:d[0xFAA9]='CJK COMPATIBILITY IDEOGRAPH-FAA9'
let s:d[0xFAAA]='CJK COMPATIBILITY IDEOGRAPH-FAAA'
let s:d[0xFAAB]='CJK COMPATIBILITY IDEOGRAPH-FAAB'
let s:d[0xFAAC]='CJK COMPATIBILITY IDEOGRAPH-FAAC'
let s:d[0xFAAD]='CJK COMPATIBILITY IDEOGRAPH-FAAD'
let s:d[0xFAAE]='CJK COMPATIBILITY IDEOGRAPH-FAAE'
let s:d[0xFAAF]='CJK COMPATIBILITY IDEOGRAPH-FAAF'
let s:d[0xFAB0]='CJK COMPATIBILITY IDEOGRAPH-FAB0'
let s:d[0xFAB1]='CJK COMPATIBILITY IDEOGRAPH-FAB1'
let s:d[0xFAB2]='CJK COMPATIBILITY IDEOGRAPH-FAB2'
let s:d[0xFAB3]='CJK COMPATIBILITY IDEOGRAPH-FAB3'
let s:d[0xFAB4]='CJK COMPATIBILITY IDEOGRAPH-FAB4'
let s:d[0xFAB5]='CJK COMPATIBILITY IDEOGRAPH-FAB5'
let s:d[0xFAB6]='CJK COMPATIBILITY IDEOGRAPH-FAB6'
let s:d[0xFAB7]='CJK COMPATIBILITY IDEOGRAPH-FAB7'
let s:d[0xFAB8]='CJK COMPATIBILITY IDEOGRAPH-FAB8'
let s:d[0xFAB9]='CJK COMPATIBILITY IDEOGRAPH-FAB9'
let s:d[0xFABA]='CJK COMPATIBILITY IDEOGRAPH-FABA'
let s:d[0xFABB]='CJK COMPATIBILITY IDEOGRAPH-FABB'
let s:d[0xFABC]='CJK COMPATIBILITY IDEOGRAPH-FABC'
let s:d[0xFABD]='CJK COMPATIBILITY IDEOGRAPH-FABD'
let s:d[0xFABE]='CJK COMPATIBILITY IDEOGRAPH-FABE'
let s:d[0xFABF]='CJK COMPATIBILITY IDEOGRAPH-FABF'
let s:d[0xFAC0]='CJK COMPATIBILITY IDEOGRAPH-FAC0'
let s:d[0xFAC1]='CJK COMPATIBILITY IDEOGRAPH-FAC1'
let s:d[0xFAC2]='CJK COMPATIBILITY IDEOGRAPH-FAC2'
let s:d[0xFAC3]='CJK COMPATIBILITY IDEOGRAPH-FAC3'
let s:d[0xFAC4]='CJK COMPATIBILITY IDEOGRAPH-FAC4'
let s:d[0xFAC5]='CJK COMPATIBILITY IDEOGRAPH-FAC5'
let s:d[0xFAC6]='CJK COMPATIBILITY IDEOGRAPH-FAC6'
let s:d[0xFAC7]='CJK COMPATIBILITY IDEOGRAPH-FAC7'
let s:d[0xFAC8]='CJK COMPATIBILITY IDEOGRAPH-FAC8'
let s:d[0xFAC9]='CJK COMPATIBILITY IDEOGRAPH-FAC9'
let s:d[0xFACA]='CJK COMPATIBILITY IDEOGRAPH-FACA'
let s:d[0xFACB]='CJK COMPATIBILITY IDEOGRAPH-FACB'
let s:d[0xFACC]='CJK COMPATIBILITY IDEOGRAPH-FACC'
let s:d[0xFACD]='CJK COMPATIBILITY IDEOGRAPH-FACD'
let s:d[0xFACE]='CJK COMPATIBILITY IDEOGRAPH-FACE'
let s:d[0xFACF]='CJK COMPATIBILITY IDEOGRAPH-FACF'
let s:d[0xFAD0]='CJK COMPATIBILITY IDEOGRAPH-FAD0'
let s:d[0xFAD1]='CJK COMPATIBILITY IDEOGRAPH-FAD1'
let s:d[0xFAD2]='CJK COMPATIBILITY IDEOGRAPH-FAD2'
let s:d[0xFAD3]='CJK COMPATIBILITY IDEOGRAPH-FAD3'
let s:d[0xFAD4]='CJK COMPATIBILITY IDEOGRAPH-FAD4'
let s:d[0xFAD5]='CJK COMPATIBILITY IDEOGRAPH-FAD5'
let s:d[0xFAD6]='CJK COMPATIBILITY IDEOGRAPH-FAD6'
let s:d[0xFAD7]='CJK COMPATIBILITY IDEOGRAPH-FAD7'
let s:d[0xFAD8]='CJK COMPATIBILITY IDEOGRAPH-FAD8'
let s:d[0xFAD9]='CJK COMPATIBILITY IDEOGRAPH-FAD9'
let s:d[0xFB00]='LATIN SMALL LIGATURE FF'
let s:d[0xFB01]='LATIN SMALL LIGATURE FI'
let s:d[0xFB02]='LATIN SMALL LIGATURE FL'
let s:d[0xFB03]='LATIN SMALL LIGATURE FFI'
let s:d[0xFB04]='LATIN SMALL LIGATURE FFL'
let s:d[0xFB05]='LATIN SMALL LIGATURE LONG S T'
let s:d[0xFB06]='LATIN SMALL LIGATURE ST'
let s:d[0xFB13]='ARMENIAN SMALL LIGATURE MEN NOW'
let s:d[0xFB14]='ARMENIAN SMALL LIGATURE MEN ECH'
let s:d[0xFB15]='ARMENIAN SMALL LIGATURE MEN INI'
let s:d[0xFB16]='ARMENIAN SMALL LIGATURE VEW NOW'
let s:d[0xFB17]='ARMENIAN SMALL LIGATURE MEN XEH'
let s:d[0xFB1D]='HEBREW LETTER YOD WITH HIRIQ'
let s:d[0xFB1E]='HEBREW POINT JUDEO-SPANISH VARIKA'
let s:d[0xFB1F]='HEBREW LIGATURE YIDDISH YOD YOD PATAH'
let s:d[0xFB20]='HEBREW LETTER ALTERNATIVE AYIN'
let s:d[0xFB21]='HEBREW LETTER WIDE ALEF'
let s:d[0xFB22]='HEBREW LETTER WIDE DALET'
let s:d[0xFB23]='HEBREW LETTER WIDE HE'
let s:d[0xFB24]='HEBREW LETTER WIDE KAF'
let s:d[0xFB25]='HEBREW LETTER WIDE LAMED'
let s:d[0xFB26]='HEBREW LETTER WIDE FINAL MEM'
let s:d[0xFB27]='HEBREW LETTER WIDE RESH'
let s:d[0xFB28]='HEBREW LETTER WIDE TAV'
let s:d[0xFB29]='HEBREW LETTER ALTERNATIVE PLUS SIGN'
let s:d[0xFB2A]='HEBREW LETTER SHIN WITH SHIN DOT'
let s:d[0xFB2B]='HEBREW LETTER SHIN WITH SIN DOT'
let s:d[0xFB2C]='HEBREW LETTER SHIN WITH DAGESH AND SHIN DOT'
let s:d[0xFB2D]='HEBREW LETTER SHIN WITH DAGESH AND SIN DOT'
let s:d[0xFB2E]='HEBREW LETTER ALEF WITH PATAH'
let s:d[0xFB2F]='HEBREW LETTER ALEF WITH QAMATS'
let s:d[0xFB30]='HEBREW LETTER ALEF WITH MAPIQ'
let s:d[0xFB31]='HEBREW LETTER BET WITH DAGESH'
let s:d[0xFB32]='HEBREW LETTER GIMEL WITH DAGESH'
let s:d[0xFB33]='HEBREW LETTER DALET WITH DAGESH'
let s:d[0xFB34]='HEBREW LETTER HE WITH MAPIQ'
let s:d[0xFB35]='HEBREW LETTER VAV WITH DAGESH'
let s:d[0xFB36]='HEBREW LETTER ZAYIN WITH DAGESH'
let s:d[0xFB38]='HEBREW LETTER TET WITH DAGESH'
let s:d[0xFB39]='HEBREW LETTER YOD WITH DAGESH'
let s:d[0xFB3A]='HEBREW LETTER FINAL KAF WITH DAGESH'
let s:d[0xFB3B]='HEBREW LETTER KAF WITH DAGESH'
let s:d[0xFB3C]='HEBREW LETTER LAMED WITH DAGESH'
let s:d[0xFB3E]='HEBREW LETTER MEM WITH DAGESH'
let s:d[0xFB40]='HEBREW LETTER NUN WITH DAGESH'
let s:d[0xFB41]='HEBREW LETTER SAMEKH WITH DAGESH'
let s:d[0xFB43]='HEBREW LETTER FINAL PE WITH DAGESH'
let s:d[0xFB44]='HEBREW LETTER PE WITH DAGESH'
let s:d[0xFB46]='HEBREW LETTER TSADI WITH DAGESH'
let s:d[0xFB47]='HEBREW LETTER QOF WITH DAGESH'
let s:d[0xFB48]='HEBREW LETTER RESH WITH DAGESH'
let s:d[0xFB49]='HEBREW LETTER SHIN WITH DAGESH'
let s:d[0xFB4A]='HEBREW LETTER TAV WITH DAGESH'
let s:d[0xFB4B]='HEBREW LETTER VAV WITH HOLAM'
let s:d[0xFB4C]='HEBREW LETTER BET WITH RAFE'
let s:d[0xFB4D]='HEBREW LETTER KAF WITH RAFE'
let s:d[0xFB4E]='HEBREW LETTER PE WITH RAFE'
let s:d[0xFB4F]='HEBREW LIGATURE ALEF LAMED'
let s:d[0xFB50]='ARABIC LETTER ALEF WASLA ISOLATED FORM'
let s:d[0xFB51]='ARABIC LETTER ALEF WASLA FINAL FORM'
let s:d[0xFB52]='ARABIC LETTER BEEH ISOLATED FORM'
let s:d[0xFB53]='ARABIC LETTER BEEH FINAL FORM'
let s:d[0xFB54]='ARABIC LETTER BEEH INITIAL FORM'
let s:d[0xFB55]='ARABIC LETTER BEEH MEDIAL FORM'
let s:d[0xFB56]='ARABIC LETTER PEH ISOLATED FORM'
let s:d[0xFB57]='ARABIC LETTER PEH FINAL FORM'
let s:d[0xFB58]='ARABIC LETTER PEH INITIAL FORM'
let s:d[0xFB59]='ARABIC LETTER PEH MEDIAL FORM'
let s:d[0xFB5A]='ARABIC LETTER BEHEH ISOLATED FORM'
let s:d[0xFB5B]='ARABIC LETTER BEHEH FINAL FORM'
let s:d[0xFB5C]='ARABIC LETTER BEHEH INITIAL FORM'
let s:d[0xFB5D]='ARABIC LETTER BEHEH MEDIAL FORM'
let s:d[0xFB5E]='ARABIC LETTER TTEHEH ISOLATED FORM'
let s:d[0xFB5F]='ARABIC LETTER TTEHEH FINAL FORM'
let s:d[0xFB60]='ARABIC LETTER TTEHEH INITIAL FORM'
let s:d[0xFB61]='ARABIC LETTER TTEHEH MEDIAL FORM'
let s:d[0xFB62]='ARABIC LETTER TEHEH ISOLATED FORM'
let s:d[0xFB63]='ARABIC LETTER TEHEH FINAL FORM'
let s:d[0xFB64]='ARABIC LETTER TEHEH INITIAL FORM'
let s:d[0xFB65]='ARABIC LETTER TEHEH MEDIAL FORM'
let s:d[0xFB66]='ARABIC LETTER TTEH ISOLATED FORM'
let s:d[0xFB67]='ARABIC LETTER TTEH FINAL FORM'
let s:d[0xFB68]='ARABIC LETTER TTEH INITIAL FORM'
let s:d[0xFB69]='ARABIC LETTER TTEH MEDIAL FORM'
let s:d[0xFB6A]='ARABIC LETTER VEH ISOLATED FORM'
let s:d[0xFB6B]='ARABIC LETTER VEH FINAL FORM'
let s:d[0xFB6C]='ARABIC LETTER VEH INITIAL FORM'
let s:d[0xFB6D]='ARABIC LETTER VEH MEDIAL FORM'
let s:d[0xFB6E]='ARABIC LETTER PEHEH ISOLATED FORM'
let s:d[0xFB6F]='ARABIC LETTER PEHEH FINAL FORM'
let s:d[0xFB70]='ARABIC LETTER PEHEH INITIAL FORM'
let s:d[0xFB71]='ARABIC LETTER PEHEH MEDIAL FORM'
let s:d[0xFB72]='ARABIC LETTER DYEH ISOLATED FORM'
let s:d[0xFB73]='ARABIC LETTER DYEH FINAL FORM'
let s:d[0xFB74]='ARABIC LETTER DYEH INITIAL FORM'
let s:d[0xFB75]='ARABIC LETTER DYEH MEDIAL FORM'
let s:d[0xFB76]='ARABIC LETTER NYEH ISOLATED FORM'
let s:d[0xFB77]='ARABIC LETTER NYEH FINAL FORM'
let s:d[0xFB78]='ARABIC LETTER NYEH INITIAL FORM'
let s:d[0xFB79]='ARABIC LETTER NYEH MEDIAL FORM'
let s:d[0xFB7A]='ARABIC LETTER TCHEH ISOLATED FORM'
let s:d[0xFB7B]='ARABIC LETTER TCHEH FINAL FORM'
let s:d[0xFB7C]='ARABIC LETTER TCHEH INITIAL FORM'
let s:d[0xFB7D]='ARABIC LETTER TCHEH MEDIAL FORM'
let s:d[0xFB7E]='ARABIC LETTER TCHEHEH ISOLATED FORM'
let s:d[0xFB7F]='ARABIC LETTER TCHEHEH FINAL FORM'
let s:d[0xFB80]='ARABIC LETTER TCHEHEH INITIAL FORM'
let s:d[0xFB81]='ARABIC LETTER TCHEHEH MEDIAL FORM'
let s:d[0xFB82]='ARABIC LETTER DDAHAL ISOLATED FORM'
let s:d[0xFB83]='ARABIC LETTER DDAHAL FINAL FORM'
let s:d[0xFB84]='ARABIC LETTER DAHAL ISOLATED FORM'
let s:d[0xFB85]='ARABIC LETTER DAHAL FINAL FORM'
let s:d[0xFB86]='ARABIC LETTER DUL ISOLATED FORM'
let s:d[0xFB87]='ARABIC LETTER DUL FINAL FORM'
let s:d[0xFB88]='ARABIC LETTER DDAL ISOLATED FORM'
let s:d[0xFB89]='ARABIC LETTER DDAL FINAL FORM'
let s:d[0xFB8A]='ARABIC LETTER JEH ISOLATED FORM'
let s:d[0xFB8B]='ARABIC LETTER JEH FINAL FORM'
let s:d[0xFB8C]='ARABIC LETTER RREH ISOLATED FORM'
let s:d[0xFB8D]='ARABIC LETTER RREH FINAL FORM'
let s:d[0xFB8E]='ARABIC LETTER KEHEH ISOLATED FORM'
let s:d[0xFB8F]='ARABIC LETTER KEHEH FINAL FORM'
let s:d[0xFB90]='ARABIC LETTER KEHEH INITIAL FORM'
let s:d[0xFB91]='ARABIC LETTER KEHEH MEDIAL FORM'
let s:d[0xFB92]='ARABIC LETTER GAF ISOLATED FORM'
let s:d[0xFB93]='ARABIC LETTER GAF FINAL FORM'
let s:d[0xFB94]='ARABIC LETTER GAF INITIAL FORM'
let s:d[0xFB95]='ARABIC LETTER GAF MEDIAL FORM'
let s:d[0xFB96]='ARABIC LETTER GUEH ISOLATED FORM'
let s:d[0xFB97]='ARABIC LETTER GUEH FINAL FORM'
let s:d[0xFB98]='ARABIC LETTER GUEH INITIAL FORM'
let s:d[0xFB99]='ARABIC LETTER GUEH MEDIAL FORM'
let s:d[0xFB9A]='ARABIC LETTER NGOEH ISOLATED FORM'
let s:d[0xFB9B]='ARABIC LETTER NGOEH FINAL FORM'
let s:d[0xFB9C]='ARABIC LETTER NGOEH INITIAL FORM'
let s:d[0xFB9D]='ARABIC LETTER NGOEH MEDIAL FORM'
let s:d[0xFB9E]='ARABIC LETTER NOON GHUNNA ISOLATED FORM'
let s:d[0xFB9F]='ARABIC LETTER NOON GHUNNA FINAL FORM'
let s:d[0xFBA0]='ARABIC LETTER RNOON ISOLATED FORM'
let s:d[0xFBA1]='ARABIC LETTER RNOON FINAL FORM'
let s:d[0xFBA2]='ARABIC LETTER RNOON INITIAL FORM'
let s:d[0xFBA3]='ARABIC LETTER RNOON MEDIAL FORM'
let s:d[0xFBA4]='ARABIC LETTER HEH WITH YEH ABOVE ISOLATED FORM'
let s:d[0xFBA5]='ARABIC LETTER HEH WITH YEH ABOVE FINAL FORM'
let s:d[0xFBA6]='ARABIC LETTER HEH GOAL ISOLATED FORM'
let s:d[0xFBA7]='ARABIC LETTER HEH GOAL FINAL FORM'
let s:d[0xFBA8]='ARABIC LETTER HEH GOAL INITIAL FORM'
let s:d[0xFBA9]='ARABIC LETTER HEH GOAL MEDIAL FORM'
let s:d[0xFBAA]='ARABIC LETTER HEH DOACHASHMEE ISOLATED FORM'
let s:d[0xFBAB]='ARABIC LETTER HEH DOACHASHMEE FINAL FORM'
let s:d[0xFBAC]='ARABIC LETTER HEH DOACHASHMEE INITIAL FORM'
let s:d[0xFBAD]='ARABIC LETTER HEH DOACHASHMEE MEDIAL FORM'
let s:d[0xFBAE]='ARABIC LETTER YEH BARREE ISOLATED FORM'
let s:d[0xFBAF]='ARABIC LETTER YEH BARREE FINAL FORM'
let s:d[0xFBB0]='ARABIC LETTER YEH BARREE WITH HAMZA ABOVE ISOLATED FORM'
let s:d[0xFBB1]='ARABIC LETTER YEH BARREE WITH HAMZA ABOVE FINAL FORM'
let s:d[0xFBB2]='ARABIC SYMBOL DOT ABOVE'
let s:d[0xFBB3]='ARABIC SYMBOL DOT BELOW'
let s:d[0xFBB4]='ARABIC SYMBOL TWO DOTS ABOVE'
let s:d[0xFBB5]='ARABIC SYMBOL TWO DOTS BELOW'
let s:d[0xFBB6]='ARABIC SYMBOL THREE DOTS ABOVE'
let s:d[0xFBB7]='ARABIC SYMBOL THREE DOTS BELOW'
let s:d[0xFBB8]='ARABIC SYMBOL THREE DOTS POINTING DOWNWARDS ABOVE'
let s:d[0xFBB9]='ARABIC SYMBOL THREE DOTS POINTING DOWNWARDS BELOW'
let s:d[0xFBBA]='ARABIC SYMBOL FOUR DOTS ABOVE'
let s:d[0xFBBB]='ARABIC SYMBOL FOUR DOTS BELOW'
let s:d[0xFBBC]='ARABIC SYMBOL DOUBLE VERTICAL BAR BELOW'
let s:d[0xFBBD]='ARABIC SYMBOL TWO DOTS VERTICALLY ABOVE'
let s:d[0xFBBE]='ARABIC SYMBOL TWO DOTS VERTICALLY BELOW'
let s:d[0xFBBF]='ARABIC SYMBOL RING'
let s:d[0xFBC0]='ARABIC SYMBOL SMALL TAH ABOVE'
let s:d[0xFBC1]='ARABIC SYMBOL SMALL TAH BELOW'
let s:d[0xFBD3]='ARABIC LETTER NG ISOLATED FORM'
let s:d[0xFBD4]='ARABIC LETTER NG FINAL FORM'
let s:d[0xFBD5]='ARABIC LETTER NG INITIAL FORM'
let s:d[0xFBD6]='ARABIC LETTER NG MEDIAL FORM'
let s:d[0xFBD7]='ARABIC LETTER U ISOLATED FORM'
let s:d[0xFBD8]='ARABIC LETTER U FINAL FORM'
let s:d[0xFBD9]='ARABIC LETTER OE ISOLATED FORM'
let s:d[0xFBDA]='ARABIC LETTER OE FINAL FORM'
let s:d[0xFBDB]='ARABIC LETTER YU ISOLATED FORM'
let s:d[0xFBDC]='ARABIC LETTER YU FINAL FORM'
let s:d[0xFBDD]='ARABIC LETTER U WITH HAMZA ABOVE ISOLATED FORM'
let s:d[0xFBDE]='ARABIC LETTER VE ISOLATED FORM'
let s:d[0xFBDF]='ARABIC LETTER VE FINAL FORM'
let s:d[0xFBE0]='ARABIC LETTER KIRGHIZ OE ISOLATED FORM'
let s:d[0xFBE1]='ARABIC LETTER KIRGHIZ OE FINAL FORM'
let s:d[0xFBE2]='ARABIC LETTER KIRGHIZ YU ISOLATED FORM'
let s:d[0xFBE3]='ARABIC LETTER KIRGHIZ YU FINAL FORM'
let s:d[0xFBE4]='ARABIC LETTER E ISOLATED FORM'
let s:d[0xFBE5]='ARABIC LETTER E FINAL FORM'
let s:d[0xFBE6]='ARABIC LETTER E INITIAL FORM'
let s:d[0xFBE7]='ARABIC LETTER E MEDIAL FORM'
let s:d[0xFBE8]='ARABIC LETTER UIGHUR KAZAKH KIRGHIZ ALEF MAKSURA INITIAL FORM'
let s:d[0xFBE9]='ARABIC LETTER UIGHUR KAZAKH KIRGHIZ ALEF MAKSURA MEDIAL FORM'
let s:d[0xFBEA]='ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH ALEF ISOLATED FORM'
let s:d[0xFBEB]='ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH ALEF FINAL FORM'
let s:d[0xFBEC]='ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH AE ISOLATED FORM'
let s:d[0xFBED]='ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH AE FINAL FORM'
let s:d[0xFBEE]='ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH WAW ISOLATED FORM'
let s:d[0xFBEF]='ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH WAW FINAL FORM'
let s:d[0xFBF0]='ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH U ISOLATED FORM'
let s:d[0xFBF1]='ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH U FINAL FORM'
let s:d[0xFBF2]='ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH OE ISOLATED FORM'
let s:d[0xFBF3]='ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH OE FINAL FORM'
let s:d[0xFBF4]='ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH YU ISOLATED FORM'
let s:d[0xFBF5]='ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH YU FINAL FORM'
let s:d[0xFBF6]='ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH E ISOLATED FORM'
let s:d[0xFBF7]='ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH E FINAL FORM'
let s:d[0xFBF8]='ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH E INITIAL FORM'
let s:d[0xFBF9]='ARABIC LIGATURE UIGHUR KIRGHIZ YEH WITH HAMZA ABOVE WITH ALEF MAKSURA ISOLATED FORM'
let s:d[0xFBFA]='ARABIC LIGATURE UIGHUR KIRGHIZ YEH WITH HAMZA ABOVE WITH ALEF MAKSURA FINAL FORM'
let s:d[0xFBFB]='ARABIC LIGATURE UIGHUR KIRGHIZ YEH WITH HAMZA ABOVE WITH ALEF MAKSURA INITIAL FORM'
let s:d[0xFBFC]='ARABIC LETTER FARSI YEH ISOLATED FORM'
let s:d[0xFBFD]='ARABIC LETTER FARSI YEH FINAL FORM'
let s:d[0xFBFE]='ARABIC LETTER FARSI YEH INITIAL FORM'
let s:d[0xFBFF]='ARABIC LETTER FARSI YEH MEDIAL FORM'
let s:d[0xFC00]='ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH JEEM ISOLATED FORM'
let s:d[0xFC01]='ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH HAH ISOLATED FORM'
let s:d[0xFC02]='ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH MEEM ISOLATED FORM'
let s:d[0xFC03]='ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH ALEF MAKSURA ISOLATED FORM'
let s:d[0xFC04]='ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH YEH ISOLATED FORM'
let s:d[0xFC05]='ARABIC LIGATURE BEH WITH JEEM ISOLATED FORM'
let s:d[0xFC06]='ARABIC LIGATURE BEH WITH HAH ISOLATED FORM'
let s:d[0xFC07]='ARABIC LIGATURE BEH WITH KHAH ISOLATED FORM'
let s:d[0xFC08]='ARABIC LIGATURE BEH WITH MEEM ISOLATED FORM'
let s:d[0xFC09]='ARABIC LIGATURE BEH WITH ALEF MAKSURA ISOLATED FORM'
let s:d[0xFC0A]='ARABIC LIGATURE BEH WITH YEH ISOLATED FORM'
let s:d[0xFC0B]='ARABIC LIGATURE TEH WITH JEEM ISOLATED FORM'
let s:d[0xFC0C]='ARABIC LIGATURE TEH WITH HAH ISOLATED FORM'
let s:d[0xFC0D]='ARABIC LIGATURE TEH WITH KHAH ISOLATED FORM'
let s:d[0xFC0E]='ARABIC LIGATURE TEH WITH MEEM ISOLATED FORM'
let s:d[0xFC0F]='ARABIC LIGATURE TEH WITH ALEF MAKSURA ISOLATED FORM'
let s:d[0xFC10]='ARABIC LIGATURE TEH WITH YEH ISOLATED FORM'
let s:d[0xFC11]='ARABIC LIGATURE THEH WITH JEEM ISOLATED FORM'
let s:d[0xFC12]='ARABIC LIGATURE THEH WITH MEEM ISOLATED FORM'
let s:d[0xFC13]='ARABIC LIGATURE THEH WITH ALEF MAKSURA ISOLATED FORM'
let s:d[0xFC14]='ARABIC LIGATURE THEH WITH YEH ISOLATED FORM'
let s:d[0xFC15]='ARABIC LIGATURE JEEM WITH HAH ISOLATED FORM'
let s:d[0xFC16]='ARABIC LIGATURE JEEM WITH MEEM ISOLATED FORM'
let s:d[0xFC17]='ARABIC LIGATURE HAH WITH JEEM ISOLATED FORM'
let s:d[0xFC18]='ARABIC LIGATURE HAH WITH MEEM ISOLATED FORM'
let s:d[0xFC19]='ARABIC LIGATURE KHAH WITH JEEM ISOLATED FORM'
let s:d[0xFC1A]='ARABIC LIGATURE KHAH WITH HAH ISOLATED FORM'
let s:d[0xFC1B]='ARABIC LIGATURE KHAH WITH MEEM ISOLATED FORM'
let s:d[0xFC1C]='ARABIC LIGATURE SEEN WITH JEEM ISOLATED FORM'
let s:d[0xFC1D]='ARABIC LIGATURE SEEN WITH HAH ISOLATED FORM'
let s:d[0xFC1E]='ARABIC LIGATURE SEEN WITH KHAH ISOLATED FORM'
let s:d[0xFC1F]='ARABIC LIGATURE SEEN WITH MEEM ISOLATED FORM'
let s:d[0xFC20]='ARABIC LIGATURE SAD WITH HAH ISOLATED FORM'
let s:d[0xFC21]='ARABIC LIGATURE SAD WITH MEEM ISOLATED FORM'
let s:d[0xFC22]='ARABIC LIGATURE DAD WITH JEEM ISOLATED FORM'
let s:d[0xFC23]='ARABIC LIGATURE DAD WITH HAH ISOLATED FORM'
let s:d[0xFC24]='ARABIC LIGATURE DAD WITH KHAH ISOLATED FORM'
let s:d[0xFC25]='ARABIC LIGATURE DAD WITH MEEM ISOLATED FORM'
let s:d[0xFC26]='ARABIC LIGATURE TAH WITH HAH ISOLATED FORM'
let s:d[0xFC27]='ARABIC LIGATURE TAH WITH MEEM ISOLATED FORM'
let s:d[0xFC28]='ARABIC LIGATURE ZAH WITH MEEM ISOLATED FORM'
let s:d[0xFC29]='ARABIC LIGATURE AIN WITH JEEM ISOLATED FORM'
let s:d[0xFC2A]='ARABIC LIGATURE AIN WITH MEEM ISOLATED FORM'
let s:d[0xFC2B]='ARABIC LIGATURE GHAIN WITH JEEM ISOLATED FORM'
let s:d[0xFC2C]='ARABIC LIGATURE GHAIN WITH MEEM ISOLATED FORM'
let s:d[0xFC2D]='ARABIC LIGATURE FEH WITH JEEM ISOLATED FORM'
let s:d[0xFC2E]='ARABIC LIGATURE FEH WITH HAH ISOLATED FORM'
let s:d[0xFC2F]='ARABIC LIGATURE FEH WITH KHAH ISOLATED FORM'
let s:d[0xFC30]='ARABIC LIGATURE FEH WITH MEEM ISOLATED FORM'
let s:d[0xFC31]='ARABIC LIGATURE FEH WITH ALEF MAKSURA ISOLATED FORM'
let s:d[0xFC32]='ARABIC LIGATURE FEH WITH YEH ISOLATED FORM'
let s:d[0xFC33]='ARABIC LIGATURE QAF WITH HAH ISOLATED FORM'
let s:d[0xFC34]='ARABIC LIGATURE QAF WITH MEEM ISOLATED FORM'
let s:d[0xFC35]='ARABIC LIGATURE QAF WITH ALEF MAKSURA ISOLATED FORM'
let s:d[0xFC36]='ARABIC LIGATURE QAF WITH YEH ISOLATED FORM'
let s:d[0xFC37]='ARABIC LIGATURE KAF WITH ALEF ISOLATED FORM'
let s:d[0xFC38]='ARABIC LIGATURE KAF WITH JEEM ISOLATED FORM'
let s:d[0xFC39]='ARABIC LIGATURE KAF WITH HAH ISOLATED FORM'
let s:d[0xFC3A]='ARABIC LIGATURE KAF WITH KHAH ISOLATED FORM'
let s:d[0xFC3B]='ARABIC LIGATURE KAF WITH LAM ISOLATED FORM'
let s:d[0xFC3C]='ARABIC LIGATURE KAF WITH MEEM ISOLATED FORM'
let s:d[0xFC3D]='ARABIC LIGATURE KAF WITH ALEF MAKSURA ISOLATED FORM'
let s:d[0xFC3E]='ARABIC LIGATURE KAF WITH YEH ISOLATED FORM'
let s:d[0xFC3F]='ARABIC LIGATURE LAM WITH JEEM ISOLATED FORM'
let s:d[0xFC40]='ARABIC LIGATURE LAM WITH HAH ISOLATED FORM'
let s:d[0xFC41]='ARABIC LIGATURE LAM WITH KHAH ISOLATED FORM'
let s:d[0xFC42]='ARABIC LIGATURE LAM WITH MEEM ISOLATED FORM'
let s:d[0xFC43]='ARABIC LIGATURE LAM WITH ALEF MAKSURA ISOLATED FORM'
let s:d[0xFC44]='ARABIC LIGATURE LAM WITH YEH ISOLATED FORM'
let s:d[0xFC45]='ARABIC LIGATURE MEEM WITH JEEM ISOLATED FORM'
let s:d[0xFC46]='ARABIC LIGATURE MEEM WITH HAH ISOLATED FORM'
let s:d[0xFC47]='ARABIC LIGATURE MEEM WITH KHAH ISOLATED FORM'
let s:d[0xFC48]='ARABIC LIGATURE MEEM WITH MEEM ISOLATED FORM'
let s:d[0xFC49]='ARABIC LIGATURE MEEM WITH ALEF MAKSURA ISOLATED FORM'
let s:d[0xFC4A]='ARABIC LIGATURE MEEM WITH YEH ISOLATED FORM'
let s:d[0xFC4B]='ARABIC LIGATURE NOON WITH JEEM ISOLATED FORM'
let s:d[0xFC4C]='ARABIC LIGATURE NOON WITH HAH ISOLATED FORM'
let s:d[0xFC4D]='ARABIC LIGATURE NOON WITH KHAH ISOLATED FORM'
let s:d[0xFC4E]='ARABIC LIGATURE NOON WITH MEEM ISOLATED FORM'
let s:d[0xFC4F]='ARABIC LIGATURE NOON WITH ALEF MAKSURA ISOLATED FORM'
let s:d[0xFC50]='ARABIC LIGATURE NOON WITH YEH ISOLATED FORM'
let s:d[0xFC51]='ARABIC LIGATURE HEH WITH JEEM ISOLATED FORM'
let s:d[0xFC52]='ARABIC LIGATURE HEH WITH MEEM ISOLATED FORM'
let s:d[0xFC53]='ARABIC LIGATURE HEH WITH ALEF MAKSURA ISOLATED FORM'
let s:d[0xFC54]='ARABIC LIGATURE HEH WITH YEH ISOLATED FORM'
let s:d[0xFC55]='ARABIC LIGATURE YEH WITH JEEM ISOLATED FORM'
let s:d[0xFC56]='ARABIC LIGATURE YEH WITH HAH ISOLATED FORM'
let s:d[0xFC57]='ARABIC LIGATURE YEH WITH KHAH ISOLATED FORM'
let s:d[0xFC58]='ARABIC LIGATURE YEH WITH MEEM ISOLATED FORM'
let s:d[0xFC59]='ARABIC LIGATURE YEH WITH ALEF MAKSURA ISOLATED FORM'
let s:d[0xFC5A]='ARABIC LIGATURE YEH WITH YEH ISOLATED FORM'
let s:d[0xFC5B]='ARABIC LIGATURE THAL WITH SUPERSCRIPT ALEF ISOLATED FORM'
let s:d[0xFC5C]='ARABIC LIGATURE REH WITH SUPERSCRIPT ALEF ISOLATED FORM'
let s:d[0xFC5D]='ARABIC LIGATURE ALEF MAKSURA WITH SUPERSCRIPT ALEF ISOLATED FORM'
let s:d[0xFC5E]='ARABIC LIGATURE SHADDA WITH DAMMATAN ISOLATED FORM'
let s:d[0xFC5F]='ARABIC LIGATURE SHADDA WITH KASRATAN ISOLATED FORM'
let s:d[0xFC60]='ARABIC LIGATURE SHADDA WITH FATHA ISOLATED FORM'
let s:d[0xFC61]='ARABIC LIGATURE SHADDA WITH DAMMA ISOLATED FORM'
let s:d[0xFC62]='ARABIC LIGATURE SHADDA WITH KASRA ISOLATED FORM'
let s:d[0xFC63]='ARABIC LIGATURE SHADDA WITH SUPERSCRIPT ALEF ISOLATED FORM'
let s:d[0xFC64]='ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH REH FINAL FORM'
let s:d[0xFC65]='ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH ZAIN FINAL FORM'
let s:d[0xFC66]='ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH MEEM FINAL FORM'
let s:d[0xFC67]='ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH NOON FINAL FORM'
let s:d[0xFC68]='ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH ALEF MAKSURA FINAL FORM'
let s:d[0xFC69]='ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH YEH FINAL FORM'
let s:d[0xFC6A]='ARABIC LIGATURE BEH WITH REH FINAL FORM'
let s:d[0xFC6B]='ARABIC LIGATURE BEH WITH ZAIN FINAL FORM'
let s:d[0xFC6C]='ARABIC LIGATURE BEH WITH MEEM FINAL FORM'
let s:d[0xFC6D]='ARABIC LIGATURE BEH WITH NOON FINAL FORM'
let s:d[0xFC6E]='ARABIC LIGATURE BEH WITH ALEF MAKSURA FINAL FORM'
let s:d[0xFC6F]='ARABIC LIGATURE BEH WITH YEH FINAL FORM'
let s:d[0xFC70]='ARABIC LIGATURE TEH WITH REH FINAL FORM'
let s:d[0xFC71]='ARABIC LIGATURE TEH WITH ZAIN FINAL FORM'
let s:d[0xFC72]='ARABIC LIGATURE TEH WITH MEEM FINAL FORM'
let s:d[0xFC73]='ARABIC LIGATURE TEH WITH NOON FINAL FORM'
let s:d[0xFC74]='ARABIC LIGATURE TEH WITH ALEF MAKSURA FINAL FORM'
let s:d[0xFC75]='ARABIC LIGATURE TEH WITH YEH FINAL FORM'
let s:d[0xFC76]='ARABIC LIGATURE THEH WITH REH FINAL FORM'
let s:d[0xFC77]='ARABIC LIGATURE THEH WITH ZAIN FINAL FORM'
let s:d[0xFC78]='ARABIC LIGATURE THEH WITH MEEM FINAL FORM'
let s:d[0xFC79]='ARABIC LIGATURE THEH WITH NOON FINAL FORM'
let s:d[0xFC7A]='ARABIC LIGATURE THEH WITH ALEF MAKSURA FINAL FORM'
let s:d[0xFC7B]='ARABIC LIGATURE THEH WITH YEH FINAL FORM'
let s:d[0xFC7C]='ARABIC LIGATURE FEH WITH ALEF MAKSURA FINAL FORM'
let s:d[0xFC7D]='ARABIC LIGATURE FEH WITH YEH FINAL FORM'
let s:d[0xFC7E]='ARABIC LIGATURE QAF WITH ALEF MAKSURA FINAL FORM'
let s:d[0xFC7F]='ARABIC LIGATURE QAF WITH YEH FINAL FORM'
let s:d[0xFC80]='ARABIC LIGATURE KAF WITH ALEF FINAL FORM'
let s:d[0xFC81]='ARABIC LIGATURE KAF WITH LAM FINAL FORM'
let s:d[0xFC82]='ARABIC LIGATURE KAF WITH MEEM FINAL FORM'
let s:d[0xFC83]='ARABIC LIGATURE KAF WITH ALEF MAKSURA FINAL FORM'
let s:d[0xFC84]='ARABIC LIGATURE KAF WITH YEH FINAL FORM'
let s:d[0xFC85]='ARABIC LIGATURE LAM WITH MEEM FINAL FORM'
let s:d[0xFC86]='ARABIC LIGATURE LAM WITH ALEF MAKSURA FINAL FORM'
let s:d[0xFC87]='ARABIC LIGATURE LAM WITH YEH FINAL FORM'
let s:d[0xFC88]='ARABIC LIGATURE MEEM WITH ALEF FINAL FORM'
let s:d[0xFC89]='ARABIC LIGATURE MEEM WITH MEEM FINAL FORM'
let s:d[0xFC8A]='ARABIC LIGATURE NOON WITH REH FINAL FORM'
let s:d[0xFC8B]='ARABIC LIGATURE NOON WITH ZAIN FINAL FORM'
let s:d[0xFC8C]='ARABIC LIGATURE NOON WITH MEEM FINAL FORM'
let s:d[0xFC8D]='ARABIC LIGATURE NOON WITH NOON FINAL FORM'
let s:d[0xFC8E]='ARABIC LIGATURE NOON WITH ALEF MAKSURA FINAL FORM'
let s:d[0xFC8F]='ARABIC LIGATURE NOON WITH YEH FINAL FORM'
let s:d[0xFC90]='ARABIC LIGATURE ALEF MAKSURA WITH SUPERSCRIPT ALEF FINAL FORM'
let s:d[0xFC91]='ARABIC LIGATURE YEH WITH REH FINAL FORM'
let s:d[0xFC92]='ARABIC LIGATURE YEH WITH ZAIN FINAL FORM'
let s:d[0xFC93]='ARABIC LIGATURE YEH WITH MEEM FINAL FORM'
let s:d[0xFC94]='ARABIC LIGATURE YEH WITH NOON FINAL FORM'
let s:d[0xFC95]='ARABIC LIGATURE YEH WITH ALEF MAKSURA FINAL FORM'
let s:d[0xFC96]='ARABIC LIGATURE YEH WITH YEH FINAL FORM'
let s:d[0xFC97]='ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH JEEM INITIAL FORM'
let s:d[0xFC98]='ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH HAH INITIAL FORM'
let s:d[0xFC99]='ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH KHAH INITIAL FORM'
let s:d[0xFC9A]='ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH MEEM INITIAL FORM'
let s:d[0xFC9B]='ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH HEH INITIAL FORM'
let s:d[0xFC9C]='ARABIC LIGATURE BEH WITH JEEM INITIAL FORM'
let s:d[0xFC9D]='ARABIC LIGATURE BEH WITH HAH INITIAL FORM'
let s:d[0xFC9E]='ARABIC LIGATURE BEH WITH KHAH INITIAL FORM'
let s:d[0xFC9F]='ARABIC LIGATURE BEH WITH MEEM INITIAL FORM'
let s:d[0xFCA0]='ARABIC LIGATURE BEH WITH HEH INITIAL FORM'
let s:d[0xFCA1]='ARABIC LIGATURE TEH WITH JEEM INITIAL FORM'
let s:d[0xFCA2]='ARABIC LIGATURE TEH WITH HAH INITIAL FORM'
let s:d[0xFCA3]='ARABIC LIGATURE TEH WITH KHAH INITIAL FORM'
let s:d[0xFCA4]='ARABIC LIGATURE TEH WITH MEEM INITIAL FORM'
let s:d[0xFCA5]='ARABIC LIGATURE TEH WITH HEH INITIAL FORM'
let s:d[0xFCA6]='ARABIC LIGATURE THEH WITH MEEM INITIAL FORM'
let s:d[0xFCA7]='ARABIC LIGATURE JEEM WITH HAH INITIAL FORM'
let s:d[0xFCA8]='ARABIC LIGATURE JEEM WITH MEEM INITIAL FORM'
let s:d[0xFCA9]='ARABIC LIGATURE HAH WITH JEEM INITIAL FORM'
let s:d[0xFCAA]='ARABIC LIGATURE HAH WITH MEEM INITIAL FORM'
let s:d[0xFCAB]='ARABIC LIGATURE KHAH WITH JEEM INITIAL FORM'
let s:d[0xFCAC]='ARABIC LIGATURE KHAH WITH MEEM INITIAL FORM'
let s:d[0xFCAD]='ARABIC LIGATURE SEEN WITH JEEM INITIAL FORM'
let s:d[0xFCAE]='ARABIC LIGATURE SEEN WITH HAH INITIAL FORM'
let s:d[0xFCAF]='ARABIC LIGATURE SEEN WITH KHAH INITIAL FORM'
let s:d[0xFCB0]='ARABIC LIGATURE SEEN WITH MEEM INITIAL FORM'
let s:d[0xFCB1]='ARABIC LIGATURE SAD WITH HAH INITIAL FORM'
let s:d[0xFCB2]='ARABIC LIGATURE SAD WITH KHAH INITIAL FORM'
let s:d[0xFCB3]='ARABIC LIGATURE SAD WITH MEEM INITIAL FORM'
let s:d[0xFCB4]='ARABIC LIGATURE DAD WITH JEEM INITIAL FORM'
let s:d[0xFCB5]='ARABIC LIGATURE DAD WITH HAH INITIAL FORM'
let s:d[0xFCB6]='ARABIC LIGATURE DAD WITH KHAH INITIAL FORM'
let s:d[0xFCB7]='ARABIC LIGATURE DAD WITH MEEM INITIAL FORM'
let s:d[0xFCB8]='ARABIC LIGATURE TAH WITH HAH INITIAL FORM'
let s:d[0xFCB9]='ARABIC LIGATURE ZAH WITH MEEM INITIAL FORM'
let s:d[0xFCBA]='ARABIC LIGATURE AIN WITH JEEM INITIAL FORM'
let s:d[0xFCBB]='ARABIC LIGATURE AIN WITH MEEM INITIAL FORM'
let s:d[0xFCBC]='ARABIC LIGATURE GHAIN WITH JEEM INITIAL FORM'
let s:d[0xFCBD]='ARABIC LIGATURE GHAIN WITH MEEM INITIAL FORM'
let s:d[0xFCBE]='ARABIC LIGATURE FEH WITH JEEM INITIAL FORM'
let s:d[0xFCBF]='ARABIC LIGATURE FEH WITH HAH INITIAL FORM'
let s:d[0xFCC0]='ARABIC LIGATURE FEH WITH KHAH INITIAL FORM'
let s:d[0xFCC1]='ARABIC LIGATURE FEH WITH MEEM INITIAL FORM'
let s:d[0xFCC2]='ARABIC LIGATURE QAF WITH HAH INITIAL FORM'
let s:d[0xFCC3]='ARABIC LIGATURE QAF WITH MEEM INITIAL FORM'
let s:d[0xFCC4]='ARABIC LIGATURE KAF WITH JEEM INITIAL FORM'
let s:d[0xFCC5]='ARABIC LIGATURE KAF WITH HAH INITIAL FORM'
let s:d[0xFCC6]='ARABIC LIGATURE KAF WITH KHAH INITIAL FORM'
let s:d[0xFCC7]='ARABIC LIGATURE KAF WITH LAM INITIAL FORM'
let s:d[0xFCC8]='ARABIC LIGATURE KAF WITH MEEM INITIAL FORM'
let s:d[0xFCC9]='ARABIC LIGATURE LAM WITH JEEM INITIAL FORM'
let s:d[0xFCCA]='ARABIC LIGATURE LAM WITH HAH INITIAL FORM'
let s:d[0xFCCB]='ARABIC LIGATURE LAM WITH KHAH INITIAL FORM'
let s:d[0xFCCC]='ARABIC LIGATURE LAM WITH MEEM INITIAL FORM'
let s:d[0xFCCD]='ARABIC LIGATURE LAM WITH HEH INITIAL FORM'
let s:d[0xFCCE]='ARABIC LIGATURE MEEM WITH JEEM INITIAL FORM'
let s:d[0xFCCF]='ARABIC LIGATURE MEEM WITH HAH INITIAL FORM'
let s:d[0xFCD0]='ARABIC LIGATURE MEEM WITH KHAH INITIAL FORM'
let s:d[0xFCD1]='ARABIC LIGATURE MEEM WITH MEEM INITIAL FORM'
let s:d[0xFCD2]='ARABIC LIGATURE NOON WITH JEEM INITIAL FORM'
let s:d[0xFCD3]='ARABIC LIGATURE NOON WITH HAH INITIAL FORM'
let s:d[0xFCD4]='ARABIC LIGATURE NOON WITH KHAH INITIAL FORM'
let s:d[0xFCD5]='ARABIC LIGATURE NOON WITH MEEM INITIAL FORM'
let s:d[0xFCD6]='ARABIC LIGATURE NOON WITH HEH INITIAL FORM'
let s:d[0xFCD7]='ARABIC LIGATURE HEH WITH JEEM INITIAL FORM'
let s:d[0xFCD8]='ARABIC LIGATURE HEH WITH MEEM INITIAL FORM'
let s:d[0xFCD9]='ARABIC LIGATURE HEH WITH SUPERSCRIPT ALEF INITIAL FORM'
let s:d[0xFCDA]='ARABIC LIGATURE YEH WITH JEEM INITIAL FORM'
let s:d[0xFCDB]='ARABIC LIGATURE YEH WITH HAH INITIAL FORM'
let s:d[0xFCDC]='ARABIC LIGATURE YEH WITH KHAH INITIAL FORM'
let s:d[0xFCDD]='ARABIC LIGATURE YEH WITH MEEM INITIAL FORM'
let s:d[0xFCDE]='ARABIC LIGATURE YEH WITH HEH INITIAL FORM'
let s:d[0xFCDF]='ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH MEEM MEDIAL FORM'
let s:d[0xFCE0]='ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH HEH MEDIAL FORM'
let s:d[0xFCE1]='ARABIC LIGATURE BEH WITH MEEM MEDIAL FORM'
let s:d[0xFCE2]='ARABIC LIGATURE BEH WITH HEH MEDIAL FORM'
let s:d[0xFCE3]='ARABIC LIGATURE TEH WITH MEEM MEDIAL FORM'
let s:d[0xFCE4]='ARABIC LIGATURE TEH WITH HEH MEDIAL FORM'
let s:d[0xFCE5]='ARABIC LIGATURE THEH WITH MEEM MEDIAL FORM'
let s:d[0xFCE6]='ARABIC LIGATURE THEH WITH HEH MEDIAL FORM'
let s:d[0xFCE7]='ARABIC LIGATURE SEEN WITH MEEM MEDIAL FORM'
let s:d[0xFCE8]='ARABIC LIGATURE SEEN WITH HEH MEDIAL FORM'
let s:d[0xFCE9]='ARABIC LIGATURE SHEEN WITH MEEM MEDIAL FORM'
let s:d[0xFCEA]='ARABIC LIGATURE SHEEN WITH HEH MEDIAL FORM'
let s:d[0xFCEB]='ARABIC LIGATURE KAF WITH LAM MEDIAL FORM'
let s:d[0xFCEC]='ARABIC LIGATURE KAF WITH MEEM MEDIAL FORM'
let s:d[0xFCED]='ARABIC LIGATURE LAM WITH MEEM MEDIAL FORM'
let s:d[0xFCEE]='ARABIC LIGATURE NOON WITH MEEM MEDIAL FORM'
let s:d[0xFCEF]='ARABIC LIGATURE NOON WITH HEH MEDIAL FORM'
let s:d[0xFCF0]='ARABIC LIGATURE YEH WITH MEEM MEDIAL FORM'
let s:d[0xFCF1]='ARABIC LIGATURE YEH WITH HEH MEDIAL FORM'
let s:d[0xFCF2]='ARABIC LIGATURE SHADDA WITH FATHA MEDIAL FORM'
let s:d[0xFCF3]='ARABIC LIGATURE SHADDA WITH DAMMA MEDIAL FORM'
let s:d[0xFCF4]='ARABIC LIGATURE SHADDA WITH KASRA MEDIAL FORM'
let s:d[0xFCF5]='ARABIC LIGATURE TAH WITH ALEF MAKSURA ISOLATED FORM'
let s:d[0xFCF6]='ARABIC LIGATURE TAH WITH YEH ISOLATED FORM'
let s:d[0xFCF7]='ARABIC LIGATURE AIN WITH ALEF MAKSURA ISOLATED FORM'
let s:d[0xFCF8]='ARABIC LIGATURE AIN WITH YEH ISOLATED FORM'
let s:d[0xFCF9]='ARABIC LIGATURE GHAIN WITH ALEF MAKSURA ISOLATED FORM'
let s:d[0xFCFA]='ARABIC LIGATURE GHAIN WITH YEH ISOLATED FORM'
let s:d[0xFCFB]='ARABIC LIGATURE SEEN WITH ALEF MAKSURA ISOLATED FORM'
let s:d[0xFCFC]='ARABIC LIGATURE SEEN WITH YEH ISOLATED FORM'
let s:d[0xFCFD]='ARABIC LIGATURE SHEEN WITH ALEF MAKSURA ISOLATED FORM'
let s:d[0xFCFE]='ARABIC LIGATURE SHEEN WITH YEH ISOLATED FORM'
let s:d[0xFCFF]='ARABIC LIGATURE HAH WITH ALEF MAKSURA ISOLATED FORM'
let s:d[0xFD00]='ARABIC LIGATURE HAH WITH YEH ISOLATED FORM'
let s:d[0xFD01]='ARABIC LIGATURE JEEM WITH ALEF MAKSURA ISOLATED FORM'
let s:d[0xFD02]='ARABIC LIGATURE JEEM WITH YEH ISOLATED FORM'
let s:d[0xFD03]='ARABIC LIGATURE KHAH WITH ALEF MAKSURA ISOLATED FORM'
let s:d[0xFD04]='ARABIC LIGATURE KHAH WITH YEH ISOLATED FORM'
let s:d[0xFD05]='ARABIC LIGATURE SAD WITH ALEF MAKSURA ISOLATED FORM'
let s:d[0xFD06]='ARABIC LIGATURE SAD WITH YEH ISOLATED FORM'
let s:d[0xFD07]='ARABIC LIGATURE DAD WITH ALEF MAKSURA ISOLATED FORM'
let s:d[0xFD08]='ARABIC LIGATURE DAD WITH YEH ISOLATED FORM'
let s:d[0xFD09]='ARABIC LIGATURE SHEEN WITH JEEM ISOLATED FORM'
let s:d[0xFD0A]='ARABIC LIGATURE SHEEN WITH HAH ISOLATED FORM'
let s:d[0xFD0B]='ARABIC LIGATURE SHEEN WITH KHAH ISOLATED FORM'
let s:d[0xFD0C]='ARABIC LIGATURE SHEEN WITH MEEM ISOLATED FORM'
let s:d[0xFD0D]='ARABIC LIGATURE SHEEN WITH REH ISOLATED FORM'
let s:d[0xFD0E]='ARABIC LIGATURE SEEN WITH REH ISOLATED FORM'
let s:d[0xFD0F]='ARABIC LIGATURE SAD WITH REH ISOLATED FORM'
let s:d[0xFD10]='ARABIC LIGATURE DAD WITH REH ISOLATED FORM'
let s:d[0xFD11]='ARABIC LIGATURE TAH WITH ALEF MAKSURA FINAL FORM'
let s:d[0xFD12]='ARABIC LIGATURE TAH WITH YEH FINAL FORM'
let s:d[0xFD13]='ARABIC LIGATURE AIN WITH ALEF MAKSURA FINAL FORM'
let s:d[0xFD14]='ARABIC LIGATURE AIN WITH YEH FINAL FORM'
let s:d[0xFD15]='ARABIC LIGATURE GHAIN WITH ALEF MAKSURA FINAL FORM'
let s:d[0xFD16]='ARABIC LIGATURE GHAIN WITH YEH FINAL FORM'
let s:d[0xFD17]='ARABIC LIGATURE SEEN WITH ALEF MAKSURA FINAL FORM'
let s:d[0xFD18]='ARABIC LIGATURE SEEN WITH YEH FINAL FORM'
let s:d[0xFD19]='ARABIC LIGATURE SHEEN WITH ALEF MAKSURA FINAL FORM'
let s:d[0xFD1A]='ARABIC LIGATURE SHEEN WITH YEH FINAL FORM'
let s:d[0xFD1B]='ARABIC LIGATURE HAH WITH ALEF MAKSURA FINAL FORM'
let s:d[0xFD1C]='ARABIC LIGATURE HAH WITH YEH FINAL FORM'
let s:d[0xFD1D]='ARABIC LIGATURE JEEM WITH ALEF MAKSURA FINAL FORM'
let s:d[0xFD1E]='ARABIC LIGATURE JEEM WITH YEH FINAL FORM'
let s:d[0xFD1F]='ARABIC LIGATURE KHAH WITH ALEF MAKSURA FINAL FORM'
let s:d[0xFD20]='ARABIC LIGATURE KHAH WITH YEH FINAL FORM'
let s:d[0xFD21]='ARABIC LIGATURE SAD WITH ALEF MAKSURA FINAL FORM'
let s:d[0xFD22]='ARABIC LIGATURE SAD WITH YEH FINAL FORM'
let s:d[0xFD23]='ARABIC LIGATURE DAD WITH ALEF MAKSURA FINAL FORM'
let s:d[0xFD24]='ARABIC LIGATURE DAD WITH YEH FINAL FORM'
let s:d[0xFD25]='ARABIC LIGATURE SHEEN WITH JEEM FINAL FORM'
let s:d[0xFD26]='ARABIC LIGATURE SHEEN WITH HAH FINAL FORM'
let s:d[0xFD27]='ARABIC LIGATURE SHEEN WITH KHAH FINAL FORM'
let s:d[0xFD28]='ARABIC LIGATURE SHEEN WITH MEEM FINAL FORM'
let s:d[0xFD29]='ARABIC LIGATURE SHEEN WITH REH FINAL FORM'
let s:d[0xFD2A]='ARABIC LIGATURE SEEN WITH REH FINAL FORM'
let s:d[0xFD2B]='ARABIC LIGATURE SAD WITH REH FINAL FORM'
let s:d[0xFD2C]='ARABIC LIGATURE DAD WITH REH FINAL FORM'
let s:d[0xFD2D]='ARABIC LIGATURE SHEEN WITH JEEM INITIAL FORM'
let s:d[0xFD2E]='ARABIC LIGATURE SHEEN WITH HAH INITIAL FORM'
let s:d[0xFD2F]='ARABIC LIGATURE SHEEN WITH KHAH INITIAL FORM'
let s:d[0xFD30]='ARABIC LIGATURE SHEEN WITH MEEM INITIAL FORM'
let s:d[0xFD31]='ARABIC LIGATURE SEEN WITH HEH INITIAL FORM'
let s:d[0xFD32]='ARABIC LIGATURE SHEEN WITH HEH INITIAL FORM'
let s:d[0xFD33]='ARABIC LIGATURE TAH WITH MEEM INITIAL FORM'
let s:d[0xFD34]='ARABIC LIGATURE SEEN WITH JEEM MEDIAL FORM'
let s:d[0xFD35]='ARABIC LIGATURE SEEN WITH HAH MEDIAL FORM'
let s:d[0xFD36]='ARABIC LIGATURE SEEN WITH KHAH MEDIAL FORM'
let s:d[0xFD37]='ARABIC LIGATURE SHEEN WITH JEEM MEDIAL FORM'
let s:d[0xFD38]='ARABIC LIGATURE SHEEN WITH HAH MEDIAL FORM'
let s:d[0xFD39]='ARABIC LIGATURE SHEEN WITH KHAH MEDIAL FORM'
let s:d[0xFD3A]='ARABIC LIGATURE TAH WITH MEEM MEDIAL FORM'
let s:d[0xFD3B]='ARABIC LIGATURE ZAH WITH MEEM MEDIAL FORM'
let s:d[0xFD3C]='ARABIC LIGATURE ALEF WITH FATHATAN FINAL FORM'
let s:d[0xFD3D]='ARABIC LIGATURE ALEF WITH FATHATAN ISOLATED FORM'
let s:d[0xFD3E]='ORNATE LEFT PARENTHESIS'
let s:d[0xFD3F]='ORNATE RIGHT PARENTHESIS'
let s:d[0xFD50]='ARABIC LIGATURE TEH WITH JEEM WITH MEEM INITIAL FORM'
let s:d[0xFD51]='ARABIC LIGATURE TEH WITH HAH WITH JEEM FINAL FORM'
let s:d[0xFD52]='ARABIC LIGATURE TEH WITH HAH WITH JEEM INITIAL FORM'
let s:d[0xFD53]='ARABIC LIGATURE TEH WITH HAH WITH MEEM INITIAL FORM'
let s:d[0xFD54]='ARABIC LIGATURE TEH WITH KHAH WITH MEEM INITIAL FORM'
let s:d[0xFD55]='ARABIC LIGATURE TEH WITH MEEM WITH JEEM INITIAL FORM'
let s:d[0xFD56]='ARABIC LIGATURE TEH WITH MEEM WITH HAH INITIAL FORM'
let s:d[0xFD57]='ARABIC LIGATURE TEH WITH MEEM WITH KHAH INITIAL FORM'
let s:d[0xFD58]='ARABIC LIGATURE JEEM WITH MEEM WITH HAH FINAL FORM'
let s:d[0xFD59]='ARABIC LIGATURE JEEM WITH MEEM WITH HAH INITIAL FORM'
let s:d[0xFD5A]='ARABIC LIGATURE HAH WITH MEEM WITH YEH FINAL FORM'
let s:d[0xFD5B]='ARABIC LIGATURE HAH WITH MEEM WITH ALEF MAKSURA FINAL FORM'
let s:d[0xFD5C]='ARABIC LIGATURE SEEN WITH HAH WITH JEEM INITIAL FORM'
let s:d[0xFD5D]='ARABIC LIGATURE SEEN WITH JEEM WITH HAH INITIAL FORM'
let s:d[0xFD5E]='ARABIC LIGATURE SEEN WITH JEEM WITH ALEF MAKSURA FINAL FORM'
let s:d[0xFD5F]='ARABIC LIGATURE SEEN WITH MEEM WITH HAH FINAL FORM'
let s:d[0xFD60]='ARABIC LIGATURE SEEN WITH MEEM WITH HAH INITIAL FORM'
let s:d[0xFD61]='ARABIC LIGATURE SEEN WITH MEEM WITH JEEM INITIAL FORM'
let s:d[0xFD62]='ARABIC LIGATURE SEEN WITH MEEM WITH MEEM FINAL FORM'
let s:d[0xFD63]='ARABIC LIGATURE SEEN WITH MEEM WITH MEEM INITIAL FORM'
let s:d[0xFD64]='ARABIC LIGATURE SAD WITH HAH WITH HAH FINAL FORM'
let s:d[0xFD65]='ARABIC LIGATURE SAD WITH HAH WITH HAH INITIAL FORM'
let s:d[0xFD66]='ARABIC LIGATURE SAD WITH MEEM WITH MEEM FINAL FORM'
let s:d[0xFD67]='ARABIC LIGATURE SHEEN WITH HAH WITH MEEM FINAL FORM'
let s:d[0xFD68]='ARABIC LIGATURE SHEEN WITH HAH WITH MEEM INITIAL FORM'
let s:d[0xFD69]='ARABIC LIGATURE SHEEN WITH JEEM WITH YEH FINAL FORM'
let s:d[0xFD6A]='ARABIC LIGATURE SHEEN WITH MEEM WITH KHAH FINAL FORM'
let s:d[0xFD6B]='ARABIC LIGATURE SHEEN WITH MEEM WITH KHAH INITIAL FORM'
let s:d[0xFD6C]='ARABIC LIGATURE SHEEN WITH MEEM WITH MEEM FINAL FORM'
let s:d[0xFD6D]='ARABIC LIGATURE SHEEN WITH MEEM WITH MEEM INITIAL FORM'
let s:d[0xFD6E]='ARABIC LIGATURE DAD WITH HAH WITH ALEF MAKSURA FINAL FORM'
let s:d[0xFD6F]='ARABIC LIGATURE DAD WITH KHAH WITH MEEM FINAL FORM'
let s:d[0xFD70]='ARABIC LIGATURE DAD WITH KHAH WITH MEEM INITIAL FORM'
let s:d[0xFD71]='ARABIC LIGATURE TAH WITH MEEM WITH HAH FINAL FORM'
let s:d[0xFD72]='ARABIC LIGATURE TAH WITH MEEM WITH HAH INITIAL FORM'
let s:d[0xFD73]='ARABIC LIGATURE TAH WITH MEEM WITH MEEM INITIAL FORM'
let s:d[0xFD74]='ARABIC LIGATURE TAH WITH MEEM WITH YEH FINAL FORM'
let s:d[0xFD75]='ARABIC LIGATURE AIN WITH JEEM WITH MEEM FINAL FORM'
let s:d[0xFD76]='ARABIC LIGATURE AIN WITH MEEM WITH MEEM FINAL FORM'
let s:d[0xFD77]='ARABIC LIGATURE AIN WITH MEEM WITH MEEM INITIAL FORM'
let s:d[0xFD78]='ARABIC LIGATURE AIN WITH MEEM WITH ALEF MAKSURA FINAL FORM'
let s:d[0xFD79]='ARABIC LIGATURE GHAIN WITH MEEM WITH MEEM FINAL FORM'
let s:d[0xFD7A]='ARABIC LIGATURE GHAIN WITH MEEM WITH YEH FINAL FORM'
let s:d[0xFD7B]='ARABIC LIGATURE GHAIN WITH MEEM WITH ALEF MAKSURA FINAL FORM'
let s:d[0xFD7C]='ARABIC LIGATURE FEH WITH KHAH WITH MEEM FINAL FORM'
let s:d[0xFD7D]='ARABIC LIGATURE FEH WITH KHAH WITH MEEM INITIAL FORM'
let s:d[0xFD7E]='ARABIC LIGATURE QAF WITH MEEM WITH HAH FINAL FORM'
let s:d[0xFD7F]='ARABIC LIGATURE QAF WITH MEEM WITH MEEM FINAL FORM'
let s:d[0xFD80]='ARABIC LIGATURE LAM WITH HAH WITH MEEM FINAL FORM'
let s:d[0xFD81]='ARABIC LIGATURE LAM WITH HAH WITH YEH FINAL FORM'
let s:d[0xFD82]='ARABIC LIGATURE LAM WITH HAH WITH ALEF MAKSURA FINAL FORM'
let s:d[0xFD83]='ARABIC LIGATURE LAM WITH JEEM WITH JEEM INITIAL FORM'
let s:d[0xFD84]='ARABIC LIGATURE LAM WITH JEEM WITH JEEM FINAL FORM'
let s:d[0xFD85]='ARABIC LIGATURE LAM WITH KHAH WITH MEEM FINAL FORM'
let s:d[0xFD86]='ARABIC LIGATURE LAM WITH KHAH WITH MEEM INITIAL FORM'
let s:d[0xFD87]='ARABIC LIGATURE LAM WITH MEEM WITH HAH FINAL FORM'
let s:d[0xFD88]='ARABIC LIGATURE LAM WITH MEEM WITH HAH INITIAL FORM'
let s:d[0xFD89]='ARABIC LIGATURE MEEM WITH HAH WITH JEEM INITIAL FORM'
let s:d[0xFD8A]='ARABIC LIGATURE MEEM WITH HAH WITH MEEM INITIAL FORM'
let s:d[0xFD8B]='ARABIC LIGATURE MEEM WITH HAH WITH YEH FINAL FORM'
let s:d[0xFD8C]='ARABIC LIGATURE MEEM WITH JEEM WITH HAH INITIAL FORM'
let s:d[0xFD8D]='ARABIC LIGATURE MEEM WITH JEEM WITH MEEM INITIAL FORM'
let s:d[0xFD8E]='ARABIC LIGATURE MEEM WITH KHAH WITH JEEM INITIAL FORM'
let s:d[0xFD8F]='ARABIC LIGATURE MEEM WITH KHAH WITH MEEM INITIAL FORM'
let s:d[0xFD92]='ARABIC LIGATURE MEEM WITH JEEM WITH KHAH INITIAL FORM'
let s:d[0xFD93]='ARABIC LIGATURE HEH WITH MEEM WITH JEEM INITIAL FORM'
let s:d[0xFD94]='ARABIC LIGATURE HEH WITH MEEM WITH MEEM INITIAL FORM'
let s:d[0xFD95]='ARABIC LIGATURE NOON WITH HAH WITH MEEM INITIAL FORM'
let s:d[0xFD96]='ARABIC LIGATURE NOON WITH HAH WITH ALEF MAKSURA FINAL FORM'
let s:d[0xFD97]='ARABIC LIGATURE NOON WITH JEEM WITH MEEM FINAL FORM'
let s:d[0xFD98]='ARABIC LIGATURE NOON WITH JEEM WITH MEEM INITIAL FORM'
let s:d[0xFD99]='ARABIC LIGATURE NOON WITH JEEM WITH ALEF MAKSURA FINAL FORM'
let s:d[0xFD9A]='ARABIC LIGATURE NOON WITH MEEM WITH YEH FINAL FORM'
let s:d[0xFD9B]='ARABIC LIGATURE NOON WITH MEEM WITH ALEF MAKSURA FINAL FORM'
let s:d[0xFD9C]='ARABIC LIGATURE YEH WITH MEEM WITH MEEM FINAL FORM'
let s:d[0xFD9D]='ARABIC LIGATURE YEH WITH MEEM WITH MEEM INITIAL FORM'
let s:d[0xFD9E]='ARABIC LIGATURE BEH WITH KHAH WITH YEH FINAL FORM'
let s:d[0xFD9F]='ARABIC LIGATURE TEH WITH JEEM WITH YEH FINAL FORM'
let s:d[0xFDA0]='ARABIC LIGATURE TEH WITH JEEM WITH ALEF MAKSURA FINAL FORM'
let s:d[0xFDA1]='ARABIC LIGATURE TEH WITH KHAH WITH YEH FINAL FORM'
let s:d[0xFDA2]='ARABIC LIGATURE TEH WITH KHAH WITH ALEF MAKSURA FINAL FORM'
let s:d[0xFDA3]='ARABIC LIGATURE TEH WITH MEEM WITH YEH FINAL FORM'
let s:d[0xFDA4]='ARABIC LIGATURE TEH WITH MEEM WITH ALEF MAKSURA FINAL FORM'
let s:d[0xFDA5]='ARABIC LIGATURE JEEM WITH MEEM WITH YEH FINAL FORM'
let s:d[0xFDA6]='ARABIC LIGATURE JEEM WITH HAH WITH ALEF MAKSURA FINAL FORM'
let s:d[0xFDA7]='ARABIC LIGATURE JEEM WITH MEEM WITH ALEF MAKSURA FINAL FORM'
let s:d[0xFDA8]='ARABIC LIGATURE SEEN WITH KHAH WITH ALEF MAKSURA FINAL FORM'
let s:d[0xFDA9]='ARABIC LIGATURE SAD WITH HAH WITH YEH FINAL FORM'
let s:d[0xFDAA]='ARABIC LIGATURE SHEEN WITH HAH WITH YEH FINAL FORM'
let s:d[0xFDAB]='ARABIC LIGATURE DAD WITH HAH WITH YEH FINAL FORM'
let s:d[0xFDAC]='ARABIC LIGATURE LAM WITH JEEM WITH YEH FINAL FORM'
let s:d[0xFDAD]='ARABIC LIGATURE LAM WITH MEEM WITH YEH FINAL FORM'
let s:d[0xFDAE]='ARABIC LIGATURE YEH WITH HAH WITH YEH FINAL FORM'
let s:d[0xFDAF]='ARABIC LIGATURE YEH WITH JEEM WITH YEH FINAL FORM'
let s:d[0xFDB0]='ARABIC LIGATURE YEH WITH MEEM WITH YEH FINAL FORM'
let s:d[0xFDB1]='ARABIC LIGATURE MEEM WITH MEEM WITH YEH FINAL FORM'
let s:d[0xFDB2]='ARABIC LIGATURE QAF WITH MEEM WITH YEH FINAL FORM'
let s:d[0xFDB3]='ARABIC LIGATURE NOON WITH HAH WITH YEH FINAL FORM'
let s:d[0xFDB4]='ARABIC LIGATURE QAF WITH MEEM WITH HAH INITIAL FORM'
let s:d[0xFDB5]='ARABIC LIGATURE LAM WITH HAH WITH MEEM INITIAL FORM'
let s:d[0xFDB6]='ARABIC LIGATURE AIN WITH MEEM WITH YEH FINAL FORM'
let s:d[0xFDB7]='ARABIC LIGATURE KAF WITH MEEM WITH YEH FINAL FORM'
let s:d[0xFDB8]='ARABIC LIGATURE NOON WITH JEEM WITH HAH INITIAL FORM'
let s:d[0xFDB9]='ARABIC LIGATURE MEEM WITH KHAH WITH YEH FINAL FORM'
let s:d[0xFDBA]='ARABIC LIGATURE LAM WITH JEEM WITH MEEM INITIAL FORM'
let s:d[0xFDBB]='ARABIC LIGATURE KAF WITH MEEM WITH MEEM FINAL FORM'
let s:d[0xFDBC]='ARABIC LIGATURE LAM WITH JEEM WITH MEEM FINAL FORM'
let s:d[0xFDBD]='ARABIC LIGATURE NOON WITH JEEM WITH HAH FINAL FORM'
let s:d[0xFDBE]='ARABIC LIGATURE JEEM WITH HAH WITH YEH FINAL FORM'
let s:d[0xFDBF]='ARABIC LIGATURE HAH WITH JEEM WITH YEH FINAL FORM'
let s:d[0xFDC0]='ARABIC LIGATURE MEEM WITH JEEM WITH YEH FINAL FORM'
let s:d[0xFDC1]='ARABIC LIGATURE FEH WITH MEEM WITH YEH FINAL FORM'
let s:d[0xFDC2]='ARABIC LIGATURE BEH WITH HAH WITH YEH FINAL FORM'
let s:d[0xFDC3]='ARABIC LIGATURE KAF WITH MEEM WITH MEEM INITIAL FORM'
let s:d[0xFDC4]='ARABIC LIGATURE AIN WITH JEEM WITH MEEM INITIAL FORM'
let s:d[0xFDC5]='ARABIC LIGATURE SAD WITH MEEM WITH MEEM INITIAL FORM'
let s:d[0xFDC6]='ARABIC LIGATURE SEEN WITH KHAH WITH YEH FINAL FORM'
let s:d[0xFDC7]='ARABIC LIGATURE NOON WITH JEEM WITH YEH FINAL FORM'
let s:d[0xFDD0]='<not a character>'
let s:d[0xFDD1]='<not a character>'
let s:d[0xFDD2]='<not a character>'
let s:d[0xFDD3]='<not a character>'
let s:d[0xFDD4]='<not a character>'
let s:d[0xFDD5]='<not a character>'
let s:d[0xFDD6]='<not a character>'
let s:d[0xFDD7]='<not a character>'
let s:d[0xFDD8]='<not a character>'
let s:d[0xFDD9]='<not a character>'
let s:d[0xFDDA]='<not a character>'
let s:d[0xFDDB]='<not a character>'
let s:d[0xFDDC]='<not a character>'
let s:d[0xFDDD]='<not a character>'
let s:d[0xFDDE]='<not a character>'
let s:d[0xFDDF]='<not a character>'
let s:d[0xFDE0]='<not a character>'
let s:d[0xFDE1]='<not a character>'
let s:d[0xFDE2]='<not a character>'
let s:d[0xFDE3]='<not a character>'
let s:d[0xFDE4]='<not a character>'
let s:d[0xFDE5]='<not a character>'
let s:d[0xFDE6]='<not a character>'
let s:d[0xFDE7]='<not a character>'
let s:d[0xFDE8]='<not a character>'
let s:d[0xFDE9]='<not a character>'
let s:d[0xFDEA]='<not a character>'
let s:d[0xFDEB]='<not a character>'
let s:d[0xFDEC]='<not a character>'
let s:d[0xFDED]='<not a character>'
let s:d[0xFDEE]='<not a character>'
let s:d[0xFDEF]='<not a character>'
let s:d[0xFDF0]='ARABIC LIGATURE SALLA USED AS KORANIC STOP SIGN ISOLATED FORM'
let s:d[0xFDF1]='ARABIC LIGATURE QALA USED AS KORANIC STOP SIGN ISOLATED FORM'
let s:d[0xFDF2]='ARABIC LIGATURE ALLAH ISOLATED FORM'
let s:d[0xFDF3]='ARABIC LIGATURE AKBAR ISOLATED FORM'
let s:d[0xFDF4]='ARABIC LIGATURE MOHAMMAD ISOLATED FORM'
let s:d[0xFDF5]='ARABIC LIGATURE SALAM ISOLATED FORM'
let s:d[0xFDF6]='ARABIC LIGATURE RASOUL ISOLATED FORM'
let s:d[0xFDF7]='ARABIC LIGATURE ALAYHE ISOLATED FORM'
let s:d[0xFDF8]='ARABIC LIGATURE WASALLAM ISOLATED FORM'
let s:d[0xFDF9]='ARABIC LIGATURE SALLA ISOLATED FORM'
let s:d[0xFDFA]='ARABIC LIGATURE SALLALLAHOU ALAYHE WASALLAM'
let s:d[0xFDFB]='ARABIC LIGATURE JALLAJALALOUHOU'
let s:d[0xFDFC]='RIAL SIGN'
let s:d[0xFDFD]='ARABIC LIGATURE BISMILLAH AR-RAHMAN AR-RAHEEM'
let s:d[0xFE00]='VARIATION SELECTOR-1'
let s:d[0xFE01]='VARIATION SELECTOR-2'
let s:d[0xFE02]='VARIATION SELECTOR-3'
let s:d[0xFE03]='VARIATION SELECTOR-4'
let s:d[0xFE04]='VARIATION SELECTOR-5'
let s:d[0xFE05]='VARIATION SELECTOR-6'
let s:d[0xFE06]='VARIATION SELECTOR-7'
let s:d[0xFE07]='VARIATION SELECTOR-8'
let s:d[0xFE08]='VARIATION SELECTOR-9'
let s:d[0xFE09]='VARIATION SELECTOR-10'
let s:d[0xFE0A]='VARIATION SELECTOR-11'
let s:d[0xFE0B]='VARIATION SELECTOR-12'
let s:d[0xFE0C]='VARIATION SELECTOR-13'
let s:d[0xFE0D]='VARIATION SELECTOR-14'
let s:d[0xFE0E]='VARIATION SELECTOR-15'
let s:d[0xFE0F]='VARIATION SELECTOR-16'
let s:d[0xFE10]='PRESENTATION FORM FOR VERTICAL COMMA'
let s:d[0xFE11]='PRESENTATION FORM FOR VERTICAL IDEOGRAPHIC COMMA'
let s:d[0xFE12]='PRESENTATION FORM FOR VERTICAL IDEOGRAPHIC FULL STOP'
let s:d[0xFE13]='PRESENTATION FORM FOR VERTICAL COLON'
let s:d[0xFE14]='PRESENTATION FORM FOR VERTICAL SEMICOLON'
let s:d[0xFE15]='PRESENTATION FORM FOR VERTICAL EXCLAMATION MARK'
let s:d[0xFE16]='PRESENTATION FORM FOR VERTICAL QUESTION MARK'
let s:d[0xFE17]='PRESENTATION FORM FOR VERTICAL LEFT WHITE LENTICULAR BRACKET'
let s:d[0xFE18]='PRESENTATION FORM FOR VERTICAL RIGHT WHITE LENTICULAR BRAKCET'
let s:d[0xFE19]='PRESENTATION FORM FOR VERTICAL HORIZONTAL ELLIPSIS'
let s:d[0xFE20]='COMBINING LIGATURE LEFT HALF'
let s:d[0xFE21]='COMBINING LIGATURE RIGHT HALF'
let s:d[0xFE22]='COMBINING DOUBLE TILDE LEFT HALF'
let s:d[0xFE23]='COMBINING DOUBLE TILDE RIGHT HALF'
let s:d[0xFE24]='COMBINING MACRON LEFT HALF'
let s:d[0xFE25]='COMBINING MACRON RIGHT HALF'
let s:d[0xFE26]='COMBINING CONJOINING MACRON'
let s:d[0xFE30]='PRESENTATION FORM FOR VERTICAL TWO DOT LEADER'
let s:d[0xFE31]='PRESENTATION FORM FOR VERTICAL EM DASH'
let s:d[0xFE32]='PRESENTATION FORM FOR VERTICAL EN DASH'
let s:d[0xFE33]='PRESENTATION FORM FOR VERTICAL LOW LINE'
let s:d[0xFE34]='PRESENTATION FORM FOR VERTICAL WAVY LOW LINE'
let s:d[0xFE35]='PRESENTATION FORM FOR VERTICAL LEFT PARENTHESIS'
let s:d[0xFE36]='PRESENTATION FORM FOR VERTICAL RIGHT PARENTHESIS'
let s:d[0xFE37]='PRESENTATION FORM FOR VERTICAL LEFT CURLY BRACKET'
let s:d[0xFE38]='PRESENTATION FORM FOR VERTICAL RIGHT CURLY BRACKET'
let s:d[0xFE39]='PRESENTATION FORM FOR VERTICAL LEFT TORTOISE SHELL BRACKET'
let s:d[0xFE3A]='PRESENTATION FORM FOR VERTICAL RIGHT TORTOISE SHELL BRACKET'
let s:d[0xFE3B]='PRESENTATION FORM FOR VERTICAL LEFT BLACK LENTICULAR BRACKET'
let s:d[0xFE3C]='PRESENTATION FORM FOR VERTICAL RIGHT BLACK LENTICULAR BRACKET'
let s:d[0xFE3D]='PRESENTATION FORM FOR VERTICAL LEFT DOUBLE ANGLE BRACKET'
let s:d[0xFE3E]='PRESENTATION FORM FOR VERTICAL RIGHT DOUBLE ANGLE BRACKET'
let s:d[0xFE3F]='PRESENTATION FORM FOR VERTICAL LEFT ANGLE BRACKET'
let s:d[0xFE40]='PRESENTATION FORM FOR VERTICAL RIGHT ANGLE BRACKET'
let s:d[0xFE41]='PRESENTATION FORM FOR VERTICAL LEFT CORNER BRACKET'
let s:d[0xFE42]='PRESENTATION FORM FOR VERTICAL RIGHT CORNER BRACKET'
let s:d[0xFE43]='PRESENTATION FORM FOR VERTICAL LEFT WHITE CORNER BRACKET'
let s:d[0xFE44]='PRESENTATION FORM FOR VERTICAL RIGHT WHITE CORNER BRACKET'
let s:d[0xFE45]='SESAME DOT'
let s:d[0xFE46]='WHITE SESAME DOT'
let s:d[0xFE47]='PRESENTATION FORM FOR VERTICAL LEFT SQUARE BRACKET'
let s:d[0xFE48]='PRESENTATION FORM FOR VERTICAL RIGHT SQUARE BRACKET'
let s:d[0xFE49]='DASHED OVERLINE'
let s:d[0xFE4A]='CENTRELINE OVERLINE'
let s:d[0xFE4B]='WAVY OVERLINE'
let s:d[0xFE4C]='DOUBLE WAVY OVERLINE'
let s:d[0xFE4D]='DASHED LOW LINE'
let s:d[0xFE4E]='CENTRELINE LOW LINE'
let s:d[0xFE4F]='WAVY LOW LINE'
let s:d[0xFE50]='SMALL COMMA'
let s:d[0xFE51]='SMALL IDEOGRAPHIC COMMA'
let s:d[0xFE52]='SMALL FULL STOP'
let s:d[0xFE54]='SMALL SEMICOLON'
let s:d[0xFE55]='SMALL COLON'
let s:d[0xFE56]='SMALL QUESTION MARK'
let s:d[0xFE57]='SMALL EXCLAMATION MARK'
let s:d[0xFE58]='SMALL EM DASH'
let s:d[0xFE59]='SMALL LEFT PARENTHESIS'
let s:d[0xFE5A]='SMALL RIGHT PARENTHESIS'
let s:d[0xFE5B]='SMALL LEFT CURLY BRACKET'
let s:d[0xFE5C]='SMALL RIGHT CURLY BRACKET'
let s:d[0xFE5D]='SMALL LEFT TORTOISE SHELL BRACKET'
let s:d[0xFE5E]='SMALL RIGHT TORTOISE SHELL BRACKET'
let s:d[0xFE5F]='SMALL NUMBER SIGN'
let s:d[0xFE60]='SMALL AMPERSAND'
let s:d[0xFE61]='SMALL ASTERISK'
let s:d[0xFE62]='SMALL PLUS SIGN'
let s:d[0xFE63]='SMALL HYPHEN-MINUS'
let s:d[0xFE64]='SMALL LESS-THAN SIGN'
let s:d[0xFE65]='SMALL GREATER-THAN SIGN'
let s:d[0xFE66]='SMALL EQUALS SIGN'
let s:d[0xFE68]='SMALL REVERSE SOLIDUS'
let s:d[0xFE69]='SMALL DOLLAR SIGN'
let s:d[0xFE6A]='SMALL PERCENT SIGN'
let s:d[0xFE6B]='SMALL COMMERCIAL AT'
let s:d[0xFE70]='ARABIC FATHATAN ISOLATED FORM'
let s:d[0xFE71]='ARABIC TATWEEL WITH FATHATAN ABOVE'
let s:d[0xFE72]='ARABIC DAMMATAN ISOLATED FORM'
let s:d[0xFE73]='ARABIC TAIL FRAGMENT'
let s:d[0xFE74]='ARABIC KASRATAN ISOLATED FORM'
let s:d[0xFE76]='ARABIC FATHA ISOLATED FORM'
let s:d[0xFE77]='ARABIC FATHA MEDIAL FORM'
let s:d[0xFE78]='ARABIC DAMMA ISOLATED FORM'
let s:d[0xFE79]='ARABIC DAMMA MEDIAL FORM'
let s:d[0xFE7A]='ARABIC KASRA ISOLATED FORM'
let s:d[0xFE7B]='ARABIC KASRA MEDIAL FORM'
let s:d[0xFE7C]='ARABIC SHADDA ISOLATED FORM'
let s:d[0xFE7D]='ARABIC SHADDA MEDIAL FORM'
let s:d[0xFE7E]='ARABIC SUKUN ISOLATED FORM'
let s:d[0xFE7F]='ARABIC SUKUN MEDIAL FORM'
let s:d[0xFE80]='ARABIC LETTER HAMZA ISOLATED FORM'
let s:d[0xFE81]='ARABIC LETTER ALEF WITH MADDA ABOVE ISOLATED FORM'
let s:d[0xFE82]='ARABIC LETTER ALEF WITH MADDA ABOVE FINAL FORM'
let s:d[0xFE83]='ARABIC LETTER ALEF WITH HAMZA ABOVE ISOLATED FORM'
let s:d[0xFE84]='ARABIC LETTER ALEF WITH HAMZA ABOVE FINAL FORM'
let s:d[0xFE85]='ARABIC LETTER WAW WITH HAMZA ABOVE ISOLATED FORM'
let s:d[0xFE86]='ARABIC LETTER WAW WITH HAMZA ABOVE FINAL FORM'
let s:d[0xFE87]='ARABIC LETTER ALEF WITH HAMZA BELOW ISOLATED FORM'
let s:d[0xFE88]='ARABIC LETTER ALEF WITH HAMZA BELOW FINAL FORM'
let s:d[0xFE89]='ARABIC LETTER YEH WITH HAMZA ABOVE ISOLATED FORM'
let s:d[0xFE8A]='ARABIC LETTER YEH WITH HAMZA ABOVE FINAL FORM'
let s:d[0xFE8B]='ARABIC LETTER YEH WITH HAMZA ABOVE INITIAL FORM'
let s:d[0xFE8C]='ARABIC LETTER YEH WITH HAMZA ABOVE MEDIAL FORM'
let s:d[0xFE8D]='ARABIC LETTER ALEF ISOLATED FORM'
let s:d[0xFE8E]='ARABIC LETTER ALEF FINAL FORM'
let s:d[0xFE8F]='ARABIC LETTER BEH ISOLATED FORM'
let s:d[0xFE90]='ARABIC LETTER BEH FINAL FORM'
let s:d[0xFE91]='ARABIC LETTER BEH INITIAL FORM'
let s:d[0xFE92]='ARABIC LETTER BEH MEDIAL FORM'
let s:d[0xFE93]='ARABIC LETTER TEH MARBUTA ISOLATED FORM'
let s:d[0xFE94]='ARABIC LETTER TEH MARBUTA FINAL FORM'
let s:d[0xFE95]='ARABIC LETTER TEH ISOLATED FORM'
let s:d[0xFE96]='ARABIC LETTER TEH FINAL FORM'
let s:d[0xFE97]='ARABIC LETTER TEH INITIAL FORM'
let s:d[0xFE98]='ARABIC LETTER TEH MEDIAL FORM'
let s:d[0xFE99]='ARABIC LETTER THEH ISOLATED FORM'
let s:d[0xFE9A]='ARABIC LETTER THEH FINAL FORM'
let s:d[0xFE9B]='ARABIC LETTER THEH INITIAL FORM'
let s:d[0xFE9C]='ARABIC LETTER THEH MEDIAL FORM'
let s:d[0xFE9D]='ARABIC LETTER JEEM ISOLATED FORM'
let s:d[0xFE9E]='ARABIC LETTER JEEM FINAL FORM'
let s:d[0xFE9F]='ARABIC LETTER JEEM INITIAL FORM'
let s:d[0xFEA0]='ARABIC LETTER JEEM MEDIAL FORM'
let s:d[0xFEA1]='ARABIC LETTER HAH ISOLATED FORM'
let s:d[0xFEA2]='ARABIC LETTER HAH FINAL FORM'
let s:d[0xFEA3]='ARABIC LETTER HAH INITIAL FORM'
let s:d[0xFEA4]='ARABIC LETTER HAH MEDIAL FORM'
let s:d[0xFEA5]='ARABIC LETTER KHAH ISOLATED FORM'
let s:d[0xFEA6]='ARABIC LETTER KHAH FINAL FORM'
let s:d[0xFEA7]='ARABIC LETTER KHAH INITIAL FORM'
let s:d[0xFEA8]='ARABIC LETTER KHAH MEDIAL FORM'
let s:d[0xFEA9]='ARABIC LETTER DAL ISOLATED FORM'
let s:d[0xFEAA]='ARABIC LETTER DAL FINAL FORM'
let s:d[0xFEAB]='ARABIC LETTER THAL ISOLATED FORM'
let s:d[0xFEAC]='ARABIC LETTER THAL FINAL FORM'
let s:d[0xFEAD]='ARABIC LETTER REH ISOLATED FORM'
let s:d[0xFEAE]='ARABIC LETTER REH FINAL FORM'
let s:d[0xFEAF]='ARABIC LETTER ZAIN ISOLATED FORM'
let s:d[0xFEB0]='ARABIC LETTER ZAIN FINAL FORM'
let s:d[0xFEB1]='ARABIC LETTER SEEN ISOLATED FORM'
let s:d[0xFEB2]='ARABIC LETTER SEEN FINAL FORM'
let s:d[0xFEB3]='ARABIC LETTER SEEN INITIAL FORM'
let s:d[0xFEB4]='ARABIC LETTER SEEN MEDIAL FORM'
let s:d[0xFEB5]='ARABIC LETTER SHEEN ISOLATED FORM'
let s:d[0xFEB6]='ARABIC LETTER SHEEN FINAL FORM'
let s:d[0xFEB7]='ARABIC LETTER SHEEN INITIAL FORM'
let s:d[0xFEB8]='ARABIC LETTER SHEEN MEDIAL FORM'
let s:d[0xFEB9]='ARABIC LETTER SAD ISOLATED FORM'
let s:d[0xFEBA]='ARABIC LETTER SAD FINAL FORM'
let s:d[0xFEBB]='ARABIC LETTER SAD INITIAL FORM'
let s:d[0xFEBC]='ARABIC LETTER SAD MEDIAL FORM'
let s:d[0xFEBD]='ARABIC LETTER DAD ISOLATED FORM'
let s:d[0xFEBE]='ARABIC LETTER DAD FINAL FORM'
let s:d[0xFEBF]='ARABIC LETTER DAD INITIAL FORM'
let s:d[0xFEC0]='ARABIC LETTER DAD MEDIAL FORM'
let s:d[0xFEC1]='ARABIC LETTER TAH ISOLATED FORM'
let s:d[0xFEC2]='ARABIC LETTER TAH FINAL FORM'
let s:d[0xFEC3]='ARABIC LETTER TAH INITIAL FORM'
let s:d[0xFEC4]='ARABIC LETTER TAH MEDIAL FORM'
let s:d[0xFEC5]='ARABIC LETTER ZAH ISOLATED FORM'
let s:d[0xFEC6]='ARABIC LETTER ZAH FINAL FORM'
let s:d[0xFEC7]='ARABIC LETTER ZAH INITIAL FORM'
let s:d[0xFEC8]='ARABIC LETTER ZAH MEDIAL FORM'
let s:d[0xFEC9]='ARABIC LETTER AIN ISOLATED FORM'
let s:d[0xFECA]='ARABIC LETTER AIN FINAL FORM'
let s:d[0xFECB]='ARABIC LETTER AIN INITIAL FORM'
let s:d[0xFECC]='ARABIC LETTER AIN MEDIAL FORM'
let s:d[0xFECD]='ARABIC LETTER GHAIN ISOLATED FORM'
let s:d[0xFECE]='ARABIC LETTER GHAIN FINAL FORM'
let s:d[0xFECF]='ARABIC LETTER GHAIN INITIAL FORM'
let s:d[0xFED0]='ARABIC LETTER GHAIN MEDIAL FORM'
let s:d[0xFED1]='ARABIC LETTER FEH ISOLATED FORM'
let s:d[0xFED2]='ARABIC LETTER FEH FINAL FORM'
let s:d[0xFED3]='ARABIC LETTER FEH INITIAL FORM'
let s:d[0xFED4]='ARABIC LETTER FEH MEDIAL FORM'
let s:d[0xFED5]='ARABIC LETTER QAF ISOLATED FORM'
let s:d[0xFED6]='ARABIC LETTER QAF FINAL FORM'
let s:d[0xFED7]='ARABIC LETTER QAF INITIAL FORM'
let s:d[0xFED8]='ARABIC LETTER QAF MEDIAL FORM'
let s:d[0xFED9]='ARABIC LETTER KAF ISOLATED FORM'
let s:d[0xFEDA]='ARABIC LETTER KAF FINAL FORM'
let s:d[0xFEDB]='ARABIC LETTER KAF INITIAL FORM'
let s:d[0xFEDC]='ARABIC LETTER KAF MEDIAL FORM'
let s:d[0xFEDD]='ARABIC LETTER LAM ISOLATED FORM'
let s:d[0xFEDE]='ARABIC LETTER LAM FINAL FORM'
let s:d[0xFEDF]='ARABIC LETTER LAM INITIAL FORM'
let s:d[0xFEE0]='ARABIC LETTER LAM MEDIAL FORM'
let s:d[0xFEE1]='ARABIC LETTER MEEM ISOLATED FORM'
let s:d[0xFEE2]='ARABIC LETTER MEEM FINAL FORM'
let s:d[0xFEE3]='ARABIC LETTER MEEM INITIAL FORM'
let s:d[0xFEE4]='ARABIC LETTER MEEM MEDIAL FORM'
let s:d[0xFEE5]='ARABIC LETTER NOON ISOLATED FORM'
let s:d[0xFEE6]='ARABIC LETTER NOON FINAL FORM'
let s:d[0xFEE7]='ARABIC LETTER NOON INITIAL FORM'
let s:d[0xFEE8]='ARABIC LETTER NOON MEDIAL FORM'
let s:d[0xFEE9]='ARABIC LETTER HEH ISOLATED FORM'
let s:d[0xFEEA]='ARABIC LETTER HEH FINAL FORM'
let s:d[0xFEEB]='ARABIC LETTER HEH INITIAL FORM'
let s:d[0xFEEC]='ARABIC LETTER HEH MEDIAL FORM'
let s:d[0xFEED]='ARABIC LETTER WAW ISOLATED FORM'
let s:d[0xFEEE]='ARABIC LETTER WAW FINAL FORM'
let s:d[0xFEEF]='ARABIC LETTER ALEF MAKSURA ISOLATED FORM'
let s:d[0xFEF0]='ARABIC LETTER ALEF MAKSURA FINAL FORM'
let s:d[0xFEF1]='ARABIC LETTER YEH ISOLATED FORM'
let s:d[0xFEF2]='ARABIC LETTER YEH FINAL FORM'
let s:d[0xFEF3]='ARABIC LETTER YEH INITIAL FORM'
let s:d[0xFEF4]='ARABIC LETTER YEH MEDIAL FORM'
let s:d[0xFEF5]='ARABIC LIGATURE LAM WITH ALEF WITH MADDA ABOVE ISOLATED FORM'
let s:d[0xFEF6]='ARABIC LIGATURE LAM WITH ALEF WITH MADDA ABOVE FINAL FORM'
let s:d[0xFEF7]='ARABIC LIGATURE LAM WITH ALEF WITH HAMZA ABOVE ISOLATED FORM'
let s:d[0xFEF8]='ARABIC LIGATURE LAM WITH ALEF WITH HAMZA ABOVE FINAL FORM'
let s:d[0xFEF9]='ARABIC LIGATURE LAM WITH ALEF WITH HAMZA BELOW ISOLATED FORM'
let s:d[0xFEFA]='ARABIC LIGATURE LAM WITH ALEF WITH HAMZA BELOW FINAL FORM'
let s:d[0xFEFB]='ARABIC LIGATURE LAM WITH ALEF ISOLATED FORM'
let s:d[0xFEFC]='ARABIC LIGATURE LAM WITH ALEF FINAL FORM'
let s:d[0xFEFF]='ZERO WIDTH NO-BREAK SPACE'
let s:d[0xFF01]='FULLWIDTH EXCLAMATION MARK'
let s:d[0xFF02]='FULLWIDTH QUOTATION MARK'
let s:d[0xFF03]='FULLWIDTH NUMBER SIGN'
let s:d[0xFF04]='FULLWIDTH DOLLAR SIGN'
let s:d[0xFF05]='FULLWIDTH PERCENT SIGN'
let s:d[0xFF06]='FULLWIDTH AMPERSAND'
let s:d[0xFF07]='FULLWIDTH APOSTROPHE'
let s:d[0xFF08]='FULLWIDTH LEFT PARENTHESIS'
let s:d[0xFF09]='FULLWIDTH RIGHT PARENTHESIS'
let s:d[0xFF0A]='FULLWIDTH ASTERISK'
let s:d[0xFF0B]='FULLWIDTH PLUS SIGN'
let s:d[0xFF0C]='FULLWIDTH COMMA'
let s:d[0xFF0D]='FULLWIDTH HYPHEN-MINUS'
let s:d[0xFF0E]='FULLWIDTH FULL STOP'
let s:d[0xFF0F]='FULLWIDTH SOLIDUS'
let s:d[0xFF10]='FULLWIDTH DIGIT ZERO'
let s:d[0xFF11]='FULLWIDTH DIGIT ONE'
let s:d[0xFF12]='FULLWIDTH DIGIT TWO'
let s:d[0xFF13]='FULLWIDTH DIGIT THREE'
let s:d[0xFF14]='FULLWIDTH DIGIT FOUR'
let s:d[0xFF15]='FULLWIDTH DIGIT FIVE'
let s:d[0xFF16]='FULLWIDTH DIGIT SIX'
let s:d[0xFF17]='FULLWIDTH DIGIT SEVEN'
let s:d[0xFF18]='FULLWIDTH DIGIT EIGHT'
let s:d[0xFF19]='FULLWIDTH DIGIT NINE'
let s:d[0xFF1A]='FULLWIDTH COLON'
let s:d[0xFF1B]='FULLWIDTH SEMICOLON'
let s:d[0xFF1C]='FULLWIDTH LESS-THAN SIGN'
let s:d[0xFF1D]='FULLWIDTH EQUALS SIGN'
let s:d[0xFF1E]='FULLWIDTH GREATER-THAN SIGN'
let s:d[0xFF1F]='FULLWIDTH QUESTION MARK'
let s:d[0xFF20]='FULLWIDTH COMMERCIAL AT'
let s:d[0xFF21]='FULLWIDTH LATIN CAPITAL LETTER A'
let s:d[0xFF22]='FULLWIDTH LATIN CAPITAL LETTER B'
let s:d[0xFF23]='FULLWIDTH LATIN CAPITAL LETTER C'
let s:d[0xFF24]='FULLWIDTH LATIN CAPITAL LETTER D'
let s:d[0xFF25]='FULLWIDTH LATIN CAPITAL LETTER E'
let s:d[0xFF26]='FULLWIDTH LATIN CAPITAL LETTER F'
let s:d[0xFF27]='FULLWIDTH LATIN CAPITAL LETTER G'
let s:d[0xFF28]='FULLWIDTH LATIN CAPITAL LETTER H'
let s:d[0xFF29]='FULLWIDTH LATIN CAPITAL LETTER I'
let s:d[0xFF2A]='FULLWIDTH LATIN CAPITAL LETTER J'
let s:d[0xFF2B]='FULLWIDTH LATIN CAPITAL LETTER K'
let s:d[0xFF2C]='FULLWIDTH LATIN CAPITAL LETTER L'
let s:d[0xFF2D]='FULLWIDTH LATIN CAPITAL LETTER M'
let s:d[0xFF2E]='FULLWIDTH LATIN CAPITAL LETTER N'
let s:d[0xFF2F]='FULLWIDTH LATIN CAPITAL LETTER O'
let s:d[0xFF30]='FULLWIDTH LATIN CAPITAL LETTER P'
let s:d[0xFF31]='FULLWIDTH LATIN CAPITAL LETTER Q'
let s:d[0xFF32]='FULLWIDTH LATIN CAPITAL LETTER R'
let s:d[0xFF33]='FULLWIDTH LATIN CAPITAL LETTER S'
let s:d[0xFF34]='FULLWIDTH LATIN CAPITAL LETTER T'
let s:d[0xFF35]='FULLWIDTH LATIN CAPITAL LETTER U'
let s:d[0xFF36]='FULLWIDTH LATIN CAPITAL LETTER V'
let s:d[0xFF37]='FULLWIDTH LATIN CAPITAL LETTER W'
let s:d[0xFF38]='FULLWIDTH LATIN CAPITAL LETTER X'
let s:d[0xFF39]='FULLWIDTH LATIN CAPITAL LETTER Y'
let s:d[0xFF3A]='FULLWIDTH LATIN CAPITAL LETTER Z'
let s:d[0xFF3B]='FULLWIDTH LEFT SQUARE BRACKET'
let s:d[0xFF3C]='FULLWIDTH REVERSE SOLIDUS'
let s:d[0xFF3D]='FULLWIDTH RIGHT SQUARE BRACKET'
let s:d[0xFF3E]='FULLWIDTH CIRCUMFLEX ACCENT'
let s:d[0xFF3F]='FULLWIDTH LOW LINE'
let s:d[0xFF40]='FULLWIDTH GRAVE ACCENT'
let s:d[0xFF41]='FULLWIDTH LATIN SMALL LETTER A'
let s:d[0xFF42]='FULLWIDTH LATIN SMALL LETTER B'
let s:d[0xFF43]='FULLWIDTH LATIN SMALL LETTER C'
let s:d[0xFF44]='FULLWIDTH LATIN SMALL LETTER D'
let s:d[0xFF45]='FULLWIDTH LATIN SMALL LETTER E'
let s:d[0xFF46]='FULLWIDTH LATIN SMALL LETTER F'
let s:d[0xFF47]='FULLWIDTH LATIN SMALL LETTER G'
let s:d[0xFF48]='FULLWIDTH LATIN SMALL LETTER H'
let s:d[0xFF49]='FULLWIDTH LATIN SMALL LETTER I'
let s:d[0xFF4A]='FULLWIDTH LATIN SMALL LETTER J'
let s:d[0xFF4B]='FULLWIDTH LATIN SMALL LETTER K'
let s:d[0xFF4C]='FULLWIDTH LATIN SMALL LETTER L'
let s:d[0xFF4D]='FULLWIDTH LATIN SMALL LETTER M'
let s:d[0xFF4E]='FULLWIDTH LATIN SMALL LETTER N'
let s:d[0xFF4F]='FULLWIDTH LATIN SMALL LETTER O'
let s:d[0xFF50]='FULLWIDTH LATIN SMALL LETTER P'
let s:d[0xFF51]='FULLWIDTH LATIN SMALL LETTER Q'
let s:d[0xFF52]='FULLWIDTH LATIN SMALL LETTER R'
let s:d[0xFF53]='FULLWIDTH LATIN SMALL LETTER S'
let s:d[0xFF54]='FULLWIDTH LATIN SMALL LETTER T'
let s:d[0xFF55]='FULLWIDTH LATIN SMALL LETTER U'
let s:d[0xFF56]='FULLWIDTH LATIN SMALL LETTER V'
let s:d[0xFF57]='FULLWIDTH LATIN SMALL LETTER W'
let s:d[0xFF58]='FULLWIDTH LATIN SMALL LETTER X'
let s:d[0xFF59]='FULLWIDTH LATIN SMALL LETTER Y'
let s:d[0xFF5A]='FULLWIDTH LATIN SMALL LETTER Z'
let s:d[0xFF5B]='FULLWIDTH LEFT CURLY BRACKET'
let s:d[0xFF5C]='FULLWIDTH VERTICAL LINE'
let s:d[0xFF5D]='FULLWIDTH RIGHT CURLY BRACKET'
let s:d[0xFF5E]='FULLWIDTH TILDE'
let s:d[0xFF5F]='FULLWIDTH LEFT WHITE PARENTHESIS'
let s:d[0xFF60]='FULLWIDTH RIGHT WHITE PARENTHESIS'
let s:d[0xFF61]='HALFWIDTH IDEOGRAPHIC FULL STOP'
let s:d[0xFF62]='HALFWIDTH LEFT CORNER BRACKET'
let s:d[0xFF63]='HALFWIDTH RIGHT CORNER BRACKET'
let s:d[0xFF64]='HALFWIDTH IDEOGRAPHIC COMMA'
let s:d[0xFF65]='HALFWIDTH KATAKANA MIDDLE DOT'
let s:d[0xFF66]='HALFWIDTH KATAKANA LETTER WO'
let s:d[0xFF67]='HALFWIDTH KATAKANA LETTER SMALL A'
let s:d[0xFF68]='HALFWIDTH KATAKANA LETTER SMALL I'
let s:d[0xFF69]='HALFWIDTH KATAKANA LETTER SMALL U'
let s:d[0xFF6A]='HALFWIDTH KATAKANA LETTER SMALL E'
let s:d[0xFF6B]='HALFWIDTH KATAKANA LETTER SMALL O'
let s:d[0xFF6C]='HALFWIDTH KATAKANA LETTER SMALL YA'
let s:d[0xFF6D]='HALFWIDTH KATAKANA LETTER SMALL YU'
let s:d[0xFF6E]='HALFWIDTH KATAKANA LETTER SMALL YO'
let s:d[0xFF6F]='HALFWIDTH KATAKANA LETTER SMALL TU'
let s:d[0xFF70]='HALFWIDTH KATAKANA-HIRAGANA PROLONGED SOUND MARK'
let s:d[0xFF71]='HALFWIDTH KATAKANA LETTER A'
let s:d[0xFF72]='HALFWIDTH KATAKANA LETTER I'
let s:d[0xFF73]='HALFWIDTH KATAKANA LETTER U'
let s:d[0xFF74]='HALFWIDTH KATAKANA LETTER E'
let s:d[0xFF75]='HALFWIDTH KATAKANA LETTER O'
let s:d[0xFF76]='HALFWIDTH KATAKANA LETTER KA'
let s:d[0xFF77]='HALFWIDTH KATAKANA LETTER KI'
let s:d[0xFF78]='HALFWIDTH KATAKANA LETTER KU'
let s:d[0xFF79]='HALFWIDTH KATAKANA LETTER KE'
let s:d[0xFF7A]='HALFWIDTH KATAKANA LETTER KO'
let s:d[0xFF7B]='HALFWIDTH KATAKANA LETTER SA'
let s:d[0xFF7C]='HALFWIDTH KATAKANA LETTER SI'
let s:d[0xFF7D]='HALFWIDTH KATAKANA LETTER SU'
let s:d[0xFF7E]='HALFWIDTH KATAKANA LETTER SE'
let s:d[0xFF7F]='HALFWIDTH KATAKANA LETTER SO'
let s:d[0xFF80]='HALFWIDTH KATAKANA LETTER TA'
let s:d[0xFF81]='HALFWIDTH KATAKANA LETTER TI'
let s:d[0xFF82]='HALFWIDTH KATAKANA LETTER TU'
let s:d[0xFF83]='HALFWIDTH KATAKANA LETTER TE'
let s:d[0xFF84]='HALFWIDTH KATAKANA LETTER TO'
let s:d[0xFF85]='HALFWIDTH KATAKANA LETTER NA'
let s:d[0xFF86]='HALFWIDTH KATAKANA LETTER NI'
let s:d[0xFF87]='HALFWIDTH KATAKANA LETTER NU'
let s:d[0xFF88]='HALFWIDTH KATAKANA LETTER NE'
let s:d[0xFF89]='HALFWIDTH KATAKANA LETTER NO'
let s:d[0xFF8A]='HALFWIDTH KATAKANA LETTER HA'
let s:d[0xFF8B]='HALFWIDTH KATAKANA LETTER HI'
let s:d[0xFF8C]='HALFWIDTH KATAKANA LETTER HU'
let s:d[0xFF8D]='HALFWIDTH KATAKANA LETTER HE'
let s:d[0xFF8E]='HALFWIDTH KATAKANA LETTER HO'
let s:d[0xFF8F]='HALFWIDTH KATAKANA LETTER MA'
let s:d[0xFF90]='HALFWIDTH KATAKANA LETTER MI'
let s:d[0xFF91]='HALFWIDTH KATAKANA LETTER MU'
let s:d[0xFF92]='HALFWIDTH KATAKANA LETTER ME'
let s:d[0xFF93]='HALFWIDTH KATAKANA LETTER MO'
let s:d[0xFF94]='HALFWIDTH KATAKANA LETTER YA'
let s:d[0xFF95]='HALFWIDTH KATAKANA LETTER YU'
let s:d[0xFF96]='HALFWIDTH KATAKANA LETTER YO'
let s:d[0xFF97]='HALFWIDTH KATAKANA LETTER RA'
let s:d[0xFF98]='HALFWIDTH KATAKANA LETTER RI'
let s:d[0xFF99]='HALFWIDTH KATAKANA LETTER RU'
let s:d[0xFF9A]='HALFWIDTH KATAKANA LETTER RE'
let s:d[0xFF9B]='HALFWIDTH KATAKANA LETTER RO'
let s:d[0xFF9C]='HALFWIDTH KATAKANA LETTER WA'
let s:d[0xFF9D]='HALFWIDTH KATAKANA LETTER N'
let s:d[0xFF9E]='HALFWIDTH KATAKANA VOICED SOUND MARK'
let s:d[0xFF9F]='HALFWIDTH KATAKANA SEMI-VOICED SOUND MARK'
let s:d[0xFFA0]='HALFWIDTH HANGUL FILLER'
let s:d[0xFFA1]='HALFWIDTH HANGUL LETTER KIYEOK'
let s:d[0xFFA2]='HALFWIDTH HANGUL LETTER SSANGKIYEOK'
let s:d[0xFFA3]='HALFWIDTH HANGUL LETTER KIYEOK-SIOS'
let s:d[0xFFA4]='HALFWIDTH HANGUL LETTER NIEUN'
let s:d[0xFFA5]='HALFWIDTH HANGUL LETTER NIEUN-CIEUC'
let s:d[0xFFA6]='HALFWIDTH HANGUL LETTER NIEUN-HIEUH'
let s:d[0xFFA7]='HALFWIDTH HANGUL LETTER TIKEUT'
let s:d[0xFFA8]='HALFWIDTH HANGUL LETTER SSANGTIKEUT'
let s:d[0xFFA9]='HALFWIDTH HANGUL LETTER RIEUL'
let s:d[0xFFAA]='HALFWIDTH HANGUL LETTER RIEUL-KIYEOK'
let s:d[0xFFAB]='HALFWIDTH HANGUL LETTER RIEUL-MIEUM'
let s:d[0xFFAC]='HALFWIDTH HANGUL LETTER RIEUL-PIEUP'
let s:d[0xFFAD]='HALFWIDTH HANGUL LETTER RIEUL-SIOS'
let s:d[0xFFAE]='HALFWIDTH HANGUL LETTER RIEUL-THIEUTH'
let s:d[0xFFAF]='HALFWIDTH HANGUL LETTER RIEUL-PHIEUPH'
let s:d[0xFFB0]='HALFWIDTH HANGUL LETTER RIEUL-HIEUH'
let s:d[0xFFB1]='HALFWIDTH HANGUL LETTER MIEUM'
let s:d[0xFFB2]='HALFWIDTH HANGUL LETTER PIEUP'
let s:d[0xFFB3]='HALFWIDTH HANGUL LETTER SSANGPIEUP'
let s:d[0xFFB4]='HALFWIDTH HANGUL LETTER PIEUP-SIOS'
let s:d[0xFFB5]='HALFWIDTH HANGUL LETTER SIOS'
let s:d[0xFFB6]='HALFWIDTH HANGUL LETTER SSANGSIOS'
let s:d[0xFFB7]='HALFWIDTH HANGUL LETTER IEUNG'
let s:d[0xFFB8]='HALFWIDTH HANGUL LETTER CIEUC'
let s:d[0xFFB9]='HALFWIDTH HANGUL LETTER SSANGCIEUC'
let s:d[0xFFBA]='HALFWIDTH HANGUL LETTER CHIEUCH'
let s:d[0xFFBB]='HALFWIDTH HANGUL LETTER KHIEUKH'
let s:d[0xFFBC]='HALFWIDTH HANGUL LETTER THIEUTH'
let s:d[0xFFBD]='HALFWIDTH HANGUL LETTER PHIEUPH'
let s:d[0xFFBE]='HALFWIDTH HANGUL LETTER HIEUH'
let s:d[0xFFC2]='HALFWIDTH HANGUL LETTER A'
let s:d[0xFFC3]='HALFWIDTH HANGUL LETTER AE'
let s:d[0xFFC4]='HALFWIDTH HANGUL LETTER YA'
let s:d[0xFFC5]='HALFWIDTH HANGUL LETTER YAE'
let s:d[0xFFC6]='HALFWIDTH HANGUL LETTER EO'
let s:d[0xFFC7]='HALFWIDTH HANGUL LETTER E'
let s:d[0xFFCA]='HALFWIDTH HANGUL LETTER YEO'
let s:d[0xFFCB]='HALFWIDTH HANGUL LETTER YE'
let s:d[0xFFCC]='HALFWIDTH HANGUL LETTER O'
let s:d[0xFFCD]='HALFWIDTH HANGUL LETTER WA'
let s:d[0xFFCE]='HALFWIDTH HANGUL LETTER WAE'
let s:d[0xFFCF]='HALFWIDTH HANGUL LETTER OE'
let s:d[0xFFD2]='HALFWIDTH HANGUL LETTER YO'
let s:d[0xFFD3]='HALFWIDTH HANGUL LETTER U'
let s:d[0xFFD4]='HALFWIDTH HANGUL LETTER WEO'
let s:d[0xFFD5]='HALFWIDTH HANGUL LETTER WE'
let s:d[0xFFD6]='HALFWIDTH HANGUL LETTER WI'
let s:d[0xFFD7]='HALFWIDTH HANGUL LETTER YU'
let s:d[0xFFDA]='HALFWIDTH HANGUL LETTER EU'
let s:d[0xFFDB]='HALFWIDTH HANGUL LETTER YI'
let s:d[0xFFDC]='HALFWIDTH HANGUL LETTER I'
let s:d[0xFFE0]='FULLWIDTH CENT SIGN'
let s:d[0xFFE1]='FULLWIDTH POUND SIGN'
let s:d[0xFFE2]='FULLWIDTH NOT SIGN'
let s:d[0xFFE3]='FULLWIDTH MACRON'
let s:d[0xFFE4]='FULLWIDTH BROKEN BAR'
let s:d[0xFFE5]='FULLWIDTH YEN SIGN'
let s:d[0xFFE6]='FULLWIDTH WON SIGN'
let s:d[0xFFE8]='HALFWIDTH FORMS LIGHT VERTICAL'
let s:d[0xFFE9]='HALFWIDTH LEFTWARDS ARROW'
let s:d[0xFFEA]='HALFWIDTH UPWARDS ARROW'
let s:d[0xFFEB]='HALFWIDTH RIGHTWARDS ARROW'
let s:d[0xFFEC]='HALFWIDTH DOWNWARDS ARROW'
let s:d[0xFFED]='HALFWIDTH BLACK SQUARE'
let s:d[0xFFEE]='HALFWIDTH WHITE CIRCLE'
let s:d[0xFFF9]='INTERLINEAR ANNOTATION ANCHOR'
let s:d[0xFFFA]='INTERLINEAR ANNOTATION SEPARATOR'
let s:d[0xFFFB]='INTERLINEAR ANNOTATION TERMINATOR'
let s:d[0xFFFC]='OBJECT REPLACEMENT CHARACTER'
let s:d[0xFFFD]='REPLACEMENT CHARACTER'
let s:d[0xFFFE]='<not a character>'
let s:d[0xFFFF]='<not a character>'
let s:d[0x10000]='LINEAR B SYLLABLE B008 A'
let s:d[0x10001]='LINEAR B SYLLABLE B038 E'
let s:d[0x10002]='LINEAR B SYLLABLE B028 I'
let s:d[0x10003]='LINEAR B SYLLABLE B061 O'
let s:d[0x10004]='LINEAR B SYLLABLE B010 U'
let s:d[0x10005]='LINEAR B SYLLABLE B001 DA'
let s:d[0x10006]='LINEAR B SYLLABLE B045 DE'
let s:d[0x10007]='LINEAR B SYLLABLE B007 DI'
let s:d[0x10008]='LINEAR B SYLLABLE B014 DO'
let s:d[0x10009]='LINEAR B SYLLABLE B051 DU'
let s:d[0x1000A]='LINEAR B SYLLABLE B057 JA'
let s:d[0x1000B]='LINEAR B SYLLABLE B046 JE'
let s:d[0x1000D]='LINEAR B SYLLABLE B036 JO'
let s:d[0x1000E]='LINEAR B SYLLABLE B065 JU'
let s:d[0x1000F]='LINEAR B SYLLABLE B077 KA'
let s:d[0x10010]='LINEAR B SYLLABLE B044 KE'
let s:d[0x10011]='LINEAR B SYLLABLE B067 KI'
let s:d[0x10012]='LINEAR B SYLLABLE B070 KO'
let s:d[0x10013]='LINEAR B SYLLABLE B081 KU'
let s:d[0x10014]='LINEAR B SYLLABLE B080 MA'
let s:d[0x10015]='LINEAR B SYLLABLE B013 ME'
let s:d[0x10016]='LINEAR B SYLLABLE B073 MI'
let s:d[0x10017]='LINEAR B SYLLABLE B015 MO'
let s:d[0x10018]='LINEAR B SYLLABLE B023 MU'
let s:d[0x10019]='LINEAR B SYLLABLE B006 NA'
let s:d[0x1001A]='LINEAR B SYLLABLE B024 NE'
let s:d[0x1001B]='LINEAR B SYLLABLE B030 NI'
let s:d[0x1001C]='LINEAR B SYLLABLE B052 NO'
let s:d[0x1001D]='LINEAR B SYLLABLE B055 NU'
let s:d[0x1001E]='LINEAR B SYLLABLE B003 PA'
let s:d[0x1001F]='LINEAR B SYLLABLE B072 PE'
let s:d[0x10020]='LINEAR B SYLLABLE B039 PI'
let s:d[0x10021]='LINEAR B SYLLABLE B011 PO'
let s:d[0x10022]='LINEAR B SYLLABLE B050 PU'
let s:d[0x10023]='LINEAR B SYLLABLE B016 QA'
let s:d[0x10024]='LINEAR B SYLLABLE B078 QE'
let s:d[0x10025]='LINEAR B SYLLABLE B021 QI'
let s:d[0x10026]='LINEAR B SYLLABLE B032 QO'
let s:d[0x10028]='LINEAR B SYLLABLE B060 RA'
let s:d[0x10029]='LINEAR B SYLLABLE B027 RE'
let s:d[0x1002A]='LINEAR B SYLLABLE B053 RI'
let s:d[0x1002B]='LINEAR B SYLLABLE B002 RO'
let s:d[0x1002C]='LINEAR B SYLLABLE B026 RU'
let s:d[0x1002D]='LINEAR B SYLLABLE B031 SA'
let s:d[0x1002E]='LINEAR B SYLLABLE B009 SE'
let s:d[0x1002F]='LINEAR B SYLLABLE B041 SI'
let s:d[0x10030]='LINEAR B SYLLABLE B012 SO'
let s:d[0x10031]='LINEAR B SYLLABLE B058 SU'
let s:d[0x10032]='LINEAR B SYLLABLE B059 TA'
let s:d[0x10033]='LINEAR B SYLLABLE B004 TE'
let s:d[0x10034]='LINEAR B SYLLABLE B037 TI'
let s:d[0x10035]='LINEAR B SYLLABLE B005 TO'
let s:d[0x10036]='LINEAR B SYLLABLE B069 TU'
let s:d[0x10037]='LINEAR B SYLLABLE B054 WA'
let s:d[0x10038]='LINEAR B SYLLABLE B075 WE'
let s:d[0x10039]='LINEAR B SYLLABLE B040 WI'
let s:d[0x1003A]='LINEAR B SYLLABLE B042 WO'
let s:d[0x1003C]='LINEAR B SYLLABLE B017 ZA'
let s:d[0x1003D]='LINEAR B SYLLABLE B074 ZE'
let s:d[0x1003F]='LINEAR B SYLLABLE B020 ZO'
let s:d[0x10040]='LINEAR B SYLLABLE B025 A2'
let s:d[0x10041]='LINEAR B SYLLABLE B043 A3'
let s:d[0x10042]='LINEAR B SYLLABLE B085 AU'
let s:d[0x10043]='LINEAR B SYLLABLE B071 DWE'
let s:d[0x10044]='LINEAR B SYLLABLE B090 DWO'
let s:d[0x10045]='LINEAR B SYLLABLE B048 NWA'
let s:d[0x10046]='LINEAR B SYLLABLE B029 PU2'
let s:d[0x10047]='LINEAR B SYLLABLE B062 PTE'
let s:d[0x10048]='LINEAR B SYLLABLE B076 RA2'
let s:d[0x10049]='LINEAR B SYLLABLE B033 RA3'
let s:d[0x1004A]='LINEAR B SYLLABLE B068 RO2'
let s:d[0x1004B]='LINEAR B SYLLABLE B066 TA2'
let s:d[0x1004C]='LINEAR B SYLLABLE B087 TWE'
let s:d[0x1004D]='LINEAR B SYLLABLE B091 TWO'
let s:d[0x10050]='LINEAR B SYMBOL B018'
let s:d[0x10051]='LINEAR B SYMBOL B019'
let s:d[0x10052]='LINEAR B SYMBOL B022'
let s:d[0x10053]='LINEAR B SYMBOL B034'
let s:d[0x10054]='LINEAR B SYMBOL B047'
let s:d[0x10055]='LINEAR B SYMBOL B049'
let s:d[0x10056]='LINEAR B SYMBOL B056'
let s:d[0x10057]='LINEAR B SYMBOL B063'
let s:d[0x10058]='LINEAR B SYMBOL B064'
let s:d[0x10059]='LINEAR B SYMBOL B079'
let s:d[0x1005A]='LINEAR B SYMBOL B082'
let s:d[0x1005B]='LINEAR B SYMBOL B083'
let s:d[0x1005C]='LINEAR B SYMBOL B086'
let s:d[0x1005D]='LINEAR B SYMBOL B089'
let s:d[0x10080]='LINEAR B IDEOGRAM B100 MAN'
let s:d[0x10081]='LINEAR B IDEOGRAM B102 WOMAN'
let s:d[0x10082]='LINEAR B IDEOGRAM B104 DEER'
let s:d[0x10083]='LINEAR B IDEOGRAM B105 EQUID'
let s:d[0x10084]='LINEAR B IDEOGRAM B105F MARE'
let s:d[0x10085]='LINEAR B IDEOGRAM B105M STALLION'
let s:d[0x10086]='LINEAR B IDEOGRAM B106F EWE'
let s:d[0x10087]='LINEAR B IDEOGRAM B106M RAM'
let s:d[0x10088]='LINEAR B IDEOGRAM B107F SHE-GOAT'
let s:d[0x10089]='LINEAR B IDEOGRAM B107M HE-GOAT'
let s:d[0x1008A]='LINEAR B IDEOGRAM B108F SOW'
let s:d[0x1008B]='LINEAR B IDEOGRAM B108M BOAR'
let s:d[0x1008C]='LINEAR B IDEOGRAM B109F COW'
let s:d[0x1008D]='LINEAR B IDEOGRAM B109M BULL'
let s:d[0x1008E]='LINEAR B IDEOGRAM B120 WHEAT'
let s:d[0x1008F]='LINEAR B IDEOGRAM B121 BARLEY'
let s:d[0x10090]='LINEAR B IDEOGRAM B122 OLIVE'
let s:d[0x10091]='LINEAR B IDEOGRAM B123 SPICE'
let s:d[0x10092]='LINEAR B IDEOGRAM B125 CYPERUS'
let s:d[0x10093]='LINEAR B MONOGRAM B127 KAPO'
let s:d[0x10094]='LINEAR B MONOGRAM B128 KANAKO'
let s:d[0x10095]='LINEAR B IDEOGRAM B130 OIL'
let s:d[0x10096]='LINEAR B IDEOGRAM B131 WINE'
let s:d[0x10097]='LINEAR B IDEOGRAM B132'
let s:d[0x10098]='LINEAR B MONOGRAM B133 AREPA'
let s:d[0x10099]='LINEAR B MONOGRAM B135 MERI'
let s:d[0x1009A]='LINEAR B IDEOGRAM B140 BRONZE'
let s:d[0x1009B]='LINEAR B IDEOGRAM B141 GOLD'
let s:d[0x1009C]='LINEAR B IDEOGRAM B142'
let s:d[0x1009D]='LINEAR B IDEOGRAM B145 WOOL'
let s:d[0x1009E]='LINEAR B IDEOGRAM B146'
let s:d[0x1009F]='LINEAR B IDEOGRAM B150'
let s:d[0x100A0]='LINEAR B IDEOGRAM B151 HORN'
let s:d[0x100A1]='LINEAR B IDEOGRAM B152'
let s:d[0x100A2]='LINEAR B IDEOGRAM B153'
let s:d[0x100A3]='LINEAR B IDEOGRAM B154'
let s:d[0x100A4]='LINEAR B MONOGRAM B156 TURO2'
let s:d[0x100A5]='LINEAR B IDEOGRAM B157'
let s:d[0x100A6]='LINEAR B IDEOGRAM B158'
let s:d[0x100A7]='LINEAR B IDEOGRAM B159 CLOTH'
let s:d[0x100A8]='LINEAR B IDEOGRAM B160'
let s:d[0x100A9]='LINEAR B IDEOGRAM B161'
let s:d[0x100AA]='LINEAR B IDEOGRAM B162 GARMENT'
let s:d[0x100AB]='LINEAR B IDEOGRAM B163 ARMOUR'
let s:d[0x100AC]='LINEAR B IDEOGRAM B164'
let s:d[0x100AD]='LINEAR B IDEOGRAM B165'
let s:d[0x100AE]='LINEAR B IDEOGRAM B166'
let s:d[0x100AF]='LINEAR B IDEOGRAM B167'
let s:d[0x100B0]='LINEAR B IDEOGRAM B168'
let s:d[0x100B1]='LINEAR B IDEOGRAM B169'
let s:d[0x100B2]='LINEAR B IDEOGRAM B170'
let s:d[0x100B3]='LINEAR B IDEOGRAM B171'
let s:d[0x100B4]='LINEAR B IDEOGRAM B172'
let s:d[0x100B5]='LINEAR B IDEOGRAM B173 MONTH'
let s:d[0x100B6]='LINEAR B IDEOGRAM B174'
let s:d[0x100B7]='LINEAR B IDEOGRAM B176 TREE'
let s:d[0x100B8]='LINEAR B IDEOGRAM B177'
let s:d[0x100B9]='LINEAR B IDEOGRAM B178'
let s:d[0x100BA]='LINEAR B IDEOGRAM B179'
let s:d[0x100BB]='LINEAR B IDEOGRAM B180'
let s:d[0x100BC]='LINEAR B IDEOGRAM B181'
let s:d[0x100BD]='LINEAR B IDEOGRAM B182'
let s:d[0x100BE]='LINEAR B IDEOGRAM B183'
let s:d[0x100BF]='LINEAR B IDEOGRAM B184'
let s:d[0x100C0]='LINEAR B IDEOGRAM B185'
let s:d[0x100C1]='LINEAR B IDEOGRAM B189'
let s:d[0x100C2]='LINEAR B IDEOGRAM B190'
let s:d[0x100C3]='LINEAR B IDEOGRAM B191 HELMET'
let s:d[0x100C4]='LINEAR B IDEOGRAM B220 FOOTSTOOL'
let s:d[0x100C5]='LINEAR B IDEOGRAM B225 BATHTUB'
let s:d[0x100C6]='LINEAR B IDEOGRAM B230 SPEAR'
let s:d[0x100C7]='LINEAR B IDEOGRAM B231 ARROW'
let s:d[0x100C8]='LINEAR B IDEOGRAM B232'
let s:d[0x100C9]='LINEAR B IDEOGRAM B233 SWORD'
let s:d[0x100CA]='LINEAR B IDEOGRAM B234'
let s:d[0x100CB]='LINEAR B IDEOGRAM B236'
let s:d[0x100CC]='LINEAR B IDEOGRAM B240 WHEELED CHARIOT'
let s:d[0x100CD]='LINEAR B IDEOGRAM B241 CHARIOT'
let s:d[0x100CE]='LINEAR B IDEOGRAM B242 CHARIOT FRAME'
let s:d[0x100CF]='LINEAR B IDEOGRAM B243 WHEEL'
let s:d[0x100D0]='LINEAR B IDEOGRAM B245'
let s:d[0x100D1]='LINEAR B IDEOGRAM B246'
let s:d[0x100D2]='LINEAR B MONOGRAM B247 DIPTE'
let s:d[0x100D3]='LINEAR B IDEOGRAM B248'
let s:d[0x100D4]='LINEAR B IDEOGRAM B249'
let s:d[0x100D5]='LINEAR B IDEOGRAM B251'
let s:d[0x100D6]='LINEAR B IDEOGRAM B252'
let s:d[0x100D7]='LINEAR B IDEOGRAM B253'
let s:d[0x100D8]='LINEAR B IDEOGRAM B254 DART'
let s:d[0x100D9]='LINEAR B IDEOGRAM B255'
let s:d[0x100DA]='LINEAR B IDEOGRAM B256'
let s:d[0x100DB]='LINEAR B IDEOGRAM B257'
let s:d[0x100DC]='LINEAR B IDEOGRAM B258'
let s:d[0x100DD]='LINEAR B IDEOGRAM B259'
let s:d[0x100DE]='LINEAR B IDEOGRAM VESSEL B155'
let s:d[0x100DF]='LINEAR B IDEOGRAM VESSEL B200'
let s:d[0x100E0]='LINEAR B IDEOGRAM VESSEL B201'
let s:d[0x100E1]='LINEAR B IDEOGRAM VESSEL B202'
let s:d[0x100E2]='LINEAR B IDEOGRAM VESSEL B203'
let s:d[0x100E3]='LINEAR B IDEOGRAM VESSEL B204'
let s:d[0x100E4]='LINEAR B IDEOGRAM VESSEL B205'
let s:d[0x100E5]='LINEAR B IDEOGRAM VESSEL B206'
let s:d[0x100E6]='LINEAR B IDEOGRAM VESSEL B207'
let s:d[0x100E7]='LINEAR B IDEOGRAM VESSEL B208'
let s:d[0x100E8]='LINEAR B IDEOGRAM VESSEL B209'
let s:d[0x100E9]='LINEAR B IDEOGRAM VESSEL B210'
let s:d[0x100EA]='LINEAR B IDEOGRAM VESSEL B211'
let s:d[0x100EB]='LINEAR B IDEOGRAM VESSEL B212'
let s:d[0x100EC]='LINEAR B IDEOGRAM VESSEL B213'
let s:d[0x100ED]='LINEAR B IDEOGRAM VESSEL B214'
let s:d[0x100EE]='LINEAR B IDEOGRAM VESSEL B215'
let s:d[0x100EF]='LINEAR B IDEOGRAM VESSEL B216'
let s:d[0x100F0]='LINEAR B IDEOGRAM VESSEL B217'
let s:d[0x100F1]='LINEAR B IDEOGRAM VESSEL B218'
let s:d[0x100F2]='LINEAR B IDEOGRAM VESSEL B219'
let s:d[0x100F3]='LINEAR B IDEOGRAM VESSEL B221'
let s:d[0x100F4]='LINEAR B IDEOGRAM VESSEL B222'
let s:d[0x100F5]='LINEAR B IDEOGRAM VESSEL B226'
let s:d[0x100F6]='LINEAR B IDEOGRAM VESSEL B227'
let s:d[0x100F7]='LINEAR B IDEOGRAM VESSEL B228'
let s:d[0x100F8]='LINEAR B IDEOGRAM VESSEL B229'
let s:d[0x100F9]='LINEAR B IDEOGRAM VESSEL B250'
let s:d[0x100FA]='LINEAR B IDEOGRAM VESSEL B305'
let s:d[0x10100]='AEGEAN WORD SEPARATOR LINE'
let s:d[0x10101]='AEGEAN WORD SEPARATOR DOT'
let s:d[0x10102]='AEGEAN CHECK MARK'
let s:d[0x10107]='AEGEAN NUMBER ONE'
let s:d[0x10108]='AEGEAN NUMBER TWO'
let s:d[0x10109]='AEGEAN NUMBER THREE'
let s:d[0x1010A]='AEGEAN NUMBER FOUR'
let s:d[0x1010B]='AEGEAN NUMBER FIVE'
let s:d[0x1010C]='AEGEAN NUMBER SIX'
let s:d[0x1010D]='AEGEAN NUMBER SEVEN'
let s:d[0x1010E]='AEGEAN NUMBER EIGHT'
let s:d[0x1010F]='AEGEAN NUMBER NINE'
let s:d[0x10110]='AEGEAN NUMBER TEN'
let s:d[0x10111]='AEGEAN NUMBER TWENTY'
let s:d[0x10112]='AEGEAN NUMBER THIRTY'
let s:d[0x10113]='AEGEAN NUMBER FORTY'
let s:d[0x10114]='AEGEAN NUMBER FIFTY'
let s:d[0x10115]='AEGEAN NUMBER SIXTY'
let s:d[0x10116]='AEGEAN NUMBER SEVENTY'
let s:d[0x10117]='AEGEAN NUMBER EIGHTY'
let s:d[0x10118]='AEGEAN NUMBER NINETY'
let s:d[0x10119]='AEGEAN NUMBER ONE HUNDRED'
let s:d[0x1011A]='AEGEAN NUMBER TWO HUNDRED'
let s:d[0x1011B]='AEGEAN NUMBER THREE HUNDRED'
let s:d[0x1011C]='AEGEAN NUMBER FOUR HUNDRED'
let s:d[0x1011D]='AEGEAN NUMBER FIVE HUNDRED'
let s:d[0x1011E]='AEGEAN NUMBER SIX HUNDRED'
let s:d[0x1011F]='AEGEAN NUMBER SEVEN HUNDRED'
let s:d[0x10120]='AEGEAN NUMBER EIGHT HUNDRED'
let s:d[0x10121]='AEGEAN NUMBER NINE HUNDRED'
let s:d[0x10122]='AEGEAN NUMBER ONE THOUSAND'
let s:d[0x10123]='AEGEAN NUMBER TWO THOUSAND'
let s:d[0x10124]='AEGEAN NUMBER THREE THOUSAND'
let s:d[0x10125]='AEGEAN NUMBER FOUR THOUSAND'
let s:d[0x10126]='AEGEAN NUMBER FIVE THOUSAND'
let s:d[0x10127]='AEGEAN NUMBER SIX THOUSAND'
let s:d[0x10128]='AEGEAN NUMBER SEVEN THOUSAND'
let s:d[0x10129]='AEGEAN NUMBER EIGHT THOUSAND'
let s:d[0x1012A]='AEGEAN NUMBER NINE THOUSAND'
let s:d[0x1012B]='AEGEAN NUMBER TEN THOUSAND'
let s:d[0x1012C]='AEGEAN NUMBER TWENTY THOUSAND'
let s:d[0x1012D]='AEGEAN NUMBER THIRTY THOUSAND'
let s:d[0x1012E]='AEGEAN NUMBER FORTY THOUSAND'
let s:d[0x1012F]='AEGEAN NUMBER FIFTY THOUSAND'
let s:d[0x10130]='AEGEAN NUMBER SIXTY THOUSAND'
let s:d[0x10131]='AEGEAN NUMBER SEVENTY THOUSAND'
let s:d[0x10132]='AEGEAN NUMBER EIGHTY THOUSAND'
let s:d[0x10133]='AEGEAN NUMBER NINETY THOUSAND'
let s:d[0x10137]='AEGEAN WEIGHT BASE UNIT'
let s:d[0x10138]='AEGEAN WEIGHT FIRST SUBUNIT'
let s:d[0x10139]='AEGEAN WEIGHT SECOND SUBUNIT'
let s:d[0x1013A]='AEGEAN WEIGHT THIRD SUBUNIT'
let s:d[0x1013B]='AEGEAN WEIGHT FOURTH SUBUNIT'
let s:d[0x1013C]='AEGEAN DRY MEASURE FIRST SUBUNIT'
let s:d[0x1013D]='AEGEAN LIQUID MEASURE FIRST SUBUNIT'
let s:d[0x1013E]='AEGEAN MEASURE SECOND SUBUNIT'
let s:d[0x1013F]='AEGEAN MEASURE THIRD SUBUNIT'
let s:d[0x10140]='GREEK ACROPHONIC ATTIC ONE QUARTER'
let s:d[0x10141]='GREEK ACROPHONIC ATTIC ONE HALF'
let s:d[0x10142]='GREEK ACROPHONIC ATTIC ONE DRACHMA'
let s:d[0x10143]='GREEK ACROPHONIC ATTIC FIVE'
let s:d[0x10144]='GREEK ACROPHONIC ATTIC FIFTY'
let s:d[0x10145]='GREEK ACROPHONIC ATTIC FIVE HUNDRED'
let s:d[0x10146]='GREEK ACROPHONIC ATTIC FIVE THOUSAND'
let s:d[0x10147]='GREEK ACROPHONIC ATTIC FIFTY THOUSAND'
let s:d[0x10148]='GREEK ACROPHONIC ATTIC FIVE TALENTS'
let s:d[0x10149]='GREEK ACROPHONIC ATTIC TEN TALENTS'
let s:d[0x1014A]='GREEK ACROPHONIC ATTIC FIFTY TALENTS'
let s:d[0x1014B]='GREEK ACROPHONIC ATTIC ONE HUNDRED TALENTS'
let s:d[0x1014C]='GREEK ACROPHONIC ATTIC FIVE HUNDRED TALENTS'
let s:d[0x1014D]='GREEK ACROPHONIC ATTIC ONE THOUSAND TALENTS'
let s:d[0x1014E]='GREEK ACROPHONIC ATTIC FIVE THOUSAND TALENTS'
let s:d[0x1014F]='GREEK ACROPHONIC ATTIC FIVE STATERS'
let s:d[0x10150]='GREEK ACROPHONIC ATTIC TEN STATERS'
let s:d[0x10151]='GREEK ACROPHONIC ATTIC FIFTY STATERS'
let s:d[0x10152]='GREEK ACROPHONIC ATTIC ONE HUNDRED STATERS'
let s:d[0x10153]='GREEK ACROPHONIC ATTIC FIVE HUNDRED STATERS'
let s:d[0x10154]='GREEK ACROPHONIC ATTIC ONE THOUSAND STATERS'
let s:d[0x10155]='GREEK ACROPHONIC ATTIC TEN THOUSAND STATERS'
let s:d[0x10156]='GREEK ACROPHONIC ATTIC FIFTY THOUSAND STATERS'
let s:d[0x10157]='GREEK ACROPHONIC ATTIC TEN MNAS'
let s:d[0x10158]='GREEK ACROPHONIC HERAEUM ONE PLETHRON'
let s:d[0x10159]='GREEK ACROPHONIC THESPIAN ONE'
let s:d[0x1015A]='GREEK ACROPHONIC HERMIONIAN ONE'
let s:d[0x1015B]='GREEK ACROPHONIC EPIDAUREAN TWO'
let s:d[0x1015C]='GREEK ACROPHONIC THESPIAN TWO'
let s:d[0x1015D]='GREEK ACROPHONIC CYRENAIC TWO DRACHMAS'
let s:d[0x1015E]='GREEK ACROPHONIC EPIDAUREAN TWO DRACHMAS'
let s:d[0x1015F]='GREEK ACROPHONIC TROEZENIAN FIVE'
let s:d[0x10160]='GREEK ACROPHONIC TROEZENIAN TEN'
let s:d[0x10161]='GREEK ACROPHONIC TROEZENIAN TEN ALTERNATE FORM'
let s:d[0x10162]='GREEK ACROPHONIC HERMIONIAN TEN'
let s:d[0x10163]='GREEK ACROPHONIC MESSENIAN TEN'
let s:d[0x10164]='GREEK ACROPHONIC THESPIAN TEN'
let s:d[0x10165]='GREEK ACROPHONIC THESPIAN THIRTY'
let s:d[0x10166]='GREEK ACROPHONIC TROEZENIAN FIFTY'
let s:d[0x10167]='GREEK ACROPHONIC TROEZENIAN FIFTY ALTERNATE FORM'
let s:d[0x10168]='GREEK ACROPHONIC HERMIONIAN FIFTY'
let s:d[0x10169]='GREEK ACROPHONIC THESPIAN FIFTY'
let s:d[0x1016A]='GREEK ACROPHONIC THESPIAN ONE HUNDRED'
let s:d[0x1016B]='GREEK ACROPHONIC THESPIAN THREE HUNDRED'
let s:d[0x1016C]='GREEK ACROPHONIC EPIDAUREAN FIVE HUNDRED'
let s:d[0x1016D]='GREEK ACROPHONIC TROEZENIAN FIVE HUNDRED'
let s:d[0x1016E]='GREEK ACROPHONIC THESPIAN FIVE HUNDRED'
let s:d[0x1016F]='GREEK ACROPHONIC CARYSTIAN FIVE HUNDRED'
let s:d[0x10170]='GREEK ACROPHONIC NAXIAN FIVE HUNDRED'
let s:d[0x10171]='GREEK ACROPHONIC THESPIAN ONE THOUSAND'
let s:d[0x10172]='GREEK ACROPHONIC THESPIAN FIVE THOUSAND'
let s:d[0x10173]='GREEK ACROPHONIC DELPHIC FIVE MNAS'
let s:d[0x10174]='GREEK ACROPHONIC STRATIAN FIFTY MNAS'
let s:d[0x10175]='GREEK ONE HALF SIGN'
let s:d[0x10176]='GREEK ONE HALF SIGN ALTERNATE FORM'
let s:d[0x10177]='GREEK TWO THIRDS SIGN'
let s:d[0x10178]='GREEK THREE QUARTERS SIGN'
let s:d[0x10179]='GREEK YEAR SIGN'
let s:d[0x1017A]='GREEK TALENT SIGN'
let s:d[0x1017B]='GREEK DRACHMA SIGN'
let s:d[0x1017C]='GREEK OBOL SIGN'
let s:d[0x1017D]='GREEK TWO OBOLS SIGN'
let s:d[0x1017E]='GREEK THREE OBOLS SIGN'
let s:d[0x1017F]='GREEK FOUR OBOLS SIGN'
let s:d[0x10180]='GREEK FIVE OBOLS SIGN'
let s:d[0x10181]='GREEK METRETES SIGN'
let s:d[0x10182]='GREEK KYATHOS BASE SIGN'
let s:d[0x10183]='GREEK LITRA SIGN'
let s:d[0x10184]='GREEK OUNKIA SIGN'
let s:d[0x10185]='GREEK XESTES SIGN'
let s:d[0x10186]='GREEK ARTABE SIGN'
let s:d[0x10187]='GREEK AROURA SIGN'
let s:d[0x10188]='GREEK GRAMMA SIGN'
let s:d[0x10189]='GREEK TRYBLION BASE SIGN'
let s:d[0x1018A]='GREEK ZERO SIGN'
let s:d[0x10190]='ROMAN SEXTANS SIGN'
let s:d[0x10191]='ROMAN UNCIA SIGN'
let s:d[0x10192]='ROMAN SEMUNCIA SIGN'
let s:d[0x10193]='ROMAN SEXTULA SIGN'
let s:d[0x10194]='ROMAN DIMIDIA SEXTULA SIGN'
let s:d[0x10195]='ROMAN SILIQUA SIGN'
let s:d[0x10196]='ROMAN DENARIUS SIGN'
let s:d[0x10197]='ROMAN QUINARIUS SIGN'
let s:d[0x10198]='ROMAN SESTERTIUS SIGN'
let s:d[0x10199]='ROMAN DUPONDIUS SIGN'
let s:d[0x1019A]='ROMAN AS SIGN'
let s:d[0x1019B]='ROMAN CENTURIAL SIGN'
let s:d[0x101D0]='PHAISTOS DISC SIGN PEDESTRIAN'
let s:d[0x101D1]='PHAISTOS DISC SIGN PLUMED HEAD'
let s:d[0x101D2]='PHAISTOS DISC SIGN TATTOOED HEAD'
let s:d[0x101D3]='PHAISTOS DISC SIGN CAPTIVE'
let s:d[0x101D4]='PHAISTOS DISC SIGN CHILD'
let s:d[0x101D5]='PHAISTOS DISC SIGN WOMAN'
let s:d[0x101D6]='PHAISTOS DISC SIGN HELMET'
let s:d[0x101D7]='PHAISTOS DISC SIGN GAUNTLET'
let s:d[0x101D8]='PHAISTOS DISC SIGN TIARA'
let s:d[0x101D9]='PHAISTOS DISC SIGN ARROW'
let s:d[0x101DA]='PHAISTOS DISC SIGN BOW'
let s:d[0x101DB]='PHAISTOS DISC SIGN SHIELD'
let s:d[0x101DC]='PHAISTOS DISC SIGN CLUB'
let s:d[0x101DD]='PHAISTOS DISC SIGN MANACLES'
let s:d[0x101DE]='PHAISTOS DISC SIGN MATTOCK'
let s:d[0x101DF]='PHAISTOS DISC SIGN SAW'
let s:d[0x101E0]='PHAISTOS DISC SIGN LID'
let s:d[0x101E1]='PHAISTOS DISC SIGN BOOMERANG'
let s:d[0x101E2]='PHAISTOS DISC SIGN CARPENTRY PLANE'
let s:d[0x101E3]='PHAISTOS DISC SIGN DOLIUM'
let s:d[0x101E4]='PHAISTOS DISC SIGN COMB'
let s:d[0x101E5]='PHAISTOS DISC SIGN SLING'
let s:d[0x101E6]='PHAISTOS DISC SIGN COLUMN'
let s:d[0x101E7]='PHAISTOS DISC SIGN BEEHIVE'
let s:d[0x101E8]='PHAISTOS DISC SIGN SHIP'
let s:d[0x101E9]='PHAISTOS DISC SIGN HORN'
let s:d[0x101EA]='PHAISTOS DISC SIGN HIDE'
let s:d[0x101EB]='PHAISTOS DISC SIGN BULLS LEG'
let s:d[0x101EC]='PHAISTOS DISC SIGN CAT'
let s:d[0x101ED]='PHAISTOS DISC SIGN RAM'
let s:d[0x101EE]='PHAISTOS DISC SIGN EAGLE'
let s:d[0x101EF]='PHAISTOS DISC SIGN DOVE'
let s:d[0x101F0]='PHAISTOS DISC SIGN TUNNY'
let s:d[0x101F1]='PHAISTOS DISC SIGN BEE'
let s:d[0x101F2]='PHAISTOS DISC SIGN PLANE TREE'
let s:d[0x101F3]='PHAISTOS DISC SIGN VINE'
let s:d[0x101F4]='PHAISTOS DISC SIGN PAPYRUS'
let s:d[0x101F5]='PHAISTOS DISC SIGN ROSETTE'
let s:d[0x101F6]='PHAISTOS DISC SIGN LILY'
let s:d[0x101F7]='PHAISTOS DISC SIGN OX BACK'
let s:d[0x101F8]='PHAISTOS DISC SIGN FLUTE'
let s:d[0x101F9]='PHAISTOS DISC SIGN GRATER'
let s:d[0x101FA]='PHAISTOS DISC SIGN STRAINER'
let s:d[0x101FB]='PHAISTOS DISC SIGN SMALL AXE'
let s:d[0x101FC]='PHAISTOS DISC SIGN WAVY BAND'
let s:d[0x101FD]='PHAISTOS DISC SIGN COMBINING OBLIQUE STROKE'
let s:d[0x10280]='LYCIAN LETTER A'
let s:d[0x10281]='LYCIAN LETTER E'
let s:d[0x10282]='LYCIAN LETTER B'
let s:d[0x10283]='LYCIAN LETTER BH'
let s:d[0x10284]='LYCIAN LETTER G'
let s:d[0x10285]='LYCIAN LETTER D'
let s:d[0x10286]='LYCIAN LETTER I'
let s:d[0x10287]='LYCIAN LETTER W'
let s:d[0x10288]='LYCIAN LETTER Z'
let s:d[0x10289]='LYCIAN LETTER TH'
let s:d[0x1028A]='LYCIAN LETTER J'
let s:d[0x1028B]='LYCIAN LETTER K'
let s:d[0x1028C]='LYCIAN LETTER Q'
let s:d[0x1028D]='LYCIAN LETTER L'
let s:d[0x1028E]='LYCIAN LETTER M'
let s:d[0x1028F]='LYCIAN LETTER N'
let s:d[0x10290]='LYCIAN LETTER MM'
let s:d[0x10291]='LYCIAN LETTER NN'
let s:d[0x10292]='LYCIAN LETTER U'
let s:d[0x10293]='LYCIAN LETTER P'
let s:d[0x10294]='LYCIAN LETTER KK'
let s:d[0x10295]='LYCIAN LETTER R'
let s:d[0x10296]='LYCIAN LETTER S'
let s:d[0x10297]='LYCIAN LETTER T'
let s:d[0x10298]='LYCIAN LETTER TT'
let s:d[0x10299]='LYCIAN LETTER AN'
let s:d[0x1029A]='LYCIAN LETTER EN'
let s:d[0x1029B]='LYCIAN LETTER H'
let s:d[0x1029C]='LYCIAN LETTER X'
let s:d[0x102A0]='CARIAN LETTER A'
let s:d[0x102A1]='CARIAN LETTER P2'
let s:d[0x102A2]='CARIAN LETTER D'
let s:d[0x102A3]='CARIAN LETTER L'
let s:d[0x102A4]='CARIAN LETTER UUU'
let s:d[0x102A5]='CARIAN LETTER R'
let s:d[0x102A6]='CARIAN LETTER LD'
let s:d[0x102A7]='CARIAN LETTER A2'
let s:d[0x102A8]='CARIAN LETTER Q'
let s:d[0x102A9]='CARIAN LETTER B'
let s:d[0x102AA]='CARIAN LETTER M'
let s:d[0x102AB]='CARIAN LETTER O'
let s:d[0x102AC]='CARIAN LETTER D2'
let s:d[0x102AD]='CARIAN LETTER T'
let s:d[0x102AE]='CARIAN LETTER SH'
let s:d[0x102AF]='CARIAN LETTER SH2'
let s:d[0x102B0]='CARIAN LETTER S'
let s:d[0x102B1]='CARIAN LETTER C-18'
let s:d[0x102B2]='CARIAN LETTER U'
let s:d[0x102B3]='CARIAN LETTER NN'
let s:d[0x102B4]='CARIAN LETTER X'
let s:d[0x102B5]='CARIAN LETTER N'
let s:d[0x102B6]='CARIAN LETTER TT2'
let s:d[0x102B7]='CARIAN LETTER P'
let s:d[0x102B8]='CARIAN LETTER SS'
let s:d[0x102B9]='CARIAN LETTER I'
let s:d[0x102BA]='CARIAN LETTER E'
let s:d[0x102BB]='CARIAN LETTER UUUU'
let s:d[0x102BC]='CARIAN LETTER K'
let s:d[0x102BD]='CARIAN LETTER K2'
let s:d[0x102BE]='CARIAN LETTER ND'
let s:d[0x102BF]='CARIAN LETTER UU'
let s:d[0x102C0]='CARIAN LETTER G'
let s:d[0x102C1]='CARIAN LETTER G2'
let s:d[0x102C2]='CARIAN LETTER ST'
let s:d[0x102C3]='CARIAN LETTER ST2'
let s:d[0x102C4]='CARIAN LETTER NG'
let s:d[0x102C5]='CARIAN LETTER II'
let s:d[0x102C6]='CARIAN LETTER C-39'
let s:d[0x102C7]='CARIAN LETTER TT'
let s:d[0x102C8]='CARIAN LETTER UUU2'
let s:d[0x102C9]='CARIAN LETTER RR'
let s:d[0x102CA]='CARIAN LETTER MB'
let s:d[0x102CB]='CARIAN LETTER MB2'
let s:d[0x102CC]='CARIAN LETTER MB3'
let s:d[0x102CD]='CARIAN LETTER MB4'
let s:d[0x102CE]='CARIAN LETTER LD2'
let s:d[0x102CF]='CARIAN LETTER E2'
let s:d[0x102D0]='CARIAN LETTER UUU3'
let s:d[0x10300]='OLD ITALIC LETTER A'
let s:d[0x10301]='OLD ITALIC LETTER BE'
let s:d[0x10302]='OLD ITALIC LETTER KE'
let s:d[0x10303]='OLD ITALIC LETTER DE'
let s:d[0x10304]='OLD ITALIC LETTER E'
let s:d[0x10305]='OLD ITALIC LETTER VE'
let s:d[0x10306]='OLD ITALIC LETTER ZE'
let s:d[0x10307]='OLD ITALIC LETTER HE'
let s:d[0x10308]='OLD ITALIC LETTER THE'
let s:d[0x10309]='OLD ITALIC LETTER I'
let s:d[0x1030A]='OLD ITALIC LETTER KA'
let s:d[0x1030B]='OLD ITALIC LETTER EL'
let s:d[0x1030C]='OLD ITALIC LETTER EM'
let s:d[0x1030D]='OLD ITALIC LETTER EN'
let s:d[0x1030E]='OLD ITALIC LETTER ESH'
let s:d[0x1030F]='OLD ITALIC LETTER O'
let s:d[0x10310]='OLD ITALIC LETTER PE'
let s:d[0x10311]='OLD ITALIC LETTER SHE'
let s:d[0x10312]='OLD ITALIC LETTER KU'
let s:d[0x10313]='OLD ITALIC LETTER ER'
let s:d[0x10314]='OLD ITALIC LETTER ES'
let s:d[0x10315]='OLD ITALIC LETTER TE'
let s:d[0x10316]='OLD ITALIC LETTER U'
let s:d[0x10317]='OLD ITALIC LETTER EKS'
let s:d[0x10318]='OLD ITALIC LETTER PHE'
let s:d[0x10319]='OLD ITALIC LETTER KHE'
let s:d[0x1031A]='OLD ITALIC LETTER EF'
let s:d[0x1031B]='OLD ITALIC LETTER ERS'
let s:d[0x1031C]='OLD ITALIC LETTER CHE'
let s:d[0x1031D]='OLD ITALIC LETTER II'
let s:d[0x1031E]='OLD ITALIC LETTER UU'
let s:d[0x10320]='OLD ITALIC NUMERAL ONE'
let s:d[0x10321]='OLD ITALIC NUMERAL FIVE'
let s:d[0x10322]='OLD ITALIC NUMERAL TEN'
let s:d[0x10323]='OLD ITALIC NUMERAL FIFTY'
let s:d[0x10330]='GOTHIC LETTER AHSA'
let s:d[0x10331]='GOTHIC LETTER BAIRKAN'
let s:d[0x10332]='GOTHIC LETTER GIBA'
let s:d[0x10333]='GOTHIC LETTER DAGS'
let s:d[0x10334]='GOTHIC LETTER AIHVUS'
let s:d[0x10335]='GOTHIC LETTER QAIRTHRA'
let s:d[0x10336]='GOTHIC LETTER IUJA'
let s:d[0x10337]='GOTHIC LETTER HAGL'
let s:d[0x10338]='GOTHIC LETTER THIUTH'
let s:d[0x10339]='GOTHIC LETTER EIS'
let s:d[0x1033A]='GOTHIC LETTER KUSMA'
let s:d[0x1033B]='GOTHIC LETTER LAGUS'
let s:d[0x1033C]='GOTHIC LETTER MANNA'
let s:d[0x1033D]='GOTHIC LETTER NAUTHS'
let s:d[0x1033E]='GOTHIC LETTER JER'
let s:d[0x1033F]='GOTHIC LETTER URUS'
let s:d[0x10340]='GOTHIC LETTER PAIRTHRA'
let s:d[0x10341]='GOTHIC LETTER NINETY'
let s:d[0x10342]='GOTHIC LETTER RAIDA'
let s:d[0x10343]='GOTHIC LETTER SAUIL'
let s:d[0x10344]='GOTHIC LETTER TEIWS'
let s:d[0x10345]='GOTHIC LETTER WINJA'
let s:d[0x10346]='GOTHIC LETTER FAIHU'
let s:d[0x10347]='GOTHIC LETTER IGGWS'
let s:d[0x10348]='GOTHIC LETTER HWAIR'
let s:d[0x10349]='GOTHIC LETTER OTHAL'
let s:d[0x1034A]='GOTHIC LETTER NINE HUNDRED'
let s:d[0x10380]='UGARITIC LETTER ALPA'
let s:d[0x10381]='UGARITIC LETTER BETA'
let s:d[0x10382]='UGARITIC LETTER GAMLA'
let s:d[0x10383]='UGARITIC LETTER KHA'
let s:d[0x10384]='UGARITIC LETTER DELTA'
let s:d[0x10385]='UGARITIC LETTER HO'
let s:d[0x10386]='UGARITIC LETTER WO'
let s:d[0x10387]='UGARITIC LETTER ZETA'
let s:d[0x10388]='UGARITIC LETTER HOTA'
let s:d[0x10389]='UGARITIC LETTER TET'
let s:d[0x1038A]='UGARITIC LETTER YOD'
let s:d[0x1038B]='UGARITIC LETTER KAF'
let s:d[0x1038C]='UGARITIC LETTER SHIN'
let s:d[0x1038D]='UGARITIC LETTER LAMDA'
let s:d[0x1038E]='UGARITIC LETTER MEM'
let s:d[0x1038F]='UGARITIC LETTER DHAL'
let s:d[0x10390]='UGARITIC LETTER NUN'
let s:d[0x10391]='UGARITIC LETTER ZU'
let s:d[0x10392]='UGARITIC LETTER SAMKA'
let s:d[0x10393]='UGARITIC LETTER AIN'
let s:d[0x10394]='UGARITIC LETTER PU'
let s:d[0x10395]='UGARITIC LETTER SADE'
let s:d[0x10396]='UGARITIC LETTER QOPA'
let s:d[0x10397]='UGARITIC LETTER RASHA'
let s:d[0x10398]='UGARITIC LETTER THANNA'
let s:d[0x10399]='UGARITIC LETTER GHAIN'
let s:d[0x1039A]='UGARITIC LETTER TO'
let s:d[0x1039B]='UGARITIC LETTER I'
let s:d[0x1039C]='UGARITIC LETTER U'
let s:d[0x1039D]='UGARITIC LETTER SSU'
let s:d[0x1039F]='UGARITIC WORD DIVIDER'
let s:d[0x103A0]='OLD PERSIAN SIGN A'
let s:d[0x103A1]='OLD PERSIAN SIGN I'
let s:d[0x103A2]='OLD PERSIAN SIGN U'
let s:d[0x103A3]='OLD PERSIAN SIGN KA'
let s:d[0x103A4]='OLD PERSIAN SIGN KU'
let s:d[0x103A5]='OLD PERSIAN SIGN GA'
let s:d[0x103A6]='OLD PERSIAN SIGN GU'
let s:d[0x103A7]='OLD PERSIAN SIGN XA'
let s:d[0x103A8]='OLD PERSIAN SIGN CA'
let s:d[0x103A9]='OLD PERSIAN SIGN JA'
let s:d[0x103AA]='OLD PERSIAN SIGN JI'
let s:d[0x103AB]='OLD PERSIAN SIGN TA'
let s:d[0x103AC]='OLD PERSIAN SIGN TU'
let s:d[0x103AD]='OLD PERSIAN SIGN DA'
let s:d[0x103AE]='OLD PERSIAN SIGN DI'
let s:d[0x103AF]='OLD PERSIAN SIGN DU'
let s:d[0x103B0]='OLD PERSIAN SIGN THA'
let s:d[0x103B1]='OLD PERSIAN SIGN PA'
let s:d[0x103B2]='OLD PERSIAN SIGN BA'
let s:d[0x103B3]='OLD PERSIAN SIGN FA'
let s:d[0x103B4]='OLD PERSIAN SIGN NA'
let s:d[0x103B5]='OLD PERSIAN SIGN NU'
let s:d[0x103B6]='OLD PERSIAN SIGN MA'
let s:d[0x103B7]='OLD PERSIAN SIGN MI'
let s:d[0x103B8]='OLD PERSIAN SIGN MU'
let s:d[0x103B9]='OLD PERSIAN SIGN YA'
let s:d[0x103BA]='OLD PERSIAN SIGN VA'
let s:d[0x103BB]='OLD PERSIAN SIGN VI'
let s:d[0x103BC]='OLD PERSIAN SIGN RA'
let s:d[0x103BD]='OLD PERSIAN SIGN RU'
let s:d[0x103BE]='OLD PERSIAN SIGN LA'
let s:d[0x103BF]='OLD PERSIAN SIGN SA'
let s:d[0x103C0]='OLD PERSIAN SIGN ZA'
let s:d[0x103C1]='OLD PERSIAN SIGN SHA'
let s:d[0x103C2]='OLD PERSIAN SIGN SSA'
let s:d[0x103C3]='OLD PERSIAN SIGN HA'
let s:d[0x103C8]='OLD PERSIAN SIGN AURAMAZDAA'
let s:d[0x103C9]='OLD PERSIAN SIGN AURAMAZDAA-2'
let s:d[0x103CA]='OLD PERSIAN SIGN AURAMAZDAAHA'
let s:d[0x103CB]='OLD PERSIAN SIGN XSHAAYATHIYA'
let s:d[0x103CC]='OLD PERSIAN SIGN DAHYAAUSH'
let s:d[0x103CD]='OLD PERSIAN SIGN DAHYAAUSH-2'
let s:d[0x103CE]='OLD PERSIAN SIGN BAGA'
let s:d[0x103CF]='OLD PERSIAN SIGN BUUMISH'
let s:d[0x103D0]='OLD PERSIAN WORD DIVIDER'
let s:d[0x103D1]='OLD PERSIAN NUMBER ONE'
let s:d[0x103D2]='OLD PERSIAN NUMBER TWO'
let s:d[0x103D3]='OLD PERSIAN NUMBER TEN'
let s:d[0x103D4]='OLD PERSIAN NUMBER TWENTY'
let s:d[0x103D5]='OLD PERSIAN NUMBER HUNDRED'
let s:d[0x10400]='DESERET CAPITAL LETTER LONG I'
let s:d[0x10401]='DESERET CAPITAL LETTER LONG E'
let s:d[0x10402]='DESERET CAPITAL LETTER LONG A'
let s:d[0x10403]='DESERET CAPITAL LETTER LONG AH'
let s:d[0x10404]='DESERET CAPITAL LETTER LONG O'
let s:d[0x10405]='DESERET CAPITAL LETTER LONG OO'
let s:d[0x10406]='DESERET CAPITAL LETTER SHORT I'
let s:d[0x10407]='DESERET CAPITAL LETTER SHORT E'
let s:d[0x10408]='DESERET CAPITAL LETTER SHORT A'
let s:d[0x10409]='DESERET CAPITAL LETTER SHORT AH'
let s:d[0x1040A]='DESERET CAPITAL LETTER SHORT O'
let s:d[0x1040B]='DESERET CAPITAL LETTER SHORT OO'
let s:d[0x1040C]='DESERET CAPITAL LETTER AY'
let s:d[0x1040D]='DESERET CAPITAL LETTER OW'
let s:d[0x1040E]='DESERET CAPITAL LETTER WU'
let s:d[0x1040F]='DESERET CAPITAL LETTER YEE'
let s:d[0x10410]='DESERET CAPITAL LETTER H'
let s:d[0x10411]='DESERET CAPITAL LETTER PEE'
let s:d[0x10412]='DESERET CAPITAL LETTER BEE'
let s:d[0x10413]='DESERET CAPITAL LETTER TEE'
let s:d[0x10414]='DESERET CAPITAL LETTER DEE'
let s:d[0x10415]='DESERET CAPITAL LETTER CHEE'
let s:d[0x10416]='DESERET CAPITAL LETTER JEE'
let s:d[0x10417]='DESERET CAPITAL LETTER KAY'
let s:d[0x10418]='DESERET CAPITAL LETTER GAY'
let s:d[0x10419]='DESERET CAPITAL LETTER EF'
let s:d[0x1041A]='DESERET CAPITAL LETTER VEE'
let s:d[0x1041B]='DESERET CAPITAL LETTER ETH'
let s:d[0x1041C]='DESERET CAPITAL LETTER THEE'
let s:d[0x1041D]='DESERET CAPITAL LETTER ES'
let s:d[0x1041E]='DESERET CAPITAL LETTER ZEE'
let s:d[0x1041F]='DESERET CAPITAL LETTER ESH'
let s:d[0x10420]='DESERET CAPITAL LETTER ZHEE'
let s:d[0x10421]='DESERET CAPITAL LETTER ER'
let s:d[0x10422]='DESERET CAPITAL LETTER EL'
let s:d[0x10423]='DESERET CAPITAL LETTER EM'
let s:d[0x10424]='DESERET CAPITAL LETTER EN'
let s:d[0x10425]='DESERET CAPITAL LETTER ENG'
let s:d[0x10426]='DESERET CAPITAL LETTER OI'
let s:d[0x10427]='DESERET CAPITAL LETTER EW'
let s:d[0x10428]='DESERET SMALL LETTER LONG I'
let s:d[0x10429]='DESERET SMALL LETTER LONG E'
let s:d[0x1042A]='DESERET SMALL LETTER LONG A'
let s:d[0x1042B]='DESERET SMALL LETTER LONG AH'
let s:d[0x1042C]='DESERET SMALL LETTER LONG O'
let s:d[0x1042D]='DESERET SMALL LETTER LONG OO'
let s:d[0x1042E]='DESERET SMALL LETTER SHORT I'
let s:d[0x1042F]='DESERET SMALL LETTER SHORT E'
let s:d[0x10430]='DESERET SMALL LETTER SHORT A'
let s:d[0x10431]='DESERET SMALL LETTER SHORT AH'
let s:d[0x10432]='DESERET SMALL LETTER SHORT O'
let s:d[0x10433]='DESERET SMALL LETTER SHORT OO'
let s:d[0x10434]='DESERET SMALL LETTER AY'
let s:d[0x10435]='DESERET SMALL LETTER OW'
let s:d[0x10436]='DESERET SMALL LETTER WU'
let s:d[0x10437]='DESERET SMALL LETTER YEE'
let s:d[0x10438]='DESERET SMALL LETTER H'
let s:d[0x10439]='DESERET SMALL LETTER PEE'
let s:d[0x1043A]='DESERET SMALL LETTER BEE'
let s:d[0x1043B]='DESERET SMALL LETTER TEE'
let s:d[0x1043C]='DESERET SMALL LETTER DEE'
let s:d[0x1043D]='DESERET SMALL LETTER CHEE'
let s:d[0x1043E]='DESERET SMALL LETTER JEE'
let s:d[0x1043F]='DESERET SMALL LETTER KAY'
let s:d[0x10440]='DESERET SMALL LETTER GAY'
let s:d[0x10441]='DESERET SMALL LETTER EF'
let s:d[0x10442]='DESERET SMALL LETTER VEE'
let s:d[0x10443]='DESERET SMALL LETTER ETH'
let s:d[0x10444]='DESERET SMALL LETTER THEE'
let s:d[0x10445]='DESERET SMALL LETTER ES'
let s:d[0x10446]='DESERET SMALL LETTER ZEE'
let s:d[0x10447]='DESERET SMALL LETTER ESH'
let s:d[0x10448]='DESERET SMALL LETTER ZHEE'
let s:d[0x10449]='DESERET SMALL LETTER ER'
let s:d[0x1044A]='DESERET SMALL LETTER EL'
let s:d[0x1044B]='DESERET SMALL LETTER EM'
let s:d[0x1044C]='DESERET SMALL LETTER EN'
let s:d[0x1044D]='DESERET SMALL LETTER ENG'
let s:d[0x1044E]='DESERET SMALL LETTER OI'
let s:d[0x1044F]='DESERET SMALL LETTER EW'
let s:d[0x10450]='SHAVIAN LETTER PEEP'
let s:d[0x10451]='SHAVIAN LETTER TOT'
let s:d[0x10452]='SHAVIAN LETTER KICK'
let s:d[0x10453]='SHAVIAN LETTER FEE'
let s:d[0x10454]='SHAVIAN LETTER THIGH'
let s:d[0x10455]='SHAVIAN LETTER SO'
let s:d[0x10456]='SHAVIAN LETTER SURE'
let s:d[0x10457]='SHAVIAN LETTER CHURCH'
let s:d[0x10458]='SHAVIAN LETTER YEA'
let s:d[0x10459]='SHAVIAN LETTER HUNG'
let s:d[0x1045A]='SHAVIAN LETTER BIB'
let s:d[0x1045B]='SHAVIAN LETTER DEAD'
let s:d[0x1045C]='SHAVIAN LETTER GAG'
let s:d[0x1045D]='SHAVIAN LETTER VOW'
let s:d[0x1045E]='SHAVIAN LETTER THEY'
let s:d[0x1045F]='SHAVIAN LETTER ZOO'
let s:d[0x10460]='SHAVIAN LETTER MEASURE'
let s:d[0x10461]='SHAVIAN LETTER JUDGE'
let s:d[0x10462]='SHAVIAN LETTER WOE'
let s:d[0x10463]='SHAVIAN LETTER HA-HA'
let s:d[0x10464]='SHAVIAN LETTER LOLL'
let s:d[0x10465]='SHAVIAN LETTER MIME'
let s:d[0x10466]='SHAVIAN LETTER IF'
let s:d[0x10467]='SHAVIAN LETTER EGG'
let s:d[0x10468]='SHAVIAN LETTER ASH'
let s:d[0x10469]='SHAVIAN LETTER ADO'
let s:d[0x1046A]='SHAVIAN LETTER ON'
let s:d[0x1046B]='SHAVIAN LETTER WOOL'
let s:d[0x1046C]='SHAVIAN LETTER OUT'
let s:d[0x1046D]='SHAVIAN LETTER AH'
let s:d[0x1046E]='SHAVIAN LETTER ROAR'
let s:d[0x1046F]='SHAVIAN LETTER NUN'
let s:d[0x10470]='SHAVIAN LETTER EAT'
let s:d[0x10471]='SHAVIAN LETTER AGE'
let s:d[0x10472]='SHAVIAN LETTER ICE'
let s:d[0x10473]='SHAVIAN LETTER UP'
let s:d[0x10474]='SHAVIAN LETTER OAK'
let s:d[0x10475]='SHAVIAN LETTER OOZE'
let s:d[0x10476]='SHAVIAN LETTER OIL'
let s:d[0x10477]='SHAVIAN LETTER AWE'
let s:d[0x10478]='SHAVIAN LETTER ARE'
let s:d[0x10479]='SHAVIAN LETTER OR'
let s:d[0x1047A]='SHAVIAN LETTER AIR'
let s:d[0x1047B]='SHAVIAN LETTER ERR'
let s:d[0x1047C]='SHAVIAN LETTER ARRAY'
let s:d[0x1047D]='SHAVIAN LETTER EAR'
let s:d[0x1047E]='SHAVIAN LETTER IAN'
let s:d[0x1047F]='SHAVIAN LETTER YEW'
let s:d[0x10480]='OSMANYA LETTER ALEF'
let s:d[0x10481]='OSMANYA LETTER BA'
let s:d[0x10482]='OSMANYA LETTER TA'
let s:d[0x10483]='OSMANYA LETTER JA'
let s:d[0x10484]='OSMANYA LETTER XA'
let s:d[0x10485]='OSMANYA LETTER KHA'
let s:d[0x10486]='OSMANYA LETTER DEEL'
let s:d[0x10487]='OSMANYA LETTER RA'
let s:d[0x10488]='OSMANYA LETTER SA'
let s:d[0x10489]='OSMANYA LETTER SHIIN'
let s:d[0x1048A]='OSMANYA LETTER DHA'
let s:d[0x1048B]='OSMANYA LETTER CAYN'
let s:d[0x1048C]='OSMANYA LETTER GA'
let s:d[0x1048D]='OSMANYA LETTER FA'
let s:d[0x1048E]='OSMANYA LETTER QAAF'
let s:d[0x1048F]='OSMANYA LETTER KAAF'
let s:d[0x10490]='OSMANYA LETTER LAAN'
let s:d[0x10491]='OSMANYA LETTER MIIN'
let s:d[0x10492]='OSMANYA LETTER NUUN'
let s:d[0x10493]='OSMANYA LETTER WAW'
let s:d[0x10494]='OSMANYA LETTER HA'
let s:d[0x10495]='OSMANYA LETTER YA'
let s:d[0x10496]='OSMANYA LETTER A'
let s:d[0x10497]='OSMANYA LETTER E'
let s:d[0x10498]='OSMANYA LETTER I'
let s:d[0x10499]='OSMANYA LETTER O'
let s:d[0x1049A]='OSMANYA LETTER U'
let s:d[0x1049B]='OSMANYA LETTER AA'
let s:d[0x1049C]='OSMANYA LETTER EE'
let s:d[0x1049D]='OSMANYA LETTER OO'
let s:d[0x104A0]='OSMANYA DIGIT ZERO'
let s:d[0x104A1]='OSMANYA DIGIT ONE'
let s:d[0x104A2]='OSMANYA DIGIT TWO'
let s:d[0x104A3]='OSMANYA DIGIT THREE'
let s:d[0x104A4]='OSMANYA DIGIT FOUR'
let s:d[0x104A5]='OSMANYA DIGIT FIVE'
let s:d[0x104A6]='OSMANYA DIGIT SIX'
let s:d[0x104A7]='OSMANYA DIGIT SEVEN'
let s:d[0x104A8]='OSMANYA DIGIT EIGHT'
let s:d[0x104A9]='OSMANYA DIGIT NINE'
let s:d[0x10800]='CYPRIOT SYLLABLE A'
let s:d[0x10801]='CYPRIOT SYLLABLE E'
let s:d[0x10802]='CYPRIOT SYLLABLE I'
let s:d[0x10803]='CYPRIOT SYLLABLE O'
let s:d[0x10804]='CYPRIOT SYLLABLE U'
let s:d[0x10805]='CYPRIOT SYLLABLE JA'
let s:d[0x10808]='CYPRIOT SYLLABLE JO'
let s:d[0x1080A]='CYPRIOT SYLLABLE KA'
let s:d[0x1080B]='CYPRIOT SYLLABLE KE'
let s:d[0x1080C]='CYPRIOT SYLLABLE KI'
let s:d[0x1080D]='CYPRIOT SYLLABLE KO'
let s:d[0x1080E]='CYPRIOT SYLLABLE KU'
let s:d[0x1080F]='CYPRIOT SYLLABLE LA'
let s:d[0x10810]='CYPRIOT SYLLABLE LE'
let s:d[0x10811]='CYPRIOT SYLLABLE LI'
let s:d[0x10812]='CYPRIOT SYLLABLE LO'
let s:d[0x10813]='CYPRIOT SYLLABLE LU'
let s:d[0x10814]='CYPRIOT SYLLABLE MA'
let s:d[0x10815]='CYPRIOT SYLLABLE ME'
let s:d[0x10816]='CYPRIOT SYLLABLE MI'
let s:d[0x10817]='CYPRIOT SYLLABLE MO'
let s:d[0x10818]='CYPRIOT SYLLABLE MU'
let s:d[0x10819]='CYPRIOT SYLLABLE NA'
let s:d[0x1081A]='CYPRIOT SYLLABLE NE'
let s:d[0x1081B]='CYPRIOT SYLLABLE NI'
let s:d[0x1081C]='CYPRIOT SYLLABLE NO'
let s:d[0x1081D]='CYPRIOT SYLLABLE NU'
let s:d[0x1081E]='CYPRIOT SYLLABLE PA'
let s:d[0x1081F]='CYPRIOT SYLLABLE PE'
let s:d[0x10820]='CYPRIOT SYLLABLE PI'
let s:d[0x10821]='CYPRIOT SYLLABLE PO'
let s:d[0x10822]='CYPRIOT SYLLABLE PU'
let s:d[0x10823]='CYPRIOT SYLLABLE RA'
let s:d[0x10824]='CYPRIOT SYLLABLE RE'
let s:d[0x10825]='CYPRIOT SYLLABLE RI'
let s:d[0x10826]='CYPRIOT SYLLABLE RO'
let s:d[0x10827]='CYPRIOT SYLLABLE RU'
let s:d[0x10828]='CYPRIOT SYLLABLE SA'
let s:d[0x10829]='CYPRIOT SYLLABLE SE'
let s:d[0x1082A]='CYPRIOT SYLLABLE SI'
let s:d[0x1082B]='CYPRIOT SYLLABLE SO'
let s:d[0x1082C]='CYPRIOT SYLLABLE SU'
let s:d[0x1082D]='CYPRIOT SYLLABLE TA'
let s:d[0x1082E]='CYPRIOT SYLLABLE TE'
let s:d[0x1082F]='CYPRIOT SYLLABLE TI'
let s:d[0x10830]='CYPRIOT SYLLABLE TO'
let s:d[0x10831]='CYPRIOT SYLLABLE TU'
let s:d[0x10832]='CYPRIOT SYLLABLE WA'
let s:d[0x10833]='CYPRIOT SYLLABLE WE'
let s:d[0x10834]='CYPRIOT SYLLABLE WI'
let s:d[0x10835]='CYPRIOT SYLLABLE WO'
let s:d[0x10837]='CYPRIOT SYLLABLE XA'
let s:d[0x10838]='CYPRIOT SYLLABLE XE'
let s:d[0x1083C]='CYPRIOT SYLLABLE ZA'
let s:d[0x1083F]='CYPRIOT SYLLABLE ZO'
let s:d[0x10840]='IMPERIAL ARAMAIC LETTER ALEPH'
let s:d[0x10841]='IMPERIAL ARAMAIC LETTER BETH'
let s:d[0x10842]='IMPERIAL ARAMAIC LETTER GIMEL'
let s:d[0x10843]='IMPERIAL ARAMAIC LETTER DALETH'
let s:d[0x10844]='IMPERIAL ARAMAIC LETTER HE'
let s:d[0x10845]='IMPERIAL ARAMAIC LETTER WAW'
let s:d[0x10846]='IMPERIAL ARAMAIC LETTER ZAYIN'
let s:d[0x10847]='IMPERIAL ARAMAIC LETTER HETH'
let s:d[0x10848]='IMPERIAL ARAMAIC LETTER TETH'
let s:d[0x10849]='IMPERIAL ARAMAIC LETTER YODH'
let s:d[0x1084A]='IMPERIAL ARAMAIC LETTER KAPH'
let s:d[0x1084B]='IMPERIAL ARAMAIC LETTER LAMEDH'
let s:d[0x1084C]='IMPERIAL ARAMAIC LETTER MEM'
let s:d[0x1084D]='IMPERIAL ARAMAIC LETTER NUN'
let s:d[0x1084E]='IMPERIAL ARAMAIC LETTER SAMEKH'
let s:d[0x1084F]='IMPERIAL ARAMAIC LETTER AYIN'
let s:d[0x10850]='IMPERIAL ARAMAIC LETTER PE'
let s:d[0x10851]='IMPERIAL ARAMAIC LETTER SADHE'
let s:d[0x10852]='IMPERIAL ARAMAIC LETTER QOPH'
let s:d[0x10853]='IMPERIAL ARAMAIC LETTER RESH'
let s:d[0x10854]='IMPERIAL ARAMAIC LETTER SHIN'
let s:d[0x10855]='IMPERIAL ARAMAIC LETTER TAW'
let s:d[0x10857]='IMPERIAL ARAMAIC SECTION SIGN'
let s:d[0x10858]='IMPERIAL ARAMAIC NUMBER ONE'
let s:d[0x10859]='IMPERIAL ARAMAIC NUMBER TWO'
let s:d[0x1085A]='IMPERIAL ARAMAIC NUMBER THREE'
let s:d[0x1085B]='IMPERIAL ARAMAIC NUMBER TEN'
let s:d[0x1085C]='IMPERIAL ARAMAIC NUMBER TWENTY'
let s:d[0x1085D]='IMPERIAL ARAMAIC NUMBER ONE HUNDRED'
let s:d[0x1085E]='IMPERIAL ARAMAIC NUMBER ONE THOUSAND'
let s:d[0x1085F]='IMPERIAL ARAMAIC NUMBER TEN THOUSAND'
let s:d[0x10900]='PHOENICIAN LETTER ALF'
let s:d[0x10901]='PHOENICIAN LETTER BET'
let s:d[0x10902]='PHOENICIAN LETTER GAML'
let s:d[0x10903]='PHOENICIAN LETTER DELT'
let s:d[0x10904]='PHOENICIAN LETTER HE'
let s:d[0x10905]='PHOENICIAN LETTER WAU'
let s:d[0x10906]='PHOENICIAN LETTER ZAI'
let s:d[0x10907]='PHOENICIAN LETTER HET'
let s:d[0x10908]='PHOENICIAN LETTER TET'
let s:d[0x10909]='PHOENICIAN LETTER YOD'
let s:d[0x1090A]='PHOENICIAN LETTER KAF'
let s:d[0x1090B]='PHOENICIAN LETTER LAMD'
let s:d[0x1090C]='PHOENICIAN LETTER MEM'
let s:d[0x1090D]='PHOENICIAN LETTER NUN'
let s:d[0x1090E]='PHOENICIAN LETTER SEMK'
let s:d[0x1090F]='PHOENICIAN LETTER AIN'
let s:d[0x10910]='PHOENICIAN LETTER PE'
let s:d[0x10911]='PHOENICIAN LETTER SADE'
let s:d[0x10912]='PHOENICIAN LETTER QOF'
let s:d[0x10913]='PHOENICIAN LETTER ROSH'
let s:d[0x10914]='PHOENICIAN LETTER SHIN'
let s:d[0x10915]='PHOENICIAN LETTER TAU'
let s:d[0x10916]='PHOENICIAN NUMBER ONE'
let s:d[0x10917]='PHOENICIAN NUMBER TEN'
let s:d[0x10918]='PHOENICIAN NUMBER TWENTY'
let s:d[0x10919]='PHOENICIAN NUMBER ONE HUNDRED'
let s:d[0x1091A]='PHOENICIAN NUMBER TWO'
let s:d[0x1091B]='PHOENICIAN NUMBER THREE'
let s:d[0x1091F]='PHOENICIAN WORD SEPARATOR'
let s:d[0x10920]='LYDIAN LETTER A'
let s:d[0x10921]='LYDIAN LETTER B'
let s:d[0x10922]='LYDIAN LETTER G'
let s:d[0x10923]='LYDIAN LETTER D'
let s:d[0x10924]='LYDIAN LETTER E'
let s:d[0x10925]='LYDIAN LETTER V'
let s:d[0x10926]='LYDIAN LETTER I'
let s:d[0x10927]='LYDIAN LETTER Y'
let s:d[0x10928]='LYDIAN LETTER K'
let s:d[0x10929]='LYDIAN LETTER L'
let s:d[0x1092A]='LYDIAN LETTER M'
let s:d[0x1092B]='LYDIAN LETTER N'
let s:d[0x1092C]='LYDIAN LETTER O'
let s:d[0x1092D]='LYDIAN LETTER R'
let s:d[0x1092E]='LYDIAN LETTER SS'
let s:d[0x1092F]='LYDIAN LETTER T'
let s:d[0x10930]='LYDIAN LETTER U'
let s:d[0x10931]='LYDIAN LETTER F'
let s:d[0x10932]='LYDIAN LETTER Q'
let s:d[0x10933]='LYDIAN LETTER S'
let s:d[0x10934]='LYDIAN LETTER TT'
let s:d[0x10935]='LYDIAN LETTER AN'
let s:d[0x10936]='LYDIAN LETTER EN'
let s:d[0x10937]='LYDIAN LETTER LY'
let s:d[0x10938]='LYDIAN LETTER NN'
let s:d[0x10939]='LYDIAN LETTER C'
let s:d[0x1093F]='LYDIAN TRIANGULAR MARK'
let s:d[0x10980]='MEROITIC HIEROGLYPHIC LETTER A'
let s:d[0x10981]='MEROITIC HIEROGLYPHIC LETTER E'
let s:d[0x10982]='MEROITIC HIEROGLYPHIC LETTER I'
let s:d[0x10983]='MEROITIC HIEROGLYPHIC LETTER O'
let s:d[0x10984]='MEROITIC HIEROGLYPHIC LETTER YA'
let s:d[0x10985]='MEROITIC HIEROGLYPHIC LETTER WA'
let s:d[0x10986]='MEROITIC HIEROGLYPHIC LETTER BA'
let s:d[0x10987]='MEROITIC HIEROGLYPHIC LETTER BA-2'
let s:d[0x10988]='MEROITIC HIEROGLYPHIC LETTER PA'
let s:d[0x10989]='MEROITIC HIEROGLYPHIC LETTER MA'
let s:d[0x1098A]='MEROITIC HIEROGLYPHIC LETTER NA'
let s:d[0x1098B]='MEROITIC HIEROGLYPHIC LETTER NA-2'
let s:d[0x1098C]='MEROITIC HIEROGLYPHIC LETTER NE'
let s:d[0x1098D]='MEROITIC HIEROGLYPHIC LETTER NE-2'
let s:d[0x1098E]='MEROITIC HIEROGLYPHIC LETTER RA'
let s:d[0x1098F]='MEROITIC HIEROGLYPHIC LETTER RA-2'
let s:d[0x10990]='MEROITIC HIEROGLYPHIC LETTER LA'
let s:d[0x10991]='MEROITIC HIEROGLYPHIC LETTER KHA'
let s:d[0x10992]='MEROITIC HIEROGLYPHIC LETTER HHA'
let s:d[0x10993]='MEROITIC HIEROGLYPHIC LETTER SA'
let s:d[0x10994]='MEROITIC HIEROGLYPHIC LETTER SA-2'
let s:d[0x10995]='MEROITIC HIEROGLYPHIC LETTER SE'
let s:d[0x10996]='MEROITIC HIEROGLYPHIC LETTER KA'
let s:d[0x10997]='MEROITIC HIEROGLYPHIC LETTER QA'
let s:d[0x10998]='MEROITIC HIEROGLYPHIC LETTER TA'
let s:d[0x10999]='MEROITIC HIEROGLYPHIC LETTER TA-2'
let s:d[0x1099A]='MEROITIC HIEROGLYPHIC LETTER TE'
let s:d[0x1099B]='MEROITIC HIEROGLYPHIC LETTER TE-2'
let s:d[0x1099C]='MEROITIC HIEROGLYPHIC LETTER TO'
let s:d[0x1099D]='MEROITIC HIEROGLYPHIC LETTER DA'
let s:d[0x1099E]='MEROITIC HIEROGLYPHIC SYMBOL VIDJ'
let s:d[0x1099F]='MEROITIC HIEROGLYPHIC SYMBOL VIDJ-2'
let s:d[0x109A0]='MEROITIC CURSIVE LETTER A'
let s:d[0x109A1]='MEROITIC CURSIVE LETTER E'
let s:d[0x109A2]='MEROITIC CURSIVE LETTER I'
let s:d[0x109A3]='MEROITIC CURSIVE LETTER O'
let s:d[0x109A4]='MEROITIC CURSIVE LETTER YA'
let s:d[0x109A5]='MEROITIC CURSIVE LETTER WA'
let s:d[0x109A6]='MEROITIC CURSIVE LETTER BA'
let s:d[0x109A7]='MEROITIC CURSIVE LETTER PA'
let s:d[0x109A8]='MEROITIC CURSIVE LETTER MA'
let s:d[0x109A9]='MEROITIC CURSIVE LETTER NA'
let s:d[0x109AA]='MEROITIC CURSIVE LETTER NE'
let s:d[0x109AB]='MEROITIC CURSIVE LETTER RA'
let s:d[0x109AC]='MEROITIC CURSIVE LETTER LA'
let s:d[0x109AD]='MEROITIC CURSIVE LETTER KHA'
let s:d[0x109AE]='MEROITIC CURSIVE LETTER HHA'
let s:d[0x109AF]='MEROITIC CURSIVE LETTER SA'
let s:d[0x109B0]='MEROITIC CURSIVE LETTER ARCHAIC SA'
let s:d[0x109B1]='MEROITIC CURSIVE LETTER SE'
let s:d[0x109B2]='MEROITIC CURSIVE LETTER KA'
let s:d[0x109B3]='MEROITIC CURSIVE LETTER QA'
let s:d[0x109B4]='MEROITIC CURSIVE LETTER TA'
let s:d[0x109B5]='MEROITIC CURSIVE LETTER TE'
let s:d[0x109B6]='MEROITIC CURSIVE LETTER TO'
let s:d[0x109B7]='MEROITIC CURSIVE LETTER DA'
let s:d[0x109BE]='MEROITIC CURSIVE LOGOGRAM RMT'
let s:d[0x109BF]='MEROITIC CURSIVE LOGOGRAM IMN'
let s:d[0x10A00]='KHAROSHTHI LETTER A'
let s:d[0x10A01]='KHAROSHTHI VOWEL SIGN I'
let s:d[0x10A02]='KHAROSHTHI VOWEL SIGN U'
let s:d[0x10A03]='KHAROSHTHI VOWEL SIGN VOCALIC R'
let s:d[0x10A05]='KHAROSHTHI VOWEL SIGN E'
let s:d[0x10A06]='KHAROSHTHI VOWEL SIGN O'
let s:d[0x10A0C]='KHAROSHTHI VOWEL LENGTH MARK'
let s:d[0x10A0D]='KHAROSHTHI SIGN DOUBLE RING BELOW'
let s:d[0x10A0E]='KHAROSHTHI SIGN ANUSVARA'
let s:d[0x10A0F]='KHAROSHTHI SIGN VISARGA'
let s:d[0x10A10]='KHAROSHTHI LETTER KA'
let s:d[0x10A11]='KHAROSHTHI LETTER KHA'
let s:d[0x10A12]='KHAROSHTHI LETTER GA'
let s:d[0x10A13]='KHAROSHTHI LETTER GHA'
let s:d[0x10A15]='KHAROSHTHI LETTER CA'
let s:d[0x10A16]='KHAROSHTHI LETTER CHA'
let s:d[0x10A17]='KHAROSHTHI LETTER JA'
let s:d[0x10A19]='KHAROSHTHI LETTER NYA'
let s:d[0x10A1A]='KHAROSHTHI LETTER TTA'
let s:d[0x10A1B]='KHAROSHTHI LETTER TTHA'
let s:d[0x10A1C]='KHAROSHTHI LETTER DDA'
let s:d[0x10A1D]='KHAROSHTHI LETTER DDHA'
let s:d[0x10A1E]='KHAROSHTHI LETTER NNA'
let s:d[0x10A1F]='KHAROSHTHI LETTER TA'
let s:d[0x10A20]='KHAROSHTHI LETTER THA'
let s:d[0x10A21]='KHAROSHTHI LETTER DA'
let s:d[0x10A22]='KHAROSHTHI LETTER DHA'
let s:d[0x10A23]='KHAROSHTHI LETTER NA'
let s:d[0x10A24]='KHAROSHTHI LETTER PA'
let s:d[0x10A25]='KHAROSHTHI LETTER PHA'
let s:d[0x10A26]='KHAROSHTHI LETTER BA'
let s:d[0x10A27]='KHAROSHTHI LETTER BHA'
let s:d[0x10A28]='KHAROSHTHI LETTER MA'
let s:d[0x10A29]='KHAROSHTHI LETTER YA'
let s:d[0x10A2A]='KHAROSHTHI LETTER RA'
let s:d[0x10A2B]='KHAROSHTHI LETTER LA'
let s:d[0x10A2C]='KHAROSHTHI LETTER VA'
let s:d[0x10A2D]='KHAROSHTHI LETTER SHA'
let s:d[0x10A2E]='KHAROSHTHI LETTER SSA'
let s:d[0x10A2F]='KHAROSHTHI LETTER SA'
let s:d[0x10A30]='KHAROSHTHI LETTER ZA'
let s:d[0x10A31]='KHAROSHTHI LETTER HA'
let s:d[0x10A32]='KHAROSHTHI LETTER KKA'
let s:d[0x10A33]='KHAROSHTHI LETTER TTTHA'
let s:d[0x10A38]='KHAROSHTHI SIGN BAR ABOVE'
let s:d[0x10A39]='KHAROSHTHI SIGN CAUDA'
let s:d[0x10A3A]='KHAROSHTHI SIGN DOT BELOW'
let s:d[0x10A3F]='KHAROSHTHI VIRAMA'
let s:d[0x10A40]='KHAROSHTHI DIGIT ONE'
let s:d[0x10A41]='KHAROSHTHI DIGIT TWO'
let s:d[0x10A42]='KHAROSHTHI DIGIT THREE'
let s:d[0x10A43]='KHAROSHTHI DIGIT FOUR'
let s:d[0x10A44]='KHAROSHTHI NUMBER TEN'
let s:d[0x10A45]='KHAROSHTHI NUMBER TWENTY'
let s:d[0x10A46]='KHAROSHTHI NUMBER ONE HUNDRED'
let s:d[0x10A47]='KHAROSHTHI NUMBER ONE THOUSAND'
let s:d[0x10A50]='KHAROSHTHI PUNCTUATION DOT'
let s:d[0x10A51]='KHAROSHTHI PUNCTUATION SMALL CIRCLE'
let s:d[0x10A52]='KHAROSHTHI PUNCTUATION CIRCLE'
let s:d[0x10A53]='KHAROSHTHI PUNCTUATION CRESCENT BAR'
let s:d[0x10A54]='KHAROSHTHI PUNCTUATION MANGALAM'
let s:d[0x10A55]='KHAROSHTHI PUNCTUATION LOTUS'
let s:d[0x10A56]='KHAROSHTHI PUNCTUATION DANDA'
let s:d[0x10A57]='KHAROSHTHI PUNCTUATION DOUBLE DANDA'
let s:d[0x10A58]='KHAROSHTHI PUNCTUATION LINES'
let s:d[0x10A60]='OLD SOUTH ARABIAN LETTER HE'
let s:d[0x10A61]='OLD SOUTH ARABIAN LETTER LAMEDH'
let s:d[0x10A62]='OLD SOUTH ARABIAN LETTER HETH'
let s:d[0x10A63]='OLD SOUTH ARABIAN LETTER MEM'
let s:d[0x10A64]='OLD SOUTH ARABIAN LETTER QOPH'
let s:d[0x10A65]='OLD SOUTH ARABIAN LETTER WAW'
let s:d[0x10A66]='OLD SOUTH ARABIAN LETTER SHIN'
let s:d[0x10A67]='OLD SOUTH ARABIAN LETTER RESH'
let s:d[0x10A68]='OLD SOUTH ARABIAN LETTER BETH'
let s:d[0x10A69]='OLD SOUTH ARABIAN LETTER TAW'
let s:d[0x10A6A]='OLD SOUTH ARABIAN LETTER SAT'
let s:d[0x10A6B]='OLD SOUTH ARABIAN LETTER KAPH'
let s:d[0x10A6C]='OLD SOUTH ARABIAN LETTER NUN'
let s:d[0x10A6D]='OLD SOUTH ARABIAN LETTER KHETH'
let s:d[0x10A6E]='OLD SOUTH ARABIAN LETTER SADHE'
let s:d[0x10A6F]='OLD SOUTH ARABIAN LETTER SAMEKH'
let s:d[0x10A70]='OLD SOUTH ARABIAN LETTER FE'
let s:d[0x10A71]='OLD SOUTH ARABIAN LETTER ALEF'
let s:d[0x10A72]='OLD SOUTH ARABIAN LETTER AYN'
let s:d[0x10A73]='OLD SOUTH ARABIAN LETTER DHADHE'
let s:d[0x10A74]='OLD SOUTH ARABIAN LETTER GIMEL'
let s:d[0x10A75]='OLD SOUTH ARABIAN LETTER DALETH'
let s:d[0x10A76]='OLD SOUTH ARABIAN LETTER GHAYN'
let s:d[0x10A77]='OLD SOUTH ARABIAN LETTER TETH'
let s:d[0x10A78]='OLD SOUTH ARABIAN LETTER ZAYN'
let s:d[0x10A79]='OLD SOUTH ARABIAN LETTER DHALETH'
let s:d[0x10A7A]='OLD SOUTH ARABIAN LETTER YODH'
let s:d[0x10A7B]='OLD SOUTH ARABIAN LETTER THAW'
let s:d[0x10A7C]='OLD SOUTH ARABIAN LETTER THETH'
let s:d[0x10A7D]='OLD SOUTH ARABIAN NUMBER ONE'
let s:d[0x10A7E]='OLD SOUTH ARABIAN NUMBER FIFTY'
let s:d[0x10A7F]='OLD SOUTH ARABIAN NUMERIC INDICATOR'
let s:d[0x10B00]='AVESTAN LETTER A'
let s:d[0x10B01]='AVESTAN LETTER AA'
let s:d[0x10B02]='AVESTAN LETTER AO'
let s:d[0x10B03]='AVESTAN LETTER AAO'
let s:d[0x10B04]='AVESTAN LETTER AN'
let s:d[0x10B05]='AVESTAN LETTER AAN'
let s:d[0x10B06]='AVESTAN LETTER AE'
let s:d[0x10B07]='AVESTAN LETTER AEE'
let s:d[0x10B08]='AVESTAN LETTER E'
let s:d[0x10B09]='AVESTAN LETTER EE'
let s:d[0x10B0A]='AVESTAN LETTER O'
let s:d[0x10B0B]='AVESTAN LETTER OO'
let s:d[0x10B0C]='AVESTAN LETTER I'
let s:d[0x10B0D]='AVESTAN LETTER II'
let s:d[0x10B0E]='AVESTAN LETTER U'
let s:d[0x10B0F]='AVESTAN LETTER UU'
let s:d[0x10B10]='AVESTAN LETTER KE'
let s:d[0x10B11]='AVESTAN LETTER XE'
let s:d[0x10B12]='AVESTAN LETTER XYE'
let s:d[0x10B13]='AVESTAN LETTER XVE'
let s:d[0x10B14]='AVESTAN LETTER GE'
let s:d[0x10B15]='AVESTAN LETTER GGE'
let s:d[0x10B16]='AVESTAN LETTER GHE'
let s:d[0x10B17]='AVESTAN LETTER CE'
let s:d[0x10B18]='AVESTAN LETTER JE'
let s:d[0x10B19]='AVESTAN LETTER TE'
let s:d[0x10B1A]='AVESTAN LETTER THE'
let s:d[0x10B1B]='AVESTAN LETTER DE'
let s:d[0x10B1C]='AVESTAN LETTER DHE'
let s:d[0x10B1D]='AVESTAN LETTER TTE'
let s:d[0x10B1E]='AVESTAN LETTER PE'
let s:d[0x10B1F]='AVESTAN LETTER FE'
let s:d[0x10B20]='AVESTAN LETTER BE'
let s:d[0x10B21]='AVESTAN LETTER BHE'
let s:d[0x10B22]='AVESTAN LETTER NGE'
let s:d[0x10B23]='AVESTAN LETTER NGYE'
let s:d[0x10B24]='AVESTAN LETTER NGVE'
let s:d[0x10B25]='AVESTAN LETTER NE'
let s:d[0x10B26]='AVESTAN LETTER NYE'
let s:d[0x10B27]='AVESTAN LETTER NNE'
let s:d[0x10B28]='AVESTAN LETTER ME'
let s:d[0x10B29]='AVESTAN LETTER HME'
let s:d[0x10B2A]='AVESTAN LETTER YYE'
let s:d[0x10B2B]='AVESTAN LETTER YE'
let s:d[0x10B2C]='AVESTAN LETTER VE'
let s:d[0x10B2D]='AVESTAN LETTER RE'
let s:d[0x10B2E]='AVESTAN LETTER LE'
let s:d[0x10B2F]='AVESTAN LETTER SE'
let s:d[0x10B30]='AVESTAN LETTER ZE'
let s:d[0x10B31]='AVESTAN LETTER SHE'
let s:d[0x10B32]='AVESTAN LETTER ZHE'
let s:d[0x10B33]='AVESTAN LETTER SHYE'
let s:d[0x10B34]='AVESTAN LETTER SSHE'
let s:d[0x10B35]='AVESTAN LETTER HE'
let s:d[0x10B39]='AVESTAN ABBREVIATION MARK'
let s:d[0x10B3A]='TINY TWO DOTS OVER ONE DOT PUNCTUATION'
let s:d[0x10B3B]='SMALL TWO DOTS OVER ONE DOT PUNCTUATION'
let s:d[0x10B3C]='LARGE TWO DOTS OVER ONE DOT PUNCTUATION'
let s:d[0x10B3D]='LARGE ONE DOT OVER TWO DOTS PUNCTUATION'
let s:d[0x10B3E]='LARGE TWO RINGS OVER ONE RING PUNCTUATION'
let s:d[0x10B3F]='LARGE ONE RING OVER TWO RINGS PUNCTUATION'
let s:d[0x10B40]='INSCRIPTIONAL PARTHIAN LETTER ALEPH'
let s:d[0x10B41]='INSCRIPTIONAL PARTHIAN LETTER BETH'
let s:d[0x10B42]='INSCRIPTIONAL PARTHIAN LETTER GIMEL'
let s:d[0x10B43]='INSCRIPTIONAL PARTHIAN LETTER DALETH'
let s:d[0x10B44]='INSCRIPTIONAL PARTHIAN LETTER HE'
let s:d[0x10B45]='INSCRIPTIONAL PARTHIAN LETTER WAW'
let s:d[0x10B46]='INSCRIPTIONAL PARTHIAN LETTER ZAYIN'
let s:d[0x10B47]='INSCRIPTIONAL PARTHIAN LETTER HETH'
let s:d[0x10B48]='INSCRIPTIONAL PARTHIAN LETTER TETH'
let s:d[0x10B49]='INSCRIPTIONAL PARTHIAN LETTER YODH'
let s:d[0x10B4A]='INSCRIPTIONAL PARTHIAN LETTER KAPH'
let s:d[0x10B4B]='INSCRIPTIONAL PARTHIAN LETTER LAMEDH'
let s:d[0x10B4C]='INSCRIPTIONAL PARTHIAN LETTER MEM'
let s:d[0x10B4D]='INSCRIPTIONAL PARTHIAN LETTER NUN'
let s:d[0x10B4E]='INSCRIPTIONAL PARTHIAN LETTER SAMEKH'
let s:d[0x10B4F]='INSCRIPTIONAL PARTHIAN LETTER AYIN'
let s:d[0x10B50]='INSCRIPTIONAL PARTHIAN LETTER PE'
let s:d[0x10B51]='INSCRIPTIONAL PARTHIAN LETTER SADHE'
let s:d[0x10B52]='INSCRIPTIONAL PARTHIAN LETTER QOPH'
let s:d[0x10B53]='INSCRIPTIONAL PARTHIAN LETTER RESH'
let s:d[0x10B54]='INSCRIPTIONAL PARTHIAN LETTER SHIN'
let s:d[0x10B55]='INSCRIPTIONAL PARTHIAN LETTER TAW'
let s:d[0x10B58]='INSCRIPTIONAL PARTHIAN NUMBER ONE'
let s:d[0x10B59]='INSCRIPTIONAL PARTHIAN NUMBER TWO'
let s:d[0x10B5A]='INSCRIPTIONAL PARTHIAN NUMBER THREE'
let s:d[0x10B5B]='INSCRIPTIONAL PARTHIAN NUMBER FOUR'
let s:d[0x10B5C]='INSCRIPTIONAL PARTHIAN NUMBER TEN'
let s:d[0x10B5D]='INSCRIPTIONAL PARTHIAN NUMBER TWENTY'
let s:d[0x10B5E]='INSCRIPTIONAL PARTHIAN NUMBER ONE HUNDRED'
let s:d[0x10B5F]='INSCRIPTIONAL PARTHIAN NUMBER ONE THOUSAND'
let s:d[0x10B60]='INSCRIPTIONAL PAHLAVI LETTER ALEPH'
let s:d[0x10B61]='INSCRIPTIONAL PAHLAVI LETTER BETH'
let s:d[0x10B62]='INSCRIPTIONAL PAHLAVI LETTER GIMEL'
let s:d[0x10B63]='INSCRIPTIONAL PAHLAVI LETTER DALETH'
let s:d[0x10B64]='INSCRIPTIONAL PAHLAVI LETTER HE'
let s:d[0x10B65]='INSCRIPTIONAL PAHLAVI LETTER WAW-AYIN-RESH'
let s:d[0x10B66]='INSCRIPTIONAL PAHLAVI LETTER ZAYIN'
let s:d[0x10B67]='INSCRIPTIONAL PAHLAVI LETTER HETH'
let s:d[0x10B68]='INSCRIPTIONAL PAHLAVI LETTER TETH'
let s:d[0x10B69]='INSCRIPTIONAL PAHLAVI LETTER YODH'
let s:d[0x10B6A]='INSCRIPTIONAL PAHLAVI LETTER KAPH'
let s:d[0x10B6B]='INSCRIPTIONAL PAHLAVI LETTER LAMEDH'
let s:d[0x10B6C]='INSCRIPTIONAL PAHLAVI LETTER MEM-QOPH'
let s:d[0x10B6D]='INSCRIPTIONAL PAHLAVI LETTER NUN'
let s:d[0x10B6E]='INSCRIPTIONAL PAHLAVI LETTER SAMEKH'
let s:d[0x10B6F]='INSCRIPTIONAL PAHLAVI LETTER PE'
let s:d[0x10B70]='INSCRIPTIONAL PAHLAVI LETTER SADHE'
let s:d[0x10B71]='INSCRIPTIONAL PAHLAVI LETTER SHIN'
let s:d[0x10B72]='INSCRIPTIONAL PAHLAVI LETTER TAW'
let s:d[0x10B78]='INSCRIPTIONAL PAHLAVI NUMBER ONE'
let s:d[0x10B79]='INSCRIPTIONAL PAHLAVI NUMBER TWO'
let s:d[0x10B7A]='INSCRIPTIONAL PAHLAVI NUMBER THREE'
let s:d[0x10B7B]='INSCRIPTIONAL PAHLAVI NUMBER FOUR'
let s:d[0x10B7C]='INSCRIPTIONAL PAHLAVI NUMBER TEN'
let s:d[0x10B7D]='INSCRIPTIONAL PAHLAVI NUMBER TWENTY'
let s:d[0x10B7E]='INSCRIPTIONAL PAHLAVI NUMBER ONE HUNDRED'
let s:d[0x10B7F]='INSCRIPTIONAL PAHLAVI NUMBER ONE THOUSAND'
let s:d[0x10C00]='OLD TURKIC LETTER ORKHON A'
let s:d[0x10C01]='OLD TURKIC LETTER YENISEI A'
let s:d[0x10C02]='OLD TURKIC LETTER YENISEI AE'
let s:d[0x10C03]='OLD TURKIC LETTER ORKHON I'
let s:d[0x10C04]='OLD TURKIC LETTER YENISEI I'
let s:d[0x10C05]='OLD TURKIC LETTER YENISEI E'
let s:d[0x10C06]='OLD TURKIC LETTER ORKHON O'
let s:d[0x10C07]='OLD TURKIC LETTER ORKHON OE'
let s:d[0x10C08]='OLD TURKIC LETTER YENISEI OE'
let s:d[0x10C09]='OLD TURKIC LETTER ORKHON AB'
let s:d[0x10C0A]='OLD TURKIC LETTER YENISEI AB'
let s:d[0x10C0B]='OLD TURKIC LETTER ORKHON AEB'
let s:d[0x10C0C]='OLD TURKIC LETTER YENISEI AEB'
let s:d[0x10C0D]='OLD TURKIC LETTER ORKHON AG'
let s:d[0x10C0E]='OLD TURKIC LETTER YENISEI AG'
let s:d[0x10C0F]='OLD TURKIC LETTER ORKHON AEG'
let s:d[0x10C10]='OLD TURKIC LETTER YENISEI AEG'
let s:d[0x10C11]='OLD TURKIC LETTER ORKHON AD'
let s:d[0x10C12]='OLD TURKIC LETTER YENISEI AD'
let s:d[0x10C13]='OLD TURKIC LETTER ORKHON AED'
let s:d[0x10C14]='OLD TURKIC LETTER ORKHON EZ'
let s:d[0x10C15]='OLD TURKIC LETTER YENISEI EZ'
let s:d[0x10C16]='OLD TURKIC LETTER ORKHON AY'
let s:d[0x10C17]='OLD TURKIC LETTER YENISEI AY'
let s:d[0x10C18]='OLD TURKIC LETTER ORKHON AEY'
let s:d[0x10C19]='OLD TURKIC LETTER YENISEI AEY'
let s:d[0x10C1A]='OLD TURKIC LETTER ORKHON AEK'
let s:d[0x10C1B]='OLD TURKIC LETTER YENISEI AEK'
let s:d[0x10C1C]='OLD TURKIC LETTER ORKHON OEK'
let s:d[0x10C1D]='OLD TURKIC LETTER YENISEI OEK'
let s:d[0x10C1E]='OLD TURKIC LETTER ORKHON AL'
let s:d[0x10C1F]='OLD TURKIC LETTER YENISEI AL'
let s:d[0x10C20]='OLD TURKIC LETTER ORKHON AEL'
let s:d[0x10C21]='OLD TURKIC LETTER ORKHON ELT'
let s:d[0x10C22]='OLD TURKIC LETTER ORKHON EM'
let s:d[0x10C23]='OLD TURKIC LETTER ORKHON AN'
let s:d[0x10C24]='OLD TURKIC LETTER ORKHON AEN'
let s:d[0x10C25]='OLD TURKIC LETTER YENISEI AEN'
let s:d[0x10C26]='OLD TURKIC LETTER ORKHON ENT'
let s:d[0x10C27]='OLD TURKIC LETTER YENISEI ENT'
let s:d[0x10C28]='OLD TURKIC LETTER ORKHON ENC'
let s:d[0x10C29]='OLD TURKIC LETTER YENISEI ENC'
let s:d[0x10C2A]='OLD TURKIC LETTER ORKHON ENY'
let s:d[0x10C2B]='OLD TURKIC LETTER YENISEI ENY'
let s:d[0x10C2C]='OLD TURKIC LETTER YENISEI ANG'
let s:d[0x10C2D]='OLD TURKIC LETTER ORKHON ENG'
let s:d[0x10C2E]='OLD TURKIC LETTER YENISEI AENG'
let s:d[0x10C2F]='OLD TURKIC LETTER ORKHON EP'
let s:d[0x10C30]='OLD TURKIC LETTER ORKHON OP'
let s:d[0x10C31]='OLD TURKIC LETTER ORKHON IC'
let s:d[0x10C32]='OLD TURKIC LETTER ORKHON EC'
let s:d[0x10C33]='OLD TURKIC LETTER YENISEI EC'
let s:d[0x10C34]='OLD TURKIC LETTER ORKHON AQ'
let s:d[0x10C35]='OLD TURKIC LETTER YENISEI AQ'
let s:d[0x10C36]='OLD TURKIC LETTER ORKHON IQ'
let s:d[0x10C37]='OLD TURKIC LETTER YENISEI IQ'
let s:d[0x10C38]='OLD TURKIC LETTER ORKHON OQ'
let s:d[0x10C39]='OLD TURKIC LETTER YENISEI OQ'
let s:d[0x10C3A]='OLD TURKIC LETTER ORKHON AR'
let s:d[0x10C3B]='OLD TURKIC LETTER YENISEI AR'
let s:d[0x10C3C]='OLD TURKIC LETTER ORKHON AER'
let s:d[0x10C3D]='OLD TURKIC LETTER ORKHON AS'
let s:d[0x10C3E]='OLD TURKIC LETTER ORKHON AES'
let s:d[0x10C3F]='OLD TURKIC LETTER ORKHON ASH'
let s:d[0x10C40]='OLD TURKIC LETTER YENISEI ASH'
let s:d[0x10C41]='OLD TURKIC LETTER ORKHON ESH'
let s:d[0x10C42]='OLD TURKIC LETTER YENISEI ESH'
let s:d[0x10C43]='OLD TURKIC LETTER ORKHON AT'
let s:d[0x10C44]='OLD TURKIC LETTER YENISEI AT'
let s:d[0x10C45]='OLD TURKIC LETTER ORKHON AET'
let s:d[0x10C46]='OLD TURKIC LETTER YENISEI AET'
let s:d[0x10C47]='OLD TURKIC LETTER ORKHON OT'
let s:d[0x10C48]='OLD TURKIC LETTER ORKHON BASH'
let s:d[0x10E60]='RUMI DIGIT ONE'
let s:d[0x10E61]='RUMI DIGIT TWO'
let s:d[0x10E62]='RUMI DIGIT THREE'
let s:d[0x10E63]='RUMI DIGIT FOUR'
let s:d[0x10E64]='RUMI DIGIT FIVE'
let s:d[0x10E65]='RUMI DIGIT SIX'
let s:d[0x10E66]='RUMI DIGIT SEVEN'
let s:d[0x10E67]='RUMI DIGIT EIGHT'
let s:d[0x10E68]='RUMI DIGIT NINE'
let s:d[0x10E69]='RUMI NUMBER TEN'
let s:d[0x10E6A]='RUMI NUMBER TWENTY'
let s:d[0x10E6B]='RUMI NUMBER THIRTY'
let s:d[0x10E6C]='RUMI NUMBER FORTY'
let s:d[0x10E6D]='RUMI NUMBER FIFTY'
let s:d[0x10E6E]='RUMI NUMBER SIXTY'
let s:d[0x10E6F]='RUMI NUMBER SEVENTY'
let s:d[0x10E70]='RUMI NUMBER EIGHTY'
let s:d[0x10E71]='RUMI NUMBER NINETY'
let s:d[0x10E72]='RUMI NUMBER ONE HUNDRED'
let s:d[0x10E73]='RUMI NUMBER TWO HUNDRED'
let s:d[0x10E74]='RUMI NUMBER THREE HUNDRED'
let s:d[0x10E75]='RUMI NUMBER FOUR HUNDRED'
let s:d[0x10E76]='RUMI NUMBER FIVE HUNDRED'
let s:d[0x10E77]='RUMI NUMBER SIX HUNDRED'
let s:d[0x10E78]='RUMI NUMBER SEVEN HUNDRED'
let s:d[0x10E79]='RUMI NUMBER EIGHT HUNDRED'
let s:d[0x10E7A]='RUMI NUMBER NINE HUNDRED'
let s:d[0x10E7B]='RUMI FRACTION ONE HALF'
let s:d[0x10E7C]='RUMI FRACTION ONE QUARTER'
let s:d[0x10E7D]='RUMI FRACTION ONE THIRD'
let s:d[0x10E7E]='RUMI FRACTION TWO THIRDS'
let s:d[0x11000]='BRAHMI SIGN CANDRABINDU'
let s:d[0x11001]='BRAHMI SIGN ANUSVARA'
let s:d[0x11002]='BRAHMI SIGN VISARGA'
let s:d[0x11003]='BRAHMI SIGN JIHVAMULIYA'
let s:d[0x11004]='BRAHMI SIGN UPADHMANIYA'
let s:d[0x11005]='BRAHMI LETTER A'
let s:d[0x11006]='BRAHMI LETTER AA'
let s:d[0x11007]='BRAHMI LETTER I'
let s:d[0x11008]='BRAHMI LETTER II'
let s:d[0x11009]='BRAHMI LETTER U'
let s:d[0x1100A]='BRAHMI LETTER UU'
let s:d[0x1100B]='BRAHMI LETTER VOCALIC R'
let s:d[0x1100C]='BRAHMI LETTER VOCALIC RR'
let s:d[0x1100D]='BRAHMI LETTER VOCALIC L'
let s:d[0x1100E]='BRAHMI LETTER VOCALIC LL'
let s:d[0x1100F]='BRAHMI LETTER E'
let s:d[0x11010]='BRAHMI LETTER AI'
let s:d[0x11011]='BRAHMI LETTER O'
let s:d[0x11012]='BRAHMI LETTER AU'
let s:d[0x11013]='BRAHMI LETTER KA'
let s:d[0x11014]='BRAHMI LETTER KHA'
let s:d[0x11015]='BRAHMI LETTER GA'
let s:d[0x11016]='BRAHMI LETTER GHA'
let s:d[0x11017]='BRAHMI LETTER NGA'
let s:d[0x11018]='BRAHMI LETTER CA'
let s:d[0x11019]='BRAHMI LETTER CHA'
let s:d[0x1101A]='BRAHMI LETTER JA'
let s:d[0x1101B]='BRAHMI LETTER JHA'
let s:d[0x1101C]='BRAHMI LETTER NYA'
let s:d[0x1101D]='BRAHMI LETTER TTA'
let s:d[0x1101E]='BRAHMI LETTER TTHA'
let s:d[0x1101F]='BRAHMI LETTER DDA'
let s:d[0x11020]='BRAHMI LETTER DDHA'
let s:d[0x11021]='BRAHMI LETTER NNA'
let s:d[0x11022]='BRAHMI LETTER TA'
let s:d[0x11023]='BRAHMI LETTER THA'
let s:d[0x11024]='BRAHMI LETTER DA'
let s:d[0x11025]='BRAHMI LETTER DHA'
let s:d[0x11026]='BRAHMI LETTER NA'
let s:d[0x11027]='BRAHMI LETTER PA'
let s:d[0x11028]='BRAHMI LETTER PHA'
let s:d[0x11029]='BRAHMI LETTER BA'
let s:d[0x1102A]='BRAHMI LETTER BHA'
let s:d[0x1102B]='BRAHMI LETTER MA'
let s:d[0x1102C]='BRAHMI LETTER YA'
let s:d[0x1102D]='BRAHMI LETTER RA'
let s:d[0x1102E]='BRAHMI LETTER LA'
let s:d[0x1102F]='BRAHMI LETTER VA'
let s:d[0x11030]='BRAHMI LETTER SHA'
let s:d[0x11031]='BRAHMI LETTER SSA'
let s:d[0x11032]='BRAHMI LETTER SA'
let s:d[0x11033]='BRAHMI LETTER HA'
let s:d[0x11034]='BRAHMI LETTER LLA'
let s:d[0x11035]='BRAHMI LETTER OLD TAMIL LLLA'
let s:d[0x11036]='BRAHMI LETTER OLD TAMIL RRA'
let s:d[0x11037]='BRAHMI LETTER OLD TAMIL NNNA'
let s:d[0x11038]='BRAHMI VOWEL SIGN AA'
let s:d[0x11039]='BRAHMI VOWEL SIGN BHATTIPROLU AA'
let s:d[0x1103A]='BRAHMI VOWEL SIGN I'
let s:d[0x1103B]='BRAHMI VOWEL SIGN II'
let s:d[0x1103C]='BRAHMI VOWEL SIGN U'
let s:d[0x1103D]='BRAHMI VOWEL SIGN UU'
let s:d[0x1103E]='BRAHMI VOWEL SIGN VOCALIC R'
let s:d[0x1103F]='BRAHMI VOWEL SIGN VOCALIC RR'
let s:d[0x11040]='BRAHMI VOWEL SIGN VOCALIC L'
let s:d[0x11041]='BRAHMI VOWEL SIGN VOCALIC LL'
let s:d[0x11042]='BRAHMI VOWEL SIGN E'
let s:d[0x11043]='BRAHMI VOWEL SIGN AI'
let s:d[0x11044]='BRAHMI VOWEL SIGN O'
let s:d[0x11045]='BRAHMI VOWEL SIGN AU'
let s:d[0x11046]='BRAHMI VIRAMA'
let s:d[0x11047]='BRAHMI DANDA'
let s:d[0x11048]='BRAHMI DOUBLE DANDA'
let s:d[0x11049]='BRAHMI PUNCTUATION DOT'
let s:d[0x1104A]='BRAHMI PUNCTUATION DOUBLE DOT'
let s:d[0x1104B]='BRAHMI PUNCTUATION LINE'
let s:d[0x1104C]='BRAHMI PUNCTUATION CRESCENT BAR'
let s:d[0x1104D]='BRAHMI PUNCTUATION LOTUS'
let s:d[0x11052]='BRAHMI NUMBER ONE'
let s:d[0x11053]='BRAHMI NUMBER TWO'
let s:d[0x11054]='BRAHMI NUMBER THREE'
let s:d[0x11055]='BRAHMI NUMBER FOUR'
let s:d[0x11056]='BRAHMI NUMBER FIVE'
let s:d[0x11057]='BRAHMI NUMBER SIX'
let s:d[0x11058]='BRAHMI NUMBER SEVEN'
let s:d[0x11059]='BRAHMI NUMBER EIGHT'
let s:d[0x1105A]='BRAHMI NUMBER NINE'
let s:d[0x1105B]='BRAHMI NUMBER TEN'
let s:d[0x1105C]='BRAHMI NUMBER TWENTY'
let s:d[0x1105D]='BRAHMI NUMBER THIRTY'
let s:d[0x1105E]='BRAHMI NUMBER FORTY'
let s:d[0x1105F]='BRAHMI NUMBER FIFTY'
let s:d[0x11060]='BRAHMI NUMBER SIXTY'
let s:d[0x11061]='BRAHMI NUMBER SEVENTY'
let s:d[0x11062]='BRAHMI NUMBER EIGHTY'
let s:d[0x11063]='BRAHMI NUMBER NINETY'
let s:d[0x11064]='BRAHMI NUMBER ONE HUNDRED'
let s:d[0x11065]='BRAHMI NUMBER ONE THOUSAND'
let s:d[0x11066]='BRAHMI DIGIT ZERO'
let s:d[0x11067]='BRAHMI DIGIT ONE'
let s:d[0x11068]='BRAHMI DIGIT TWO'
let s:d[0x11069]='BRAHMI DIGIT THREE'
let s:d[0x1106A]='BRAHMI DIGIT FOUR'
let s:d[0x1106B]='BRAHMI DIGIT FIVE'
let s:d[0x1106C]='BRAHMI DIGIT SIX'
let s:d[0x1106D]='BRAHMI DIGIT SEVEN'
let s:d[0x1106E]='BRAHMI DIGIT EIGHT'
let s:d[0x1106F]='BRAHMI DIGIT NINE'
let s:d[0x11080]='KAITHI SIGN CANDRABINDU'
let s:d[0x11081]='KAITHI SIGN ANUSVARA'
let s:d[0x11082]='KAITHI SIGN VISARGA'
let s:d[0x11083]='KAITHI LETTER A'
let s:d[0x11084]='KAITHI LETTER AA'
let s:d[0x11085]='KAITHI LETTER I'
let s:d[0x11086]='KAITHI LETTER II'
let s:d[0x11087]='KAITHI LETTER U'
let s:d[0x11088]='KAITHI LETTER UU'
let s:d[0x11089]='KAITHI LETTER E'
let s:d[0x1108A]='KAITHI LETTER AI'
let s:d[0x1108B]='KAITHI LETTER O'
let s:d[0x1108C]='KAITHI LETTER AU'
let s:d[0x1108D]='KAITHI LETTER KA'
let s:d[0x1108E]='KAITHI LETTER KHA'
let s:d[0x1108F]='KAITHI LETTER GA'
let s:d[0x11090]='KAITHI LETTER GHA'
let s:d[0x11091]='KAITHI LETTER NGA'
let s:d[0x11092]='KAITHI LETTER CA'
let s:d[0x11093]='KAITHI LETTER CHA'
let s:d[0x11094]='KAITHI LETTER JA'
let s:d[0x11095]='KAITHI LETTER JHA'
let s:d[0x11096]='KAITHI LETTER NYA'
let s:d[0x11097]='KAITHI LETTER TTA'
let s:d[0x11098]='KAITHI LETTER TTHA'
let s:d[0x11099]='KAITHI LETTER DDA'
let s:d[0x1109A]='KAITHI LETTER DDDHA'
let s:d[0x1109B]='KAITHI LETTER DDHA'
let s:d[0x1109C]='KAITHI LETTER RHA'
let s:d[0x1109D]='KAITHI LETTER NNA'
let s:d[0x1109E]='KAITHI LETTER TA'
let s:d[0x1109F]='KAITHI LETTER THA'
let s:d[0x110A0]='KAITHI LETTER DA'
let s:d[0x110A1]='KAITHI LETTER DHA'
let s:d[0x110A2]='KAITHI LETTER NA'
let s:d[0x110A3]='KAITHI LETTER PA'
let s:d[0x110A4]='KAITHI LETTER PHA'
let s:d[0x110A5]='KAITHI LETTER BA'
let s:d[0x110A6]='KAITHI LETTER BHA'
let s:d[0x110A7]='KAITHI LETTER MA'
let s:d[0x110A8]='KAITHI LETTER YA'
let s:d[0x110A9]='KAITHI LETTER RA'
let s:d[0x110AA]='KAITHI LETTER LA'
let s:d[0x110AB]='KAITHI LETTER VA'
let s:d[0x110AC]='KAITHI LETTER SHA'
let s:d[0x110AD]='KAITHI LETTER SSA'
let s:d[0x110AE]='KAITHI LETTER SA'
let s:d[0x110AF]='KAITHI LETTER HA'
let s:d[0x110B0]='KAITHI VOWEL SIGN AA'
let s:d[0x110B1]='KAITHI VOWEL SIGN I'
let s:d[0x110B2]='KAITHI VOWEL SIGN II'
let s:d[0x110B3]='KAITHI VOWEL SIGN U'
let s:d[0x110B4]='KAITHI VOWEL SIGN UU'
let s:d[0x110B5]='KAITHI VOWEL SIGN E'
let s:d[0x110B6]='KAITHI VOWEL SIGN AI'
let s:d[0x110B7]='KAITHI VOWEL SIGN O'
let s:d[0x110B8]='KAITHI VOWEL SIGN AU'
let s:d[0x110B9]='KAITHI SIGN VIRAMA'
let s:d[0x110BA]='KAITHI SIGN NUKTA'
let s:d[0x110BB]='KAITHI ABBREVIATION SIGN'
let s:d[0x110BC]='KAITHI ENUMERATION SIGN'
let s:d[0x110BD]='KAITHI NUMBER SIGN'
let s:d[0x110BE]='KAITHI SECTION MARK'
let s:d[0x110BF]='KAITHI DOUBLE SECTION MARK'
let s:d[0x110C0]='KAITHI DANDA'
let s:d[0x110C1]='KAITHI DOUBLE DANDA'
let s:d[0x110D0]='SORA SOMPENG LETTER SAH'
let s:d[0x110D1]='SORA SOMPENG LETTER TAH'
let s:d[0x110D2]='SORA SOMPENG LETTER BAH'
let s:d[0x110D3]='SORA SOMPENG LETTER CAH'
let s:d[0x110D4]='SORA SOMPENG LETTER DAH'
let s:d[0x110D5]='SORA SOMPENG LETTER GAH'
let s:d[0x110D6]='SORA SOMPENG LETTER MAH'
let s:d[0x110D7]='SORA SOMPENG LETTER NGAH'
let s:d[0x110D8]='SORA SOMPENG LETTER LAH'
let s:d[0x110D9]='SORA SOMPENG LETTER NAH'
let s:d[0x110DA]='SORA SOMPENG LETTER VAH'
let s:d[0x110DB]='SORA SOMPENG LETTER PAH'
let s:d[0x110DC]='SORA SOMPENG LETTER YAH'
let s:d[0x110DD]='SORA SOMPENG LETTER RAH'
let s:d[0x110DE]='SORA SOMPENG LETTER HAH'
let s:d[0x110DF]='SORA SOMPENG LETTER KAH'
let s:d[0x110E0]='SORA SOMPENG LETTER JAH'
let s:d[0x110E1]='SORA SOMPENG LETTER NYAH'
let s:d[0x110E2]='SORA SOMPENG LETTER AH'
let s:d[0x110E3]='SORA SOMPENG LETTER EEH'
let s:d[0x110E4]='SORA SOMPENG LETTER IH'
let s:d[0x110E5]='SORA SOMPENG LETTER UH'
let s:d[0x110E6]='SORA SOMPENG LETTER OH'
let s:d[0x110E7]='SORA SOMPENG LETTER EH'
let s:d[0x110E8]='SORA SOMPENG LETTER MAE'
let s:d[0x110F0]='SORA SOMPENG DIGIT ZERO'
let s:d[0x110F1]='SORA SOMPENG DIGIT ONE'
let s:d[0x110F2]='SORA SOMPENG DIGIT TWO'
let s:d[0x110F3]='SORA SOMPENG DIGIT THREE'
let s:d[0x110F4]='SORA SOMPENG DIGIT FOUR'
let s:d[0x110F5]='SORA SOMPENG DIGIT FIVE'
let s:d[0x110F6]='SORA SOMPENG DIGIT SIX'
let s:d[0x110F7]='SORA SOMPENG DIGIT SEVEN'
let s:d[0x110F8]='SORA SOMPENG DIGIT EIGHT'
let s:d[0x110F9]='SORA SOMPENG DIGIT NINE'
let s:d[0x11100]='CHAKMA SIGN CANDRABINDU'
let s:d[0x11101]='CHAKMA SIGN ANUSVARA'
let s:d[0x11102]='CHAKMA SIGN VISARGA'
let s:d[0x11103]='CHAKMA LETTER AA'
let s:d[0x11104]='CHAKMA LETTER I'
let s:d[0x11105]='CHAKMA LETTER U'
let s:d[0x11106]='CHAKMA LETTER E'
let s:d[0x11107]='CHAKMA LETTER KAA'
let s:d[0x11108]='CHAKMA LETTER KHAA'
let s:d[0x11109]='CHAKMA LETTER GAA'
let s:d[0x1110A]='CHAKMA LETTER GHAA'
let s:d[0x1110B]='CHAKMA LETTER NGAA'
let s:d[0x1110C]='CHAKMA LETTER CAA'
let s:d[0x1110D]='CHAKMA LETTER CHAA'
let s:d[0x1110E]='CHAKMA LETTER JAA'
let s:d[0x1110F]='CHAKMA LETTER JHAA'
let s:d[0x11110]='CHAKMA LETTER NYAA'
let s:d[0x11111]='CHAKMA LETTER TTAA'
let s:d[0x11112]='CHAKMA LETTER TTHAA'
let s:d[0x11113]='CHAKMA LETTER DDAA'
let s:d[0x11114]='CHAKMA LETTER DDHAA'
let s:d[0x11115]='CHAKMA LETTER NNAA'
let s:d[0x11116]='CHAKMA LETTER TAA'
let s:d[0x11117]='CHAKMA LETTER THAA'
let s:d[0x11118]='CHAKMA LETTER DAA'
let s:d[0x11119]='CHAKMA LETTER DHAA'
let s:d[0x1111A]='CHAKMA LETTER NAA'
let s:d[0x1111B]='CHAKMA LETTER PAA'
let s:d[0x1111C]='CHAKMA LETTER PHAA'
let s:d[0x1111D]='CHAKMA LETTER BAA'
let s:d[0x1111E]='CHAKMA LETTER BHAA'
let s:d[0x1111F]='CHAKMA LETTER MAA'
let s:d[0x11120]='CHAKMA LETTER YYAA'
let s:d[0x11121]='CHAKMA LETTER YAA'
let s:d[0x11122]='CHAKMA LETTER RAA'
let s:d[0x11123]='CHAKMA LETTER LAA'
let s:d[0x11124]='CHAKMA LETTER WAA'
let s:d[0x11125]='CHAKMA LETTER SAA'
let s:d[0x11126]='CHAKMA LETTER HAA'
let s:d[0x11127]='CHAKMA VOWEL SIGN A'
let s:d[0x11128]='CHAKMA VOWEL SIGN I'
let s:d[0x11129]='CHAKMA VOWEL SIGN II'
let s:d[0x1112A]='CHAKMA VOWEL SIGN U'
let s:d[0x1112B]='CHAKMA VOWEL SIGN UU'
let s:d[0x1112C]='CHAKMA VOWEL SIGN E'
let s:d[0x1112D]='CHAKMA VOWEL SIGN AI'
let s:d[0x1112E]='CHAKMA VOWEL SIGN O'
let s:d[0x1112F]='CHAKMA VOWEL SIGN AU'
let s:d[0x11130]='CHAKMA VOWEL SIGN OI'
let s:d[0x11131]='CHAKMA O MARK'
let s:d[0x11132]='CHAKMA AU MARK'
let s:d[0x11133]='CHAKMA VIRAMA'
let s:d[0x11134]='CHAKMA MAAYYAA'
let s:d[0x11136]='CHAKMA DIGIT ZERO'
let s:d[0x11137]='CHAKMA DIGIT ONE'
let s:d[0x11138]='CHAKMA DIGIT TWO'
let s:d[0x11139]='CHAKMA DIGIT THREE'
let s:d[0x1113A]='CHAKMA DIGIT FOUR'
let s:d[0x1113B]='CHAKMA DIGIT FIVE'
let s:d[0x1113C]='CHAKMA DIGIT SIX'
let s:d[0x1113D]='CHAKMA DIGIT SEVEN'
let s:d[0x1113E]='CHAKMA DIGIT EIGHT'
let s:d[0x1113F]='CHAKMA DIGIT NINE'
let s:d[0x11140]='CHAKMA SECTION MARK'
let s:d[0x11141]='CHAKMA DANDA'
let s:d[0x11142]='CHAKMA DOUBLE DANDA'
let s:d[0x11143]='CHAKMA QUESTION MARK'
let s:d[0x11180]='SHARADA SIGN CANDRABINDU'
let s:d[0x11181]='SHARADA SIGN ANUSVARA'
let s:d[0x11182]='SHARADA SIGN VISARGA'
let s:d[0x11183]='SHARADA LETTER A'
let s:d[0x11184]='SHARADA LETTER AA'
let s:d[0x11185]='SHARADA LETTER I'
let s:d[0x11186]='SHARADA LETTER II'
let s:d[0x11187]='SHARADA LETTER U'
let s:d[0x11188]='SHARADA LETTER UU'
let s:d[0x11189]='SHARADA LETTER VOCALIC R'
let s:d[0x1118A]='SHARADA LETTER VOCALIC RR'
let s:d[0x1118B]='SHARADA LETTER VOCALIC L'
let s:d[0x1118C]='SHARADA LETTER VOCALIC LL'
let s:d[0x1118D]='SHARADA LETTER E'
let s:d[0x1118E]='SHARADA LETTER AI'
let s:d[0x1118F]='SHARADA LETTER O'
let s:d[0x11190]='SHARADA LETTER AU'
let s:d[0x11191]='SHARADA LETTER KA'
let s:d[0x11192]='SHARADA LETTER KHA'
let s:d[0x11193]='SHARADA LETTER GA'
let s:d[0x11194]='SHARADA LETTER GHA'
let s:d[0x11195]='SHARADA LETTER NGA'
let s:d[0x11196]='SHARADA LETTER CA'
let s:d[0x11197]='SHARADA LETTER CHA'
let s:d[0x11198]='SHARADA LETTER JA'
let s:d[0x11199]='SHARADA LETTER JHA'
let s:d[0x1119A]='SHARADA LETTER NYA'
let s:d[0x1119B]='SHARADA LETTER TTA'
let s:d[0x1119C]='SHARADA LETTER TTHA'
let s:d[0x1119D]='SHARADA LETTER DDA'
let s:d[0x1119E]='SHARADA LETTER DDHA'
let s:d[0x1119F]='SHARADA LETTER NNA'
let s:d[0x111A0]='SHARADA LETTER TA'
let s:d[0x111A1]='SHARADA LETTER THA'
let s:d[0x111A2]='SHARADA LETTER DA'
let s:d[0x111A3]='SHARADA LETTER DHA'
let s:d[0x111A4]='SHARADA LETTER NA'
let s:d[0x111A5]='SHARADA LETTER PA'
let s:d[0x111A6]='SHARADA LETTER PHA'
let s:d[0x111A7]='SHARADA LETTER BA'
let s:d[0x111A8]='SHARADA LETTER BHA'
let s:d[0x111A9]='SHARADA LETTER MA'
let s:d[0x111AA]='SHARADA LETTER YA'
let s:d[0x111AB]='SHARADA LETTER RA'
let s:d[0x111AC]='SHARADA LETTER LA'
let s:d[0x111AD]='SHARADA LETTER LLA'
let s:d[0x111AE]='SHARADA LETTER VA'
let s:d[0x111AF]='SHARADA LETTER SHA'
let s:d[0x111B0]='SHARADA LETTER SSA'
let s:d[0x111B1]='SHARADA LETTER SA'
let s:d[0x111B2]='SHARADA LETTER HA'
let s:d[0x111B3]='SHARADA VOWEL SIGN AA'
let s:d[0x111B4]='SHARADA VOWEL SIGN I'
let s:d[0x111B5]='SHARADA VOWEL SIGN II'
let s:d[0x111B6]='SHARADA VOWEL SIGN U'
let s:d[0x111B7]='SHARADA VOWEL SIGN UU'
let s:d[0x111B8]='SHARADA VOWEL SIGN VOCALIC R'
let s:d[0x111B9]='SHARADA VOWEL SIGN VOCALIC RR'
let s:d[0x111BA]='SHARADA VOWEL SIGN VOCALIC L'
let s:d[0x111BB]='SHARADA VOWEL SIGN VOCALIC LL'
let s:d[0x111BC]='SHARADA VOWEL SIGN E'
let s:d[0x111BD]='SHARADA VOWEL SIGN AI'
let s:d[0x111BE]='SHARADA VOWEL SIGN O'
let s:d[0x111BF]='SHARADA VOWEL SIGN AU'
let s:d[0x111C0]='SHARADA SIGN VIRAMA'
let s:d[0x111C1]='SHARADA SIGN AVAGRAHA'
let s:d[0x111C2]='SHARADA SIGN JIHVAMULIYA'
let s:d[0x111C3]='SHARADA SIGN UPADHMANIYA'
let s:d[0x111C4]='SHARADA OM'
let s:d[0x111C5]='SHARADA DANDA'
let s:d[0x111C6]='SHARADA DOUBLE DANDA'
let s:d[0x111C7]='SHARADA ABBREVIATION SIGN'
let s:d[0x111C8]='SHARADA SEPARATOR'
let s:d[0x111D0]='SHARADA DIGIT ZERO'
let s:d[0x111D1]='SHARADA DIGIT ONE'
let s:d[0x111D2]='SHARADA DIGIT TWO'
let s:d[0x111D3]='SHARADA DIGIT THREE'
let s:d[0x111D4]='SHARADA DIGIT FOUR'
let s:d[0x111D5]='SHARADA DIGIT FIVE'
let s:d[0x111D6]='SHARADA DIGIT SIX'
let s:d[0x111D7]='SHARADA DIGIT SEVEN'
let s:d[0x111D8]='SHARADA DIGIT EIGHT'
let s:d[0x111D9]='SHARADA DIGIT NINE'
let s:d[0x11680]='TAKRI LETTER A'
let s:d[0x11681]='TAKRI LETTER AA'
let s:d[0x11682]='TAKRI LETTER I'
let s:d[0x11683]='TAKRI LETTER II'
let s:d[0x11684]='TAKRI LETTER U'
let s:d[0x11685]='TAKRI LETTER UU'
let s:d[0x11686]='TAKRI LETTER E'
let s:d[0x11687]='TAKRI LETTER AI'
let s:d[0x11688]='TAKRI LETTER O'
let s:d[0x11689]='TAKRI LETTER AU'
let s:d[0x1168A]='TAKRI LETTER KA'
let s:d[0x1168B]='TAKRI LETTER KHA'
let s:d[0x1168C]='TAKRI LETTER GA'
let s:d[0x1168D]='TAKRI LETTER GHA'
let s:d[0x1168E]='TAKRI LETTER NGA'
let s:d[0x1168F]='TAKRI LETTER CA'
let s:d[0x11690]='TAKRI LETTER CHA'
let s:d[0x11691]='TAKRI LETTER JA'
let s:d[0x11692]='TAKRI LETTER JHA'
let s:d[0x11693]='TAKRI LETTER NYA'
let s:d[0x11694]='TAKRI LETTER TTA'
let s:d[0x11695]='TAKRI LETTER TTHA'
let s:d[0x11696]='TAKRI LETTER DDA'
let s:d[0x11697]='TAKRI LETTER DDHA'
let s:d[0x11698]='TAKRI LETTER NNA'
let s:d[0x11699]='TAKRI LETTER TA'
let s:d[0x1169A]='TAKRI LETTER THA'
let s:d[0x1169B]='TAKRI LETTER DA'
let s:d[0x1169C]='TAKRI LETTER DHA'
let s:d[0x1169D]='TAKRI LETTER NA'
let s:d[0x1169E]='TAKRI LETTER PA'
let s:d[0x1169F]='TAKRI LETTER PHA'
let s:d[0x116A0]='TAKRI LETTER BA'
let s:d[0x116A1]='TAKRI LETTER BHA'
let s:d[0x116A2]='TAKRI LETTER MA'
let s:d[0x116A3]='TAKRI LETTER YA'
let s:d[0x116A4]='TAKRI LETTER RA'
let s:d[0x116A5]='TAKRI LETTER LA'
let s:d[0x116A6]='TAKRI LETTER VA'
let s:d[0x116A7]='TAKRI LETTER SHA'
let s:d[0x116A8]='TAKRI LETTER SA'
let s:d[0x116A9]='TAKRI LETTER HA'
let s:d[0x116AA]='TAKRI LETTER RRA'
let s:d[0x116AB]='TAKRI SIGN ANUSVARA'
let s:d[0x116AC]='TAKRI SIGN VISARGA'
let s:d[0x116AD]='TAKRI VOWEL SIGN AA'
let s:d[0x116AE]='TAKRI VOWEL SIGN I'
let s:d[0x116AF]='TAKRI VOWEL SIGN II'
let s:d[0x116B0]='TAKRI VOWEL SIGN U'
let s:d[0x116B1]='TAKRI VOWEL SIGN UU'
let s:d[0x116B2]='TAKRI VOWEL SIGN E'
let s:d[0x116B3]='TAKRI VOWEL SIGN AI'
let s:d[0x116B4]='TAKRI VOWEL SIGN O'
let s:d[0x116B5]='TAKRI VOWEL SIGN AU'
let s:d[0x116B6]='TAKRI SIGN VIRAMA'
let s:d[0x116B7]='TAKRI SIGN NUKTA'
let s:d[0x116C0]='TAKRI DIGIT ZERO'
let s:d[0x116C1]='TAKRI DIGIT ONE'
let s:d[0x116C2]='TAKRI DIGIT TWO'
let s:d[0x116C3]='TAKRI DIGIT THREE'
let s:d[0x116C4]='TAKRI DIGIT FOUR'
let s:d[0x116C5]='TAKRI DIGIT FIVE'
let s:d[0x116C6]='TAKRI DIGIT SIX'
let s:d[0x116C7]='TAKRI DIGIT SEVEN'
let s:d[0x116C8]='TAKRI DIGIT EIGHT'
let s:d[0x116C9]='TAKRI DIGIT NINE'
let s:d[0x12000]='CUNEIFORM SIGN A'
let s:d[0x12001]='CUNEIFORM SIGN A TIMES A'
let s:d[0x12002]='CUNEIFORM SIGN A TIMES BAD'
let s:d[0x12003]='CUNEIFORM SIGN A TIMES GAN2 TENU'
let s:d[0x12004]='CUNEIFORM SIGN A TIMES HA'
let s:d[0x12005]='CUNEIFORM SIGN A TIMES IGI'
let s:d[0x12006]='CUNEIFORM SIGN A TIMES LAGAR GUNU'
let s:d[0x12007]='CUNEIFORM SIGN A TIMES MUSH'
let s:d[0x12008]='CUNEIFORM SIGN A TIMES SAG'
let s:d[0x12009]='CUNEIFORM SIGN A2'
let s:d[0x1200A]='CUNEIFORM SIGN AB'
let s:d[0x1200B]='CUNEIFORM SIGN AB TIMES ASH2'
let s:d[0x1200C]='CUNEIFORM SIGN AB TIMES DUN3 GUNU'
let s:d[0x1200D]='CUNEIFORM SIGN AB TIMES GAL'
let s:d[0x1200E]='CUNEIFORM SIGN AB TIMES GAN2 TENU'
let s:d[0x1200F]='CUNEIFORM SIGN AB TIMES HA'
let s:d[0x12010]='CUNEIFORM SIGN AB TIMES IGI GUNU'
let s:d[0x12011]='CUNEIFORM SIGN AB TIMES IMIN'
let s:d[0x12012]='CUNEIFORM SIGN AB TIMES LAGAB'
let s:d[0x12013]='CUNEIFORM SIGN AB TIMES SHESH'
let s:d[0x12014]='CUNEIFORM SIGN AB TIMES U PLUS U PLUS U'
let s:d[0x12015]='CUNEIFORM SIGN AB GUNU'
let s:d[0x12016]='CUNEIFORM SIGN AB2'
let s:d[0x12017]='CUNEIFORM SIGN AB2 TIMES BALAG'
let s:d[0x12018]='CUNEIFORM SIGN AB2 TIMES GAN2 TENU'
let s:d[0x12019]='CUNEIFORM SIGN AB2 TIMES ME PLUS EN'
let s:d[0x1201A]='CUNEIFORM SIGN AB2 TIMES SHA3'
let s:d[0x1201B]='CUNEIFORM SIGN AB2 TIMES TAK4'
let s:d[0x1201C]='CUNEIFORM SIGN AD'
let s:d[0x1201D]='CUNEIFORM SIGN AK'
let s:d[0x1201E]='CUNEIFORM SIGN AK TIMES ERIN2'
let s:d[0x1201F]='CUNEIFORM SIGN AK TIMES SHITA PLUS GISH'
let s:d[0x12020]='CUNEIFORM SIGN AL'
let s:d[0x12021]='CUNEIFORM SIGN AL TIMES AL'
let s:d[0x12022]='CUNEIFORM SIGN AL TIMES DIM2'
let s:d[0x12023]='CUNEIFORM SIGN AL TIMES GISH'
let s:d[0x12024]='CUNEIFORM SIGN AL TIMES HA'
let s:d[0x12025]='CUNEIFORM SIGN AL TIMES KAD3'
let s:d[0x12026]='CUNEIFORM SIGN AL TIMES KI'
let s:d[0x12027]='CUNEIFORM SIGN AL TIMES SHE'
let s:d[0x12028]='CUNEIFORM SIGN AL TIMES USH'
let s:d[0x12029]='CUNEIFORM SIGN ALAN'
let s:d[0x1202A]='CUNEIFORM SIGN ALEPH'
let s:d[0x1202B]='CUNEIFORM SIGN AMAR'
let s:d[0x1202C]='CUNEIFORM SIGN AMAR TIMES SHE'
let s:d[0x1202D]='CUNEIFORM SIGN AN'
let s:d[0x1202E]='CUNEIFORM SIGN AN OVER AN'
let s:d[0x1202F]='CUNEIFORM SIGN AN THREE TIMES'
let s:d[0x12030]='CUNEIFORM SIGN AN PLUS NAGA OPPOSING AN PLUS NAGA'
let s:d[0x12031]='CUNEIFORM SIGN AN PLUS NAGA SQUARED'
let s:d[0x12032]='CUNEIFORM SIGN ANSHE'
let s:d[0x12033]='CUNEIFORM SIGN APIN'
let s:d[0x12034]='CUNEIFORM SIGN ARAD'
let s:d[0x12035]='CUNEIFORM SIGN ARAD TIMES KUR'
let s:d[0x12036]='CUNEIFORM SIGN ARKAB'
let s:d[0x12037]='CUNEIFORM SIGN ASAL2'
let s:d[0x12038]='CUNEIFORM SIGN ASH'
let s:d[0x12039]='CUNEIFORM SIGN ASH ZIDA TENU'
let s:d[0x1203A]='CUNEIFORM SIGN ASH KABA TENU'
let s:d[0x1203B]='CUNEIFORM SIGN ASH OVER ASH TUG2 OVER TUG2 TUG2 OVER TUG2 PAP'
let s:d[0x1203C]='CUNEIFORM SIGN ASH OVER ASH OVER ASH'
let s:d[0x1203D]='CUNEIFORM SIGN ASH OVER ASH OVER ASH CROSSING ASH OVER ASH OVER ASH'
let s:d[0x1203E]='CUNEIFORM SIGN ASH2'
let s:d[0x1203F]='CUNEIFORM SIGN ASHGAB'
let s:d[0x12040]='CUNEIFORM SIGN BA'
let s:d[0x12041]='CUNEIFORM SIGN BAD'
let s:d[0x12042]='CUNEIFORM SIGN BAG3'
let s:d[0x12043]='CUNEIFORM SIGN BAHAR2'
let s:d[0x12044]='CUNEIFORM SIGN BAL'
let s:d[0x12045]='CUNEIFORM SIGN BAL OVER BAL'
let s:d[0x12046]='CUNEIFORM SIGN BALAG'
let s:d[0x12047]='CUNEIFORM SIGN BAR'
let s:d[0x12048]='CUNEIFORM SIGN BARA2'
let s:d[0x12049]='CUNEIFORM SIGN BI'
let s:d[0x1204A]='CUNEIFORM SIGN BI TIMES A'
let s:d[0x1204B]='CUNEIFORM SIGN BI TIMES GAR'
let s:d[0x1204C]='CUNEIFORM SIGN BI TIMES IGI GUNU'
let s:d[0x1204D]='CUNEIFORM SIGN BU'
let s:d[0x1204E]='CUNEIFORM SIGN BU OVER BU AB'
let s:d[0x1204F]='CUNEIFORM SIGN BU OVER BU UN'
let s:d[0x12050]='CUNEIFORM SIGN BU CROSSING BU'
let s:d[0x12051]='CUNEIFORM SIGN BULUG'
let s:d[0x12052]='CUNEIFORM SIGN BULUG OVER BULUG'
let s:d[0x12053]='CUNEIFORM SIGN BUR'
let s:d[0x12054]='CUNEIFORM SIGN BUR2'
let s:d[0x12055]='CUNEIFORM SIGN DA'
let s:d[0x12056]='CUNEIFORM SIGN DAG'
let s:d[0x12057]='CUNEIFORM SIGN DAG KISIM5 TIMES A PLUS MASH'
let s:d[0x12058]='CUNEIFORM SIGN DAG KISIM5 TIMES AMAR'
let s:d[0x12059]='CUNEIFORM SIGN DAG KISIM5 TIMES BALAG'
let s:d[0x1205A]='CUNEIFORM SIGN DAG KISIM5 TIMES BI'
let s:d[0x1205B]='CUNEIFORM SIGN DAG KISIM5 TIMES GA'
let s:d[0x1205C]='CUNEIFORM SIGN DAG KISIM5 TIMES GA PLUS MASH'
let s:d[0x1205D]='CUNEIFORM SIGN DAG KISIM5 TIMES GI'
let s:d[0x1205E]='CUNEIFORM SIGN DAG KISIM5 TIMES GIR2'
let s:d[0x1205F]='CUNEIFORM SIGN DAG KISIM5 TIMES GUD'
let s:d[0x12060]='CUNEIFORM SIGN DAG KISIM5 TIMES HA'
let s:d[0x12061]='CUNEIFORM SIGN DAG KISIM5 TIMES IR'
let s:d[0x12062]='CUNEIFORM SIGN DAG KISIM5 TIMES IR PLUS LU'
let s:d[0x12063]='CUNEIFORM SIGN DAG KISIM5 TIMES KAK'
let s:d[0x12064]='CUNEIFORM SIGN DAG KISIM5 TIMES LA'
let s:d[0x12065]='CUNEIFORM SIGN DAG KISIM5 TIMES LU'
let s:d[0x12066]='CUNEIFORM SIGN DAG KISIM5 TIMES LU PLUS MASH2'
let s:d[0x12067]='CUNEIFORM SIGN DAG KISIM5 TIMES LUM'
let s:d[0x12068]='CUNEIFORM SIGN DAG KISIM5 TIMES NE'
let s:d[0x12069]='CUNEIFORM SIGN DAG KISIM5 TIMES PAP PLUS PAP'
let s:d[0x1206A]='CUNEIFORM SIGN DAG KISIM5 TIMES SI'
let s:d[0x1206B]='CUNEIFORM SIGN DAG KISIM5 TIMES TAK4'
let s:d[0x1206C]='CUNEIFORM SIGN DAG KISIM5 TIMES U2 PLUS GIR2'
let s:d[0x1206D]='CUNEIFORM SIGN DAG KISIM5 TIMES USH'
let s:d[0x1206E]='CUNEIFORM SIGN DAM'
let s:d[0x1206F]='CUNEIFORM SIGN DAR'
let s:d[0x12070]='CUNEIFORM SIGN DARA3'
let s:d[0x12071]='CUNEIFORM SIGN DARA4'
let s:d[0x12072]='CUNEIFORM SIGN DI'
let s:d[0x12073]='CUNEIFORM SIGN DIB'
let s:d[0x12074]='CUNEIFORM SIGN DIM'
let s:d[0x12075]='CUNEIFORM SIGN DIM TIMES SHE'
let s:d[0x12076]='CUNEIFORM SIGN DIM2'
let s:d[0x12077]='CUNEIFORM SIGN DIN'
let s:d[0x12078]='CUNEIFORM SIGN DIN KASKAL U GUNU DISH'
let s:d[0x12079]='CUNEIFORM SIGN DISH'
let s:d[0x1207A]='CUNEIFORM SIGN DU'
let s:d[0x1207B]='CUNEIFORM SIGN DU OVER DU'
let s:d[0x1207C]='CUNEIFORM SIGN DU GUNU'
let s:d[0x1207D]='CUNEIFORM SIGN DU SHESHIG'
let s:d[0x1207E]='CUNEIFORM SIGN DUB'
let s:d[0x1207F]='CUNEIFORM SIGN DUB TIMES ESH2'
let s:d[0x12080]='CUNEIFORM SIGN DUB2'
let s:d[0x12081]='CUNEIFORM SIGN DUG'
let s:d[0x12082]='CUNEIFORM SIGN DUGUD'
let s:d[0x12083]='CUNEIFORM SIGN DUH'
let s:d[0x12084]='CUNEIFORM SIGN DUN'
let s:d[0x12085]='CUNEIFORM SIGN DUN3'
let s:d[0x12086]='CUNEIFORM SIGN DUN3 GUNU'
let s:d[0x12087]='CUNEIFORM SIGN DUN3 GUNU GUNU'
let s:d[0x12088]='CUNEIFORM SIGN DUN4'
let s:d[0x12089]='CUNEIFORM SIGN DUR2'
let s:d[0x1208A]='CUNEIFORM SIGN E'
let s:d[0x1208B]='CUNEIFORM SIGN E TIMES PAP'
let s:d[0x1208C]='CUNEIFORM SIGN E OVER E NUN OVER NUN'
let s:d[0x1208D]='CUNEIFORM SIGN E2'
let s:d[0x1208E]='CUNEIFORM SIGN E2 TIMES A PLUS HA PLUS DA'
let s:d[0x1208F]='CUNEIFORM SIGN E2 TIMES GAR'
let s:d[0x12090]='CUNEIFORM SIGN E2 TIMES MI'
let s:d[0x12091]='CUNEIFORM SIGN E2 TIMES SAL'
let s:d[0x12092]='CUNEIFORM SIGN E2 TIMES SHE'
let s:d[0x12093]='CUNEIFORM SIGN E2 TIMES U'
let s:d[0x12094]='CUNEIFORM SIGN EDIN'
let s:d[0x12095]='CUNEIFORM SIGN EGIR'
let s:d[0x12096]='CUNEIFORM SIGN EL'
let s:d[0x12097]='CUNEIFORM SIGN EN'
let s:d[0x12098]='CUNEIFORM SIGN EN TIMES GAN2'
let s:d[0x12099]='CUNEIFORM SIGN EN TIMES GAN2 TENU'
let s:d[0x1209A]='CUNEIFORM SIGN EN TIMES ME'
let s:d[0x1209B]='CUNEIFORM SIGN EN CROSSING EN'
let s:d[0x1209C]='CUNEIFORM SIGN EN OPPOSING EN'
let s:d[0x1209D]='CUNEIFORM SIGN EN SQUARED'
let s:d[0x1209E]='CUNEIFORM SIGN EREN'
let s:d[0x1209F]='CUNEIFORM SIGN ERIN2'
let s:d[0x120A0]='CUNEIFORM SIGN ESH2'
let s:d[0x120A1]='CUNEIFORM SIGN EZEN'
let s:d[0x120A2]='CUNEIFORM SIGN EZEN TIMES A'
let s:d[0x120A3]='CUNEIFORM SIGN EZEN TIMES A PLUS LAL'
let s:d[0x120A4]='CUNEIFORM SIGN EZEN TIMES A PLUS LAL TIMES LAL'
let s:d[0x120A5]='CUNEIFORM SIGN EZEN TIMES AN'
let s:d[0x120A6]='CUNEIFORM SIGN EZEN TIMES BAD'
let s:d[0x120A7]='CUNEIFORM SIGN EZEN TIMES DUN3 GUNU'
let s:d[0x120A8]='CUNEIFORM SIGN EZEN TIMES DUN3 GUNU GUNU'
let s:d[0x120A9]='CUNEIFORM SIGN EZEN TIMES HA'
let s:d[0x120AA]='CUNEIFORM SIGN EZEN TIMES HA GUNU'
let s:d[0x120AB]='CUNEIFORM SIGN EZEN TIMES IGI GUNU'
let s:d[0x120AC]='CUNEIFORM SIGN EZEN TIMES KASKAL'
let s:d[0x120AD]='CUNEIFORM SIGN EZEN TIMES KASKAL SQUARED'
let s:d[0x120AE]='CUNEIFORM SIGN EZEN TIMES KU3'
let s:d[0x120AF]='CUNEIFORM SIGN EZEN TIMES LA'
let s:d[0x120B0]='CUNEIFORM SIGN EZEN TIMES LAL TIMES LAL'
let s:d[0x120B1]='CUNEIFORM SIGN EZEN TIMES LI'
let s:d[0x120B2]='CUNEIFORM SIGN EZEN TIMES LU'
let s:d[0x120B3]='CUNEIFORM SIGN EZEN TIMES U2'
let s:d[0x120B4]='CUNEIFORM SIGN EZEN TIMES UD'
let s:d[0x120B5]='CUNEIFORM SIGN GA'
let s:d[0x120B6]='CUNEIFORM SIGN GA GUNU'
let s:d[0x120B7]='CUNEIFORM SIGN GA2'
let s:d[0x120B8]='CUNEIFORM SIGN GA2 TIMES A PLUS DA PLUS HA'
let s:d[0x120B9]='CUNEIFORM SIGN GA2 TIMES A PLUS HA'
let s:d[0x120BA]='CUNEIFORM SIGN GA2 TIMES A PLUS IGI'
let s:d[0x120BB]='CUNEIFORM SIGN GA2 TIMES AB2 TENU PLUS TAB'
let s:d[0x120BC]='CUNEIFORM SIGN GA2 TIMES AN'
let s:d[0x120BD]='CUNEIFORM SIGN GA2 TIMES ASH'
let s:d[0x120BE]='CUNEIFORM SIGN GA2 TIMES ASH2 PLUS GAL'
let s:d[0x120BF]='CUNEIFORM SIGN GA2 TIMES BAD'
let s:d[0x120C0]='CUNEIFORM SIGN GA2 TIMES BAR PLUS RA'
let s:d[0x120C1]='CUNEIFORM SIGN GA2 TIMES BUR'
let s:d[0x120C2]='CUNEIFORM SIGN GA2 TIMES BUR PLUS RA'
let s:d[0x120C3]='CUNEIFORM SIGN GA2 TIMES DA'
let s:d[0x120C4]='CUNEIFORM SIGN GA2 TIMES DI'
let s:d[0x120C5]='CUNEIFORM SIGN GA2 TIMES DIM TIMES SHE'
let s:d[0x120C6]='CUNEIFORM SIGN GA2 TIMES DUB'
let s:d[0x120C7]='CUNEIFORM SIGN GA2 TIMES EL'
let s:d[0x120C8]='CUNEIFORM SIGN GA2 TIMES EL PLUS LA'
let s:d[0x120C9]='CUNEIFORM SIGN GA2 TIMES EN'
let s:d[0x120CA]='CUNEIFORM SIGN GA2 TIMES EN TIMES GAN2 TENU'
let s:d[0x120CB]='CUNEIFORM SIGN GA2 TIMES GAN2 TENU'
let s:d[0x120CC]='CUNEIFORM SIGN GA2 TIMES GAR'
let s:d[0x120CD]='CUNEIFORM SIGN GA2 TIMES GI'
let s:d[0x120CE]='CUNEIFORM SIGN GA2 TIMES GI4'
let s:d[0x120CF]='CUNEIFORM SIGN GA2 TIMES GI4 PLUS A'
let s:d[0x120D0]='CUNEIFORM SIGN GA2 TIMES GIR2 PLUS SU'
let s:d[0x120D1]='CUNEIFORM SIGN GA2 TIMES HA PLUS LU PLUS ESH2'
let s:d[0x120D2]='CUNEIFORM SIGN GA2 TIMES HAL'
let s:d[0x120D3]='CUNEIFORM SIGN GA2 TIMES HAL PLUS LA'
let s:d[0x120D4]='CUNEIFORM SIGN GA2 TIMES HI PLUS LI'
let s:d[0x120D5]='CUNEIFORM SIGN GA2 TIMES HUB2'
let s:d[0x120D6]='CUNEIFORM SIGN GA2 TIMES IGI GUNU'
let s:d[0x120D7]='CUNEIFORM SIGN GA2 TIMES ISH PLUS HU PLUS ASH'
let s:d[0x120D8]='CUNEIFORM SIGN GA2 TIMES KAK'
let s:d[0x120D9]='CUNEIFORM SIGN GA2 TIMES KASKAL'
let s:d[0x120DA]='CUNEIFORM SIGN GA2 TIMES KID'
let s:d[0x120DB]='CUNEIFORM SIGN GA2 TIMES KID PLUS LAL'
let s:d[0x120DC]='CUNEIFORM SIGN GA2 TIMES KU3 PLUS AN'
let s:d[0x120DD]='CUNEIFORM SIGN GA2 TIMES LA'
let s:d[0x120DE]='CUNEIFORM SIGN GA2 TIMES ME PLUS EN'
let s:d[0x120DF]='CUNEIFORM SIGN GA2 TIMES MI'
let s:d[0x120E0]='CUNEIFORM SIGN GA2 TIMES NUN'
let s:d[0x120E1]='CUNEIFORM SIGN GA2 TIMES NUN OVER NUN'
let s:d[0x120E2]='CUNEIFORM SIGN GA2 TIMES PA'
let s:d[0x120E3]='CUNEIFORM SIGN GA2 TIMES SAL'
let s:d[0x120E4]='CUNEIFORM SIGN GA2 TIMES SAR'
let s:d[0x120E5]='CUNEIFORM SIGN GA2 TIMES SHE'
let s:d[0x120E6]='CUNEIFORM SIGN GA2 TIMES SHE PLUS TUR'
let s:d[0x120E7]='CUNEIFORM SIGN GA2 TIMES SHID'
let s:d[0x120E8]='CUNEIFORM SIGN GA2 TIMES SUM'
let s:d[0x120E9]='CUNEIFORM SIGN GA2 TIMES TAK4'
let s:d[0x120EA]='CUNEIFORM SIGN GA2 TIMES U'
let s:d[0x120EB]='CUNEIFORM SIGN GA2 TIMES UD'
let s:d[0x120EC]='CUNEIFORM SIGN GA2 TIMES UD PLUS DU'
let s:d[0x120ED]='CUNEIFORM SIGN GA2 OVER GA2'
let s:d[0x120EE]='CUNEIFORM SIGN GABA'
let s:d[0x120EF]='CUNEIFORM SIGN GABA CROSSING GABA'
let s:d[0x120F0]='CUNEIFORM SIGN GAD'
let s:d[0x120F1]='CUNEIFORM SIGN GAD OVER GAD GAR OVER GAR'
let s:d[0x120F2]='CUNEIFORM SIGN GAL'
let s:d[0x120F3]='CUNEIFORM SIGN GAL GAD OVER GAD GAR OVER GAR'
let s:d[0x120F4]='CUNEIFORM SIGN GALAM'
let s:d[0x120F5]='CUNEIFORM SIGN GAM'
let s:d[0x120F6]='CUNEIFORM SIGN GAN'
let s:d[0x120F7]='CUNEIFORM SIGN GAN2'
let s:d[0x120F8]='CUNEIFORM SIGN GAN2 TENU'
let s:d[0x120F9]='CUNEIFORM SIGN GAN2 OVER GAN2'
let s:d[0x120FA]='CUNEIFORM SIGN GAN2 CROSSING GAN2'
let s:d[0x120FB]='CUNEIFORM SIGN GAR'
let s:d[0x120FC]='CUNEIFORM SIGN GAR3'
let s:d[0x120FD]='CUNEIFORM SIGN GASHAN'
let s:d[0x120FE]='CUNEIFORM SIGN GESHTIN'
let s:d[0x120FF]='CUNEIFORM SIGN GESHTIN TIMES KUR'
let s:d[0x12100]='CUNEIFORM SIGN GI'
let s:d[0x12101]='CUNEIFORM SIGN GI TIMES E'
let s:d[0x12102]='CUNEIFORM SIGN GI TIMES U'
let s:d[0x12103]='CUNEIFORM SIGN GI CROSSING GI'
let s:d[0x12104]='CUNEIFORM SIGN GI4'
let s:d[0x12105]='CUNEIFORM SIGN GI4 OVER GI4'
let s:d[0x12106]='CUNEIFORM SIGN GI4 CROSSING GI4'
let s:d[0x12107]='CUNEIFORM SIGN GIDIM'
let s:d[0x12108]='CUNEIFORM SIGN GIR2'
let s:d[0x12109]='CUNEIFORM SIGN GIR2 GUNU'
let s:d[0x1210A]='CUNEIFORM SIGN GIR3'
let s:d[0x1210B]='CUNEIFORM SIGN GIR3 TIMES A PLUS IGI'
let s:d[0x1210C]='CUNEIFORM SIGN GIR3 TIMES GAN2 TENU'
let s:d[0x1210D]='CUNEIFORM SIGN GIR3 TIMES IGI'
let s:d[0x1210E]='CUNEIFORM SIGN GIR3 TIMES LU PLUS IGI'
let s:d[0x1210F]='CUNEIFORM SIGN GIR3 TIMES PA'
let s:d[0x12110]='CUNEIFORM SIGN GISAL'
let s:d[0x12111]='CUNEIFORM SIGN GISH'
let s:d[0x12112]='CUNEIFORM SIGN GISH CROSSING GISH'
let s:d[0x12113]='CUNEIFORM SIGN GISH TIMES BAD'
let s:d[0x12114]='CUNEIFORM SIGN GISH TIMES TAK4'
let s:d[0x12115]='CUNEIFORM SIGN GISH TENU'
let s:d[0x12116]='CUNEIFORM SIGN GU'
let s:d[0x12117]='CUNEIFORM SIGN GU CROSSING GU'
let s:d[0x12118]='CUNEIFORM SIGN GU2'
let s:d[0x12119]='CUNEIFORM SIGN GU2 TIMES KAK'
let s:d[0x1211A]='CUNEIFORM SIGN GU2 TIMES KAK TIMES IGI GUNU'
let s:d[0x1211B]='CUNEIFORM SIGN GU2 TIMES NUN'
let s:d[0x1211C]='CUNEIFORM SIGN GU2 TIMES SAL PLUS TUG2'
let s:d[0x1211D]='CUNEIFORM SIGN GU2 GUNU'
let s:d[0x1211E]='CUNEIFORM SIGN GUD'
let s:d[0x1211F]='CUNEIFORM SIGN GUD TIMES A PLUS KUR'
let s:d[0x12120]='CUNEIFORM SIGN GUD TIMES KUR'
let s:d[0x12121]='CUNEIFORM SIGN GUD OVER GUD LUGAL'
let s:d[0x12122]='CUNEIFORM SIGN GUL'
let s:d[0x12123]='CUNEIFORM SIGN GUM'
let s:d[0x12124]='CUNEIFORM SIGN GUM TIMES SHE'
let s:d[0x12125]='CUNEIFORM SIGN GUR'
let s:d[0x12126]='CUNEIFORM SIGN GUR7'
let s:d[0x12127]='CUNEIFORM SIGN GURUN'
let s:d[0x12128]='CUNEIFORM SIGN GURUSH'
let s:d[0x12129]='CUNEIFORM SIGN HA'
let s:d[0x1212A]='CUNEIFORM SIGN HA TENU'
let s:d[0x1212B]='CUNEIFORM SIGN HA GUNU'
let s:d[0x1212C]='CUNEIFORM SIGN HAL'
let s:d[0x1212D]='CUNEIFORM SIGN HI'
let s:d[0x1212E]='CUNEIFORM SIGN HI TIMES ASH'
let s:d[0x1212F]='CUNEIFORM SIGN HI TIMES ASH2'
let s:d[0x12130]='CUNEIFORM SIGN HI TIMES BAD'
let s:d[0x12131]='CUNEIFORM SIGN HI TIMES DISH'
let s:d[0x12132]='CUNEIFORM SIGN HI TIMES GAD'
let s:d[0x12133]='CUNEIFORM SIGN HI TIMES KIN'
let s:d[0x12134]='CUNEIFORM SIGN HI TIMES NUN'
let s:d[0x12135]='CUNEIFORM SIGN HI TIMES SHE'
let s:d[0x12136]='CUNEIFORM SIGN HI TIMES U'
let s:d[0x12137]='CUNEIFORM SIGN HU'
let s:d[0x12138]='CUNEIFORM SIGN HUB2'
let s:d[0x12139]='CUNEIFORM SIGN HUB2 TIMES AN'
let s:d[0x1213A]='CUNEIFORM SIGN HUB2 TIMES HAL'
let s:d[0x1213B]='CUNEIFORM SIGN HUB2 TIMES KASKAL'
let s:d[0x1213C]='CUNEIFORM SIGN HUB2 TIMES LISH'
let s:d[0x1213D]='CUNEIFORM SIGN HUB2 TIMES UD'
let s:d[0x1213E]='CUNEIFORM SIGN HUL2'
let s:d[0x1213F]='CUNEIFORM SIGN I'
let s:d[0x12140]='CUNEIFORM SIGN I A'
let s:d[0x12141]='CUNEIFORM SIGN IB'
let s:d[0x12142]='CUNEIFORM SIGN IDIM'
let s:d[0x12143]='CUNEIFORM SIGN IDIM OVER IDIM BUR'
let s:d[0x12144]='CUNEIFORM SIGN IDIM OVER IDIM SQUARED'
let s:d[0x12145]='CUNEIFORM SIGN IG'
let s:d[0x12146]='CUNEIFORM SIGN IGI'
let s:d[0x12147]='CUNEIFORM SIGN IGI DIB'
let s:d[0x12148]='CUNEIFORM SIGN IGI RI'
let s:d[0x12149]='CUNEIFORM SIGN IGI OVER IGI SHIR OVER SHIR UD OVER UD'
let s:d[0x1214A]='CUNEIFORM SIGN IGI GUNU'
let s:d[0x1214B]='CUNEIFORM SIGN IL'
let s:d[0x1214C]='CUNEIFORM SIGN IL TIMES GAN2 TENU'
let s:d[0x1214D]='CUNEIFORM SIGN IL2'
let s:d[0x1214E]='CUNEIFORM SIGN IM'
let s:d[0x1214F]='CUNEIFORM SIGN IM TIMES TAK4'
let s:d[0x12150]='CUNEIFORM SIGN IM CROSSING IM'
let s:d[0x12151]='CUNEIFORM SIGN IM OPPOSING IM'
let s:d[0x12152]='CUNEIFORM SIGN IM SQUARED'
let s:d[0x12153]='CUNEIFORM SIGN IMIN'
let s:d[0x12154]='CUNEIFORM SIGN IN'
let s:d[0x12155]='CUNEIFORM SIGN IR'
let s:d[0x12156]='CUNEIFORM SIGN ISH'
let s:d[0x12157]='CUNEIFORM SIGN KA'
let s:d[0x12158]='CUNEIFORM SIGN KA TIMES A'
let s:d[0x12159]='CUNEIFORM SIGN KA TIMES AD'
let s:d[0x1215A]='CUNEIFORM SIGN KA TIMES AD PLUS KU3'
let s:d[0x1215B]='CUNEIFORM SIGN KA TIMES ASH2'
let s:d[0x1215C]='CUNEIFORM SIGN KA TIMES BAD'
let s:d[0x1215D]='CUNEIFORM SIGN KA TIMES BALAG'
let s:d[0x1215E]='CUNEIFORM SIGN KA TIMES BAR'
let s:d[0x1215F]='CUNEIFORM SIGN KA TIMES BI'
let s:d[0x12160]='CUNEIFORM SIGN KA TIMES ERIN2'
let s:d[0x12161]='CUNEIFORM SIGN KA TIMES ESH2'
let s:d[0x12162]='CUNEIFORM SIGN KA TIMES GA'
let s:d[0x12163]='CUNEIFORM SIGN KA TIMES GAL'
let s:d[0x12164]='CUNEIFORM SIGN KA TIMES GAN2 TENU'
let s:d[0x12165]='CUNEIFORM SIGN KA TIMES GAR'
let s:d[0x12166]='CUNEIFORM SIGN KA TIMES GAR PLUS SHA3 PLUS A'
let s:d[0x12167]='CUNEIFORM SIGN KA TIMES GI'
let s:d[0x12168]='CUNEIFORM SIGN KA TIMES GIR2'
let s:d[0x12169]='CUNEIFORM SIGN KA TIMES GISH PLUS SAR'
let s:d[0x1216A]='CUNEIFORM SIGN KA TIMES GISH CROSSING GISH'
let s:d[0x1216B]='CUNEIFORM SIGN KA TIMES GU'
let s:d[0x1216C]='CUNEIFORM SIGN KA TIMES GUR7'
let s:d[0x1216D]='CUNEIFORM SIGN KA TIMES IGI'
let s:d[0x1216E]='CUNEIFORM SIGN KA TIMES IM'
let s:d[0x1216F]='CUNEIFORM SIGN KA TIMES KAK'
let s:d[0x12170]='CUNEIFORM SIGN KA TIMES KI'
let s:d[0x12171]='CUNEIFORM SIGN KA TIMES KID'
let s:d[0x12172]='CUNEIFORM SIGN KA TIMES LI'
let s:d[0x12173]='CUNEIFORM SIGN KA TIMES LU'
let s:d[0x12174]='CUNEIFORM SIGN KA TIMES ME'
let s:d[0x12175]='CUNEIFORM SIGN KA TIMES ME PLUS DU'
let s:d[0x12176]='CUNEIFORM SIGN KA TIMES ME PLUS GI'
let s:d[0x12177]='CUNEIFORM SIGN KA TIMES ME PLUS TE'
let s:d[0x12178]='CUNEIFORM SIGN KA TIMES MI'
let s:d[0x12179]='CUNEIFORM SIGN KA TIMES MI PLUS NUNUZ'
let s:d[0x1217A]='CUNEIFORM SIGN KA TIMES NE'
let s:d[0x1217B]='CUNEIFORM SIGN KA TIMES NUN'
let s:d[0x1217C]='CUNEIFORM SIGN KA TIMES PI'
let s:d[0x1217D]='CUNEIFORM SIGN KA TIMES RU'
let s:d[0x1217E]='CUNEIFORM SIGN KA TIMES SA'
let s:d[0x1217F]='CUNEIFORM SIGN KA TIMES SAR'
let s:d[0x12180]='CUNEIFORM SIGN KA TIMES SHA'
let s:d[0x12181]='CUNEIFORM SIGN KA TIMES SHE'
let s:d[0x12182]='CUNEIFORM SIGN KA TIMES SHID'
let s:d[0x12183]='CUNEIFORM SIGN KA TIMES SHU'
let s:d[0x12184]='CUNEIFORM SIGN KA TIMES SIG'
let s:d[0x12185]='CUNEIFORM SIGN KA TIMES SUHUR'
let s:d[0x12186]='CUNEIFORM SIGN KA TIMES TAR'
let s:d[0x12187]='CUNEIFORM SIGN KA TIMES U'
let s:d[0x12188]='CUNEIFORM SIGN KA TIMES U2'
let s:d[0x12189]='CUNEIFORM SIGN KA TIMES UD'
let s:d[0x1218A]='CUNEIFORM SIGN KA TIMES UMUM TIMES PA'
let s:d[0x1218B]='CUNEIFORM SIGN KA TIMES USH'
let s:d[0x1218C]='CUNEIFORM SIGN KA TIMES ZI'
let s:d[0x1218D]='CUNEIFORM SIGN KA2'
let s:d[0x1218E]='CUNEIFORM SIGN KA2 CROSSING KA2'
let s:d[0x1218F]='CUNEIFORM SIGN KAB'
let s:d[0x12190]='CUNEIFORM SIGN KAD2'
let s:d[0x12191]='CUNEIFORM SIGN KAD3'
let s:d[0x12192]='CUNEIFORM SIGN KAD4'
let s:d[0x12193]='CUNEIFORM SIGN KAD5'
let s:d[0x12194]='CUNEIFORM SIGN KAD5 OVER KAD5'
let s:d[0x12195]='CUNEIFORM SIGN KAK'
let s:d[0x12196]='CUNEIFORM SIGN KAK TIMES IGI GUNU'
let s:d[0x12197]='CUNEIFORM SIGN KAL'
let s:d[0x12198]='CUNEIFORM SIGN KAL TIMES BAD'
let s:d[0x12199]='CUNEIFORM SIGN KAL CROSSING KAL'
let s:d[0x1219A]='CUNEIFORM SIGN KAM2'
let s:d[0x1219B]='CUNEIFORM SIGN KAM4'
let s:d[0x1219C]='CUNEIFORM SIGN KASKAL'
let s:d[0x1219D]='CUNEIFORM SIGN KASKAL LAGAB TIMES U OVER LAGAB TIMES U'
let s:d[0x1219E]='CUNEIFORM SIGN KASKAL OVER KASKAL LAGAB TIMES U OVER LAGAB TIMES U'
let s:d[0x1219F]='CUNEIFORM SIGN KESH2'
let s:d[0x121A0]='CUNEIFORM SIGN KI'
let s:d[0x121A1]='CUNEIFORM SIGN KI TIMES BAD'
let s:d[0x121A2]='CUNEIFORM SIGN KI TIMES U'
let s:d[0x121A3]='CUNEIFORM SIGN KI TIMES UD'
let s:d[0x121A4]='CUNEIFORM SIGN KID'
let s:d[0x121A5]='CUNEIFORM SIGN KIN'
let s:d[0x121A6]='CUNEIFORM SIGN KISAL'
let s:d[0x121A7]='CUNEIFORM SIGN KISH'
let s:d[0x121A8]='CUNEIFORM SIGN KISIM5'
let s:d[0x121A9]='CUNEIFORM SIGN KISIM5 OVER KISIM5'
let s:d[0x121AA]='CUNEIFORM SIGN KU'
let s:d[0x121AB]='CUNEIFORM SIGN KU OVER HI TIMES ASH2 KU OVER HI TIMES ASH2'
let s:d[0x121AC]='CUNEIFORM SIGN KU3'
let s:d[0x121AD]='CUNEIFORM SIGN KU4'
let s:d[0x121AE]='CUNEIFORM SIGN KU4 VARIANT FORM'
let s:d[0x121AF]='CUNEIFORM SIGN KU7'
let s:d[0x121B0]='CUNEIFORM SIGN KUL'
let s:d[0x121B1]='CUNEIFORM SIGN KUL GUNU'
let s:d[0x121B2]='CUNEIFORM SIGN KUN'
let s:d[0x121B3]='CUNEIFORM SIGN KUR'
let s:d[0x121B4]='CUNEIFORM SIGN KUR OPPOSING KUR'
let s:d[0x121B5]='CUNEIFORM SIGN KUSHU2'
let s:d[0x121B6]='CUNEIFORM SIGN KWU318'
let s:d[0x121B7]='CUNEIFORM SIGN LA'
let s:d[0x121B8]='CUNEIFORM SIGN LAGAB'
let s:d[0x121B9]='CUNEIFORM SIGN LAGAB TIMES A'
let s:d[0x121BA]='CUNEIFORM SIGN LAGAB TIMES A PLUS DA PLUS HA'
let s:d[0x121BB]='CUNEIFORM SIGN LAGAB TIMES A PLUS GAR'
let s:d[0x121BC]='CUNEIFORM SIGN LAGAB TIMES A PLUS LAL'
let s:d[0x121BD]='CUNEIFORM SIGN LAGAB TIMES AL'
let s:d[0x121BE]='CUNEIFORM SIGN LAGAB TIMES AN'
let s:d[0x121BF]='CUNEIFORM SIGN LAGAB TIMES ASH ZIDA TENU'
let s:d[0x121C0]='CUNEIFORM SIGN LAGAB TIMES BAD'
let s:d[0x121C1]='CUNEIFORM SIGN LAGAB TIMES BI'
let s:d[0x121C2]='CUNEIFORM SIGN LAGAB TIMES DAR'
let s:d[0x121C3]='CUNEIFORM SIGN LAGAB TIMES EN'
let s:d[0x121C4]='CUNEIFORM SIGN LAGAB TIMES GA'
let s:d[0x121C5]='CUNEIFORM SIGN LAGAB TIMES GAR'
let s:d[0x121C6]='CUNEIFORM SIGN LAGAB TIMES GUD'
let s:d[0x121C7]='CUNEIFORM SIGN LAGAB TIMES GUD PLUS GUD'
let s:d[0x121C8]='CUNEIFORM SIGN LAGAB TIMES HA'
let s:d[0x121C9]='CUNEIFORM SIGN LAGAB TIMES HAL'
let s:d[0x121CA]='CUNEIFORM SIGN LAGAB TIMES HI TIMES NUN'
let s:d[0x121CB]='CUNEIFORM SIGN LAGAB TIMES IGI GUNU'
let s:d[0x121CC]='CUNEIFORM SIGN LAGAB TIMES IM'
let s:d[0x121CD]='CUNEIFORM SIGN LAGAB TIMES IM PLUS HA'
let s:d[0x121CE]='CUNEIFORM SIGN LAGAB TIMES IM PLUS LU'
let s:d[0x121CF]='CUNEIFORM SIGN LAGAB TIMES KI'
let s:d[0x121D0]='CUNEIFORM SIGN LAGAB TIMES KIN'
let s:d[0x121D1]='CUNEIFORM SIGN LAGAB TIMES KU3'
let s:d[0x121D2]='CUNEIFORM SIGN LAGAB TIMES KUL'
let s:d[0x121D3]='CUNEIFORM SIGN LAGAB TIMES KUL PLUS HI PLUS A'
let s:d[0x121D4]='CUNEIFORM SIGN LAGAB TIMES LAGAB'
let s:d[0x121D5]='CUNEIFORM SIGN LAGAB TIMES LISH'
let s:d[0x121D6]='CUNEIFORM SIGN LAGAB TIMES LU'
let s:d[0x121D7]='CUNEIFORM SIGN LAGAB TIMES LUL'
let s:d[0x121D8]='CUNEIFORM SIGN LAGAB TIMES ME'
let s:d[0x121D9]='CUNEIFORM SIGN LAGAB TIMES ME PLUS EN'
let s:d[0x121DA]='CUNEIFORM SIGN LAGAB TIMES MUSH'
let s:d[0x121DB]='CUNEIFORM SIGN LAGAB TIMES NE'
let s:d[0x121DC]='CUNEIFORM SIGN LAGAB TIMES SHE PLUS SUM'
let s:d[0x121DD]='CUNEIFORM SIGN LAGAB TIMES SHITA PLUS GISH PLUS ERIN2'
let s:d[0x121DE]='CUNEIFORM SIGN LAGAB TIMES SHITA PLUS GISH TENU'
let s:d[0x121DF]='CUNEIFORM SIGN LAGAB TIMES SHU2'
let s:d[0x121E0]='CUNEIFORM SIGN LAGAB TIMES SHU2 PLUS SHU2'
let s:d[0x121E1]='CUNEIFORM SIGN LAGAB TIMES SUM'
let s:d[0x121E2]='CUNEIFORM SIGN LAGAB TIMES TAG'
let s:d[0x121E3]='CUNEIFORM SIGN LAGAB TIMES TAK4'
let s:d[0x121E4]='CUNEIFORM SIGN LAGAB TIMES TE PLUS A PLUS SU PLUS NA'
let s:d[0x121E5]='CUNEIFORM SIGN LAGAB TIMES U'
let s:d[0x121E6]='CUNEIFORM SIGN LAGAB TIMES U PLUS A'
let s:d[0x121E7]='CUNEIFORM SIGN LAGAB TIMES U PLUS U PLUS U'
let s:d[0x121E8]='CUNEIFORM SIGN LAGAB TIMES U2 PLUS ASH'
let s:d[0x121E9]='CUNEIFORM SIGN LAGAB TIMES UD'
let s:d[0x121EA]='CUNEIFORM SIGN LAGAB TIMES USH'
let s:d[0x121EB]='CUNEIFORM SIGN LAGAB SQUARED'
let s:d[0x121EC]='CUNEIFORM SIGN LAGAR'
let s:d[0x121ED]='CUNEIFORM SIGN LAGAR TIMES SHE'
let s:d[0x121EE]='CUNEIFORM SIGN LAGAR TIMES SHE PLUS SUM'
let s:d[0x121EF]='CUNEIFORM SIGN LAGAR GUNU'
let s:d[0x121F0]='CUNEIFORM SIGN LAGAR GUNU OVER LAGAR GUNU SHE'
let s:d[0x121F1]='CUNEIFORM SIGN LAHSHU'
let s:d[0x121F2]='CUNEIFORM SIGN LAL'
let s:d[0x121F3]='CUNEIFORM SIGN LAL TIMES LAL'
let s:d[0x121F4]='CUNEIFORM SIGN LAM'
let s:d[0x121F5]='CUNEIFORM SIGN LAM TIMES KUR'
let s:d[0x121F6]='CUNEIFORM SIGN LAM TIMES KUR PLUS RU'
let s:d[0x121F7]='CUNEIFORM SIGN LI'
let s:d[0x121F8]='CUNEIFORM SIGN LIL'
let s:d[0x121F9]='CUNEIFORM SIGN LIMMU2'
let s:d[0x121FA]='CUNEIFORM SIGN LISH'
let s:d[0x121FB]='CUNEIFORM SIGN LU'
let s:d[0x121FC]='CUNEIFORM SIGN LU TIMES BAD'
let s:d[0x121FD]='CUNEIFORM SIGN LU2'
let s:d[0x121FE]='CUNEIFORM SIGN LU2 TIMES AL'
let s:d[0x121FF]='CUNEIFORM SIGN LU2 TIMES BAD'
let s:d[0x12200]='CUNEIFORM SIGN LU2 TIMES ESH2'
let s:d[0x12201]='CUNEIFORM SIGN LU2 TIMES ESH2 TENU'
let s:d[0x12202]='CUNEIFORM SIGN LU2 TIMES GAN2 TENU'
let s:d[0x12203]='CUNEIFORM SIGN LU2 TIMES HI TIMES BAD'
let s:d[0x12204]='CUNEIFORM SIGN LU2 TIMES IM'
let s:d[0x12205]='CUNEIFORM SIGN LU2 TIMES KAD2'
let s:d[0x12206]='CUNEIFORM SIGN LU2 TIMES KAD3'
let s:d[0x12207]='CUNEIFORM SIGN LU2 TIMES KAD3 PLUS ASH'
let s:d[0x12208]='CUNEIFORM SIGN LU2 TIMES KI'
let s:d[0x12209]='CUNEIFORM SIGN LU2 TIMES LA PLUS ASH'
let s:d[0x1220A]='CUNEIFORM SIGN LU2 TIMES LAGAB'
let s:d[0x1220B]='CUNEIFORM SIGN LU2 TIMES ME PLUS EN'
let s:d[0x1220C]='CUNEIFORM SIGN LU2 TIMES NE'
let s:d[0x1220D]='CUNEIFORM SIGN LU2 TIMES NU'
let s:d[0x1220E]='CUNEIFORM SIGN LU2 TIMES SI PLUS ASH'
let s:d[0x1220F]='CUNEIFORM SIGN LU2 TIMES SIK2 PLUS BU'
let s:d[0x12210]='CUNEIFORM SIGN LU2 TIMES TUG2'
let s:d[0x12211]='CUNEIFORM SIGN LU2 TENU'
let s:d[0x12212]='CUNEIFORM SIGN LU2 CROSSING LU2'
let s:d[0x12213]='CUNEIFORM SIGN LU2 OPPOSING LU2'
let s:d[0x12214]='CUNEIFORM SIGN LU2 SQUARED'
let s:d[0x12215]='CUNEIFORM SIGN LU2 SHESHIG'
let s:d[0x12216]='CUNEIFORM SIGN LU3'
let s:d[0x12217]='CUNEIFORM SIGN LUGAL'
let s:d[0x12218]='CUNEIFORM SIGN LUGAL OVER LUGAL'
let s:d[0x12219]='CUNEIFORM SIGN LUGAL OPPOSING LUGAL'
let s:d[0x1221A]='CUNEIFORM SIGN LUGAL SHESHIG'
let s:d[0x1221B]='CUNEIFORM SIGN LUH'
let s:d[0x1221C]='CUNEIFORM SIGN LUL'
let s:d[0x1221D]='CUNEIFORM SIGN LUM'
let s:d[0x1221E]='CUNEIFORM SIGN LUM OVER LUM'
let s:d[0x1221F]='CUNEIFORM SIGN LUM OVER LUM GAR OVER GAR'
let s:d[0x12220]='CUNEIFORM SIGN MA'
let s:d[0x12221]='CUNEIFORM SIGN MA TIMES TAK4'
let s:d[0x12222]='CUNEIFORM SIGN MA GUNU'
let s:d[0x12223]='CUNEIFORM SIGN MA2'
let s:d[0x12224]='CUNEIFORM SIGN MAH'
let s:d[0x12225]='CUNEIFORM SIGN MAR'
let s:d[0x12226]='CUNEIFORM SIGN MASH'
let s:d[0x12227]='CUNEIFORM SIGN MASH2'
let s:d[0x12228]='CUNEIFORM SIGN ME'
let s:d[0x12229]='CUNEIFORM SIGN MES'
let s:d[0x1222A]='CUNEIFORM SIGN MI'
let s:d[0x1222B]='CUNEIFORM SIGN MIN'
let s:d[0x1222C]='CUNEIFORM SIGN MU'
let s:d[0x1222D]='CUNEIFORM SIGN MU OVER MU'
let s:d[0x1222E]='CUNEIFORM SIGN MUG'
let s:d[0x1222F]='CUNEIFORM SIGN MUG GUNU'
let s:d[0x12230]='CUNEIFORM SIGN MUNSUB'
let s:d[0x12231]='CUNEIFORM SIGN MURGU2'
let s:d[0x12232]='CUNEIFORM SIGN MUSH'
let s:d[0x12233]='CUNEIFORM SIGN MUSH TIMES A'
let s:d[0x12234]='CUNEIFORM SIGN MUSH TIMES KUR'
let s:d[0x12235]='CUNEIFORM SIGN MUSH TIMES ZA'
let s:d[0x12236]='CUNEIFORM SIGN MUSH OVER MUSH'
let s:d[0x12237]='CUNEIFORM SIGN MUSH OVER MUSH TIMES A PLUS NA'
let s:d[0x12238]='CUNEIFORM SIGN MUSH CROSSING MUSH'
let s:d[0x12239]='CUNEIFORM SIGN MUSH3'
let s:d[0x1223A]='CUNEIFORM SIGN MUSH3 TIMES A'
let s:d[0x1223B]='CUNEIFORM SIGN MUSH3 TIMES A PLUS DI'
let s:d[0x1223C]='CUNEIFORM SIGN MUSH3 TIMES DI'
let s:d[0x1223D]='CUNEIFORM SIGN MUSH3 GUNU'
let s:d[0x1223E]='CUNEIFORM SIGN NA'
let s:d[0x1223F]='CUNEIFORM SIGN NA2'
let s:d[0x12240]='CUNEIFORM SIGN NAGA'
let s:d[0x12241]='CUNEIFORM SIGN NAGA INVERTED'
let s:d[0x12242]='CUNEIFORM SIGN NAGA TIMES SHU TENU'
let s:d[0x12243]='CUNEIFORM SIGN NAGA OPPOSING NAGA'
let s:d[0x12244]='CUNEIFORM SIGN NAGAR'
let s:d[0x12245]='CUNEIFORM SIGN NAM NUTILLU'
let s:d[0x12246]='CUNEIFORM SIGN NAM'
let s:d[0x12247]='CUNEIFORM SIGN NAM2'
let s:d[0x12248]='CUNEIFORM SIGN NE'
let s:d[0x12249]='CUNEIFORM SIGN NE TIMES A'
let s:d[0x1224A]='CUNEIFORM SIGN NE TIMES UD'
let s:d[0x1224B]='CUNEIFORM SIGN NE SHESHIG'
let s:d[0x1224C]='CUNEIFORM SIGN NI'
let s:d[0x1224D]='CUNEIFORM SIGN NI TIMES E'
let s:d[0x1224E]='CUNEIFORM SIGN NI2'
let s:d[0x1224F]='CUNEIFORM SIGN NIM'
let s:d[0x12250]='CUNEIFORM SIGN NIM TIMES GAN2 TENU'
let s:d[0x12251]='CUNEIFORM SIGN NIM TIMES GAR PLUS GAN2 TENU'
let s:d[0x12252]='CUNEIFORM SIGN NINDA2'
let s:d[0x12253]='CUNEIFORM SIGN NINDA2 TIMES AN'
let s:d[0x12254]='CUNEIFORM SIGN NINDA2 TIMES ASH'
let s:d[0x12255]='CUNEIFORM SIGN NINDA2 TIMES ASH PLUS ASH'
let s:d[0x12256]='CUNEIFORM SIGN NINDA2 TIMES GUD'
let s:d[0x12257]='CUNEIFORM SIGN NINDA2 TIMES ME PLUS GAN2 TENU'
let s:d[0x12258]='CUNEIFORM SIGN NINDA2 TIMES NE'
let s:d[0x12259]='CUNEIFORM SIGN NINDA2 TIMES NUN'
let s:d[0x1225A]='CUNEIFORM SIGN NINDA2 TIMES SHE'
let s:d[0x1225B]='CUNEIFORM SIGN NINDA2 TIMES SHE PLUS A AN'
let s:d[0x1225C]='CUNEIFORM SIGN NINDA2 TIMES SHE PLUS ASH'
let s:d[0x1225D]='CUNEIFORM SIGN NINDA2 TIMES SHE PLUS ASH PLUS ASH'
let s:d[0x1225E]='CUNEIFORM SIGN NINDA2 TIMES U2 PLUS ASH'
let s:d[0x1225F]='CUNEIFORM SIGN NINDA2 TIMES USH'
let s:d[0x12260]='CUNEIFORM SIGN NISAG'
let s:d[0x12261]='CUNEIFORM SIGN NU'
let s:d[0x12262]='CUNEIFORM SIGN NU11'
let s:d[0x12263]='CUNEIFORM SIGN NUN'
let s:d[0x12264]='CUNEIFORM SIGN NUN LAGAR TIMES GAR'
let s:d[0x12265]='CUNEIFORM SIGN NUN LAGAR TIMES MASH'
let s:d[0x12266]='CUNEIFORM SIGN NUN LAGAR TIMES SAL'
let s:d[0x12267]='CUNEIFORM SIGN NUN LAGAR TIMES SAL OVER NUN LAGAR TIMES SAL'
let s:d[0x12268]='CUNEIFORM SIGN NUN LAGAR TIMES USH'
let s:d[0x12269]='CUNEIFORM SIGN NUN TENU'
let s:d[0x1226A]='CUNEIFORM SIGN NUN OVER NUN'
let s:d[0x1226B]='CUNEIFORM SIGN NUN CROSSING NUN'
let s:d[0x1226C]='CUNEIFORM SIGN NUN CROSSING NUN LAGAR OVER LAGAR'
let s:d[0x1226D]='CUNEIFORM SIGN NUNUZ'
let s:d[0x1226E]='CUNEIFORM SIGN NUNUZ AB2 TIMES ASHGAB'
let s:d[0x1226F]='CUNEIFORM SIGN NUNUZ AB2 TIMES BI'
let s:d[0x12270]='CUNEIFORM SIGN NUNUZ AB2 TIMES DUG'
let s:d[0x12271]='CUNEIFORM SIGN NUNUZ AB2 TIMES GUD'
let s:d[0x12272]='CUNEIFORM SIGN NUNUZ AB2 TIMES IGI GUNU'
let s:d[0x12273]='CUNEIFORM SIGN NUNUZ AB2 TIMES KAD3'
let s:d[0x12274]='CUNEIFORM SIGN NUNUZ AB2 TIMES LA'
let s:d[0x12275]='CUNEIFORM SIGN NUNUZ AB2 TIMES NE'
let s:d[0x12276]='CUNEIFORM SIGN NUNUZ AB2 TIMES SILA3'
let s:d[0x12277]='CUNEIFORM SIGN NUNUZ AB2 TIMES U2'
let s:d[0x12278]='CUNEIFORM SIGN NUNUZ KISIM5 TIMES BI'
let s:d[0x12279]='CUNEIFORM SIGN NUNUZ KISIM5 TIMES BI U'
let s:d[0x1227A]='CUNEIFORM SIGN PA'
let s:d[0x1227B]='CUNEIFORM SIGN PAD'
let s:d[0x1227C]='CUNEIFORM SIGN PAN'
let s:d[0x1227D]='CUNEIFORM SIGN PAP'
let s:d[0x1227E]='CUNEIFORM SIGN PESH2'
let s:d[0x1227F]='CUNEIFORM SIGN PI'
let s:d[0x12280]='CUNEIFORM SIGN PI TIMES A'
let s:d[0x12281]='CUNEIFORM SIGN PI TIMES AB'
let s:d[0x12282]='CUNEIFORM SIGN PI TIMES BI'
let s:d[0x12283]='CUNEIFORM SIGN PI TIMES BU'
let s:d[0x12284]='CUNEIFORM SIGN PI TIMES E'
let s:d[0x12285]='CUNEIFORM SIGN PI TIMES I'
let s:d[0x12286]='CUNEIFORM SIGN PI TIMES IB'
let s:d[0x12287]='CUNEIFORM SIGN PI TIMES U'
let s:d[0x12288]='CUNEIFORM SIGN PI TIMES U2'
let s:d[0x12289]='CUNEIFORM SIGN PI CROSSING PI'
let s:d[0x1228A]='CUNEIFORM SIGN PIRIG'
let s:d[0x1228B]='CUNEIFORM SIGN PIRIG TIMES KAL'
let s:d[0x1228C]='CUNEIFORM SIGN PIRIG TIMES UD'
let s:d[0x1228D]='CUNEIFORM SIGN PIRIG TIMES ZA'
let s:d[0x1228E]='CUNEIFORM SIGN PIRIG OPPOSING PIRIG'
let s:d[0x1228F]='CUNEIFORM SIGN RA'
let s:d[0x12290]='CUNEIFORM SIGN RAB'
let s:d[0x12291]='CUNEIFORM SIGN RI'
let s:d[0x12292]='CUNEIFORM SIGN RU'
let s:d[0x12293]='CUNEIFORM SIGN SA'
let s:d[0x12294]='CUNEIFORM SIGN SAG NUTILLU'
let s:d[0x12295]='CUNEIFORM SIGN SAG'
let s:d[0x12296]='CUNEIFORM SIGN SAG TIMES A'
let s:d[0x12297]='CUNEIFORM SIGN SAG TIMES DU'
let s:d[0x12298]='CUNEIFORM SIGN SAG TIMES DUB'
let s:d[0x12299]='CUNEIFORM SIGN SAG TIMES HA'
let s:d[0x1229A]='CUNEIFORM SIGN SAG TIMES KAK'
let s:d[0x1229B]='CUNEIFORM SIGN SAG TIMES KUR'
let s:d[0x1229C]='CUNEIFORM SIGN SAG TIMES LUM'
let s:d[0x1229D]='CUNEIFORM SIGN SAG TIMES MI'
let s:d[0x1229E]='CUNEIFORM SIGN SAG TIMES NUN'
let s:d[0x1229F]='CUNEIFORM SIGN SAG TIMES SAL'
let s:d[0x122A0]='CUNEIFORM SIGN SAG TIMES SHID'
let s:d[0x122A1]='CUNEIFORM SIGN SAG TIMES TAB'
let s:d[0x122A2]='CUNEIFORM SIGN SAG TIMES U2'
let s:d[0x122A3]='CUNEIFORM SIGN SAG TIMES UB'
let s:d[0x122A4]='CUNEIFORM SIGN SAG TIMES UM'
let s:d[0x122A5]='CUNEIFORM SIGN SAG TIMES UR'
let s:d[0x122A6]='CUNEIFORM SIGN SAG TIMES USH'
let s:d[0x122A7]='CUNEIFORM SIGN SAG OVER SAG'
let s:d[0x122A8]='CUNEIFORM SIGN SAG GUNU'
let s:d[0x122A9]='CUNEIFORM SIGN SAL'
let s:d[0x122AA]='CUNEIFORM SIGN SAL LAGAB TIMES ASH2'
let s:d[0x122AB]='CUNEIFORM SIGN SANGA2'
let s:d[0x122AC]='CUNEIFORM SIGN SAR'
let s:d[0x122AD]='CUNEIFORM SIGN SHA'
let s:d[0x122AE]='CUNEIFORM SIGN SHA3'
let s:d[0x122AF]='CUNEIFORM SIGN SHA3 TIMES A'
let s:d[0x122B0]='CUNEIFORM SIGN SHA3 TIMES BAD'
let s:d[0x122B1]='CUNEIFORM SIGN SHA3 TIMES GISH'
let s:d[0x122B2]='CUNEIFORM SIGN SHA3 TIMES NE'
let s:d[0x122B3]='CUNEIFORM SIGN SHA3 TIMES SHU2'
let s:d[0x122B4]='CUNEIFORM SIGN SHA3 TIMES TUR'
let s:d[0x122B5]='CUNEIFORM SIGN SHA3 TIMES U'
let s:d[0x122B6]='CUNEIFORM SIGN SHA3 TIMES U PLUS A'
let s:d[0x122B7]='CUNEIFORM SIGN SHA6'
let s:d[0x122B8]='CUNEIFORM SIGN SHAB6'
let s:d[0x122B9]='CUNEIFORM SIGN SHAR2'
let s:d[0x122BA]='CUNEIFORM SIGN SHE'
let s:d[0x122BB]='CUNEIFORM SIGN SHE HU'
let s:d[0x122BC]='CUNEIFORM SIGN SHE OVER SHE GAD OVER GAD GAR OVER GAR'
let s:d[0x122BD]='CUNEIFORM SIGN SHE OVER SHE TAB OVER TAB GAR OVER GAR'
let s:d[0x122BE]='CUNEIFORM SIGN SHEG9'
let s:d[0x122BF]='CUNEIFORM SIGN SHEN'
let s:d[0x122C0]='CUNEIFORM SIGN SHESH'
let s:d[0x122C1]='CUNEIFORM SIGN SHESH2'
let s:d[0x122C2]='CUNEIFORM SIGN SHESHLAM'
let s:d[0x122C3]='CUNEIFORM SIGN SHID'
let s:d[0x122C4]='CUNEIFORM SIGN SHID TIMES A'
let s:d[0x122C5]='CUNEIFORM SIGN SHID TIMES IM'
let s:d[0x122C6]='CUNEIFORM SIGN SHIM'
let s:d[0x122C7]='CUNEIFORM SIGN SHIM TIMES A'
let s:d[0x122C8]='CUNEIFORM SIGN SHIM TIMES BAL'
let s:d[0x122C9]='CUNEIFORM SIGN SHIM TIMES BULUG'
let s:d[0x122CA]='CUNEIFORM SIGN SHIM TIMES DIN'
let s:d[0x122CB]='CUNEIFORM SIGN SHIM TIMES GAR'
let s:d[0x122CC]='CUNEIFORM SIGN SHIM TIMES IGI'
let s:d[0x122CD]='CUNEIFORM SIGN SHIM TIMES IGI GUNU'
let s:d[0x122CE]='CUNEIFORM SIGN SHIM TIMES KUSHU2'
let s:d[0x122CF]='CUNEIFORM SIGN SHIM TIMES LUL'
let s:d[0x122D0]='CUNEIFORM SIGN SHIM TIMES MUG'
let s:d[0x122D1]='CUNEIFORM SIGN SHIM TIMES SAL'
let s:d[0x122D2]='CUNEIFORM SIGN SHINIG'
let s:d[0x122D3]='CUNEIFORM SIGN SHIR'
let s:d[0x122D4]='CUNEIFORM SIGN SHIR TENU'
let s:d[0x122D5]='CUNEIFORM SIGN SHIR OVER SHIR BUR OVER BUR'
let s:d[0x122D6]='CUNEIFORM SIGN SHITA'
let s:d[0x122D7]='CUNEIFORM SIGN SHU'
let s:d[0x122D8]='CUNEIFORM SIGN SHU OVER INVERTED SHU'
let s:d[0x122D9]='CUNEIFORM SIGN SHU2'
let s:d[0x122DA]='CUNEIFORM SIGN SHUBUR'
let s:d[0x122DB]='CUNEIFORM SIGN SI'
let s:d[0x122DC]='CUNEIFORM SIGN SI GUNU'
let s:d[0x122DD]='CUNEIFORM SIGN SIG'
let s:d[0x122DE]='CUNEIFORM SIGN SIG4'
let s:d[0x122DF]='CUNEIFORM SIGN SIG4 OVER SIG4 SHU2'
let s:d[0x122E0]='CUNEIFORM SIGN SIK2'
let s:d[0x122E1]='CUNEIFORM SIGN SILA3'
let s:d[0x122E2]='CUNEIFORM SIGN SU'
let s:d[0x122E3]='CUNEIFORM SIGN SU OVER SU'
let s:d[0x122E4]='CUNEIFORM SIGN SUD'
let s:d[0x122E5]='CUNEIFORM SIGN SUD2'
let s:d[0x122E6]='CUNEIFORM SIGN SUHUR'
let s:d[0x122E7]='CUNEIFORM SIGN SUM'
let s:d[0x122E8]='CUNEIFORM SIGN SUMASH'
let s:d[0x122E9]='CUNEIFORM SIGN SUR'
let s:d[0x122EA]='CUNEIFORM SIGN SUR9'
let s:d[0x122EB]='CUNEIFORM SIGN TA'
let s:d[0x122EC]='CUNEIFORM SIGN TA ASTERISK'
let s:d[0x122ED]='CUNEIFORM SIGN TA TIMES HI'
let s:d[0x122EE]='CUNEIFORM SIGN TA TIMES MI'
let s:d[0x122EF]='CUNEIFORM SIGN TA GUNU'
let s:d[0x122F0]='CUNEIFORM SIGN TAB'
let s:d[0x122F1]='CUNEIFORM SIGN TAB OVER TAB NI OVER NI DISH OVER DISH'
let s:d[0x122F2]='CUNEIFORM SIGN TAB SQUARED'
let s:d[0x122F3]='CUNEIFORM SIGN TAG'
let s:d[0x122F4]='CUNEIFORM SIGN TAG TIMES BI'
let s:d[0x122F5]='CUNEIFORM SIGN TAG TIMES GUD'
let s:d[0x122F6]='CUNEIFORM SIGN TAG TIMES SHE'
let s:d[0x122F7]='CUNEIFORM SIGN TAG TIMES SHU'
let s:d[0x122F8]='CUNEIFORM SIGN TAG TIMES TUG2'
let s:d[0x122F9]='CUNEIFORM SIGN TAG TIMES UD'
let s:d[0x122FA]='CUNEIFORM SIGN TAK4'
let s:d[0x122FB]='CUNEIFORM SIGN TAR'
let s:d[0x122FC]='CUNEIFORM SIGN TE'
let s:d[0x122FD]='CUNEIFORM SIGN TE GUNU'
let s:d[0x122FE]='CUNEIFORM SIGN TI'
let s:d[0x122FF]='CUNEIFORM SIGN TI TENU'
let s:d[0x12300]='CUNEIFORM SIGN TIL'
let s:d[0x12301]='CUNEIFORM SIGN TIR'
let s:d[0x12302]='CUNEIFORM SIGN TIR TIMES TAK4'
let s:d[0x12303]='CUNEIFORM SIGN TIR OVER TIR'
let s:d[0x12304]='CUNEIFORM SIGN TIR OVER TIR GAD OVER GAD GAR OVER GAR'
let s:d[0x12305]='CUNEIFORM SIGN TU'
let s:d[0x12306]='CUNEIFORM SIGN TUG2'
let s:d[0x12307]='CUNEIFORM SIGN TUK'
let s:d[0x12308]='CUNEIFORM SIGN TUM'
let s:d[0x12309]='CUNEIFORM SIGN TUR'
let s:d[0x1230A]='CUNEIFORM SIGN TUR OVER TUR ZA OVER ZA'
let s:d[0x1230B]='CUNEIFORM SIGN U'
let s:d[0x1230C]='CUNEIFORM SIGN U GUD'
let s:d[0x1230D]='CUNEIFORM SIGN U U U'
let s:d[0x1230E]='CUNEIFORM SIGN U OVER U PA OVER PA GAR OVER GAR'
let s:d[0x1230F]='CUNEIFORM SIGN U OVER U SUR OVER SUR'
let s:d[0x12310]='CUNEIFORM SIGN U OVER U U REVERSED OVER U REVERSED'
let s:d[0x12311]='CUNEIFORM SIGN U2'
let s:d[0x12312]='CUNEIFORM SIGN UB'
let s:d[0x12313]='CUNEIFORM SIGN UD'
let s:d[0x12314]='CUNEIFORM SIGN UD KUSHU2'
let s:d[0x12315]='CUNEIFORM SIGN UD TIMES BAD'
let s:d[0x12316]='CUNEIFORM SIGN UD TIMES MI'
let s:d[0x12317]='CUNEIFORM SIGN UD TIMES U PLUS U PLUS U'
let s:d[0x12318]='CUNEIFORM SIGN UD TIMES U PLUS U PLUS U GUNU'
let s:d[0x12319]='CUNEIFORM SIGN UD GUNU'
let s:d[0x1231A]='CUNEIFORM SIGN UD SHESHIG'
let s:d[0x1231B]='CUNEIFORM SIGN UD SHESHIG TIMES BAD'
let s:d[0x1231C]='CUNEIFORM SIGN UDUG'
let s:d[0x1231D]='CUNEIFORM SIGN UM'
let s:d[0x1231E]='CUNEIFORM SIGN UM TIMES LAGAB'
let s:d[0x1231F]='CUNEIFORM SIGN UM TIMES ME PLUS DA'
let s:d[0x12320]='CUNEIFORM SIGN UM TIMES SHA3'
let s:d[0x12321]='CUNEIFORM SIGN UM TIMES U'
let s:d[0x12322]='CUNEIFORM SIGN UMBIN'
let s:d[0x12323]='CUNEIFORM SIGN UMUM'
let s:d[0x12324]='CUNEIFORM SIGN UMUM TIMES KASKAL'
let s:d[0x12325]='CUNEIFORM SIGN UMUM TIMES PA'
let s:d[0x12326]='CUNEIFORM SIGN UN'
let s:d[0x12327]='CUNEIFORM SIGN UN GUNU'
let s:d[0x12328]='CUNEIFORM SIGN UR'
let s:d[0x12329]='CUNEIFORM SIGN UR CROSSING UR'
let s:d[0x1232A]='CUNEIFORM SIGN UR SHESHIG'
let s:d[0x1232B]='CUNEIFORM SIGN UR2'
let s:d[0x1232C]='CUNEIFORM SIGN UR2 TIMES A PLUS HA'
let s:d[0x1232D]='CUNEIFORM SIGN UR2 TIMES A PLUS NA'
let s:d[0x1232E]='CUNEIFORM SIGN UR2 TIMES AL'
let s:d[0x1232F]='CUNEIFORM SIGN UR2 TIMES HA'
let s:d[0x12330]='CUNEIFORM SIGN UR2 TIMES NUN'
let s:d[0x12331]='CUNEIFORM SIGN UR2 TIMES U2'
let s:d[0x12332]='CUNEIFORM SIGN UR2 TIMES U2 PLUS ASH'
let s:d[0x12333]='CUNEIFORM SIGN UR2 TIMES U2 PLUS BI'
let s:d[0x12334]='CUNEIFORM SIGN UR4'
let s:d[0x12335]='CUNEIFORM SIGN URI'
let s:d[0x12336]='CUNEIFORM SIGN URI3'
let s:d[0x12337]='CUNEIFORM SIGN URU'
let s:d[0x12338]='CUNEIFORM SIGN URU TIMES A'
let s:d[0x12339]='CUNEIFORM SIGN URU TIMES ASHGAB'
let s:d[0x1233A]='CUNEIFORM SIGN URU TIMES BAR'
let s:d[0x1233B]='CUNEIFORM SIGN URU TIMES DUN'
let s:d[0x1233C]='CUNEIFORM SIGN URU TIMES GA'
let s:d[0x1233D]='CUNEIFORM SIGN URU TIMES GAL'
let s:d[0x1233E]='CUNEIFORM SIGN URU TIMES GAN2 TENU'
let s:d[0x1233F]='CUNEIFORM SIGN URU TIMES GAR'
let s:d[0x12340]='CUNEIFORM SIGN URU TIMES GU'
let s:d[0x12341]='CUNEIFORM SIGN URU TIMES HA'
let s:d[0x12342]='CUNEIFORM SIGN URU TIMES IGI'
let s:d[0x12343]='CUNEIFORM SIGN URU TIMES IM'
let s:d[0x12344]='CUNEIFORM SIGN URU TIMES ISH'
let s:d[0x12345]='CUNEIFORM SIGN URU TIMES KI'
let s:d[0x12346]='CUNEIFORM SIGN URU TIMES LUM'
let s:d[0x12347]='CUNEIFORM SIGN URU TIMES MIN'
let s:d[0x12348]='CUNEIFORM SIGN URU TIMES PA'
let s:d[0x12349]='CUNEIFORM SIGN URU TIMES SHE'
let s:d[0x1234A]='CUNEIFORM SIGN URU TIMES SIG4'
let s:d[0x1234B]='CUNEIFORM SIGN URU TIMES TU'
let s:d[0x1234C]='CUNEIFORM SIGN URU TIMES U PLUS GUD'
let s:d[0x1234D]='CUNEIFORM SIGN URU TIMES UD'
let s:d[0x1234E]='CUNEIFORM SIGN URU TIMES URUDA'
let s:d[0x1234F]='CUNEIFORM SIGN URUDA'
let s:d[0x12350]='CUNEIFORM SIGN URUDA TIMES U'
let s:d[0x12351]='CUNEIFORM SIGN USH'
let s:d[0x12352]='CUNEIFORM SIGN USH TIMES A'
let s:d[0x12353]='CUNEIFORM SIGN USH TIMES KU'
let s:d[0x12354]='CUNEIFORM SIGN USH TIMES KUR'
let s:d[0x12355]='CUNEIFORM SIGN USH TIMES TAK4'
let s:d[0x12356]='CUNEIFORM SIGN USHX'
let s:d[0x12357]='CUNEIFORM SIGN USH2'
let s:d[0x12358]='CUNEIFORM SIGN USHUMX'
let s:d[0x12359]='CUNEIFORM SIGN UTUKI'
let s:d[0x1235A]='CUNEIFORM SIGN UZ3'
let s:d[0x1235B]='CUNEIFORM SIGN UZ3 TIMES KASKAL'
let s:d[0x1235C]='CUNEIFORM SIGN UZU'
let s:d[0x1235D]='CUNEIFORM SIGN ZA'
let s:d[0x1235E]='CUNEIFORM SIGN ZA TENU'
let s:d[0x1235F]='CUNEIFORM SIGN ZA SQUARED TIMES KUR'
let s:d[0x12360]='CUNEIFORM SIGN ZAG'
let s:d[0x12361]='CUNEIFORM SIGN ZAMX'
let s:d[0x12362]='CUNEIFORM SIGN ZE2'
let s:d[0x12363]='CUNEIFORM SIGN ZI'
let s:d[0x12364]='CUNEIFORM SIGN ZI OVER ZI'
let s:d[0x12365]='CUNEIFORM SIGN ZI3'
let s:d[0x12366]='CUNEIFORM SIGN ZIB'
let s:d[0x12367]='CUNEIFORM SIGN ZIB KABA TENU'
let s:d[0x12368]='CUNEIFORM SIGN ZIG'
let s:d[0x12369]='CUNEIFORM SIGN ZIZ2'
let s:d[0x1236A]='CUNEIFORM SIGN ZU'
let s:d[0x1236B]='CUNEIFORM SIGN ZU5'
let s:d[0x1236C]='CUNEIFORM SIGN ZU5 TIMES A'
let s:d[0x1236D]='CUNEIFORM SIGN ZUBUR'
let s:d[0x1236E]='CUNEIFORM SIGN ZUM'
let s:d[0x12400]='CUNEIFORM NUMERIC SIGN TWO ASH'
let s:d[0x12401]='CUNEIFORM NUMERIC SIGN THREE ASH'
let s:d[0x12402]='CUNEIFORM NUMERIC SIGN FOUR ASH'
let s:d[0x12403]='CUNEIFORM NUMERIC SIGN FIVE ASH'
let s:d[0x12404]='CUNEIFORM NUMERIC SIGN SIX ASH'
let s:d[0x12405]='CUNEIFORM NUMERIC SIGN SEVEN ASH'
let s:d[0x12406]='CUNEIFORM NUMERIC SIGN EIGHT ASH'
let s:d[0x12407]='CUNEIFORM NUMERIC SIGN NINE ASH'
let s:d[0x12408]='CUNEIFORM NUMERIC SIGN THREE DISH'
let s:d[0x12409]='CUNEIFORM NUMERIC SIGN FOUR DISH'
let s:d[0x1240A]='CUNEIFORM NUMERIC SIGN FIVE DISH'
let s:d[0x1240B]='CUNEIFORM NUMERIC SIGN SIX DISH'
let s:d[0x1240C]='CUNEIFORM NUMERIC SIGN SEVEN DISH'
let s:d[0x1240D]='CUNEIFORM NUMERIC SIGN EIGHT DISH'
let s:d[0x1240E]='CUNEIFORM NUMERIC SIGN NINE DISH'
let s:d[0x1240F]='CUNEIFORM NUMERIC SIGN FOUR U'
let s:d[0x12410]='CUNEIFORM NUMERIC SIGN FIVE U'
let s:d[0x12411]='CUNEIFORM NUMERIC SIGN SIX U'
let s:d[0x12412]='CUNEIFORM NUMERIC SIGN SEVEN U'
let s:d[0x12413]='CUNEIFORM NUMERIC SIGN EIGHT U'
let s:d[0x12414]='CUNEIFORM NUMERIC SIGN NINE U'
let s:d[0x12415]='CUNEIFORM NUMERIC SIGN ONE GESH2'
let s:d[0x12416]='CUNEIFORM NUMERIC SIGN TWO GESH2'
let s:d[0x12417]='CUNEIFORM NUMERIC SIGN THREE GESH2'
let s:d[0x12418]='CUNEIFORM NUMERIC SIGN FOUR GESH2'
let s:d[0x12419]='CUNEIFORM NUMERIC SIGN FIVE GESH2'
let s:d[0x1241A]='CUNEIFORM NUMERIC SIGN SIX GESH2'
let s:d[0x1241B]='CUNEIFORM NUMERIC SIGN SEVEN GESH2'
let s:d[0x1241C]='CUNEIFORM NUMERIC SIGN EIGHT GESH2'
let s:d[0x1241D]='CUNEIFORM NUMERIC SIGN NINE GESH2'
let s:d[0x1241E]='CUNEIFORM NUMERIC SIGN ONE GESHU'
let s:d[0x1241F]='CUNEIFORM NUMERIC SIGN TWO GESHU'
let s:d[0x12420]='CUNEIFORM NUMERIC SIGN THREE GESHU'
let s:d[0x12421]='CUNEIFORM NUMERIC SIGN FOUR GESHU'
let s:d[0x12422]='CUNEIFORM NUMERIC SIGN FIVE GESHU'
let s:d[0x12423]='CUNEIFORM NUMERIC SIGN TWO SHAR2'
let s:d[0x12424]='CUNEIFORM NUMERIC SIGN THREE SHAR2'
let s:d[0x12425]='CUNEIFORM NUMERIC SIGN THREE SHAR2 VARIANT FORM'
let s:d[0x12426]='CUNEIFORM NUMERIC SIGN FOUR SHAR2'
let s:d[0x12427]='CUNEIFORM NUMERIC SIGN FIVE SHAR2'
let s:d[0x12428]='CUNEIFORM NUMERIC SIGN SIX SHAR2'
let s:d[0x12429]='CUNEIFORM NUMERIC SIGN SEVEN SHAR2'
let s:d[0x1242A]='CUNEIFORM NUMERIC SIGN EIGHT SHAR2'
let s:d[0x1242B]='CUNEIFORM NUMERIC SIGN NINE SHAR2'
let s:d[0x1242C]='CUNEIFORM NUMERIC SIGN ONE SHARU'
let s:d[0x1242D]='CUNEIFORM NUMERIC SIGN TWO SHARU'
let s:d[0x1242E]='CUNEIFORM NUMERIC SIGN THREE SHARU'
let s:d[0x1242F]='CUNEIFORM NUMERIC SIGN THREE SHARU VARIANT FORM'
let s:d[0x12430]='CUNEIFORM NUMERIC SIGN FOUR SHARU'
let s:d[0x12431]='CUNEIFORM NUMERIC SIGN FIVE SHARU'
let s:d[0x12432]='CUNEIFORM NUMERIC SIGN SHAR2 TIMES GAL PLUS DISH'
let s:d[0x12433]='CUNEIFORM NUMERIC SIGN SHAR2 TIMES GAL PLUS MIN'
let s:d[0x12434]='CUNEIFORM NUMERIC SIGN ONE BURU'
let s:d[0x12435]='CUNEIFORM NUMERIC SIGN TWO BURU'
let s:d[0x12436]='CUNEIFORM NUMERIC SIGN THREE BURU'
let s:d[0x12437]='CUNEIFORM NUMERIC SIGN THREE BURU VARIANT FORM'
let s:d[0x12438]='CUNEIFORM NUMERIC SIGN FOUR BURU'
let s:d[0x12439]='CUNEIFORM NUMERIC SIGN FIVE BURU'
let s:d[0x1243A]='CUNEIFORM NUMERIC SIGN THREE VARIANT FORM ESH16'
let s:d[0x1243B]='CUNEIFORM NUMERIC SIGN THREE VARIANT FORM ESH21'
let s:d[0x1243C]='CUNEIFORM NUMERIC SIGN FOUR VARIANT FORM LIMMU'
let s:d[0x1243D]='CUNEIFORM NUMERIC SIGN FOUR VARIANT FORM LIMMU4'
let s:d[0x1243E]='CUNEIFORM NUMERIC SIGN FOUR VARIANT FORM LIMMU A'
let s:d[0x1243F]='CUNEIFORM NUMERIC SIGN FOUR VARIANT FORM LIMMU B'
let s:d[0x12440]='CUNEIFORM NUMERIC SIGN SIX VARIANT FORM ASH9'
let s:d[0x12441]='CUNEIFORM NUMERIC SIGN SEVEN VARIANT FORM IMIN3'
let s:d[0x12442]='CUNEIFORM NUMERIC SIGN SEVEN VARIANT FORM IMIN A'
let s:d[0x12443]='CUNEIFORM NUMERIC SIGN SEVEN VARIANT FORM IMIN B'
let s:d[0x12444]='CUNEIFORM NUMERIC SIGN EIGHT VARIANT FORM USSU'
let s:d[0x12445]='CUNEIFORM NUMERIC SIGN EIGHT VARIANT FORM USSU3'
let s:d[0x12446]='CUNEIFORM NUMERIC SIGN NINE VARIANT FORM ILIMMU'
let s:d[0x12447]='CUNEIFORM NUMERIC SIGN NINE VARIANT FORM ILIMMU3'
let s:d[0x12448]='CUNEIFORM NUMERIC SIGN NINE VARIANT FORM ILIMMU4'
let s:d[0x12449]='CUNEIFORM NUMERIC SIGN NINE VARIANT FORM ILIMMU A'
let s:d[0x1244A]='CUNEIFORM NUMERIC SIGN TWO ASH TENU'
let s:d[0x1244B]='CUNEIFORM NUMERIC SIGN THREE ASH TENU'
let s:d[0x1244C]='CUNEIFORM NUMERIC SIGN FOUR ASH TENU'
let s:d[0x1244D]='CUNEIFORM NUMERIC SIGN FIVE ASH TENU'
let s:d[0x1244E]='CUNEIFORM NUMERIC SIGN SIX ASH TENU'
let s:d[0x1244F]='CUNEIFORM NUMERIC SIGN ONE BAN2'
let s:d[0x12450]='CUNEIFORM NUMERIC SIGN TWO BAN2'
let s:d[0x12451]='CUNEIFORM NUMERIC SIGN THREE BAN2'
let s:d[0x12452]='CUNEIFORM NUMERIC SIGN FOUR BAN2'
let s:d[0x12453]='CUNEIFORM NUMERIC SIGN FOUR BAN2 VARIANT FORM'
let s:d[0x12454]='CUNEIFORM NUMERIC SIGN FIVE BAN2'
let s:d[0x12455]='CUNEIFORM NUMERIC SIGN FIVE BAN2 VARIANT FORM'
let s:d[0x12456]='CUNEIFORM NUMERIC SIGN NIGIDAMIN'
let s:d[0x12457]='CUNEIFORM NUMERIC SIGN NIGIDAESH'
let s:d[0x12458]='CUNEIFORM NUMERIC SIGN ONE ESHE3'
let s:d[0x12459]='CUNEIFORM NUMERIC SIGN TWO ESHE3'
let s:d[0x1245A]='CUNEIFORM NUMERIC SIGN ONE THIRD DISH'
let s:d[0x1245B]='CUNEIFORM NUMERIC SIGN TWO THIRDS DISH'
let s:d[0x1245C]='CUNEIFORM NUMERIC SIGN FIVE SIXTHS DISH'
let s:d[0x1245D]='CUNEIFORM NUMERIC SIGN ONE THIRD VARIANT FORM A'
let s:d[0x1245E]='CUNEIFORM NUMERIC SIGN TWO THIRDS VARIANT FORM A'
let s:d[0x1245F]='CUNEIFORM NUMERIC SIGN ONE EIGHTH ASH'
let s:d[0x12460]='CUNEIFORM NUMERIC SIGN ONE QUARTER ASH'
let s:d[0x12461]='CUNEIFORM NUMERIC SIGN OLD ASSYRIAN ONE SIXTH'
let s:d[0x12462]='CUNEIFORM NUMERIC SIGN OLD ASSYRIAN ONE QUARTER'
let s:d[0x12470]='CUNEIFORM PUNCTUATION SIGN OLD ASSYRIAN WORD DIVIDER'
let s:d[0x12471]='CUNEIFORM PUNCTUATION SIGN VERTICAL COLON'
let s:d[0x12472]='CUNEIFORM PUNCTUATION SIGN DIAGONAL COLON'
let s:d[0x12473]='CUNEIFORM PUNCTUATION SIGN DIAGONAL TRICOLON'
let s:d[0x13000]='EGYPTIAN HIEROGLYPH A001'
let s:d[0x13001]='EGYPTIAN HIEROGLYPH A002'
let s:d[0x13002]='EGYPTIAN HIEROGLYPH A003'
let s:d[0x13003]='EGYPTIAN HIEROGLYPH A004'
let s:d[0x13004]='EGYPTIAN HIEROGLYPH A005'
let s:d[0x13005]='EGYPTIAN HIEROGLYPH A005A'
let s:d[0x13006]='EGYPTIAN HIEROGLYPH A006'
let s:d[0x13007]='EGYPTIAN HIEROGLYPH A006A'
let s:d[0x13008]='EGYPTIAN HIEROGLYPH A006B'
let s:d[0x13009]='EGYPTIAN HIEROGLYPH A007'
let s:d[0x1300A]='EGYPTIAN HIEROGLYPH A008'
let s:d[0x1300B]='EGYPTIAN HIEROGLYPH A009'
let s:d[0x1300C]='EGYPTIAN HIEROGLYPH A010'
let s:d[0x1300D]='EGYPTIAN HIEROGLYPH A011'
let s:d[0x1300E]='EGYPTIAN HIEROGLYPH A012'
let s:d[0x1300F]='EGYPTIAN HIEROGLYPH A013'
let s:d[0x13010]='EGYPTIAN HIEROGLYPH A014'
let s:d[0x13011]='EGYPTIAN HIEROGLYPH A014A'
let s:d[0x13012]='EGYPTIAN HIEROGLYPH A015'
let s:d[0x13013]='EGYPTIAN HIEROGLYPH A016'
let s:d[0x13014]='EGYPTIAN HIEROGLYPH A017'
let s:d[0x13015]='EGYPTIAN HIEROGLYPH A017A'
let s:d[0x13016]='EGYPTIAN HIEROGLYPH A018'
let s:d[0x13017]='EGYPTIAN HIEROGLYPH A019'
let s:d[0x13018]='EGYPTIAN HIEROGLYPH A020'
let s:d[0x13019]='EGYPTIAN HIEROGLYPH A021'
let s:d[0x1301A]='EGYPTIAN HIEROGLYPH A022'
let s:d[0x1301B]='EGYPTIAN HIEROGLYPH A023'
let s:d[0x1301C]='EGYPTIAN HIEROGLYPH A024'
let s:d[0x1301D]='EGYPTIAN HIEROGLYPH A025'
let s:d[0x1301E]='EGYPTIAN HIEROGLYPH A026'
let s:d[0x1301F]='EGYPTIAN HIEROGLYPH A027'
let s:d[0x13020]='EGYPTIAN HIEROGLYPH A028'
let s:d[0x13021]='EGYPTIAN HIEROGLYPH A029'
let s:d[0x13022]='EGYPTIAN HIEROGLYPH A030'
let s:d[0x13023]='EGYPTIAN HIEROGLYPH A031'
let s:d[0x13024]='EGYPTIAN HIEROGLYPH A032'
let s:d[0x13025]='EGYPTIAN HIEROGLYPH A032A'
let s:d[0x13026]='EGYPTIAN HIEROGLYPH A033'
let s:d[0x13027]='EGYPTIAN HIEROGLYPH A034'
let s:d[0x13028]='EGYPTIAN HIEROGLYPH A035'
let s:d[0x13029]='EGYPTIAN HIEROGLYPH A036'
let s:d[0x1302A]='EGYPTIAN HIEROGLYPH A037'
let s:d[0x1302B]='EGYPTIAN HIEROGLYPH A038'
let s:d[0x1302C]='EGYPTIAN HIEROGLYPH A039'
let s:d[0x1302D]='EGYPTIAN HIEROGLYPH A040'
let s:d[0x1302E]='EGYPTIAN HIEROGLYPH A040A'
let s:d[0x1302F]='EGYPTIAN HIEROGLYPH A041'
let s:d[0x13030]='EGYPTIAN HIEROGLYPH A042'
let s:d[0x13031]='EGYPTIAN HIEROGLYPH A042A'
let s:d[0x13032]='EGYPTIAN HIEROGLYPH A043'
let s:d[0x13033]='EGYPTIAN HIEROGLYPH A043A'
let s:d[0x13034]='EGYPTIAN HIEROGLYPH A044'
let s:d[0x13035]='EGYPTIAN HIEROGLYPH A045'
let s:d[0x13036]='EGYPTIAN HIEROGLYPH A045A'
let s:d[0x13037]='EGYPTIAN HIEROGLYPH A046'
let s:d[0x13038]='EGYPTIAN HIEROGLYPH A047'
let s:d[0x13039]='EGYPTIAN HIEROGLYPH A048'
let s:d[0x1303A]='EGYPTIAN HIEROGLYPH A049'
let s:d[0x1303B]='EGYPTIAN HIEROGLYPH A050'
let s:d[0x1303C]='EGYPTIAN HIEROGLYPH A051'
let s:d[0x1303D]='EGYPTIAN HIEROGLYPH A052'
let s:d[0x1303E]='EGYPTIAN HIEROGLYPH A053'
let s:d[0x1303F]='EGYPTIAN HIEROGLYPH A054'
let s:d[0x13040]='EGYPTIAN HIEROGLYPH A055'
let s:d[0x13041]='EGYPTIAN HIEROGLYPH A056'
let s:d[0x13042]='EGYPTIAN HIEROGLYPH A057'
let s:d[0x13043]='EGYPTIAN HIEROGLYPH A058'
let s:d[0x13044]='EGYPTIAN HIEROGLYPH A059'
let s:d[0x13045]='EGYPTIAN HIEROGLYPH A060'
let s:d[0x13046]='EGYPTIAN HIEROGLYPH A061'
let s:d[0x13047]='EGYPTIAN HIEROGLYPH A062'
let s:d[0x13048]='EGYPTIAN HIEROGLYPH A063'
let s:d[0x13049]='EGYPTIAN HIEROGLYPH A064'
let s:d[0x1304A]='EGYPTIAN HIEROGLYPH A065'
let s:d[0x1304B]='EGYPTIAN HIEROGLYPH A066'
let s:d[0x1304C]='EGYPTIAN HIEROGLYPH A067'
let s:d[0x1304D]='EGYPTIAN HIEROGLYPH A068'
let s:d[0x1304E]='EGYPTIAN HIEROGLYPH A069'
let s:d[0x1304F]='EGYPTIAN HIEROGLYPH A070'
let s:d[0x13050]='EGYPTIAN HIEROGLYPH B001'
let s:d[0x13051]='EGYPTIAN HIEROGLYPH B002'
let s:d[0x13052]='EGYPTIAN HIEROGLYPH B003'
let s:d[0x13053]='EGYPTIAN HIEROGLYPH B004'
let s:d[0x13054]='EGYPTIAN HIEROGLYPH B005'
let s:d[0x13055]='EGYPTIAN HIEROGLYPH B005A'
let s:d[0x13056]='EGYPTIAN HIEROGLYPH B006'
let s:d[0x13057]='EGYPTIAN HIEROGLYPH B007'
let s:d[0x13058]='EGYPTIAN HIEROGLYPH B008'
let s:d[0x13059]='EGYPTIAN HIEROGLYPH B009'
let s:d[0x1305A]='EGYPTIAN HIEROGLYPH C001'
let s:d[0x1305B]='EGYPTIAN HIEROGLYPH C002'
let s:d[0x1305C]='EGYPTIAN HIEROGLYPH C002A'
let s:d[0x1305D]='EGYPTIAN HIEROGLYPH C002B'
let s:d[0x1305E]='EGYPTIAN HIEROGLYPH C002C'
let s:d[0x1305F]='EGYPTIAN HIEROGLYPH C003'
let s:d[0x13060]='EGYPTIAN HIEROGLYPH C004'
let s:d[0x13061]='EGYPTIAN HIEROGLYPH C005'
let s:d[0x13062]='EGYPTIAN HIEROGLYPH C006'
let s:d[0x13063]='EGYPTIAN HIEROGLYPH C007'
let s:d[0x13064]='EGYPTIAN HIEROGLYPH C008'
let s:d[0x13065]='EGYPTIAN HIEROGLYPH C009'
let s:d[0x13066]='EGYPTIAN HIEROGLYPH C010'
let s:d[0x13067]='EGYPTIAN HIEROGLYPH C010A'
let s:d[0x13068]='EGYPTIAN HIEROGLYPH C011'
let s:d[0x13069]='EGYPTIAN HIEROGLYPH C012'
let s:d[0x1306A]='EGYPTIAN HIEROGLYPH C013'
let s:d[0x1306B]='EGYPTIAN HIEROGLYPH C014'
let s:d[0x1306C]='EGYPTIAN HIEROGLYPH C015'
let s:d[0x1306D]='EGYPTIAN HIEROGLYPH C016'
let s:d[0x1306E]='EGYPTIAN HIEROGLYPH C017'
let s:d[0x1306F]='EGYPTIAN HIEROGLYPH C018'
let s:d[0x13070]='EGYPTIAN HIEROGLYPH C019'
let s:d[0x13071]='EGYPTIAN HIEROGLYPH C020'
let s:d[0x13072]='EGYPTIAN HIEROGLYPH C021'
let s:d[0x13073]='EGYPTIAN HIEROGLYPH C022'
let s:d[0x13074]='EGYPTIAN HIEROGLYPH C023'
let s:d[0x13075]='EGYPTIAN HIEROGLYPH C024'
let s:d[0x13076]='EGYPTIAN HIEROGLYPH D001'
let s:d[0x13077]='EGYPTIAN HIEROGLYPH D002'
let s:d[0x13078]='EGYPTIAN HIEROGLYPH D003'
let s:d[0x13079]='EGYPTIAN HIEROGLYPH D004'
let s:d[0x1307A]='EGYPTIAN HIEROGLYPH D005'
let s:d[0x1307B]='EGYPTIAN HIEROGLYPH D006'
let s:d[0x1307C]='EGYPTIAN HIEROGLYPH D007'
let s:d[0x1307D]='EGYPTIAN HIEROGLYPH D008'
let s:d[0x1307E]='EGYPTIAN HIEROGLYPH D008A'
let s:d[0x1307F]='EGYPTIAN HIEROGLYPH D009'
let s:d[0x13080]='EGYPTIAN HIEROGLYPH D010'
let s:d[0x13081]='EGYPTIAN HIEROGLYPH D011'
let s:d[0x13082]='EGYPTIAN HIEROGLYPH D012'
let s:d[0x13083]='EGYPTIAN HIEROGLYPH D013'
let s:d[0x13084]='EGYPTIAN HIEROGLYPH D014'
let s:d[0x13085]='EGYPTIAN HIEROGLYPH D015'
let s:d[0x13086]='EGYPTIAN HIEROGLYPH D016'
let s:d[0x13087]='EGYPTIAN HIEROGLYPH D017'
let s:d[0x13088]='EGYPTIAN HIEROGLYPH D018'
let s:d[0x13089]='EGYPTIAN HIEROGLYPH D019'
let s:d[0x1308A]='EGYPTIAN HIEROGLYPH D020'
let s:d[0x1308B]='EGYPTIAN HIEROGLYPH D021'
let s:d[0x1308C]='EGYPTIAN HIEROGLYPH D022'
let s:d[0x1308D]='EGYPTIAN HIEROGLYPH D023'
let s:d[0x1308E]='EGYPTIAN HIEROGLYPH D024'
let s:d[0x1308F]='EGYPTIAN HIEROGLYPH D025'
let s:d[0x13090]='EGYPTIAN HIEROGLYPH D026'
let s:d[0x13091]='EGYPTIAN HIEROGLYPH D027'
let s:d[0x13092]='EGYPTIAN HIEROGLYPH D027A'
let s:d[0x13093]='EGYPTIAN HIEROGLYPH D028'
let s:d[0x13094]='EGYPTIAN HIEROGLYPH D029'
let s:d[0x13095]='EGYPTIAN HIEROGLYPH D030'
let s:d[0x13096]='EGYPTIAN HIEROGLYPH D031'
let s:d[0x13097]='EGYPTIAN HIEROGLYPH D031A'
let s:d[0x13098]='EGYPTIAN HIEROGLYPH D032'
let s:d[0x13099]='EGYPTIAN HIEROGLYPH D033'
let s:d[0x1309A]='EGYPTIAN HIEROGLYPH D034'
let s:d[0x1309B]='EGYPTIAN HIEROGLYPH D034A'
let s:d[0x1309C]='EGYPTIAN HIEROGLYPH D035'
let s:d[0x1309D]='EGYPTIAN HIEROGLYPH D036'
let s:d[0x1309E]='EGYPTIAN HIEROGLYPH D037'
let s:d[0x1309F]='EGYPTIAN HIEROGLYPH D038'
let s:d[0x130A0]='EGYPTIAN HIEROGLYPH D039'
let s:d[0x130A1]='EGYPTIAN HIEROGLYPH D040'
let s:d[0x130A2]='EGYPTIAN HIEROGLYPH D041'
let s:d[0x130A3]='EGYPTIAN HIEROGLYPH D042'
let s:d[0x130A4]='EGYPTIAN HIEROGLYPH D043'
let s:d[0x130A5]='EGYPTIAN HIEROGLYPH D044'
let s:d[0x130A6]='EGYPTIAN HIEROGLYPH D045'
let s:d[0x130A7]='EGYPTIAN HIEROGLYPH D046'
let s:d[0x130A8]='EGYPTIAN HIEROGLYPH D046A'
let s:d[0x130A9]='EGYPTIAN HIEROGLYPH D047'
let s:d[0x130AA]='EGYPTIAN HIEROGLYPH D048'
let s:d[0x130AB]='EGYPTIAN HIEROGLYPH D048A'
let s:d[0x130AC]='EGYPTIAN HIEROGLYPH D049'
let s:d[0x130AD]='EGYPTIAN HIEROGLYPH D050'
let s:d[0x130AE]='EGYPTIAN HIEROGLYPH D050A'
let s:d[0x130AF]='EGYPTIAN HIEROGLYPH D050B'
let s:d[0x130B0]='EGYPTIAN HIEROGLYPH D050C'
let s:d[0x130B1]='EGYPTIAN HIEROGLYPH D050D'
let s:d[0x130B2]='EGYPTIAN HIEROGLYPH D050E'
let s:d[0x130B3]='EGYPTIAN HIEROGLYPH D050F'
let s:d[0x130B4]='EGYPTIAN HIEROGLYPH D050G'
let s:d[0x130B5]='EGYPTIAN HIEROGLYPH D050H'
let s:d[0x130B6]='EGYPTIAN HIEROGLYPH D050I'
let s:d[0x130B7]='EGYPTIAN HIEROGLYPH D051'
let s:d[0x130B8]='EGYPTIAN HIEROGLYPH D052'
let s:d[0x130B9]='EGYPTIAN HIEROGLYPH D052A'
let s:d[0x130BA]='EGYPTIAN HIEROGLYPH D053'
let s:d[0x130BB]='EGYPTIAN HIEROGLYPH D054'
let s:d[0x130BC]='EGYPTIAN HIEROGLYPH D054A'
let s:d[0x130BD]='EGYPTIAN HIEROGLYPH D055'
let s:d[0x130BE]='EGYPTIAN HIEROGLYPH D056'
let s:d[0x130BF]='EGYPTIAN HIEROGLYPH D057'
let s:d[0x130C0]='EGYPTIAN HIEROGLYPH D058'
let s:d[0x130C1]='EGYPTIAN HIEROGLYPH D059'
let s:d[0x130C2]='EGYPTIAN HIEROGLYPH D060'
let s:d[0x130C3]='EGYPTIAN HIEROGLYPH D061'
let s:d[0x130C4]='EGYPTIAN HIEROGLYPH D062'
let s:d[0x130C5]='EGYPTIAN HIEROGLYPH D063'
let s:d[0x130C6]='EGYPTIAN HIEROGLYPH D064'
let s:d[0x130C7]='EGYPTIAN HIEROGLYPH D065'
let s:d[0x130C8]='EGYPTIAN HIEROGLYPH D066'
let s:d[0x130C9]='EGYPTIAN HIEROGLYPH D067'
let s:d[0x130CA]='EGYPTIAN HIEROGLYPH D067A'
let s:d[0x130CB]='EGYPTIAN HIEROGLYPH D067B'
let s:d[0x130CC]='EGYPTIAN HIEROGLYPH D067C'
let s:d[0x130CD]='EGYPTIAN HIEROGLYPH D067D'
let s:d[0x130CE]='EGYPTIAN HIEROGLYPH D067E'
let s:d[0x130CF]='EGYPTIAN HIEROGLYPH D067F'
let s:d[0x130D0]='EGYPTIAN HIEROGLYPH D067G'
let s:d[0x130D1]='EGYPTIAN HIEROGLYPH D067H'
let s:d[0x130D2]='EGYPTIAN HIEROGLYPH E001'
let s:d[0x130D3]='EGYPTIAN HIEROGLYPH E002'
let s:d[0x130D4]='EGYPTIAN HIEROGLYPH E003'
let s:d[0x130D5]='EGYPTIAN HIEROGLYPH E004'
let s:d[0x130D6]='EGYPTIAN HIEROGLYPH E005'
let s:d[0x130D7]='EGYPTIAN HIEROGLYPH E006'
let s:d[0x130D8]='EGYPTIAN HIEROGLYPH E007'
let s:d[0x130D9]='EGYPTIAN HIEROGLYPH E008'
let s:d[0x130DA]='EGYPTIAN HIEROGLYPH E008A'
let s:d[0x130DB]='EGYPTIAN HIEROGLYPH E009'
let s:d[0x130DC]='EGYPTIAN HIEROGLYPH E009A'
let s:d[0x130DD]='EGYPTIAN HIEROGLYPH E010'
let s:d[0x130DE]='EGYPTIAN HIEROGLYPH E011'
let s:d[0x130DF]='EGYPTIAN HIEROGLYPH E012'
let s:d[0x130E0]='EGYPTIAN HIEROGLYPH E013'
let s:d[0x130E1]='EGYPTIAN HIEROGLYPH E014'
let s:d[0x130E2]='EGYPTIAN HIEROGLYPH E015'
let s:d[0x130E3]='EGYPTIAN HIEROGLYPH E016'
let s:d[0x130E4]='EGYPTIAN HIEROGLYPH E016A'
let s:d[0x130E5]='EGYPTIAN HIEROGLYPH E017'
let s:d[0x130E6]='EGYPTIAN HIEROGLYPH E017A'
let s:d[0x130E7]='EGYPTIAN HIEROGLYPH E018'
let s:d[0x130E8]='EGYPTIAN HIEROGLYPH E019'
let s:d[0x130E9]='EGYPTIAN HIEROGLYPH E020'
let s:d[0x130EA]='EGYPTIAN HIEROGLYPH E020A'
let s:d[0x130EB]='EGYPTIAN HIEROGLYPH E021'
let s:d[0x130EC]='EGYPTIAN HIEROGLYPH E022'
let s:d[0x130ED]='EGYPTIAN HIEROGLYPH E023'
let s:d[0x130EE]='EGYPTIAN HIEROGLYPH E024'
let s:d[0x130EF]='EGYPTIAN HIEROGLYPH E025'
let s:d[0x130F0]='EGYPTIAN HIEROGLYPH E026'
let s:d[0x130F1]='EGYPTIAN HIEROGLYPH E027'
let s:d[0x130F2]='EGYPTIAN HIEROGLYPH E028'
let s:d[0x130F3]='EGYPTIAN HIEROGLYPH E028A'
let s:d[0x130F4]='EGYPTIAN HIEROGLYPH E029'
let s:d[0x130F5]='EGYPTIAN HIEROGLYPH E030'
let s:d[0x130F6]='EGYPTIAN HIEROGLYPH E031'
let s:d[0x130F7]='EGYPTIAN HIEROGLYPH E032'
let s:d[0x130F8]='EGYPTIAN HIEROGLYPH E033'
let s:d[0x130F9]='EGYPTIAN HIEROGLYPH E034'
let s:d[0x130FA]='EGYPTIAN HIEROGLYPH E034A'
let s:d[0x130FB]='EGYPTIAN HIEROGLYPH E036'
let s:d[0x130FC]='EGYPTIAN HIEROGLYPH E037'
let s:d[0x130FD]='EGYPTIAN HIEROGLYPH E038'
let s:d[0x130FE]='EGYPTIAN HIEROGLYPH F001'
let s:d[0x130FF]='EGYPTIAN HIEROGLYPH F001A'
let s:d[0x13100]='EGYPTIAN HIEROGLYPH F002'
let s:d[0x13101]='EGYPTIAN HIEROGLYPH F003'
let s:d[0x13102]='EGYPTIAN HIEROGLYPH F004'
let s:d[0x13103]='EGYPTIAN HIEROGLYPH F005'
let s:d[0x13104]='EGYPTIAN HIEROGLYPH F006'
let s:d[0x13105]='EGYPTIAN HIEROGLYPH F007'
let s:d[0x13106]='EGYPTIAN HIEROGLYPH F008'
let s:d[0x13107]='EGYPTIAN HIEROGLYPH F009'
let s:d[0x13108]='EGYPTIAN HIEROGLYPH F010'
let s:d[0x13109]='EGYPTIAN HIEROGLYPH F011'
let s:d[0x1310A]='EGYPTIAN HIEROGLYPH F012'
let s:d[0x1310B]='EGYPTIAN HIEROGLYPH F013'
let s:d[0x1310C]='EGYPTIAN HIEROGLYPH F013A'
let s:d[0x1310D]='EGYPTIAN HIEROGLYPH F014'
let s:d[0x1310E]='EGYPTIAN HIEROGLYPH F015'
let s:d[0x1310F]='EGYPTIAN HIEROGLYPH F016'
let s:d[0x13110]='EGYPTIAN HIEROGLYPH F017'
let s:d[0x13111]='EGYPTIAN HIEROGLYPH F018'
let s:d[0x13112]='EGYPTIAN HIEROGLYPH F019'
let s:d[0x13113]='EGYPTIAN HIEROGLYPH F020'
let s:d[0x13114]='EGYPTIAN HIEROGLYPH F021'
let s:d[0x13115]='EGYPTIAN HIEROGLYPH F021A'
let s:d[0x13116]='EGYPTIAN HIEROGLYPH F022'
let s:d[0x13117]='EGYPTIAN HIEROGLYPH F023'
let s:d[0x13118]='EGYPTIAN HIEROGLYPH F024'
let s:d[0x13119]='EGYPTIAN HIEROGLYPH F025'
let s:d[0x1311A]='EGYPTIAN HIEROGLYPH F026'
let s:d[0x1311B]='EGYPTIAN HIEROGLYPH F027'
let s:d[0x1311C]='EGYPTIAN HIEROGLYPH F028'
let s:d[0x1311D]='EGYPTIAN HIEROGLYPH F029'
let s:d[0x1311E]='EGYPTIAN HIEROGLYPH F030'
let s:d[0x1311F]='EGYPTIAN HIEROGLYPH F031'
let s:d[0x13120]='EGYPTIAN HIEROGLYPH F031A'
let s:d[0x13121]='EGYPTIAN HIEROGLYPH F032'
let s:d[0x13122]='EGYPTIAN HIEROGLYPH F033'
let s:d[0x13123]='EGYPTIAN HIEROGLYPH F034'
let s:d[0x13124]='EGYPTIAN HIEROGLYPH F035'
let s:d[0x13125]='EGYPTIAN HIEROGLYPH F036'
let s:d[0x13126]='EGYPTIAN HIEROGLYPH F037'
let s:d[0x13127]='EGYPTIAN HIEROGLYPH F037A'
let s:d[0x13128]='EGYPTIAN HIEROGLYPH F038'
let s:d[0x13129]='EGYPTIAN HIEROGLYPH F038A'
let s:d[0x1312A]='EGYPTIAN HIEROGLYPH F039'
let s:d[0x1312B]='EGYPTIAN HIEROGLYPH F040'
let s:d[0x1312C]='EGYPTIAN HIEROGLYPH F041'
let s:d[0x1312D]='EGYPTIAN HIEROGLYPH F042'
let s:d[0x1312E]='EGYPTIAN HIEROGLYPH F043'
let s:d[0x1312F]='EGYPTIAN HIEROGLYPH F044'
let s:d[0x13130]='EGYPTIAN HIEROGLYPH F045'
let s:d[0x13131]='EGYPTIAN HIEROGLYPH F045A'
let s:d[0x13132]='EGYPTIAN HIEROGLYPH F046'
let s:d[0x13133]='EGYPTIAN HIEROGLYPH F046A'
let s:d[0x13134]='EGYPTIAN HIEROGLYPH F047'
let s:d[0x13135]='EGYPTIAN HIEROGLYPH F047A'
let s:d[0x13136]='EGYPTIAN HIEROGLYPH F048'
let s:d[0x13137]='EGYPTIAN HIEROGLYPH F049'
let s:d[0x13138]='EGYPTIAN HIEROGLYPH F050'
let s:d[0x13139]='EGYPTIAN HIEROGLYPH F051'
let s:d[0x1313A]='EGYPTIAN HIEROGLYPH F051A'
let s:d[0x1313B]='EGYPTIAN HIEROGLYPH F051B'
let s:d[0x1313C]='EGYPTIAN HIEROGLYPH F051C'
let s:d[0x1313D]='EGYPTIAN HIEROGLYPH F052'
let s:d[0x1313E]='EGYPTIAN HIEROGLYPH F053'
let s:d[0x1313F]='EGYPTIAN HIEROGLYPH G001'
let s:d[0x13140]='EGYPTIAN HIEROGLYPH G002'
let s:d[0x13141]='EGYPTIAN HIEROGLYPH G003'
let s:d[0x13142]='EGYPTIAN HIEROGLYPH G004'
let s:d[0x13143]='EGYPTIAN HIEROGLYPH G005'
let s:d[0x13144]='EGYPTIAN HIEROGLYPH G006'
let s:d[0x13145]='EGYPTIAN HIEROGLYPH G006A'
let s:d[0x13146]='EGYPTIAN HIEROGLYPH G007'
let s:d[0x13147]='EGYPTIAN HIEROGLYPH G007A'
let s:d[0x13148]='EGYPTIAN HIEROGLYPH G007B'
let s:d[0x13149]='EGYPTIAN HIEROGLYPH G008'
let s:d[0x1314A]='EGYPTIAN HIEROGLYPH G009'
let s:d[0x1314B]='EGYPTIAN HIEROGLYPH G010'
let s:d[0x1314C]='EGYPTIAN HIEROGLYPH G011'
let s:d[0x1314D]='EGYPTIAN HIEROGLYPH G011A'
let s:d[0x1314E]='EGYPTIAN HIEROGLYPH G012'
let s:d[0x1314F]='EGYPTIAN HIEROGLYPH G013'
let s:d[0x13150]='EGYPTIAN HIEROGLYPH G014'
let s:d[0x13151]='EGYPTIAN HIEROGLYPH G015'
let s:d[0x13152]='EGYPTIAN HIEROGLYPH G016'
let s:d[0x13153]='EGYPTIAN HIEROGLYPH G017'
let s:d[0x13154]='EGYPTIAN HIEROGLYPH G018'
let s:d[0x13155]='EGYPTIAN HIEROGLYPH G019'
let s:d[0x13156]='EGYPTIAN HIEROGLYPH G020'
let s:d[0x13157]='EGYPTIAN HIEROGLYPH G020A'
let s:d[0x13158]='EGYPTIAN HIEROGLYPH G021'
let s:d[0x13159]='EGYPTIAN HIEROGLYPH G022'
let s:d[0x1315A]='EGYPTIAN HIEROGLYPH G023'
let s:d[0x1315B]='EGYPTIAN HIEROGLYPH G024'
let s:d[0x1315C]='EGYPTIAN HIEROGLYPH G025'
let s:d[0x1315D]='EGYPTIAN HIEROGLYPH G026'
let s:d[0x1315E]='EGYPTIAN HIEROGLYPH G026A'
let s:d[0x1315F]='EGYPTIAN HIEROGLYPH G027'
let s:d[0x13160]='EGYPTIAN HIEROGLYPH G028'
let s:d[0x13161]='EGYPTIAN HIEROGLYPH G029'
let s:d[0x13162]='EGYPTIAN HIEROGLYPH G030'
let s:d[0x13163]='EGYPTIAN HIEROGLYPH G031'
let s:d[0x13164]='EGYPTIAN HIEROGLYPH G032'
let s:d[0x13165]='EGYPTIAN HIEROGLYPH G033'
let s:d[0x13166]='EGYPTIAN HIEROGLYPH G034'
let s:d[0x13167]='EGYPTIAN HIEROGLYPH G035'
let s:d[0x13168]='EGYPTIAN HIEROGLYPH G036'
let s:d[0x13169]='EGYPTIAN HIEROGLYPH G036A'
let s:d[0x1316A]='EGYPTIAN HIEROGLYPH G037'
let s:d[0x1316B]='EGYPTIAN HIEROGLYPH G037A'
let s:d[0x1316C]='EGYPTIAN HIEROGLYPH G038'
let s:d[0x1316D]='EGYPTIAN HIEROGLYPH G039'
let s:d[0x1316E]='EGYPTIAN HIEROGLYPH G040'
let s:d[0x1316F]='EGYPTIAN HIEROGLYPH G041'
let s:d[0x13170]='EGYPTIAN HIEROGLYPH G042'
let s:d[0x13171]='EGYPTIAN HIEROGLYPH G043'
let s:d[0x13172]='EGYPTIAN HIEROGLYPH G043A'
let s:d[0x13173]='EGYPTIAN HIEROGLYPH G044'
let s:d[0x13174]='EGYPTIAN HIEROGLYPH G045'
let s:d[0x13175]='EGYPTIAN HIEROGLYPH G045A'
let s:d[0x13176]='EGYPTIAN HIEROGLYPH G046'
let s:d[0x13177]='EGYPTIAN HIEROGLYPH G047'
let s:d[0x13178]='EGYPTIAN HIEROGLYPH G048'
let s:d[0x13179]='EGYPTIAN HIEROGLYPH G049'
let s:d[0x1317A]='EGYPTIAN HIEROGLYPH G050'
let s:d[0x1317B]='EGYPTIAN HIEROGLYPH G051'
let s:d[0x1317C]='EGYPTIAN HIEROGLYPH G052'
let s:d[0x1317D]='EGYPTIAN HIEROGLYPH G053'
let s:d[0x1317E]='EGYPTIAN HIEROGLYPH G054'
let s:d[0x1317F]='EGYPTIAN HIEROGLYPH H001'
let s:d[0x13180]='EGYPTIAN HIEROGLYPH H002'
let s:d[0x13181]='EGYPTIAN HIEROGLYPH H003'
let s:d[0x13182]='EGYPTIAN HIEROGLYPH H004'
let s:d[0x13183]='EGYPTIAN HIEROGLYPH H005'
let s:d[0x13184]='EGYPTIAN HIEROGLYPH H006'
let s:d[0x13185]='EGYPTIAN HIEROGLYPH H006A'
let s:d[0x13186]='EGYPTIAN HIEROGLYPH H007'
let s:d[0x13187]='EGYPTIAN HIEROGLYPH H008'
let s:d[0x13188]='EGYPTIAN HIEROGLYPH I001'
let s:d[0x13189]='EGYPTIAN HIEROGLYPH I002'
let s:d[0x1318A]='EGYPTIAN HIEROGLYPH I003'
let s:d[0x1318B]='EGYPTIAN HIEROGLYPH I004'
let s:d[0x1318C]='EGYPTIAN HIEROGLYPH I005'
let s:d[0x1318D]='EGYPTIAN HIEROGLYPH I005A'
let s:d[0x1318E]='EGYPTIAN HIEROGLYPH I006'
let s:d[0x1318F]='EGYPTIAN HIEROGLYPH I007'
let s:d[0x13190]='EGYPTIAN HIEROGLYPH I008'
let s:d[0x13191]='EGYPTIAN HIEROGLYPH I009'
let s:d[0x13192]='EGYPTIAN HIEROGLYPH I009A'
let s:d[0x13193]='EGYPTIAN HIEROGLYPH I010'
let s:d[0x13194]='EGYPTIAN HIEROGLYPH I010A'
let s:d[0x13195]='EGYPTIAN HIEROGLYPH I011'
let s:d[0x13196]='EGYPTIAN HIEROGLYPH I011A'
let s:d[0x13197]='EGYPTIAN HIEROGLYPH I012'
let s:d[0x13198]='EGYPTIAN HIEROGLYPH I013'
let s:d[0x13199]='EGYPTIAN HIEROGLYPH I014'
let s:d[0x1319A]='EGYPTIAN HIEROGLYPH I015'
let s:d[0x1319B]='EGYPTIAN HIEROGLYPH K001'
let s:d[0x1319C]='EGYPTIAN HIEROGLYPH K002'
let s:d[0x1319D]='EGYPTIAN HIEROGLYPH K003'
let s:d[0x1319E]='EGYPTIAN HIEROGLYPH K004'
let s:d[0x1319F]='EGYPTIAN HIEROGLYPH K005'
let s:d[0x131A0]='EGYPTIAN HIEROGLYPH K006'
let s:d[0x131A1]='EGYPTIAN HIEROGLYPH K007'
let s:d[0x131A2]='EGYPTIAN HIEROGLYPH K008'
let s:d[0x131A3]='EGYPTIAN HIEROGLYPH L001'
let s:d[0x131A4]='EGYPTIAN HIEROGLYPH L002'
let s:d[0x131A5]='EGYPTIAN HIEROGLYPH L002A'
let s:d[0x131A6]='EGYPTIAN HIEROGLYPH L003'
let s:d[0x131A7]='EGYPTIAN HIEROGLYPH L004'
let s:d[0x131A8]='EGYPTIAN HIEROGLYPH L005'
let s:d[0x131A9]='EGYPTIAN HIEROGLYPH L006'
let s:d[0x131AA]='EGYPTIAN HIEROGLYPH L006A'
let s:d[0x131AB]='EGYPTIAN HIEROGLYPH L007'
let s:d[0x131AC]='EGYPTIAN HIEROGLYPH L008'
let s:d[0x131AD]='EGYPTIAN HIEROGLYPH M001'
let s:d[0x131AE]='EGYPTIAN HIEROGLYPH M001A'
let s:d[0x131AF]='EGYPTIAN HIEROGLYPH M001B'
let s:d[0x131B0]='EGYPTIAN HIEROGLYPH M002'
let s:d[0x131B1]='EGYPTIAN HIEROGLYPH M003'
let s:d[0x131B2]='EGYPTIAN HIEROGLYPH M003A'
let s:d[0x131B3]='EGYPTIAN HIEROGLYPH M004'
let s:d[0x131B4]='EGYPTIAN HIEROGLYPH M005'
let s:d[0x131B5]='EGYPTIAN HIEROGLYPH M006'
let s:d[0x131B6]='EGYPTIAN HIEROGLYPH M007'
let s:d[0x131B7]='EGYPTIAN HIEROGLYPH M008'
let s:d[0x131B8]='EGYPTIAN HIEROGLYPH M009'
let s:d[0x131B9]='EGYPTIAN HIEROGLYPH M010'
let s:d[0x131BA]='EGYPTIAN HIEROGLYPH M010A'
let s:d[0x131BB]='EGYPTIAN HIEROGLYPH M011'
let s:d[0x131BC]='EGYPTIAN HIEROGLYPH M012'
let s:d[0x131BD]='EGYPTIAN HIEROGLYPH M012A'
let s:d[0x131BE]='EGYPTIAN HIEROGLYPH M012B'
let s:d[0x131BF]='EGYPTIAN HIEROGLYPH M012C'
let s:d[0x131C0]='EGYPTIAN HIEROGLYPH M012D'
let s:d[0x131C1]='EGYPTIAN HIEROGLYPH M012E'
let s:d[0x131C2]='EGYPTIAN HIEROGLYPH M012F'
let s:d[0x131C3]='EGYPTIAN HIEROGLYPH M012G'
let s:d[0x131C4]='EGYPTIAN HIEROGLYPH M012H'
let s:d[0x131C5]='EGYPTIAN HIEROGLYPH M013'
let s:d[0x131C6]='EGYPTIAN HIEROGLYPH M014'
let s:d[0x131C7]='EGYPTIAN HIEROGLYPH M015'
let s:d[0x131C8]='EGYPTIAN HIEROGLYPH M015A'
let s:d[0x131C9]='EGYPTIAN HIEROGLYPH M016'
let s:d[0x131CA]='EGYPTIAN HIEROGLYPH M016A'
let s:d[0x131CB]='EGYPTIAN HIEROGLYPH M017'
let s:d[0x131CC]='EGYPTIAN HIEROGLYPH M017A'
let s:d[0x131CD]='EGYPTIAN HIEROGLYPH M018'
let s:d[0x131CE]='EGYPTIAN HIEROGLYPH M019'
let s:d[0x131CF]='EGYPTIAN HIEROGLYPH M020'
let s:d[0x131D0]='EGYPTIAN HIEROGLYPH M021'
let s:d[0x131D1]='EGYPTIAN HIEROGLYPH M022'
let s:d[0x131D2]='EGYPTIAN HIEROGLYPH M022A'
let s:d[0x131D3]='EGYPTIAN HIEROGLYPH M023'
let s:d[0x131D4]='EGYPTIAN HIEROGLYPH M024'
let s:d[0x131D5]='EGYPTIAN HIEROGLYPH M024A'
let s:d[0x131D6]='EGYPTIAN HIEROGLYPH M025'
let s:d[0x131D7]='EGYPTIAN HIEROGLYPH M026'
let s:d[0x131D8]='EGYPTIAN HIEROGLYPH M027'
let s:d[0x131D9]='EGYPTIAN HIEROGLYPH M028'
let s:d[0x131DA]='EGYPTIAN HIEROGLYPH M028A'
let s:d[0x131DB]='EGYPTIAN HIEROGLYPH M029'
let s:d[0x131DC]='EGYPTIAN HIEROGLYPH M030'
let s:d[0x131DD]='EGYPTIAN HIEROGLYPH M031'
let s:d[0x131DE]='EGYPTIAN HIEROGLYPH M031A'
let s:d[0x131DF]='EGYPTIAN HIEROGLYPH M032'
let s:d[0x131E0]='EGYPTIAN HIEROGLYPH M033'
let s:d[0x131E1]='EGYPTIAN HIEROGLYPH M033A'
let s:d[0x131E2]='EGYPTIAN HIEROGLYPH M033B'
let s:d[0x131E3]='EGYPTIAN HIEROGLYPH M034'
let s:d[0x131E4]='EGYPTIAN HIEROGLYPH M035'
let s:d[0x131E5]='EGYPTIAN HIEROGLYPH M036'
let s:d[0x131E6]='EGYPTIAN HIEROGLYPH M037'
let s:d[0x131E7]='EGYPTIAN HIEROGLYPH M038'
let s:d[0x131E8]='EGYPTIAN HIEROGLYPH M039'
let s:d[0x131E9]='EGYPTIAN HIEROGLYPH M040'
let s:d[0x131EA]='EGYPTIAN HIEROGLYPH M040A'
let s:d[0x131EB]='EGYPTIAN HIEROGLYPH M041'
let s:d[0x131EC]='EGYPTIAN HIEROGLYPH M042'
let s:d[0x131ED]='EGYPTIAN HIEROGLYPH M043'
let s:d[0x131EE]='EGYPTIAN HIEROGLYPH M044'
let s:d[0x131EF]='EGYPTIAN HIEROGLYPH N001'
let s:d[0x131F0]='EGYPTIAN HIEROGLYPH N002'
let s:d[0x131F1]='EGYPTIAN HIEROGLYPH N003'
let s:d[0x131F2]='EGYPTIAN HIEROGLYPH N004'
let s:d[0x131F3]='EGYPTIAN HIEROGLYPH N005'
let s:d[0x131F4]='EGYPTIAN HIEROGLYPH N006'
let s:d[0x131F5]='EGYPTIAN HIEROGLYPH N007'
let s:d[0x131F6]='EGYPTIAN HIEROGLYPH N008'
let s:d[0x131F7]='EGYPTIAN HIEROGLYPH N009'
let s:d[0x131F8]='EGYPTIAN HIEROGLYPH N010'
let s:d[0x131F9]='EGYPTIAN HIEROGLYPH N011'
let s:d[0x131FA]='EGYPTIAN HIEROGLYPH N012'
let s:d[0x131FB]='EGYPTIAN HIEROGLYPH N013'
let s:d[0x131FC]='EGYPTIAN HIEROGLYPH N014'
let s:d[0x131FD]='EGYPTIAN HIEROGLYPH N015'
let s:d[0x131FE]='EGYPTIAN HIEROGLYPH N016'
let s:d[0x131FF]='EGYPTIAN HIEROGLYPH N017'
let s:d[0x13200]='EGYPTIAN HIEROGLYPH N018'
let s:d[0x13201]='EGYPTIAN HIEROGLYPH N018A'
let s:d[0x13202]='EGYPTIAN HIEROGLYPH N018B'
let s:d[0x13203]='EGYPTIAN HIEROGLYPH N019'
let s:d[0x13204]='EGYPTIAN HIEROGLYPH N020'
let s:d[0x13205]='EGYPTIAN HIEROGLYPH N021'
let s:d[0x13206]='EGYPTIAN HIEROGLYPH N022'
let s:d[0x13207]='EGYPTIAN HIEROGLYPH N023'
let s:d[0x13208]='EGYPTIAN HIEROGLYPH N024'
let s:d[0x13209]='EGYPTIAN HIEROGLYPH N025'
let s:d[0x1320A]='EGYPTIAN HIEROGLYPH N025A'
let s:d[0x1320B]='EGYPTIAN HIEROGLYPH N026'
let s:d[0x1320C]='EGYPTIAN HIEROGLYPH N027'
let s:d[0x1320D]='EGYPTIAN HIEROGLYPH N028'
let s:d[0x1320E]='EGYPTIAN HIEROGLYPH N029'
let s:d[0x1320F]='EGYPTIAN HIEROGLYPH N030'
let s:d[0x13210]='EGYPTIAN HIEROGLYPH N031'
let s:d[0x13211]='EGYPTIAN HIEROGLYPH N032'
let s:d[0x13212]='EGYPTIAN HIEROGLYPH N033'
let s:d[0x13213]='EGYPTIAN HIEROGLYPH N033A'
let s:d[0x13214]='EGYPTIAN HIEROGLYPH N034'
let s:d[0x13215]='EGYPTIAN HIEROGLYPH N034A'
let s:d[0x13216]='EGYPTIAN HIEROGLYPH N035'
let s:d[0x13217]='EGYPTIAN HIEROGLYPH N035A'
let s:d[0x13218]='EGYPTIAN HIEROGLYPH N036'
let s:d[0x13219]='EGYPTIAN HIEROGLYPH N037'
let s:d[0x1321A]='EGYPTIAN HIEROGLYPH N037A'
let s:d[0x1321B]='EGYPTIAN HIEROGLYPH N038'
let s:d[0x1321C]='EGYPTIAN HIEROGLYPH N039'
let s:d[0x1321D]='EGYPTIAN HIEROGLYPH N040'
let s:d[0x1321E]='EGYPTIAN HIEROGLYPH N041'
let s:d[0x1321F]='EGYPTIAN HIEROGLYPH N042'
let s:d[0x13220]='EGYPTIAN HIEROGLYPH NL001'
let s:d[0x13221]='EGYPTIAN HIEROGLYPH NL002'
let s:d[0x13222]='EGYPTIAN HIEROGLYPH NL003'
let s:d[0x13223]='EGYPTIAN HIEROGLYPH NL004'
let s:d[0x13224]='EGYPTIAN HIEROGLYPH NL005'
let s:d[0x13225]='EGYPTIAN HIEROGLYPH NL005A'
let s:d[0x13226]='EGYPTIAN HIEROGLYPH NL006'
let s:d[0x13227]='EGYPTIAN HIEROGLYPH NL007'
let s:d[0x13228]='EGYPTIAN HIEROGLYPH NL008'
let s:d[0x13229]='EGYPTIAN HIEROGLYPH NL009'
let s:d[0x1322A]='EGYPTIAN HIEROGLYPH NL010'
let s:d[0x1322B]='EGYPTIAN HIEROGLYPH NL011'
let s:d[0x1322C]='EGYPTIAN HIEROGLYPH NL012'
let s:d[0x1322D]='EGYPTIAN HIEROGLYPH NL013'
let s:d[0x1322E]='EGYPTIAN HIEROGLYPH NL014'
let s:d[0x1322F]='EGYPTIAN HIEROGLYPH NL015'
let s:d[0x13230]='EGYPTIAN HIEROGLYPH NL016'
let s:d[0x13231]='EGYPTIAN HIEROGLYPH NL017'
let s:d[0x13232]='EGYPTIAN HIEROGLYPH NL017A'
let s:d[0x13233]='EGYPTIAN HIEROGLYPH NL018'
let s:d[0x13234]='EGYPTIAN HIEROGLYPH NL019'
let s:d[0x13235]='EGYPTIAN HIEROGLYPH NL020'
let s:d[0x13236]='EGYPTIAN HIEROGLYPH NU001'
let s:d[0x13237]='EGYPTIAN HIEROGLYPH NU002'
let s:d[0x13238]='EGYPTIAN HIEROGLYPH NU003'
let s:d[0x13239]='EGYPTIAN HIEROGLYPH NU004'
let s:d[0x1323A]='EGYPTIAN HIEROGLYPH NU005'
let s:d[0x1323B]='EGYPTIAN HIEROGLYPH NU006'
let s:d[0x1323C]='EGYPTIAN HIEROGLYPH NU007'
let s:d[0x1323D]='EGYPTIAN HIEROGLYPH NU008'
let s:d[0x1323E]='EGYPTIAN HIEROGLYPH NU009'
let s:d[0x1323F]='EGYPTIAN HIEROGLYPH NU010'
let s:d[0x13240]='EGYPTIAN HIEROGLYPH NU010A'
let s:d[0x13241]='EGYPTIAN HIEROGLYPH NU011'
let s:d[0x13242]='EGYPTIAN HIEROGLYPH NU011A'
let s:d[0x13243]='EGYPTIAN HIEROGLYPH NU012'
let s:d[0x13244]='EGYPTIAN HIEROGLYPH NU013'
let s:d[0x13245]='EGYPTIAN HIEROGLYPH NU014'
let s:d[0x13246]='EGYPTIAN HIEROGLYPH NU015'
let s:d[0x13247]='EGYPTIAN HIEROGLYPH NU016'
let s:d[0x13248]='EGYPTIAN HIEROGLYPH NU017'
let s:d[0x13249]='EGYPTIAN HIEROGLYPH NU018'
let s:d[0x1324A]='EGYPTIAN HIEROGLYPH NU018A'
let s:d[0x1324B]='EGYPTIAN HIEROGLYPH NU019'
let s:d[0x1324C]='EGYPTIAN HIEROGLYPH NU020'
let s:d[0x1324D]='EGYPTIAN HIEROGLYPH NU021'
let s:d[0x1324E]='EGYPTIAN HIEROGLYPH NU022'
let s:d[0x1324F]='EGYPTIAN HIEROGLYPH NU022A'
let s:d[0x13250]='EGYPTIAN HIEROGLYPH O001'
let s:d[0x13251]='EGYPTIAN HIEROGLYPH O001A'
let s:d[0x13252]='EGYPTIAN HIEROGLYPH O002'
let s:d[0x13253]='EGYPTIAN HIEROGLYPH O003'
let s:d[0x13254]='EGYPTIAN HIEROGLYPH O004'
let s:d[0x13255]='EGYPTIAN HIEROGLYPH O005'
let s:d[0x13256]='EGYPTIAN HIEROGLYPH O005A'
let s:d[0x13257]='EGYPTIAN HIEROGLYPH O006'
let s:d[0x13258]='EGYPTIAN HIEROGLYPH O006A'
let s:d[0x13259]='EGYPTIAN HIEROGLYPH O006B'
let s:d[0x1325A]='EGYPTIAN HIEROGLYPH O006C'
let s:d[0x1325B]='EGYPTIAN HIEROGLYPH O006D'
let s:d[0x1325C]='EGYPTIAN HIEROGLYPH O006E'
let s:d[0x1325D]='EGYPTIAN HIEROGLYPH O006F'
let s:d[0x1325E]='EGYPTIAN HIEROGLYPH O007'
let s:d[0x1325F]='EGYPTIAN HIEROGLYPH O008'
let s:d[0x13260]='EGYPTIAN HIEROGLYPH O009'
let s:d[0x13261]='EGYPTIAN HIEROGLYPH O010'
let s:d[0x13262]='EGYPTIAN HIEROGLYPH O010A'
let s:d[0x13263]='EGYPTIAN HIEROGLYPH O010B'
let s:d[0x13264]='EGYPTIAN HIEROGLYPH O010C'
let s:d[0x13265]='EGYPTIAN HIEROGLYPH O011'
let s:d[0x13266]='EGYPTIAN HIEROGLYPH O012'
let s:d[0x13267]='EGYPTIAN HIEROGLYPH O013'
let s:d[0x13268]='EGYPTIAN HIEROGLYPH O014'
let s:d[0x13269]='EGYPTIAN HIEROGLYPH O015'
let s:d[0x1326A]='EGYPTIAN HIEROGLYPH O016'
let s:d[0x1326B]='EGYPTIAN HIEROGLYPH O017'
let s:d[0x1326C]='EGYPTIAN HIEROGLYPH O018'
let s:d[0x1326D]='EGYPTIAN HIEROGLYPH O019'
let s:d[0x1326E]='EGYPTIAN HIEROGLYPH O019A'
let s:d[0x1326F]='EGYPTIAN HIEROGLYPH O020'
let s:d[0x13270]='EGYPTIAN HIEROGLYPH O020A'
let s:d[0x13271]='EGYPTIAN HIEROGLYPH O021'
let s:d[0x13272]='EGYPTIAN HIEROGLYPH O022'
let s:d[0x13273]='EGYPTIAN HIEROGLYPH O023'
let s:d[0x13274]='EGYPTIAN HIEROGLYPH O024'
let s:d[0x13275]='EGYPTIAN HIEROGLYPH O024A'
let s:d[0x13276]='EGYPTIAN HIEROGLYPH O025'
let s:d[0x13277]='EGYPTIAN HIEROGLYPH O025A'
let s:d[0x13278]='EGYPTIAN HIEROGLYPH O026'
let s:d[0x13279]='EGYPTIAN HIEROGLYPH O027'
let s:d[0x1327A]='EGYPTIAN HIEROGLYPH O028'
let s:d[0x1327B]='EGYPTIAN HIEROGLYPH O029'
let s:d[0x1327C]='EGYPTIAN HIEROGLYPH O029A'
let s:d[0x1327D]='EGYPTIAN HIEROGLYPH O030'
let s:d[0x1327E]='EGYPTIAN HIEROGLYPH O030A'
let s:d[0x1327F]='EGYPTIAN HIEROGLYPH O031'
let s:d[0x13280]='EGYPTIAN HIEROGLYPH O032'
let s:d[0x13281]='EGYPTIAN HIEROGLYPH O033'
let s:d[0x13282]='EGYPTIAN HIEROGLYPH O033A'
let s:d[0x13283]='EGYPTIAN HIEROGLYPH O034'
let s:d[0x13284]='EGYPTIAN HIEROGLYPH O035'
let s:d[0x13285]='EGYPTIAN HIEROGLYPH O036'
let s:d[0x13286]='EGYPTIAN HIEROGLYPH O036A'
let s:d[0x13287]='EGYPTIAN HIEROGLYPH O036B'
let s:d[0x13288]='EGYPTIAN HIEROGLYPH O036C'
let s:d[0x13289]='EGYPTIAN HIEROGLYPH O036D'
let s:d[0x1328A]='EGYPTIAN HIEROGLYPH O037'
let s:d[0x1328B]='EGYPTIAN HIEROGLYPH O038'
let s:d[0x1328C]='EGYPTIAN HIEROGLYPH O039'
let s:d[0x1328D]='EGYPTIAN HIEROGLYPH O040'
let s:d[0x1328E]='EGYPTIAN HIEROGLYPH O041'
let s:d[0x1328F]='EGYPTIAN HIEROGLYPH O042'
let s:d[0x13290]='EGYPTIAN HIEROGLYPH O043'
let s:d[0x13291]='EGYPTIAN HIEROGLYPH O044'
let s:d[0x13292]='EGYPTIAN HIEROGLYPH O045'
let s:d[0x13293]='EGYPTIAN HIEROGLYPH O046'
let s:d[0x13294]='EGYPTIAN HIEROGLYPH O047'
let s:d[0x13295]='EGYPTIAN HIEROGLYPH O048'
let s:d[0x13296]='EGYPTIAN HIEROGLYPH O049'
let s:d[0x13297]='EGYPTIAN HIEROGLYPH O050'
let s:d[0x13298]='EGYPTIAN HIEROGLYPH O050A'
let s:d[0x13299]='EGYPTIAN HIEROGLYPH O050B'
let s:d[0x1329A]='EGYPTIAN HIEROGLYPH O051'
let s:d[0x1329B]='EGYPTIAN HIEROGLYPH P001'
let s:d[0x1329C]='EGYPTIAN HIEROGLYPH P001A'
let s:d[0x1329D]='EGYPTIAN HIEROGLYPH P002'
let s:d[0x1329E]='EGYPTIAN HIEROGLYPH P003'
let s:d[0x1329F]='EGYPTIAN HIEROGLYPH P003A'
let s:d[0x132A0]='EGYPTIAN HIEROGLYPH P004'
let s:d[0x132A1]='EGYPTIAN HIEROGLYPH P005'
let s:d[0x132A2]='EGYPTIAN HIEROGLYPH P006'
let s:d[0x132A3]='EGYPTIAN HIEROGLYPH P007'
let s:d[0x132A4]='EGYPTIAN HIEROGLYPH P008'
let s:d[0x132A5]='EGYPTIAN HIEROGLYPH P009'
let s:d[0x132A6]='EGYPTIAN HIEROGLYPH P010'
let s:d[0x132A7]='EGYPTIAN HIEROGLYPH P011'
let s:d[0x132A8]='EGYPTIAN HIEROGLYPH Q001'
let s:d[0x132A9]='EGYPTIAN HIEROGLYPH Q002'
let s:d[0x132AA]='EGYPTIAN HIEROGLYPH Q003'
let s:d[0x132AB]='EGYPTIAN HIEROGLYPH Q004'
let s:d[0x132AC]='EGYPTIAN HIEROGLYPH Q005'
let s:d[0x132AD]='EGYPTIAN HIEROGLYPH Q006'
let s:d[0x132AE]='EGYPTIAN HIEROGLYPH Q007'
let s:d[0x132AF]='EGYPTIAN HIEROGLYPH R001'
let s:d[0x132B0]='EGYPTIAN HIEROGLYPH R002'
let s:d[0x132B1]='EGYPTIAN HIEROGLYPH R002A'
let s:d[0x132B2]='EGYPTIAN HIEROGLYPH R003'
let s:d[0x132B3]='EGYPTIAN HIEROGLYPH R003A'
let s:d[0x132B4]='EGYPTIAN HIEROGLYPH R003B'
let s:d[0x132B5]='EGYPTIAN HIEROGLYPH R004'
let s:d[0x132B6]='EGYPTIAN HIEROGLYPH R005'
let s:d[0x132B7]='EGYPTIAN HIEROGLYPH R006'
let s:d[0x132B8]='EGYPTIAN HIEROGLYPH R007'
let s:d[0x132B9]='EGYPTIAN HIEROGLYPH R008'
let s:d[0x132BA]='EGYPTIAN HIEROGLYPH R009'
let s:d[0x132BB]='EGYPTIAN HIEROGLYPH R010'
let s:d[0x132BC]='EGYPTIAN HIEROGLYPH R010A'
let s:d[0x132BD]='EGYPTIAN HIEROGLYPH R011'
let s:d[0x132BE]='EGYPTIAN HIEROGLYPH R012'
let s:d[0x132BF]='EGYPTIAN HIEROGLYPH R013'
let s:d[0x132C0]='EGYPTIAN HIEROGLYPH R014'
let s:d[0x132C1]='EGYPTIAN HIEROGLYPH R015'
let s:d[0x132C2]='EGYPTIAN HIEROGLYPH R016'
let s:d[0x132C3]='EGYPTIAN HIEROGLYPH R016A'
let s:d[0x132C4]='EGYPTIAN HIEROGLYPH R017'
let s:d[0x132C5]='EGYPTIAN HIEROGLYPH R018'
let s:d[0x132C6]='EGYPTIAN HIEROGLYPH R019'
let s:d[0x132C7]='EGYPTIAN HIEROGLYPH R020'
let s:d[0x132C8]='EGYPTIAN HIEROGLYPH R021'
let s:d[0x132C9]='EGYPTIAN HIEROGLYPH R022'
let s:d[0x132CA]='EGYPTIAN HIEROGLYPH R023'
let s:d[0x132CB]='EGYPTIAN HIEROGLYPH R024'
let s:d[0x132CC]='EGYPTIAN HIEROGLYPH R025'
let s:d[0x132CD]='EGYPTIAN HIEROGLYPH R026'
let s:d[0x132CE]='EGYPTIAN HIEROGLYPH R027'
let s:d[0x132CF]='EGYPTIAN HIEROGLYPH R028'
let s:d[0x132D0]='EGYPTIAN HIEROGLYPH R029'
let s:d[0x132D1]='EGYPTIAN HIEROGLYPH S001'
let s:d[0x132D2]='EGYPTIAN HIEROGLYPH S002'
let s:d[0x132D3]='EGYPTIAN HIEROGLYPH S002A'
let s:d[0x132D4]='EGYPTIAN HIEROGLYPH S003'
let s:d[0x132D5]='EGYPTIAN HIEROGLYPH S004'
let s:d[0x132D6]='EGYPTIAN HIEROGLYPH S005'
let s:d[0x132D7]='EGYPTIAN HIEROGLYPH S006'
let s:d[0x132D8]='EGYPTIAN HIEROGLYPH S006A'
let s:d[0x132D9]='EGYPTIAN HIEROGLYPH S007'
let s:d[0x132DA]='EGYPTIAN HIEROGLYPH S008'
let s:d[0x132DB]='EGYPTIAN HIEROGLYPH S009'
let s:d[0x132DC]='EGYPTIAN HIEROGLYPH S010'
let s:d[0x132DD]='EGYPTIAN HIEROGLYPH S011'
let s:d[0x132DE]='EGYPTIAN HIEROGLYPH S012'
let s:d[0x132DF]='EGYPTIAN HIEROGLYPH S013'
let s:d[0x132E0]='EGYPTIAN HIEROGLYPH S014'
let s:d[0x132E1]='EGYPTIAN HIEROGLYPH S014A'
let s:d[0x132E2]='EGYPTIAN HIEROGLYPH S014B'
let s:d[0x132E3]='EGYPTIAN HIEROGLYPH S015'
let s:d[0x132E4]='EGYPTIAN HIEROGLYPH S016'
let s:d[0x132E5]='EGYPTIAN HIEROGLYPH S017'
let s:d[0x132E6]='EGYPTIAN HIEROGLYPH S017A'
let s:d[0x132E7]='EGYPTIAN HIEROGLYPH S018'
let s:d[0x132E8]='EGYPTIAN HIEROGLYPH S019'
let s:d[0x132E9]='EGYPTIAN HIEROGLYPH S020'
let s:d[0x132EA]='EGYPTIAN HIEROGLYPH S021'
let s:d[0x132EB]='EGYPTIAN HIEROGLYPH S022'
let s:d[0x132EC]='EGYPTIAN HIEROGLYPH S023'
let s:d[0x132ED]='EGYPTIAN HIEROGLYPH S024'
let s:d[0x132EE]='EGYPTIAN HIEROGLYPH S025'
let s:d[0x132EF]='EGYPTIAN HIEROGLYPH S026'
let s:d[0x132F0]='EGYPTIAN HIEROGLYPH S026A'
let s:d[0x132F1]='EGYPTIAN HIEROGLYPH S026B'
let s:d[0x132F2]='EGYPTIAN HIEROGLYPH S027'
let s:d[0x132F3]='EGYPTIAN HIEROGLYPH S028'
let s:d[0x132F4]='EGYPTIAN HIEROGLYPH S029'
let s:d[0x132F5]='EGYPTIAN HIEROGLYPH S030'
let s:d[0x132F6]='EGYPTIAN HIEROGLYPH S031'
let s:d[0x132F7]='EGYPTIAN HIEROGLYPH S032'
let s:d[0x132F8]='EGYPTIAN HIEROGLYPH S033'
let s:d[0x132F9]='EGYPTIAN HIEROGLYPH S034'
let s:d[0x132FA]='EGYPTIAN HIEROGLYPH S035'
let s:d[0x132FB]='EGYPTIAN HIEROGLYPH S035A'
let s:d[0x132FC]='EGYPTIAN HIEROGLYPH S036'
let s:d[0x132FD]='EGYPTIAN HIEROGLYPH S037'
let s:d[0x132FE]='EGYPTIAN HIEROGLYPH S038'
let s:d[0x132FF]='EGYPTIAN HIEROGLYPH S039'
let s:d[0x13300]='EGYPTIAN HIEROGLYPH S040'
let s:d[0x13301]='EGYPTIAN HIEROGLYPH S041'
let s:d[0x13302]='EGYPTIAN HIEROGLYPH S042'
let s:d[0x13303]='EGYPTIAN HIEROGLYPH S043'
let s:d[0x13304]='EGYPTIAN HIEROGLYPH S044'
let s:d[0x13305]='EGYPTIAN HIEROGLYPH S045'
let s:d[0x13306]='EGYPTIAN HIEROGLYPH S046'
let s:d[0x13307]='EGYPTIAN HIEROGLYPH T001'
let s:d[0x13308]='EGYPTIAN HIEROGLYPH T002'
let s:d[0x13309]='EGYPTIAN HIEROGLYPH T003'
let s:d[0x1330A]='EGYPTIAN HIEROGLYPH T003A'
let s:d[0x1330B]='EGYPTIAN HIEROGLYPH T004'
let s:d[0x1330C]='EGYPTIAN HIEROGLYPH T005'
let s:d[0x1330D]='EGYPTIAN HIEROGLYPH T006'
let s:d[0x1330E]='EGYPTIAN HIEROGLYPH T007'
let s:d[0x1330F]='EGYPTIAN HIEROGLYPH T007A'
let s:d[0x13310]='EGYPTIAN HIEROGLYPH T008'
let s:d[0x13311]='EGYPTIAN HIEROGLYPH T008A'
let s:d[0x13312]='EGYPTIAN HIEROGLYPH T009'
let s:d[0x13313]='EGYPTIAN HIEROGLYPH T009A'
let s:d[0x13314]='EGYPTIAN HIEROGLYPH T010'
let s:d[0x13315]='EGYPTIAN HIEROGLYPH T011'
let s:d[0x13316]='EGYPTIAN HIEROGLYPH T011A'
let s:d[0x13317]='EGYPTIAN HIEROGLYPH T012'
let s:d[0x13318]='EGYPTIAN HIEROGLYPH T013'
let s:d[0x13319]='EGYPTIAN HIEROGLYPH T014'
let s:d[0x1331A]='EGYPTIAN HIEROGLYPH T015'
let s:d[0x1331B]='EGYPTIAN HIEROGLYPH T016'
let s:d[0x1331C]='EGYPTIAN HIEROGLYPH T016A'
let s:d[0x1331D]='EGYPTIAN HIEROGLYPH T017'
let s:d[0x1331E]='EGYPTIAN HIEROGLYPH T018'
let s:d[0x1331F]='EGYPTIAN HIEROGLYPH T019'
let s:d[0x13320]='EGYPTIAN HIEROGLYPH T020'
let s:d[0x13321]='EGYPTIAN HIEROGLYPH T021'
let s:d[0x13322]='EGYPTIAN HIEROGLYPH T022'
let s:d[0x13323]='EGYPTIAN HIEROGLYPH T023'
let s:d[0x13324]='EGYPTIAN HIEROGLYPH T024'
let s:d[0x13325]='EGYPTIAN HIEROGLYPH T025'
let s:d[0x13326]='EGYPTIAN HIEROGLYPH T026'
let s:d[0x13327]='EGYPTIAN HIEROGLYPH T027'
let s:d[0x13328]='EGYPTIAN HIEROGLYPH T028'
let s:d[0x13329]='EGYPTIAN HIEROGLYPH T029'
let s:d[0x1332A]='EGYPTIAN HIEROGLYPH T030'
let s:d[0x1332B]='EGYPTIAN HIEROGLYPH T031'
let s:d[0x1332C]='EGYPTIAN HIEROGLYPH T032'
let s:d[0x1332D]='EGYPTIAN HIEROGLYPH T032A'
let s:d[0x1332E]='EGYPTIAN HIEROGLYPH T033'
let s:d[0x1332F]='EGYPTIAN HIEROGLYPH T033A'
let s:d[0x13330]='EGYPTIAN HIEROGLYPH T034'
let s:d[0x13331]='EGYPTIAN HIEROGLYPH T035'
let s:d[0x13332]='EGYPTIAN HIEROGLYPH T036'
let s:d[0x13333]='EGYPTIAN HIEROGLYPH U001'
let s:d[0x13334]='EGYPTIAN HIEROGLYPH U002'
let s:d[0x13335]='EGYPTIAN HIEROGLYPH U003'
let s:d[0x13336]='EGYPTIAN HIEROGLYPH U004'
let s:d[0x13337]='EGYPTIAN HIEROGLYPH U005'
let s:d[0x13338]='EGYPTIAN HIEROGLYPH U006'
let s:d[0x13339]='EGYPTIAN HIEROGLYPH U006A'
let s:d[0x1333A]='EGYPTIAN HIEROGLYPH U006B'
let s:d[0x1333B]='EGYPTIAN HIEROGLYPH U007'
let s:d[0x1333C]='EGYPTIAN HIEROGLYPH U008'
let s:d[0x1333D]='EGYPTIAN HIEROGLYPH U009'
let s:d[0x1333E]='EGYPTIAN HIEROGLYPH U010'
let s:d[0x1333F]='EGYPTIAN HIEROGLYPH U011'
let s:d[0x13340]='EGYPTIAN HIEROGLYPH U012'
let s:d[0x13341]='EGYPTIAN HIEROGLYPH U013'
let s:d[0x13342]='EGYPTIAN HIEROGLYPH U014'
let s:d[0x13343]='EGYPTIAN HIEROGLYPH U015'
let s:d[0x13344]='EGYPTIAN HIEROGLYPH U016'
let s:d[0x13345]='EGYPTIAN HIEROGLYPH U017'
let s:d[0x13346]='EGYPTIAN HIEROGLYPH U018'
let s:d[0x13347]='EGYPTIAN HIEROGLYPH U019'
let s:d[0x13348]='EGYPTIAN HIEROGLYPH U020'
let s:d[0x13349]='EGYPTIAN HIEROGLYPH U021'
let s:d[0x1334A]='EGYPTIAN HIEROGLYPH U022'
let s:d[0x1334B]='EGYPTIAN HIEROGLYPH U023'
let s:d[0x1334C]='EGYPTIAN HIEROGLYPH U023A'
let s:d[0x1334D]='EGYPTIAN HIEROGLYPH U024'
let s:d[0x1334E]='EGYPTIAN HIEROGLYPH U025'
let s:d[0x1334F]='EGYPTIAN HIEROGLYPH U026'
let s:d[0x13350]='EGYPTIAN HIEROGLYPH U027'
let s:d[0x13351]='EGYPTIAN HIEROGLYPH U028'
let s:d[0x13352]='EGYPTIAN HIEROGLYPH U029'
let s:d[0x13353]='EGYPTIAN HIEROGLYPH U029A'
let s:d[0x13354]='EGYPTIAN HIEROGLYPH U030'
let s:d[0x13355]='EGYPTIAN HIEROGLYPH U031'
let s:d[0x13356]='EGYPTIAN HIEROGLYPH U032'
let s:d[0x13357]='EGYPTIAN HIEROGLYPH U032A'
let s:d[0x13358]='EGYPTIAN HIEROGLYPH U033'
let s:d[0x13359]='EGYPTIAN HIEROGLYPH U034'
let s:d[0x1335A]='EGYPTIAN HIEROGLYPH U035'
let s:d[0x1335B]='EGYPTIAN HIEROGLYPH U036'
let s:d[0x1335C]='EGYPTIAN HIEROGLYPH U037'
let s:d[0x1335D]='EGYPTIAN HIEROGLYPH U038'
let s:d[0x1335E]='EGYPTIAN HIEROGLYPH U039'
let s:d[0x1335F]='EGYPTIAN HIEROGLYPH U040'
let s:d[0x13360]='EGYPTIAN HIEROGLYPH U041'
let s:d[0x13361]='EGYPTIAN HIEROGLYPH U042'
let s:d[0x13362]='EGYPTIAN HIEROGLYPH V001'
let s:d[0x13363]='EGYPTIAN HIEROGLYPH V001A'
let s:d[0x13364]='EGYPTIAN HIEROGLYPH V001B'
let s:d[0x13365]='EGYPTIAN HIEROGLYPH V001C'
let s:d[0x13366]='EGYPTIAN HIEROGLYPH V001D'
let s:d[0x13367]='EGYPTIAN HIEROGLYPH V001E'
let s:d[0x13368]='EGYPTIAN HIEROGLYPH V001F'
let s:d[0x13369]='EGYPTIAN HIEROGLYPH V001G'
let s:d[0x1336A]='EGYPTIAN HIEROGLYPH V001H'
let s:d[0x1336B]='EGYPTIAN HIEROGLYPH V001I'
let s:d[0x1336C]='EGYPTIAN HIEROGLYPH V002'
let s:d[0x1336D]='EGYPTIAN HIEROGLYPH V002A'
let s:d[0x1336E]='EGYPTIAN HIEROGLYPH V003'
let s:d[0x1336F]='EGYPTIAN HIEROGLYPH V004'
let s:d[0x13370]='EGYPTIAN HIEROGLYPH V005'
let s:d[0x13371]='EGYPTIAN HIEROGLYPH V006'
let s:d[0x13372]='EGYPTIAN HIEROGLYPH V007'
let s:d[0x13373]='EGYPTIAN HIEROGLYPH V007A'
let s:d[0x13374]='EGYPTIAN HIEROGLYPH V007B'
let s:d[0x13375]='EGYPTIAN HIEROGLYPH V008'
let s:d[0x13376]='EGYPTIAN HIEROGLYPH V009'
let s:d[0x13377]='EGYPTIAN HIEROGLYPH V010'
let s:d[0x13378]='EGYPTIAN HIEROGLYPH V011'
let s:d[0x13379]='EGYPTIAN HIEROGLYPH V011A'
let s:d[0x1337A]='EGYPTIAN HIEROGLYPH V011B'
let s:d[0x1337B]='EGYPTIAN HIEROGLYPH V011C'
let s:d[0x1337C]='EGYPTIAN HIEROGLYPH V012'
let s:d[0x1337D]='EGYPTIAN HIEROGLYPH V012A'
let s:d[0x1337E]='EGYPTIAN HIEROGLYPH V012B'
let s:d[0x1337F]='EGYPTIAN HIEROGLYPH V013'
let s:d[0x13380]='EGYPTIAN HIEROGLYPH V014'
let s:d[0x13381]='EGYPTIAN HIEROGLYPH V015'
let s:d[0x13382]='EGYPTIAN HIEROGLYPH V016'
let s:d[0x13383]='EGYPTIAN HIEROGLYPH V017'
let s:d[0x13384]='EGYPTIAN HIEROGLYPH V018'
let s:d[0x13385]='EGYPTIAN HIEROGLYPH V019'
let s:d[0x13386]='EGYPTIAN HIEROGLYPH V020'
let s:d[0x13387]='EGYPTIAN HIEROGLYPH V020A'
let s:d[0x13388]='EGYPTIAN HIEROGLYPH V020B'
let s:d[0x13389]='EGYPTIAN HIEROGLYPH V020C'
let s:d[0x1338A]='EGYPTIAN HIEROGLYPH V020D'
let s:d[0x1338B]='EGYPTIAN HIEROGLYPH V020E'
let s:d[0x1338C]='EGYPTIAN HIEROGLYPH V020F'
let s:d[0x1338D]='EGYPTIAN HIEROGLYPH V020G'
let s:d[0x1338E]='EGYPTIAN HIEROGLYPH V020H'
let s:d[0x1338F]='EGYPTIAN HIEROGLYPH V020I'
let s:d[0x13390]='EGYPTIAN HIEROGLYPH V020J'
let s:d[0x13391]='EGYPTIAN HIEROGLYPH V020K'
let s:d[0x13392]='EGYPTIAN HIEROGLYPH V020L'
let s:d[0x13393]='EGYPTIAN HIEROGLYPH V021'
let s:d[0x13394]='EGYPTIAN HIEROGLYPH V022'
let s:d[0x13395]='EGYPTIAN HIEROGLYPH V023'
let s:d[0x13396]='EGYPTIAN HIEROGLYPH V023A'
let s:d[0x13397]='EGYPTIAN HIEROGLYPH V024'
let s:d[0x13398]='EGYPTIAN HIEROGLYPH V025'
let s:d[0x13399]='EGYPTIAN HIEROGLYPH V026'
let s:d[0x1339A]='EGYPTIAN HIEROGLYPH V027'
let s:d[0x1339B]='EGYPTIAN HIEROGLYPH V028'
let s:d[0x1339C]='EGYPTIAN HIEROGLYPH V028A'
let s:d[0x1339D]='EGYPTIAN HIEROGLYPH V029'
let s:d[0x1339E]='EGYPTIAN HIEROGLYPH V029A'
let s:d[0x1339F]='EGYPTIAN HIEROGLYPH V030'
let s:d[0x133A0]='EGYPTIAN HIEROGLYPH V030A'
let s:d[0x133A1]='EGYPTIAN HIEROGLYPH V031'
let s:d[0x133A2]='EGYPTIAN HIEROGLYPH V031A'
let s:d[0x133A3]='EGYPTIAN HIEROGLYPH V032'
let s:d[0x133A4]='EGYPTIAN HIEROGLYPH V033'
let s:d[0x133A5]='EGYPTIAN HIEROGLYPH V033A'
let s:d[0x133A6]='EGYPTIAN HIEROGLYPH V034'
let s:d[0x133A7]='EGYPTIAN HIEROGLYPH V035'
let s:d[0x133A8]='EGYPTIAN HIEROGLYPH V036'
let s:d[0x133A9]='EGYPTIAN HIEROGLYPH V037'
let s:d[0x133AA]='EGYPTIAN HIEROGLYPH V037A'
let s:d[0x133AB]='EGYPTIAN HIEROGLYPH V038'
let s:d[0x133AC]='EGYPTIAN HIEROGLYPH V039'
let s:d[0x133AD]='EGYPTIAN HIEROGLYPH V040'
let s:d[0x133AE]='EGYPTIAN HIEROGLYPH V040A'
let s:d[0x133AF]='EGYPTIAN HIEROGLYPH W001'
let s:d[0x133B0]='EGYPTIAN HIEROGLYPH W002'
let s:d[0x133B1]='EGYPTIAN HIEROGLYPH W003'
let s:d[0x133B2]='EGYPTIAN HIEROGLYPH W003A'
let s:d[0x133B3]='EGYPTIAN HIEROGLYPH W004'
let s:d[0x133B4]='EGYPTIAN HIEROGLYPH W005'
let s:d[0x133B5]='EGYPTIAN HIEROGLYPH W006'
let s:d[0x133B6]='EGYPTIAN HIEROGLYPH W007'
let s:d[0x133B7]='EGYPTIAN HIEROGLYPH W008'
let s:d[0x133B8]='EGYPTIAN HIEROGLYPH W009'
let s:d[0x133B9]='EGYPTIAN HIEROGLYPH W009A'
let s:d[0x133BA]='EGYPTIAN HIEROGLYPH W010'
let s:d[0x133BB]='EGYPTIAN HIEROGLYPH W010A'
let s:d[0x133BC]='EGYPTIAN HIEROGLYPH W011'
let s:d[0x133BD]='EGYPTIAN HIEROGLYPH W012'
let s:d[0x133BE]='EGYPTIAN HIEROGLYPH W013'
let s:d[0x133BF]='EGYPTIAN HIEROGLYPH W014'
let s:d[0x133C0]='EGYPTIAN HIEROGLYPH W014A'
let s:d[0x133C1]='EGYPTIAN HIEROGLYPH W015'
let s:d[0x133C2]='EGYPTIAN HIEROGLYPH W016'
let s:d[0x133C3]='EGYPTIAN HIEROGLYPH W017'
let s:d[0x133C4]='EGYPTIAN HIEROGLYPH W017A'
let s:d[0x133C5]='EGYPTIAN HIEROGLYPH W018'
let s:d[0x133C6]='EGYPTIAN HIEROGLYPH W018A'
let s:d[0x133C7]='EGYPTIAN HIEROGLYPH W019'
let s:d[0x133C8]='EGYPTIAN HIEROGLYPH W020'
let s:d[0x133C9]='EGYPTIAN HIEROGLYPH W021'
let s:d[0x133CA]='EGYPTIAN HIEROGLYPH W022'
let s:d[0x133CB]='EGYPTIAN HIEROGLYPH W023'
let s:d[0x133CC]='EGYPTIAN HIEROGLYPH W024'
let s:d[0x133CD]='EGYPTIAN HIEROGLYPH W024A'
let s:d[0x133CE]='EGYPTIAN HIEROGLYPH W025'
let s:d[0x133CF]='EGYPTIAN HIEROGLYPH X001'
let s:d[0x133D0]='EGYPTIAN HIEROGLYPH X002'
let s:d[0x133D1]='EGYPTIAN HIEROGLYPH X003'
let s:d[0x133D2]='EGYPTIAN HIEROGLYPH X004'
let s:d[0x133D3]='EGYPTIAN HIEROGLYPH X004A'
let s:d[0x133D4]='EGYPTIAN HIEROGLYPH X004B'
let s:d[0x133D5]='EGYPTIAN HIEROGLYPH X005'
let s:d[0x133D6]='EGYPTIAN HIEROGLYPH X006'
let s:d[0x133D7]='EGYPTIAN HIEROGLYPH X006A'
let s:d[0x133D8]='EGYPTIAN HIEROGLYPH X007'
let s:d[0x133D9]='EGYPTIAN HIEROGLYPH X008'
let s:d[0x133DA]='EGYPTIAN HIEROGLYPH X008A'
let s:d[0x133DB]='EGYPTIAN HIEROGLYPH Y001'
let s:d[0x133DC]='EGYPTIAN HIEROGLYPH Y001A'
let s:d[0x133DD]='EGYPTIAN HIEROGLYPH Y002'
let s:d[0x133DE]='EGYPTIAN HIEROGLYPH Y003'
let s:d[0x133DF]='EGYPTIAN HIEROGLYPH Y004'
let s:d[0x133E0]='EGYPTIAN HIEROGLYPH Y005'
let s:d[0x133E1]='EGYPTIAN HIEROGLYPH Y006'
let s:d[0x133E2]='EGYPTIAN HIEROGLYPH Y007'
let s:d[0x133E3]='EGYPTIAN HIEROGLYPH Y008'
let s:d[0x133E4]='EGYPTIAN HIEROGLYPH Z001'
let s:d[0x133E5]='EGYPTIAN HIEROGLYPH Z002'
let s:d[0x133E6]='EGYPTIAN HIEROGLYPH Z002A'
let s:d[0x133E7]='EGYPTIAN HIEROGLYPH Z002B'
let s:d[0x133E8]='EGYPTIAN HIEROGLYPH Z002C'
let s:d[0x133E9]='EGYPTIAN HIEROGLYPH Z002D'
let s:d[0x133EA]='EGYPTIAN HIEROGLYPH Z003'
let s:d[0x133EB]='EGYPTIAN HIEROGLYPH Z003A'
let s:d[0x133EC]='EGYPTIAN HIEROGLYPH Z003B'
let s:d[0x133ED]='EGYPTIAN HIEROGLYPH Z004'
let s:d[0x133EE]='EGYPTIAN HIEROGLYPH Z004A'
let s:d[0x133EF]='EGYPTIAN HIEROGLYPH Z005'
let s:d[0x133F0]='EGYPTIAN HIEROGLYPH Z005A'
let s:d[0x133F1]='EGYPTIAN HIEROGLYPH Z006'
let s:d[0x133F2]='EGYPTIAN HIEROGLYPH Z007'
let s:d[0x133F3]='EGYPTIAN HIEROGLYPH Z008'
let s:d[0x133F4]='EGYPTIAN HIEROGLYPH Z009'
let s:d[0x133F5]='EGYPTIAN HIEROGLYPH Z010'
let s:d[0x133F6]='EGYPTIAN HIEROGLYPH Z011'
let s:d[0x133F7]='EGYPTIAN HIEROGLYPH Z012'
let s:d[0x133F8]='EGYPTIAN HIEROGLYPH Z013'
let s:d[0x133F9]='EGYPTIAN HIEROGLYPH Z014'
let s:d[0x133FA]='EGYPTIAN HIEROGLYPH Z015'
let s:d[0x133FB]='EGYPTIAN HIEROGLYPH Z015A'
let s:d[0x133FC]='EGYPTIAN HIEROGLYPH Z015B'
let s:d[0x133FD]='EGYPTIAN HIEROGLYPH Z015C'
let s:d[0x133FE]='EGYPTIAN HIEROGLYPH Z015D'
let s:d[0x133FF]='EGYPTIAN HIEROGLYPH Z015E'
let s:d[0x13400]='EGYPTIAN HIEROGLYPH Z015F'
let s:d[0x13401]='EGYPTIAN HIEROGLYPH Z015G'
let s:d[0x13402]='EGYPTIAN HIEROGLYPH Z015H'
let s:d[0x13403]='EGYPTIAN HIEROGLYPH Z015I'
let s:d[0x13404]='EGYPTIAN HIEROGLYPH Z016'
let s:d[0x13405]='EGYPTIAN HIEROGLYPH Z016A'
let s:d[0x13406]='EGYPTIAN HIEROGLYPH Z016B'
let s:d[0x13407]='EGYPTIAN HIEROGLYPH Z016C'
let s:d[0x13408]='EGYPTIAN HIEROGLYPH Z016D'
let s:d[0x13409]='EGYPTIAN HIEROGLYPH Z016E'
let s:d[0x1340A]='EGYPTIAN HIEROGLYPH Z016F'
let s:d[0x1340B]='EGYPTIAN HIEROGLYPH Z016G'
let s:d[0x1340C]='EGYPTIAN HIEROGLYPH Z016H'
let s:d[0x1340D]='EGYPTIAN HIEROGLYPH AA001'
let s:d[0x1340E]='EGYPTIAN HIEROGLYPH AA002'
let s:d[0x1340F]='EGYPTIAN HIEROGLYPH AA003'
let s:d[0x13410]='EGYPTIAN HIEROGLYPH AA004'
let s:d[0x13411]='EGYPTIAN HIEROGLYPH AA005'
let s:d[0x13412]='EGYPTIAN HIEROGLYPH AA006'
let s:d[0x13413]='EGYPTIAN HIEROGLYPH AA007'
let s:d[0x13414]='EGYPTIAN HIEROGLYPH AA007A'
let s:d[0x13415]='EGYPTIAN HIEROGLYPH AA007B'
let s:d[0x13416]='EGYPTIAN HIEROGLYPH AA008'
let s:d[0x13417]='EGYPTIAN HIEROGLYPH AA009'
let s:d[0x13418]='EGYPTIAN HIEROGLYPH AA010'
let s:d[0x13419]='EGYPTIAN HIEROGLYPH AA011'
let s:d[0x1341A]='EGYPTIAN HIEROGLYPH AA012'
let s:d[0x1341B]='EGYPTIAN HIEROGLYPH AA013'
let s:d[0x1341C]='EGYPTIAN HIEROGLYPH AA014'
let s:d[0x1341D]='EGYPTIAN HIEROGLYPH AA015'
let s:d[0x1341E]='EGYPTIAN HIEROGLYPH AA016'
let s:d[0x1341F]='EGYPTIAN HIEROGLYPH AA017'
let s:d[0x13420]='EGYPTIAN HIEROGLYPH AA018'
let s:d[0x13421]='EGYPTIAN HIEROGLYPH AA019'
let s:d[0x13422]='EGYPTIAN HIEROGLYPH AA020'
let s:d[0x13423]='EGYPTIAN HIEROGLYPH AA021'
let s:d[0x13424]='EGYPTIAN HIEROGLYPH AA022'
let s:d[0x13425]='EGYPTIAN HIEROGLYPH AA023'
let s:d[0x13426]='EGYPTIAN HIEROGLYPH AA024'
let s:d[0x13427]='EGYPTIAN HIEROGLYPH AA025'
let s:d[0x13428]='EGYPTIAN HIEROGLYPH AA026'
let s:d[0x13429]='EGYPTIAN HIEROGLYPH AA027'
let s:d[0x1342A]='EGYPTIAN HIEROGLYPH AA028'
let s:d[0x1342B]='EGYPTIAN HIEROGLYPH AA029'
let s:d[0x1342C]='EGYPTIAN HIEROGLYPH AA030'
let s:d[0x1342D]='EGYPTIAN HIEROGLYPH AA031'
let s:d[0x1342E]='EGYPTIAN HIEROGLYPH AA032'
let s:d[0x16800]='BAMUM LETTER PHASE-A NGKUE MFON'
let s:d[0x16801]='BAMUM LETTER PHASE-A GBIEE FON'
let s:d[0x16802]='BAMUM LETTER PHASE-A PON MFON PIPAEMGBIEE'
let s:d[0x16803]='BAMUM LETTER PHASE-A PON MFON PIPAEMBA'
let s:d[0x16804]='BAMUM LETTER PHASE-A NAA MFON'
let s:d[0x16805]='BAMUM LETTER PHASE-A SHUENSHUET'
let s:d[0x16806]='BAMUM LETTER PHASE-A TITA MFON'
let s:d[0x16807]='BAMUM LETTER PHASE-A NZA MFON'
let s:d[0x16808]='BAMUM LETTER PHASE-A SHINDA PA NJI'
let s:d[0x16809]='BAMUM LETTER PHASE-A PON PA NJI PIPAEMGBIEE'
let s:d[0x1680A]='BAMUM LETTER PHASE-A PON PA NJI PIPAEMBA'
let s:d[0x1680B]='BAMUM LETTER PHASE-A MAEMBGBIEE'
let s:d[0x1680C]='BAMUM LETTER PHASE-A TU MAEMBA'
let s:d[0x1680D]='BAMUM LETTER PHASE-A NGANGU'
let s:d[0x1680E]='BAMUM LETTER PHASE-A MAEMVEUX'
let s:d[0x1680F]='BAMUM LETTER PHASE-A MANSUAE'
let s:d[0x16810]='BAMUM LETTER PHASE-A MVEUAENGAM'
let s:d[0x16811]='BAMUM LETTER PHASE-A SEUNYAM'
let s:d[0x16812]='BAMUM LETTER PHASE-A NTOQPEN'
let s:d[0x16813]='BAMUM LETTER PHASE-A KEUKEUTNDA'
let s:d[0x16814]='BAMUM LETTER PHASE-A NKINDI'
let s:d[0x16815]='BAMUM LETTER PHASE-A SUU'
let s:d[0x16816]='BAMUM LETTER PHASE-A NGKUENZEUM'
let s:d[0x16817]='BAMUM LETTER PHASE-A LAPAQ'
let s:d[0x16818]='BAMUM LETTER PHASE-A LET KUT'
let s:d[0x16819]='BAMUM LETTER PHASE-A NTAP MFAA'
let s:d[0x1681A]='BAMUM LETTER PHASE-A MAEKEUP'
let s:d[0x1681B]='BAMUM LETTER PHASE-A PASHAE'
let s:d[0x1681C]='BAMUM LETTER PHASE-A GHEUAERAE'
let s:d[0x1681D]='BAMUM LETTER PHASE-A PAMSHAE'
let s:d[0x1681E]='BAMUM LETTER PHASE-A MON NGGEUAET'
let s:d[0x1681F]='BAMUM LETTER PHASE-A NZUN MEUT'
let s:d[0x16820]='BAMUM LETTER PHASE-A U YUQ NAE'
let s:d[0x16821]='BAMUM LETTER PHASE-A GHEUAEGHEUAE'
let s:d[0x16822]='BAMUM LETTER PHASE-A NTAP NTAA'
let s:d[0x16823]='BAMUM LETTER PHASE-A SISA'
let s:d[0x16824]='BAMUM LETTER PHASE-A MGBASA'
let s:d[0x16825]='BAMUM LETTER PHASE-A MEUNJOMNDEUQ'
let s:d[0x16826]='BAMUM LETTER PHASE-A MOOMPUQ'
let s:d[0x16827]='BAMUM LETTER PHASE-A KAFA'
let s:d[0x16828]='BAMUM LETTER PHASE-A PA LEERAEWA'
let s:d[0x16829]='BAMUM LETTER PHASE-A NDA LEERAEWA'
let s:d[0x1682A]='BAMUM LETTER PHASE-A PET'
let s:d[0x1682B]='BAMUM LETTER PHASE-A MAEMKPEN'
let s:d[0x1682C]='BAMUM LETTER PHASE-A NIKA'
let s:d[0x1682D]='BAMUM LETTER PHASE-A PUP'
let s:d[0x1682E]='BAMUM LETTER PHASE-A TUAEP'
let s:d[0x1682F]='BAMUM LETTER PHASE-A LUAEP'
let s:d[0x16830]='BAMUM LETTER PHASE-A SONJAM'
let s:d[0x16831]='BAMUM LETTER PHASE-A TEUTEUWEN'
let s:d[0x16832]='BAMUM LETTER PHASE-A MAENYI'
let s:d[0x16833]='BAMUM LETTER PHASE-A KET'
let s:d[0x16834]='BAMUM LETTER PHASE-A NDAANGGEUAET'
let s:d[0x16835]='BAMUM LETTER PHASE-A KUOQ'
let s:d[0x16836]='BAMUM LETTER PHASE-A MOOMEUT'
let s:d[0x16837]='BAMUM LETTER PHASE-A SHUM'
let s:d[0x16838]='BAMUM LETTER PHASE-A LOMMAE'
let s:d[0x16839]='BAMUM LETTER PHASE-A FIRI'
let s:d[0x1683A]='BAMUM LETTER PHASE-A ROM'
let s:d[0x1683B]='BAMUM LETTER PHASE-A KPOQ'
let s:d[0x1683C]='BAMUM LETTER PHASE-A SOQ'
let s:d[0x1683D]='BAMUM LETTER PHASE-A MAP PIEET'
let s:d[0x1683E]='BAMUM LETTER PHASE-A SHIRAE'
let s:d[0x1683F]='BAMUM LETTER PHASE-A NTAP'
let s:d[0x16840]='BAMUM LETTER PHASE-A SHOQ NSHUT YUM'
let s:d[0x16841]='BAMUM LETTER PHASE-A NYIT MONGKEUAEQ'
let s:d[0x16842]='BAMUM LETTER PHASE-A PAARAE'
let s:d[0x16843]='BAMUM LETTER PHASE-A NKAARAE'
let s:d[0x16844]='BAMUM LETTER PHASE-A UNKNOWN'
let s:d[0x16845]='BAMUM LETTER PHASE-A NGGEN'
let s:d[0x16846]='BAMUM LETTER PHASE-A MAESI'
let s:d[0x16847]='BAMUM LETTER PHASE-A NJAM'
let s:d[0x16848]='BAMUM LETTER PHASE-A MBANYI'
let s:d[0x16849]='BAMUM LETTER PHASE-A NYET'
let s:d[0x1684A]='BAMUM LETTER PHASE-A TEUAEN'
let s:d[0x1684B]='BAMUM LETTER PHASE-A SOT'
let s:d[0x1684C]='BAMUM LETTER PHASE-A PAAM'
let s:d[0x1684D]='BAMUM LETTER PHASE-A NSHIEE'
let s:d[0x1684E]='BAMUM LETTER PHASE-A MAEM'
let s:d[0x1684F]='BAMUM LETTER PHASE-A NYI'
let s:d[0x16850]='BAMUM LETTER PHASE-A KAQ'
let s:d[0x16851]='BAMUM LETTER PHASE-A NSHA'
let s:d[0x16852]='BAMUM LETTER PHASE-A VEE'
let s:d[0x16853]='BAMUM LETTER PHASE-A LU'
let s:d[0x16854]='BAMUM LETTER PHASE-A NEN'
let s:d[0x16855]='BAMUM LETTER PHASE-A NAQ'
let s:d[0x16856]='BAMUM LETTER PHASE-A MBAQ'
let s:d[0x16857]='BAMUM LETTER PHASE-B NSHUET'
let s:d[0x16858]='BAMUM LETTER PHASE-B TU MAEMGBIEE'
let s:d[0x16859]='BAMUM LETTER PHASE-B SIEE'
let s:d[0x1685A]='BAMUM LETTER PHASE-B SET TU'
let s:d[0x1685B]='BAMUM LETTER PHASE-B LOM NTEUM'
let s:d[0x1685C]='BAMUM LETTER PHASE-B MBA MAELEE'
let s:d[0x1685D]='BAMUM LETTER PHASE-B KIEEM'
let s:d[0x1685E]='BAMUM LETTER PHASE-B YEURAE'
let s:d[0x1685F]='BAMUM LETTER PHASE-B MBAARAE'
let s:d[0x16860]='BAMUM LETTER PHASE-B KAM'
let s:d[0x16861]='BAMUM LETTER PHASE-B PEESHI'
let s:d[0x16862]='BAMUM LETTER PHASE-B YAFU LEERAEWA'
let s:d[0x16863]='BAMUM LETTER PHASE-B LAM NSHUT NYAM'
let s:d[0x16864]='BAMUM LETTER PHASE-B NTIEE SHEUOQ'
let s:d[0x16865]='BAMUM LETTER PHASE-B NDU NJAA'
let s:d[0x16866]='BAMUM LETTER PHASE-B GHEUGHEUAEM'
let s:d[0x16867]='BAMUM LETTER PHASE-B PIT'
let s:d[0x16868]='BAMUM LETTER PHASE-B TU NSIEE'
let s:d[0x16869]='BAMUM LETTER PHASE-B SHET NJAQ'
let s:d[0x1686A]='BAMUM LETTER PHASE-B SHEUAEQTU'
let s:d[0x1686B]='BAMUM LETTER PHASE-B MFON TEUAEQ'
let s:d[0x1686C]='BAMUM LETTER PHASE-B MBIT MBAAKET'
let s:d[0x1686D]='BAMUM LETTER PHASE-B NYI NTEUM'
let s:d[0x1686E]='BAMUM LETTER PHASE-B KEUPUQ'
let s:d[0x1686F]='BAMUM LETTER PHASE-B GHEUGHEN'
let s:d[0x16870]='BAMUM LETTER PHASE-B KEUYEUX'
let s:d[0x16871]='BAMUM LETTER PHASE-B LAANAE'
let s:d[0x16872]='BAMUM LETTER PHASE-B PARUM'
let s:d[0x16873]='BAMUM LETTER PHASE-B VEUM'
let s:d[0x16874]='BAMUM LETTER PHASE-B NGKINDI MVOP'
let s:d[0x16875]='BAMUM LETTER PHASE-B NGGEU MBU'
let s:d[0x16876]='BAMUM LETTER PHASE-B WUAET'
let s:d[0x16877]='BAMUM LETTER PHASE-B SAKEUAE'
let s:d[0x16878]='BAMUM LETTER PHASE-B TAAM'
let s:d[0x16879]='BAMUM LETTER PHASE-B MEUQ'
let s:d[0x1687A]='BAMUM LETTER PHASE-B NGGUOQ'
let s:d[0x1687B]='BAMUM LETTER PHASE-B NGGUOQ LARGE'
let s:d[0x1687C]='BAMUM LETTER PHASE-B MFIYAQ'
let s:d[0x1687D]='BAMUM LETTER PHASE-B SUE'
let s:d[0x1687E]='BAMUM LETTER PHASE-B MBEURI'
let s:d[0x1687F]='BAMUM LETTER PHASE-B MONTIEEN'
let s:d[0x16880]='BAMUM LETTER PHASE-B NYAEMAE'
let s:d[0x16881]='BAMUM LETTER PHASE-B PUNGAAM'
let s:d[0x16882]='BAMUM LETTER PHASE-B MEUT NGGEET'
let s:d[0x16883]='BAMUM LETTER PHASE-B FEUX'
let s:d[0x16884]='BAMUM LETTER PHASE-B MBUOQ'
let s:d[0x16885]='BAMUM LETTER PHASE-B FEE'
let s:d[0x16886]='BAMUM LETTER PHASE-B KEUAEM'
let s:d[0x16887]='BAMUM LETTER PHASE-B MA NJEUAENA'
let s:d[0x16888]='BAMUM LETTER PHASE-B MA NJUQA'
let s:d[0x16889]='BAMUM LETTER PHASE-B LET'
let s:d[0x1688A]='BAMUM LETTER PHASE-B NGGAAM'
let s:d[0x1688B]='BAMUM LETTER PHASE-B NSEN'
let s:d[0x1688C]='BAMUM LETTER PHASE-B MA'
let s:d[0x1688D]='BAMUM LETTER PHASE-B KIQ'
let s:d[0x1688E]='BAMUM LETTER PHASE-B NGOM'
let s:d[0x1688F]='BAMUM LETTER PHASE-C NGKUE MAEMBA'
let s:d[0x16890]='BAMUM LETTER PHASE-C NZA'
let s:d[0x16891]='BAMUM LETTER PHASE-C YUM'
let s:d[0x16892]='BAMUM LETTER PHASE-C WANGKUOQ'
let s:d[0x16893]='BAMUM LETTER PHASE-C NGGEN'
let s:d[0x16894]='BAMUM LETTER PHASE-C NDEUAEREE'
let s:d[0x16895]='BAMUM LETTER PHASE-C NGKAQ'
let s:d[0x16896]='BAMUM LETTER PHASE-C GHARAE'
let s:d[0x16897]='BAMUM LETTER PHASE-C MBEEKEET'
let s:d[0x16898]='BAMUM LETTER PHASE-C GBAYI'
let s:d[0x16899]='BAMUM LETTER PHASE-C NYIR MKPARAQ MEUN'
let s:d[0x1689A]='BAMUM LETTER PHASE-C NTU MBIT'
let s:d[0x1689B]='BAMUM LETTER PHASE-C MBEUM'
let s:d[0x1689C]='BAMUM LETTER PHASE-C PIRIEEN'
let s:d[0x1689D]='BAMUM LETTER PHASE-C NDOMBU'
let s:d[0x1689E]='BAMUM LETTER PHASE-C MBAA CABBAGE-TREE'
let s:d[0x1689F]='BAMUM LETTER PHASE-C KEUSHEUAEP'
let s:d[0x168A0]='BAMUM LETTER PHASE-C GHAP'
let s:d[0x168A1]='BAMUM LETTER PHASE-C KEUKAQ'
let s:d[0x168A2]='BAMUM LETTER PHASE-C YU MUOMAE'
let s:d[0x168A3]='BAMUM LETTER PHASE-C NZEUM'
let s:d[0x168A4]='BAMUM LETTER PHASE-C MBUE'
let s:d[0x168A5]='BAMUM LETTER PHASE-C NSEUAEN'
let s:d[0x168A6]='BAMUM LETTER PHASE-C MBIT'
let s:d[0x168A7]='BAMUM LETTER PHASE-C YEUQ'
let s:d[0x168A8]='BAMUM LETTER PHASE-C KPARAQ'
let s:d[0x168A9]='BAMUM LETTER PHASE-C KAA'
let s:d[0x168AA]='BAMUM LETTER PHASE-C SEUX'
let s:d[0x168AB]='BAMUM LETTER PHASE-C NDIDA'
let s:d[0x168AC]='BAMUM LETTER PHASE-C TAASHAE'
let s:d[0x168AD]='BAMUM LETTER PHASE-C NJUEQ'
let s:d[0x168AE]='BAMUM LETTER PHASE-C TITA YUE'
let s:d[0x168AF]='BAMUM LETTER PHASE-C SUAET'
let s:d[0x168B0]='BAMUM LETTER PHASE-C NGGUAEN NYAM'
let s:d[0x168B1]='BAMUM LETTER PHASE-C VEUX'
let s:d[0x168B2]='BAMUM LETTER PHASE-C NANSANAQ'
let s:d[0x168B3]='BAMUM LETTER PHASE-C MA KEUAERI'
let s:d[0x168B4]='BAMUM LETTER PHASE-C NTAA'
let s:d[0x168B5]='BAMUM LETTER PHASE-C NGGUON'
let s:d[0x168B6]='BAMUM LETTER PHASE-C LAP'
let s:d[0x168B7]='BAMUM LETTER PHASE-C MBIRIEEN'
let s:d[0x168B8]='BAMUM LETTER PHASE-C MGBASAQ'
let s:d[0x168B9]='BAMUM LETTER PHASE-C NTEUNGBA'
let s:d[0x168BA]='BAMUM LETTER PHASE-C TEUTEUX'
let s:d[0x168BB]='BAMUM LETTER PHASE-C NGGUM'
let s:d[0x168BC]='BAMUM LETTER PHASE-C FUE'
let s:d[0x168BD]='BAMUM LETTER PHASE-C NDEUT'
let s:d[0x168BE]='BAMUM LETTER PHASE-C NSA'
let s:d[0x168BF]='BAMUM LETTER PHASE-C NSHAQ'
let s:d[0x168C0]='BAMUM LETTER PHASE-C BUNG'
let s:d[0x168C1]='BAMUM LETTER PHASE-C VEUAEPEN'
let s:d[0x168C2]='BAMUM LETTER PHASE-C MBERAE'
let s:d[0x168C3]='BAMUM LETTER PHASE-C RU'
let s:d[0x168C4]='BAMUM LETTER PHASE-C NJAEM'
let s:d[0x168C5]='BAMUM LETTER PHASE-C LAM'
let s:d[0x168C6]='BAMUM LETTER PHASE-C TITUAEP'
let s:d[0x168C7]='BAMUM LETTER PHASE-C NSUOT NGOM'
let s:d[0x168C8]='BAMUM LETTER PHASE-C NJEEEE'
let s:d[0x168C9]='BAMUM LETTER PHASE-C KET'
let s:d[0x168CA]='BAMUM LETTER PHASE-C NGGU'
let s:d[0x168CB]='BAMUM LETTER PHASE-C MAESI'
let s:d[0x168CC]='BAMUM LETTER PHASE-C MBUAEM'
let s:d[0x168CD]='BAMUM LETTER PHASE-C LU'
let s:d[0x168CE]='BAMUM LETTER PHASE-C KUT'
let s:d[0x168CF]='BAMUM LETTER PHASE-C NJAM'
let s:d[0x168D0]='BAMUM LETTER PHASE-C NGOM'
let s:d[0x168D1]='BAMUM LETTER PHASE-C WUP'
let s:d[0x168D2]='BAMUM LETTER PHASE-C NGGUEET'
let s:d[0x168D3]='BAMUM LETTER PHASE-C NSOM'
let s:d[0x168D4]='BAMUM LETTER PHASE-C NTEN'
let s:d[0x168D5]='BAMUM LETTER PHASE-C KUOP NKAARAE'
let s:d[0x168D6]='BAMUM LETTER PHASE-C NSUN'
let s:d[0x168D7]='BAMUM LETTER PHASE-C NDAM'
let s:d[0x168D8]='BAMUM LETTER PHASE-C MA NSIEE'
let s:d[0x168D9]='BAMUM LETTER PHASE-C YAA'
let s:d[0x168DA]='BAMUM LETTER PHASE-C NDAP'
let s:d[0x168DB]='BAMUM LETTER PHASE-C SHUEQ'
let s:d[0x168DC]='BAMUM LETTER PHASE-C SETFON'
let s:d[0x168DD]='BAMUM LETTER PHASE-C MBI'
let s:d[0x168DE]='BAMUM LETTER PHASE-C MAEMBA'
let s:d[0x168DF]='BAMUM LETTER PHASE-C MBANYI'
let s:d[0x168E0]='BAMUM LETTER PHASE-C KEUSEUX'
let s:d[0x168E1]='BAMUM LETTER PHASE-C MBEUX'
let s:d[0x168E2]='BAMUM LETTER PHASE-C KEUM'
let s:d[0x168E3]='BAMUM LETTER PHASE-C MBAA PICKET'
let s:d[0x168E4]='BAMUM LETTER PHASE-C YUWOQ'
let s:d[0x168E5]='BAMUM LETTER PHASE-C NJEUX'
let s:d[0x168E6]='BAMUM LETTER PHASE-C MIEE'
let s:d[0x168E7]='BAMUM LETTER PHASE-C MUAE'
let s:d[0x168E8]='BAMUM LETTER PHASE-C SHIQ'
let s:d[0x168E9]='BAMUM LETTER PHASE-C KEN LAW'
let s:d[0x168EA]='BAMUM LETTER PHASE-C KEN FATIGUE'
let s:d[0x168EB]='BAMUM LETTER PHASE-C NGAQ'
let s:d[0x168EC]='BAMUM LETTER PHASE-C NAQ'
let s:d[0x168ED]='BAMUM LETTER PHASE-C LIQ'
let s:d[0x168EE]='BAMUM LETTER PHASE-C PIN'
let s:d[0x168EF]='BAMUM LETTER PHASE-C PEN'
let s:d[0x168F0]='BAMUM LETTER PHASE-C TET'
let s:d[0x168F1]='BAMUM LETTER PHASE-D MBUO'
let s:d[0x168F2]='BAMUM LETTER PHASE-D WAP'
let s:d[0x168F3]='BAMUM LETTER PHASE-D NJI'
let s:d[0x168F4]='BAMUM LETTER PHASE-D MFON'
let s:d[0x168F5]='BAMUM LETTER PHASE-D NJIEE'
let s:d[0x168F6]='BAMUM LETTER PHASE-D LIEE'
let s:d[0x168F7]='BAMUM LETTER PHASE-D NJEUT'
let s:d[0x168F8]='BAMUM LETTER PHASE-D NSHEE'
let s:d[0x168F9]='BAMUM LETTER PHASE-D NGGAAMAE'
let s:d[0x168FA]='BAMUM LETTER PHASE-D NYAM'
let s:d[0x168FB]='BAMUM LETTER PHASE-D WUAEN'
let s:d[0x168FC]='BAMUM LETTER PHASE-D NGKUN'
let s:d[0x168FD]='BAMUM LETTER PHASE-D SHEE'
let s:d[0x168FE]='BAMUM LETTER PHASE-D NGKAP'
let s:d[0x168FF]='BAMUM LETTER PHASE-D KEUAETMEUN'
let s:d[0x16900]='BAMUM LETTER PHASE-D TEUT'
let s:d[0x16901]='BAMUM LETTER PHASE-D SHEUAE'
let s:d[0x16902]='BAMUM LETTER PHASE-D NJAP'
let s:d[0x16903]='BAMUM LETTER PHASE-D SUE'
let s:d[0x16904]='BAMUM LETTER PHASE-D KET'
let s:d[0x16905]='BAMUM LETTER PHASE-D YAEMMAE'
let s:d[0x16906]='BAMUM LETTER PHASE-D KUOM'
let s:d[0x16907]='BAMUM LETTER PHASE-D SAP'
let s:d[0x16908]='BAMUM LETTER PHASE-D MFEUT'
let s:d[0x16909]='BAMUM LETTER PHASE-D NDEUX'
let s:d[0x1690A]='BAMUM LETTER PHASE-D MALEERI'
let s:d[0x1690B]='BAMUM LETTER PHASE-D MEUT'
let s:d[0x1690C]='BAMUM LETTER PHASE-D SEUAEQ'
let s:d[0x1690D]='BAMUM LETTER PHASE-D YEN'
let s:d[0x1690E]='BAMUM LETTER PHASE-D NJEUAEM'
let s:d[0x1690F]='BAMUM LETTER PHASE-D KEUOT MBUAE'
let s:d[0x16910]='BAMUM LETTER PHASE-D NGKEURI'
let s:d[0x16911]='BAMUM LETTER PHASE-D TU'
let s:d[0x16912]='BAMUM LETTER PHASE-D GHAA'
let s:d[0x16913]='BAMUM LETTER PHASE-D NGKYEE'
let s:d[0x16914]='BAMUM LETTER PHASE-D FEUFEUAET'
let s:d[0x16915]='BAMUM LETTER PHASE-D NDEE'
let s:d[0x16916]='BAMUM LETTER PHASE-D MGBOFUM'
let s:d[0x16917]='BAMUM LETTER PHASE-D LEUAEP'
let s:d[0x16918]='BAMUM LETTER PHASE-D NDON'
let s:d[0x16919]='BAMUM LETTER PHASE-D MONI'
let s:d[0x1691A]='BAMUM LETTER PHASE-D MGBEUN'
let s:d[0x1691B]='BAMUM LETTER PHASE-D PUUT'
let s:d[0x1691C]='BAMUM LETTER PHASE-D MGBIEE'
let s:d[0x1691D]='BAMUM LETTER PHASE-D MFO'
let s:d[0x1691E]='BAMUM LETTER PHASE-D LUM'
let s:d[0x1691F]='BAMUM LETTER PHASE-D NSIEEP'
let s:d[0x16920]='BAMUM LETTER PHASE-D MBAA'
let s:d[0x16921]='BAMUM LETTER PHASE-D KWAET'
let s:d[0x16922]='BAMUM LETTER PHASE-D NYET'
let s:d[0x16923]='BAMUM LETTER PHASE-D TEUAEN'
let s:d[0x16924]='BAMUM LETTER PHASE-D SOT'
let s:d[0x16925]='BAMUM LETTER PHASE-D YUWOQ'
let s:d[0x16926]='BAMUM LETTER PHASE-D KEUM'
let s:d[0x16927]='BAMUM LETTER PHASE-D RAEM'
let s:d[0x16928]='BAMUM LETTER PHASE-D TEEEE'
let s:d[0x16929]='BAMUM LETTER PHASE-D NGKEUAEQ'
let s:d[0x1692A]='BAMUM LETTER PHASE-D MFEUAE'
let s:d[0x1692B]='BAMUM LETTER PHASE-D NSIEET'
let s:d[0x1692C]='BAMUM LETTER PHASE-D KEUP'
let s:d[0x1692D]='BAMUM LETTER PHASE-D PIP'
let s:d[0x1692E]='BAMUM LETTER PHASE-D PEUTAE'
let s:d[0x1692F]='BAMUM LETTER PHASE-D NYUE'
let s:d[0x16930]='BAMUM LETTER PHASE-D LET'
let s:d[0x16931]='BAMUM LETTER PHASE-D NGGAAM'
let s:d[0x16932]='BAMUM LETTER PHASE-D MFIEE'
let s:d[0x16933]='BAMUM LETTER PHASE-D NGGWAEN'
let s:d[0x16934]='BAMUM LETTER PHASE-D YUOM'
let s:d[0x16935]='BAMUM LETTER PHASE-D PAP'
let s:d[0x16936]='BAMUM LETTER PHASE-D YUOP'
let s:d[0x16937]='BAMUM LETTER PHASE-D NDAM'
let s:d[0x16938]='BAMUM LETTER PHASE-D NTEUM'
let s:d[0x16939]='BAMUM LETTER PHASE-D SUAE'
let s:d[0x1693A]='BAMUM LETTER PHASE-D KUN'
let s:d[0x1693B]='BAMUM LETTER PHASE-D NGGEUX'
let s:d[0x1693C]='BAMUM LETTER PHASE-D NGKIEE'
let s:d[0x1693D]='BAMUM LETTER PHASE-D TUOT'
let s:d[0x1693E]='BAMUM LETTER PHASE-D MEUN'
let s:d[0x1693F]='BAMUM LETTER PHASE-D KUQ'
let s:d[0x16940]='BAMUM LETTER PHASE-D NSUM'
let s:d[0x16941]='BAMUM LETTER PHASE-D TEUN'
let s:d[0x16942]='BAMUM LETTER PHASE-D MAENJET'
let s:d[0x16943]='BAMUM LETTER PHASE-D NGGAP'
let s:d[0x16944]='BAMUM LETTER PHASE-D LEUM'
let s:d[0x16945]='BAMUM LETTER PHASE-D NGGUOM'
let s:d[0x16946]='BAMUM LETTER PHASE-D NSHUT'
let s:d[0x16947]='BAMUM LETTER PHASE-D NJUEQ'
let s:d[0x16948]='BAMUM LETTER PHASE-D GHEUAE'
let s:d[0x16949]='BAMUM LETTER PHASE-D KU'
let s:d[0x1694A]='BAMUM LETTER PHASE-D REN OLD'
let s:d[0x1694B]='BAMUM LETTER PHASE-D TAE'
let s:d[0x1694C]='BAMUM LETTER PHASE-D TOQ'
let s:d[0x1694D]='BAMUM LETTER PHASE-D NYI'
let s:d[0x1694E]='BAMUM LETTER PHASE-D RII'
let s:d[0x1694F]='BAMUM LETTER PHASE-D LEEEE'
let s:d[0x16950]='BAMUM LETTER PHASE-D MEEEE'
let s:d[0x16951]='BAMUM LETTER PHASE-D M'
let s:d[0x16952]='BAMUM LETTER PHASE-D SUU'
let s:d[0x16953]='BAMUM LETTER PHASE-D MU'
let s:d[0x16954]='BAMUM LETTER PHASE-D SHII'
let s:d[0x16955]='BAMUM LETTER PHASE-D SHEUX'
let s:d[0x16956]='BAMUM LETTER PHASE-D KYEE'
let s:d[0x16957]='BAMUM LETTER PHASE-D NU'
let s:d[0x16958]='BAMUM LETTER PHASE-D SHU'
let s:d[0x16959]='BAMUM LETTER PHASE-D NTEE'
let s:d[0x1695A]='BAMUM LETTER PHASE-D PEE'
let s:d[0x1695B]='BAMUM LETTER PHASE-D NI'
let s:d[0x1695C]='BAMUM LETTER PHASE-D SHOQ'
let s:d[0x1695D]='BAMUM LETTER PHASE-D PUQ'
let s:d[0x1695E]='BAMUM LETTER PHASE-D MVOP'
let s:d[0x1695F]='BAMUM LETTER PHASE-D LOQ'
let s:d[0x16960]='BAMUM LETTER PHASE-D REN MUCH'
let s:d[0x16961]='BAMUM LETTER PHASE-D TI'
let s:d[0x16962]='BAMUM LETTER PHASE-D NTUU'
let s:d[0x16963]='BAMUM LETTER PHASE-D MBAA SEVEN'
let s:d[0x16964]='BAMUM LETTER PHASE-D SAQ'
let s:d[0x16965]='BAMUM LETTER PHASE-D FAA'
let s:d[0x16966]='BAMUM LETTER PHASE-E NDAP'
let s:d[0x16967]='BAMUM LETTER PHASE-E TOON'
let s:d[0x16968]='BAMUM LETTER PHASE-E MBEUM'
let s:d[0x16969]='BAMUM LETTER PHASE-E LAP'
let s:d[0x1696A]='BAMUM LETTER PHASE-E VOM'
let s:d[0x1696B]='BAMUM LETTER PHASE-E LOON'
let s:d[0x1696C]='BAMUM LETTER PHASE-E PAA'
let s:d[0x1696D]='BAMUM LETTER PHASE-E SOM'
let s:d[0x1696E]='BAMUM LETTER PHASE-E RAQ'
let s:d[0x1696F]='BAMUM LETTER PHASE-E NSHUOP'
let s:d[0x16970]='BAMUM LETTER PHASE-E NDUN'
let s:d[0x16971]='BAMUM LETTER PHASE-E PUAE'
let s:d[0x16972]='BAMUM LETTER PHASE-E TAM'
let s:d[0x16973]='BAMUM LETTER PHASE-E NGKA'
let s:d[0x16974]='BAMUM LETTER PHASE-E KPEUX'
let s:d[0x16975]='BAMUM LETTER PHASE-E WUO'
let s:d[0x16976]='BAMUM LETTER PHASE-E SEE'
let s:d[0x16977]='BAMUM LETTER PHASE-E NGGEUAET'
let s:d[0x16978]='BAMUM LETTER PHASE-E PAAM'
let s:d[0x16979]='BAMUM LETTER PHASE-E TOO'
let s:d[0x1697A]='BAMUM LETTER PHASE-E KUOP'
let s:d[0x1697B]='BAMUM LETTER PHASE-E LOM'
let s:d[0x1697C]='BAMUM LETTER PHASE-E NSHIEE'
let s:d[0x1697D]='BAMUM LETTER PHASE-E NGOP'
let s:d[0x1697E]='BAMUM LETTER PHASE-E MAEM'
let s:d[0x1697F]='BAMUM LETTER PHASE-E NGKEUX'
let s:d[0x16980]='BAMUM LETTER PHASE-E NGOQ'
let s:d[0x16981]='BAMUM LETTER PHASE-E NSHUE'
let s:d[0x16982]='BAMUM LETTER PHASE-E RIMGBA'
let s:d[0x16983]='BAMUM LETTER PHASE-E NJEUX'
let s:d[0x16984]='BAMUM LETTER PHASE-E PEEM'
let s:d[0x16985]='BAMUM LETTER PHASE-E SAA'
let s:d[0x16986]='BAMUM LETTER PHASE-E NGGURAE'
let s:d[0x16987]='BAMUM LETTER PHASE-E MGBA'
let s:d[0x16988]='BAMUM LETTER PHASE-E GHEUX'
let s:d[0x16989]='BAMUM LETTER PHASE-E NGKEUAEM'
let s:d[0x1698A]='BAMUM LETTER PHASE-E NJAEMLI'
let s:d[0x1698B]='BAMUM LETTER PHASE-E MAP'
let s:d[0x1698C]='BAMUM LETTER PHASE-E LOOT'
let s:d[0x1698D]='BAMUM LETTER PHASE-E NGGEEEE'
let s:d[0x1698E]='BAMUM LETTER PHASE-E NDIQ'
let s:d[0x1698F]='BAMUM LETTER PHASE-E TAEN NTEUM'
let s:d[0x16990]='BAMUM LETTER PHASE-E SET'
let s:d[0x16991]='BAMUM LETTER PHASE-E PUM'
let s:d[0x16992]='BAMUM LETTER PHASE-E NDAA SOFTNESS'
let s:d[0x16993]='BAMUM LETTER PHASE-E NGGUAESHAE NYAM'
let s:d[0x16994]='BAMUM LETTER PHASE-E YIEE'
let s:d[0x16995]='BAMUM LETTER PHASE-E GHEUN'
let s:d[0x16996]='BAMUM LETTER PHASE-E TUAE'
let s:d[0x16997]='BAMUM LETTER PHASE-E YEUAE'
let s:d[0x16998]='BAMUM LETTER PHASE-E PO'
let s:d[0x16999]='BAMUM LETTER PHASE-E TUMAE'
let s:d[0x1699A]='BAMUM LETTER PHASE-E KEUAE'
let s:d[0x1699B]='BAMUM LETTER PHASE-E SUAEN'
let s:d[0x1699C]='BAMUM LETTER PHASE-E TEUAEQ'
let s:d[0x1699D]='BAMUM LETTER PHASE-E VEUAE'
let s:d[0x1699E]='BAMUM LETTER PHASE-E WEUX'
let s:d[0x1699F]='BAMUM LETTER PHASE-E LAAM'
let s:d[0x169A0]='BAMUM LETTER PHASE-E PU'
let s:d[0x169A1]='BAMUM LETTER PHASE-E TAAQ'
let s:d[0x169A2]='BAMUM LETTER PHASE-E GHAAMAE'
let s:d[0x169A3]='BAMUM LETTER PHASE-E NGEUREUT'
let s:d[0x169A4]='BAMUM LETTER PHASE-E SHEUAEQ'
let s:d[0x169A5]='BAMUM LETTER PHASE-E MGBEN'
let s:d[0x169A6]='BAMUM LETTER PHASE-E MBEE'
let s:d[0x169A7]='BAMUM LETTER PHASE-E NZAQ'
let s:d[0x169A8]='BAMUM LETTER PHASE-E NKOM'
let s:d[0x169A9]='BAMUM LETTER PHASE-E GBET'
let s:d[0x169AA]='BAMUM LETTER PHASE-E TUM'
let s:d[0x169AB]='BAMUM LETTER PHASE-E KUET'
let s:d[0x169AC]='BAMUM LETTER PHASE-E YAP'
let s:d[0x169AD]='BAMUM LETTER PHASE-E NYI CLEAVER'
let s:d[0x169AE]='BAMUM LETTER PHASE-E YIT'
let s:d[0x169AF]='BAMUM LETTER PHASE-E MFEUQ'
let s:d[0x169B0]='BAMUM LETTER PHASE-E NDIAQ'
let s:d[0x169B1]='BAMUM LETTER PHASE-E PIEEQ'
let s:d[0x169B2]='BAMUM LETTER PHASE-E YUEQ'
let s:d[0x169B3]='BAMUM LETTER PHASE-E LEUAEM'
let s:d[0x169B4]='BAMUM LETTER PHASE-E FUE'
let s:d[0x169B5]='BAMUM LETTER PHASE-E GBEUX'
let s:d[0x169B6]='BAMUM LETTER PHASE-E NGKUP'
let s:d[0x169B7]='BAMUM LETTER PHASE-E KET'
let s:d[0x169B8]='BAMUM LETTER PHASE-E MAE'
let s:d[0x169B9]='BAMUM LETTER PHASE-E NGKAAMI'
let s:d[0x169BA]='BAMUM LETTER PHASE-E GHET'
let s:d[0x169BB]='BAMUM LETTER PHASE-E FA'
let s:d[0x169BC]='BAMUM LETTER PHASE-E NTUM'
let s:d[0x169BD]='BAMUM LETTER PHASE-E PEUT'
let s:d[0x169BE]='BAMUM LETTER PHASE-E YEUM'
let s:d[0x169BF]='BAMUM LETTER PHASE-E NGGEUAE'
let s:d[0x169C0]='BAMUM LETTER PHASE-E NYI BETWEEN'
let s:d[0x169C1]='BAMUM LETTER PHASE-E NZUQ'
let s:d[0x169C2]='BAMUM LETTER PHASE-E POON'
let s:d[0x169C3]='BAMUM LETTER PHASE-E MIEE'
let s:d[0x169C4]='BAMUM LETTER PHASE-E FUET'
let s:d[0x169C5]='BAMUM LETTER PHASE-E NAE'
let s:d[0x169C6]='BAMUM LETTER PHASE-E MUAE'
let s:d[0x169C7]='BAMUM LETTER PHASE-E GHEUAE'
let s:d[0x169C8]='BAMUM LETTER PHASE-E FU I'
let s:d[0x169C9]='BAMUM LETTER PHASE-E MVI'
let s:d[0x169CA]='BAMUM LETTER PHASE-E PUAQ'
let s:d[0x169CB]='BAMUM LETTER PHASE-E NGKUM'
let s:d[0x169CC]='BAMUM LETTER PHASE-E KUT'
let s:d[0x169CD]='BAMUM LETTER PHASE-E PIET'
let s:d[0x169CE]='BAMUM LETTER PHASE-E NTAP'
let s:d[0x169CF]='BAMUM LETTER PHASE-E YEUAET'
let s:d[0x169D0]='BAMUM LETTER PHASE-E NGGUP'
let s:d[0x169D1]='BAMUM LETTER PHASE-E PA PEOPLE'
let s:d[0x169D2]='BAMUM LETTER PHASE-E FU CALL'
let s:d[0x169D3]='BAMUM LETTER PHASE-E FOM'
let s:d[0x169D4]='BAMUM LETTER PHASE-E NJEE'
let s:d[0x169D5]='BAMUM LETTER PHASE-E A'
let s:d[0x169D6]='BAMUM LETTER PHASE-E TOQ'
let s:d[0x169D7]='BAMUM LETTER PHASE-E O'
let s:d[0x169D8]='BAMUM LETTER PHASE-E I'
let s:d[0x169D9]='BAMUM LETTER PHASE-E LAQ'
let s:d[0x169DA]='BAMUM LETTER PHASE-E PA PLURAL'
let s:d[0x169DB]='BAMUM LETTER PHASE-E TAA'
let s:d[0x169DC]='BAMUM LETTER PHASE-E TAQ'
let s:d[0x169DD]='BAMUM LETTER PHASE-E NDAA MY HOUSE'
let s:d[0x169DE]='BAMUM LETTER PHASE-E SHIQ'
let s:d[0x169DF]='BAMUM LETTER PHASE-E YEUX'
let s:d[0x169E0]='BAMUM LETTER PHASE-E NGUAE'
let s:d[0x169E1]='BAMUM LETTER PHASE-E YUAEN'
let s:d[0x169E2]='BAMUM LETTER PHASE-E YOQ SWIMMING'
let s:d[0x169E3]='BAMUM LETTER PHASE-E YOQ COVER'
let s:d[0x169E4]='BAMUM LETTER PHASE-E YUQ'
let s:d[0x169E5]='BAMUM LETTER PHASE-E YUN'
let s:d[0x169E6]='BAMUM LETTER PHASE-E KEUX'
let s:d[0x169E7]='BAMUM LETTER PHASE-E PEUX'
let s:d[0x169E8]='BAMUM LETTER PHASE-E NJEE EPOCH'
let s:d[0x169E9]='BAMUM LETTER PHASE-E PUE'
let s:d[0x169EA]='BAMUM LETTER PHASE-E WUE'
let s:d[0x169EB]='BAMUM LETTER PHASE-E FEE'
let s:d[0x169EC]='BAMUM LETTER PHASE-E VEE'
let s:d[0x169ED]='BAMUM LETTER PHASE-E LU'
let s:d[0x169EE]='BAMUM LETTER PHASE-E MI'
let s:d[0x169EF]='BAMUM LETTER PHASE-E REUX'
let s:d[0x169F0]='BAMUM LETTER PHASE-E RAE'
let s:d[0x169F1]='BAMUM LETTER PHASE-E NGUAET'
let s:d[0x169F2]='BAMUM LETTER PHASE-E NGA'
let s:d[0x169F3]='BAMUM LETTER PHASE-E SHO'
let s:d[0x169F4]='BAMUM LETTER PHASE-E SHOQ'
let s:d[0x169F5]='BAMUM LETTER PHASE-E FU REMEDY'
let s:d[0x169F6]='BAMUM LETTER PHASE-E NA'
let s:d[0x169F7]='BAMUM LETTER PHASE-E PI'
let s:d[0x169F8]='BAMUM LETTER PHASE-E LOQ'
let s:d[0x169F9]='BAMUM LETTER PHASE-E KO'
let s:d[0x169FA]='BAMUM LETTER PHASE-E MEN'
let s:d[0x169FB]='BAMUM LETTER PHASE-E MA'
let s:d[0x169FC]='BAMUM LETTER PHASE-E MAQ'
let s:d[0x169FD]='BAMUM LETTER PHASE-E TEU'
let s:d[0x169FE]='BAMUM LETTER PHASE-E KI'
let s:d[0x169FF]='BAMUM LETTER PHASE-E MON'
let s:d[0x16A00]='BAMUM LETTER PHASE-E TEN'
let s:d[0x16A01]='BAMUM LETTER PHASE-E FAQ'
let s:d[0x16A02]='BAMUM LETTER PHASE-E GHOM'
let s:d[0x16A03]='BAMUM LETTER PHASE-F KA'
let s:d[0x16A04]='BAMUM LETTER PHASE-F U'
let s:d[0x16A05]='BAMUM LETTER PHASE-F KU'
let s:d[0x16A06]='BAMUM LETTER PHASE-F EE'
let s:d[0x16A07]='BAMUM LETTER PHASE-F REE'
let s:d[0x16A08]='BAMUM LETTER PHASE-F TAE'
let s:d[0x16A09]='BAMUM LETTER PHASE-F NYI'
let s:d[0x16A0A]='BAMUM LETTER PHASE-F LA'
let s:d[0x16A0B]='BAMUM LETTER PHASE-F RII'
let s:d[0x16A0C]='BAMUM LETTER PHASE-F RIEE'
let s:d[0x16A0D]='BAMUM LETTER PHASE-F MEEEE'
let s:d[0x16A0E]='BAMUM LETTER PHASE-F TAA'
let s:d[0x16A0F]='BAMUM LETTER PHASE-F NDAA'
let s:d[0x16A10]='BAMUM LETTER PHASE-F NJAEM'
let s:d[0x16A11]='BAMUM LETTER PHASE-F M'
let s:d[0x16A12]='BAMUM LETTER PHASE-F SUU'
let s:d[0x16A13]='BAMUM LETTER PHASE-F SHII'
let s:d[0x16A14]='BAMUM LETTER PHASE-F SI'
let s:d[0x16A15]='BAMUM LETTER PHASE-F SEUX'
let s:d[0x16A16]='BAMUM LETTER PHASE-F KYEE'
let s:d[0x16A17]='BAMUM LETTER PHASE-F KET'
let s:d[0x16A18]='BAMUM LETTER PHASE-F NUAE'
let s:d[0x16A19]='BAMUM LETTER PHASE-F NU'
let s:d[0x16A1A]='BAMUM LETTER PHASE-F NJUAE'
let s:d[0x16A1B]='BAMUM LETTER PHASE-F YOQ'
let s:d[0x16A1C]='BAMUM LETTER PHASE-F SHU'
let s:d[0x16A1D]='BAMUM LETTER PHASE-F YA'
let s:d[0x16A1E]='BAMUM LETTER PHASE-F NSHA'
let s:d[0x16A1F]='BAMUM LETTER PHASE-F PEUX'
let s:d[0x16A20]='BAMUM LETTER PHASE-F NTEE'
let s:d[0x16A21]='BAMUM LETTER PHASE-F WUE'
let s:d[0x16A22]='BAMUM LETTER PHASE-F PEE'
let s:d[0x16A23]='BAMUM LETTER PHASE-F RU'
let s:d[0x16A24]='BAMUM LETTER PHASE-F NI'
let s:d[0x16A25]='BAMUM LETTER PHASE-F REUX'
let s:d[0x16A26]='BAMUM LETTER PHASE-F KEN'
let s:d[0x16A27]='BAMUM LETTER PHASE-F NGKWAEN'
let s:d[0x16A28]='BAMUM LETTER PHASE-F NGGA'
let s:d[0x16A29]='BAMUM LETTER PHASE-F SHO'
let s:d[0x16A2A]='BAMUM LETTER PHASE-F PUAE'
let s:d[0x16A2B]='BAMUM LETTER PHASE-F FOM'
let s:d[0x16A2C]='BAMUM LETTER PHASE-F WA'
let s:d[0x16A2D]='BAMUM LETTER PHASE-F LI'
let s:d[0x16A2E]='BAMUM LETTER PHASE-F LOQ'
let s:d[0x16A2F]='BAMUM LETTER PHASE-F KO'
let s:d[0x16A30]='BAMUM LETTER PHASE-F MBEN'
let s:d[0x16A31]='BAMUM LETTER PHASE-F REN'
let s:d[0x16A32]='BAMUM LETTER PHASE-F MA'
let s:d[0x16A33]='BAMUM LETTER PHASE-F MO'
let s:d[0x16A34]='BAMUM LETTER PHASE-F MBAA'
let s:d[0x16A35]='BAMUM LETTER PHASE-F TET'
let s:d[0x16A36]='BAMUM LETTER PHASE-F KPA'
let s:d[0x16A37]='BAMUM LETTER PHASE-F SAMBA'
let s:d[0x16A38]='BAMUM LETTER PHASE-F VUEQ'
let s:d[0x16F00]='MIAO LETTER PA'
let s:d[0x16F01]='MIAO LETTER BA'
let s:d[0x16F02]='MIAO LETTER YI PA'
let s:d[0x16F03]='MIAO LETTER PLA'
let s:d[0x16F04]='MIAO LETTER MA'
let s:d[0x16F05]='MIAO LETTER MHA'
let s:d[0x16F06]='MIAO LETTER ARCHAIC MA'
let s:d[0x16F07]='MIAO LETTER FA'
let s:d[0x16F08]='MIAO LETTER VA'
let s:d[0x16F09]='MIAO LETTER VFA'
let s:d[0x16F0A]='MIAO LETTER TA'
let s:d[0x16F0B]='MIAO LETTER DA'
let s:d[0x16F0C]='MIAO LETTER YI TTA'
let s:d[0x16F0D]='MIAO LETTER YI TA'
let s:d[0x16F0E]='MIAO LETTER TTA'
let s:d[0x16F0F]='MIAO LETTER DDA'
let s:d[0x16F10]='MIAO LETTER NA'
let s:d[0x16F11]='MIAO LETTER NHA'
let s:d[0x16F12]='MIAO LETTER YI NNA'
let s:d[0x16F13]='MIAO LETTER ARCHAIC NA'
let s:d[0x16F14]='MIAO LETTER NNA'
let s:d[0x16F15]='MIAO LETTER NNHA'
let s:d[0x16F16]='MIAO LETTER LA'
let s:d[0x16F17]='MIAO LETTER LYA'
let s:d[0x16F18]='MIAO LETTER LHA'
let s:d[0x16F19]='MIAO LETTER LHYA'
let s:d[0x16F1A]='MIAO LETTER TLHA'
let s:d[0x16F1B]='MIAO LETTER DLHA'
let s:d[0x16F1C]='MIAO LETTER TLHYA'
let s:d[0x16F1D]='MIAO LETTER DLHYA'
let s:d[0x16F1E]='MIAO LETTER KA'
let s:d[0x16F1F]='MIAO LETTER GA'
let s:d[0x16F20]='MIAO LETTER YI KA'
let s:d[0x16F21]='MIAO LETTER QA'
let s:d[0x16F22]='MIAO LETTER QGA'
let s:d[0x16F23]='MIAO LETTER NGA'
let s:d[0x16F24]='MIAO LETTER NGHA'
let s:d[0x16F25]='MIAO LETTER ARCHAIC NGA'
let s:d[0x16F26]='MIAO LETTER HA'
let s:d[0x16F27]='MIAO LETTER XA'
let s:d[0x16F28]='MIAO LETTER GHA'
let s:d[0x16F29]='MIAO LETTER GHHA'
let s:d[0x16F2A]='MIAO LETTER TSSA'
let s:d[0x16F2B]='MIAO LETTER DZZA'
let s:d[0x16F2C]='MIAO LETTER NYA'
let s:d[0x16F2D]='MIAO LETTER NYHA'
let s:d[0x16F2E]='MIAO LETTER TSHA'
let s:d[0x16F2F]='MIAO LETTER DZHA'
let s:d[0x16F30]='MIAO LETTER YI TSHA'
let s:d[0x16F31]='MIAO LETTER YI DZHA'
let s:d[0x16F32]='MIAO LETTER REFORMED TSHA'
let s:d[0x16F33]='MIAO LETTER SHA'
let s:d[0x16F34]='MIAO LETTER SSA'
let s:d[0x16F35]='MIAO LETTER ZHA'
let s:d[0x16F36]='MIAO LETTER ZSHA'
let s:d[0x16F37]='MIAO LETTER TSA'
let s:d[0x16F38]='MIAO LETTER DZA'
let s:d[0x16F39]='MIAO LETTER YI TSA'
let s:d[0x16F3A]='MIAO LETTER SA'
let s:d[0x16F3B]='MIAO LETTER ZA'
let s:d[0x16F3C]='MIAO LETTER ZSA'
let s:d[0x16F3D]='MIAO LETTER ZZA'
let s:d[0x16F3E]='MIAO LETTER ZZSA'
let s:d[0x16F3F]='MIAO LETTER ARCHAIC ZZA'
let s:d[0x16F40]='MIAO LETTER ZZYA'
let s:d[0x16F41]='MIAO LETTER ZZSYA'
let s:d[0x16F42]='MIAO LETTER WA'
let s:d[0x16F43]='MIAO LETTER AH'
let s:d[0x16F44]='MIAO LETTER HHA'
let s:d[0x16F50]='MIAO LETTER NASALIZATION'
let s:d[0x16F51]='MIAO SIGN ASPIRATION'
let s:d[0x16F52]='MIAO SIGN REFORMED VOICING'
let s:d[0x16F53]='MIAO SIGN REFORMED ASPIRATION'
let s:d[0x16F54]='MIAO VOWEL SIGN A'
let s:d[0x16F55]='MIAO VOWEL SIGN AA'
let s:d[0x16F56]='MIAO VOWEL SIGN AHH'
let s:d[0x16F57]='MIAO VOWEL SIGN AN'
let s:d[0x16F58]='MIAO VOWEL SIGN ANG'
let s:d[0x16F59]='MIAO VOWEL SIGN O'
let s:d[0x16F5A]='MIAO VOWEL SIGN OO'
let s:d[0x16F5B]='MIAO VOWEL SIGN WO'
let s:d[0x16F5C]='MIAO VOWEL SIGN W'
let s:d[0x16F5D]='MIAO VOWEL SIGN E'
let s:d[0x16F5E]='MIAO VOWEL SIGN EN'
let s:d[0x16F5F]='MIAO VOWEL SIGN ENG'
let s:d[0x16F60]='MIAO VOWEL SIGN OEY'
let s:d[0x16F61]='MIAO VOWEL SIGN I'
let s:d[0x16F62]='MIAO VOWEL SIGN IA'
let s:d[0x16F63]='MIAO VOWEL SIGN IAN'
let s:d[0x16F64]='MIAO VOWEL SIGN IANG'
let s:d[0x16F65]='MIAO VOWEL SIGN IO'
let s:d[0x16F66]='MIAO VOWEL SIGN IE'
let s:d[0x16F67]='MIAO VOWEL SIGN II'
let s:d[0x16F68]='MIAO VOWEL SIGN IU'
let s:d[0x16F69]='MIAO VOWEL SIGN ING'
let s:d[0x16F6A]='MIAO VOWEL SIGN U'
let s:d[0x16F6B]='MIAO VOWEL SIGN UA'
let s:d[0x16F6C]='MIAO VOWEL SIGN UAN'
let s:d[0x16F6D]='MIAO VOWEL SIGN UANG'
let s:d[0x16F6E]='MIAO VOWEL SIGN UU'
let s:d[0x16F6F]='MIAO VOWEL SIGN UEI'
let s:d[0x16F70]='MIAO VOWEL SIGN UNG'
let s:d[0x16F71]='MIAO VOWEL SIGN Y'
let s:d[0x16F72]='MIAO VOWEL SIGN YI'
let s:d[0x16F73]='MIAO VOWEL SIGN AE'
let s:d[0x16F74]='MIAO VOWEL SIGN AEE'
let s:d[0x16F75]='MIAO VOWEL SIGN ERR'
let s:d[0x16F76]='MIAO VOWEL SIGN ROUNDED ERR'
let s:d[0x16F77]='MIAO VOWEL SIGN ER'
let s:d[0x16F78]='MIAO VOWEL SIGN ROUNDED ER'
let s:d[0x16F79]='MIAO VOWEL SIGN AI'
let s:d[0x16F7A]='MIAO VOWEL SIGN EI'
let s:d[0x16F7B]='MIAO VOWEL SIGN AU'
let s:d[0x16F7C]='MIAO VOWEL SIGN OU'
let s:d[0x16F7D]='MIAO VOWEL SIGN N'
let s:d[0x16F7E]='MIAO VOWEL SIGN NG'
let s:d[0x16F8F]='MIAO TONE RIGHT'
let s:d[0x16F90]='MIAO TONE TOP RIGHT'
let s:d[0x16F91]='MIAO TONE ABOVE'
let s:d[0x16F92]='MIAO TONE BELOW'
let s:d[0x16F93]='MIAO LETTER TONE-2'
let s:d[0x16F94]='MIAO LETTER TONE-3'
let s:d[0x16F95]='MIAO LETTER TONE-4'
let s:d[0x16F96]='MIAO LETTER TONE-5'
let s:d[0x16F97]='MIAO LETTER TONE-6'
let s:d[0x16F98]='MIAO LETTER TONE-7'
let s:d[0x16F99]='MIAO LETTER TONE-8'
let s:d[0x16F9A]='MIAO LETTER REFORMED TONE-1'
let s:d[0x16F9B]='MIAO LETTER REFORMED TONE-2'
let s:d[0x16F9C]='MIAO LETTER REFORMED TONE-4'
let s:d[0x16F9D]='MIAO LETTER REFORMED TONE-5'
let s:d[0x16F9E]='MIAO LETTER REFORMED TONE-6'
let s:d[0x16F9F]='MIAO LETTER REFORMED TONE-8'
let s:d[0x1B000]='KATAKANA LETTER ARCHAIC E'
let s:d[0x1B001]='HIRAGANA LETTER ARCHAIC YE'
let s:d[0x1D000]='BYZANTINE MUSICAL SYMBOL PSILI'
let s:d[0x1D001]='BYZANTINE MUSICAL SYMBOL DASEIA'
let s:d[0x1D002]='BYZANTINE MUSICAL SYMBOL PERISPOMENI'
let s:d[0x1D003]='BYZANTINE MUSICAL SYMBOL OXEIA EKFONITIKON'
let s:d[0x1D004]='BYZANTINE MUSICAL SYMBOL OXEIA DIPLI'
let s:d[0x1D005]='BYZANTINE MUSICAL SYMBOL VAREIA EKFONITIKON'
let s:d[0x1D006]='BYZANTINE MUSICAL SYMBOL VAREIA DIPLI'
let s:d[0x1D007]='BYZANTINE MUSICAL SYMBOL KATHISTI'
let s:d[0x1D008]='BYZANTINE MUSICAL SYMBOL SYRMATIKI'
let s:d[0x1D009]='BYZANTINE MUSICAL SYMBOL PARAKLITIKI'
let s:d[0x1D00A]='BYZANTINE MUSICAL SYMBOL YPOKRISIS'
let s:d[0x1D00B]='BYZANTINE MUSICAL SYMBOL YPOKRISIS DIPLI'
let s:d[0x1D00C]='BYZANTINE MUSICAL SYMBOL KREMASTI'
let s:d[0x1D00D]='BYZANTINE MUSICAL SYMBOL APESO EKFONITIKON'
let s:d[0x1D00E]='BYZANTINE MUSICAL SYMBOL EXO EKFONITIKON'
let s:d[0x1D00F]='BYZANTINE MUSICAL SYMBOL TELEIA'
let s:d[0x1D010]='BYZANTINE MUSICAL SYMBOL KENTIMATA'
let s:d[0x1D011]='BYZANTINE MUSICAL SYMBOL APOSTROFOS'
let s:d[0x1D012]='BYZANTINE MUSICAL SYMBOL APOSTROFOS DIPLI'
let s:d[0x1D013]='BYZANTINE MUSICAL SYMBOL SYNEVMA'
let s:d[0x1D014]='BYZANTINE MUSICAL SYMBOL THITA'
let s:d[0x1D015]='BYZANTINE MUSICAL SYMBOL OLIGON ARCHAION'
let s:d[0x1D016]='BYZANTINE MUSICAL SYMBOL GORGON ARCHAION'
let s:d[0x1D017]='BYZANTINE MUSICAL SYMBOL PSILON'
let s:d[0x1D018]='BYZANTINE MUSICAL SYMBOL CHAMILON'
let s:d[0x1D019]='BYZANTINE MUSICAL SYMBOL VATHY'
let s:d[0x1D01A]='BYZANTINE MUSICAL SYMBOL ISON ARCHAION'
let s:d[0x1D01B]='BYZANTINE MUSICAL SYMBOL KENTIMA ARCHAION'
let s:d[0x1D01C]='BYZANTINE MUSICAL SYMBOL KENTIMATA ARCHAION'
let s:d[0x1D01D]='BYZANTINE MUSICAL SYMBOL SAXIMATA'
let s:d[0x1D01E]='BYZANTINE MUSICAL SYMBOL PARICHON'
let s:d[0x1D01F]='BYZANTINE MUSICAL SYMBOL STAVROS APODEXIA'
let s:d[0x1D020]='BYZANTINE MUSICAL SYMBOL OXEIAI ARCHAION'
let s:d[0x1D021]='BYZANTINE MUSICAL SYMBOL VAREIAI ARCHAION'
let s:d[0x1D022]='BYZANTINE MUSICAL SYMBOL APODERMA ARCHAION'
let s:d[0x1D023]='BYZANTINE MUSICAL SYMBOL APOTHEMA'
let s:d[0x1D024]='BYZANTINE MUSICAL SYMBOL KLASMA'
let s:d[0x1D025]='BYZANTINE MUSICAL SYMBOL REVMA'
let s:d[0x1D026]='BYZANTINE MUSICAL SYMBOL PIASMA ARCHAION'
let s:d[0x1D027]='BYZANTINE MUSICAL SYMBOL TINAGMA'
let s:d[0x1D028]='BYZANTINE MUSICAL SYMBOL ANATRICHISMA'
let s:d[0x1D029]='BYZANTINE MUSICAL SYMBOL SEISMA'
let s:d[0x1D02A]='BYZANTINE MUSICAL SYMBOL SYNAGMA ARCHAION'
let s:d[0x1D02B]='BYZANTINE MUSICAL SYMBOL SYNAGMA META STAVROU'
let s:d[0x1D02C]='BYZANTINE MUSICAL SYMBOL OYRANISMA ARCHAION'
let s:d[0x1D02D]='BYZANTINE MUSICAL SYMBOL THEMA'
let s:d[0x1D02E]='BYZANTINE MUSICAL SYMBOL LEMOI'
let s:d[0x1D02F]='BYZANTINE MUSICAL SYMBOL DYO'
let s:d[0x1D030]='BYZANTINE MUSICAL SYMBOL TRIA'
let s:d[0x1D031]='BYZANTINE MUSICAL SYMBOL TESSERA'
let s:d[0x1D032]='BYZANTINE MUSICAL SYMBOL KRATIMATA'
let s:d[0x1D033]='BYZANTINE MUSICAL SYMBOL APESO EXO NEO'
let s:d[0x1D034]='BYZANTINE MUSICAL SYMBOL FTHORA ARCHAION'
let s:d[0x1D035]='BYZANTINE MUSICAL SYMBOL IMIFTHORA'
let s:d[0x1D036]='BYZANTINE MUSICAL SYMBOL TROMIKON ARCHAION'
let s:d[0x1D037]='BYZANTINE MUSICAL SYMBOL KATAVA TROMIKON'
let s:d[0x1D038]='BYZANTINE MUSICAL SYMBOL PELASTON'
let s:d[0x1D039]='BYZANTINE MUSICAL SYMBOL PSIFISTON'
let s:d[0x1D03A]='BYZANTINE MUSICAL SYMBOL KONTEVMA'
let s:d[0x1D03B]='BYZANTINE MUSICAL SYMBOL CHOREVMA ARCHAION'
let s:d[0x1D03C]='BYZANTINE MUSICAL SYMBOL RAPISMA'
let s:d[0x1D03D]='BYZANTINE MUSICAL SYMBOL PARAKALESMA ARCHAION'
let s:d[0x1D03E]='BYZANTINE MUSICAL SYMBOL PARAKLITIKI ARCHAION'
let s:d[0x1D03F]='BYZANTINE MUSICAL SYMBOL ICHADIN'
let s:d[0x1D040]='BYZANTINE MUSICAL SYMBOL NANA'
let s:d[0x1D041]='BYZANTINE MUSICAL SYMBOL PETASMA'
let s:d[0x1D042]='BYZANTINE MUSICAL SYMBOL KONTEVMA ALLO'
let s:d[0x1D043]='BYZANTINE MUSICAL SYMBOL TROMIKON ALLO'
let s:d[0x1D044]='BYZANTINE MUSICAL SYMBOL STRAGGISMATA'
let s:d[0x1D045]='BYZANTINE MUSICAL SYMBOL GRONTHISMATA'
let s:d[0x1D046]='BYZANTINE MUSICAL SYMBOL ISON NEO'
let s:d[0x1D047]='BYZANTINE MUSICAL SYMBOL OLIGON NEO'
let s:d[0x1D048]='BYZANTINE MUSICAL SYMBOL OXEIA NEO'
let s:d[0x1D049]='BYZANTINE MUSICAL SYMBOL PETASTI'
let s:d[0x1D04A]='BYZANTINE MUSICAL SYMBOL KOUFISMA'
let s:d[0x1D04B]='BYZANTINE MUSICAL SYMBOL PETASTOKOUFISMA'
let s:d[0x1D04C]='BYZANTINE MUSICAL SYMBOL KRATIMOKOUFISMA'
let s:d[0x1D04D]='BYZANTINE MUSICAL SYMBOL PELASTON NEO'
let s:d[0x1D04E]='BYZANTINE MUSICAL SYMBOL KENTIMATA NEO ANO'
let s:d[0x1D04F]='BYZANTINE MUSICAL SYMBOL KENTIMA NEO ANO'
let s:d[0x1D050]='BYZANTINE MUSICAL SYMBOL YPSILI'
let s:d[0x1D051]='BYZANTINE MUSICAL SYMBOL APOSTROFOS NEO'
let s:d[0x1D052]='BYZANTINE MUSICAL SYMBOL APOSTROFOI SYNDESMOS NEO'
let s:d[0x1D053]='BYZANTINE MUSICAL SYMBOL YPORROI'
let s:d[0x1D054]='BYZANTINE MUSICAL SYMBOL KRATIMOYPORROON'
let s:d[0x1D055]='BYZANTINE MUSICAL SYMBOL ELAFRON'
let s:d[0x1D056]='BYZANTINE MUSICAL SYMBOL CHAMILI'
let s:d[0x1D057]='BYZANTINE MUSICAL SYMBOL MIKRON ISON'
let s:d[0x1D058]='BYZANTINE MUSICAL SYMBOL VAREIA NEO'
let s:d[0x1D059]='BYZANTINE MUSICAL SYMBOL PIASMA NEO'
let s:d[0x1D05A]='BYZANTINE MUSICAL SYMBOL PSIFISTON NEO'
let s:d[0x1D05B]='BYZANTINE MUSICAL SYMBOL OMALON'
let s:d[0x1D05C]='BYZANTINE MUSICAL SYMBOL ANTIKENOMA'
let s:d[0x1D05D]='BYZANTINE MUSICAL SYMBOL LYGISMA'
let s:d[0x1D05E]='BYZANTINE MUSICAL SYMBOL PARAKLITIKI NEO'
let s:d[0x1D05F]='BYZANTINE MUSICAL SYMBOL PARAKALESMA NEO'
let s:d[0x1D060]='BYZANTINE MUSICAL SYMBOL ETERON PARAKALESMA'
let s:d[0x1D061]='BYZANTINE MUSICAL SYMBOL KYLISMA'
let s:d[0x1D062]='BYZANTINE MUSICAL SYMBOL ANTIKENOKYLISMA'
let s:d[0x1D063]='BYZANTINE MUSICAL SYMBOL TROMIKON NEO'
let s:d[0x1D064]='BYZANTINE MUSICAL SYMBOL EKSTREPTON'
let s:d[0x1D065]='BYZANTINE MUSICAL SYMBOL SYNAGMA NEO'
let s:d[0x1D066]='BYZANTINE MUSICAL SYMBOL SYRMA'
let s:d[0x1D067]='BYZANTINE MUSICAL SYMBOL CHOREVMA NEO'
let s:d[0x1D068]='BYZANTINE MUSICAL SYMBOL EPEGERMA'
let s:d[0x1D069]='BYZANTINE MUSICAL SYMBOL SEISMA NEO'
let s:d[0x1D06A]='BYZANTINE MUSICAL SYMBOL XIRON KLASMA'
let s:d[0x1D06B]='BYZANTINE MUSICAL SYMBOL TROMIKOPSIFISTON'
let s:d[0x1D06C]='BYZANTINE MUSICAL SYMBOL PSIFISTOLYGISMA'
let s:d[0x1D06D]='BYZANTINE MUSICAL SYMBOL TROMIKOLYGISMA'
let s:d[0x1D06E]='BYZANTINE MUSICAL SYMBOL TROMIKOPARAKALESMA'
let s:d[0x1D06F]='BYZANTINE MUSICAL SYMBOL PSIFISTOPARAKALESMA'
let s:d[0x1D070]='BYZANTINE MUSICAL SYMBOL TROMIKOSYNAGMA'
let s:d[0x1D071]='BYZANTINE MUSICAL SYMBOL PSIFISTOSYNAGMA'
let s:d[0x1D072]='BYZANTINE MUSICAL SYMBOL GORGOSYNTHETON'
let s:d[0x1D073]='BYZANTINE MUSICAL SYMBOL ARGOSYNTHETON'
let s:d[0x1D074]='BYZANTINE MUSICAL SYMBOL ETERON ARGOSYNTHETON'
let s:d[0x1D075]='BYZANTINE MUSICAL SYMBOL OYRANISMA NEO'
let s:d[0x1D076]='BYZANTINE MUSICAL SYMBOL THEMATISMOS ESO'
let s:d[0x1D077]='BYZANTINE MUSICAL SYMBOL THEMATISMOS EXO'
let s:d[0x1D078]='BYZANTINE MUSICAL SYMBOL THEMA APLOUN'
let s:d[0x1D079]='BYZANTINE MUSICAL SYMBOL THES KAI APOTHES'
let s:d[0x1D07A]='BYZANTINE MUSICAL SYMBOL KATAVASMA'
let s:d[0x1D07B]='BYZANTINE MUSICAL SYMBOL ENDOFONON'
let s:d[0x1D07C]='BYZANTINE MUSICAL SYMBOL YFEN KATO'
let s:d[0x1D07D]='BYZANTINE MUSICAL SYMBOL YFEN ANO'
let s:d[0x1D07E]='BYZANTINE MUSICAL SYMBOL STAVROS'
let s:d[0x1D07F]='BYZANTINE MUSICAL SYMBOL KLASMA ANO'
let s:d[0x1D080]='BYZANTINE MUSICAL SYMBOL DIPLI ARCHAION'
let s:d[0x1D081]='BYZANTINE MUSICAL SYMBOL KRATIMA ARCHAION'
let s:d[0x1D082]='BYZANTINE MUSICAL SYMBOL KRATIMA ALLO'
let s:d[0x1D083]='BYZANTINE MUSICAL SYMBOL KRATIMA NEO'
let s:d[0x1D084]='BYZANTINE MUSICAL SYMBOL APODERMA NEO'
let s:d[0x1D085]='BYZANTINE MUSICAL SYMBOL APLI'
let s:d[0x1D086]='BYZANTINE MUSICAL SYMBOL DIPLI'
let s:d[0x1D087]='BYZANTINE MUSICAL SYMBOL TRIPLI'
let s:d[0x1D088]='BYZANTINE MUSICAL SYMBOL TETRAPLI'
let s:d[0x1D089]='BYZANTINE MUSICAL SYMBOL KORONIS'
let s:d[0x1D08A]='BYZANTINE MUSICAL SYMBOL LEIMMA ENOS CHRONOU'
let s:d[0x1D08B]='BYZANTINE MUSICAL SYMBOL LEIMMA DYO CHRONON'
let s:d[0x1D08C]='BYZANTINE MUSICAL SYMBOL LEIMMA TRION CHRONON'
let s:d[0x1D08D]='BYZANTINE MUSICAL SYMBOL LEIMMA TESSARON CHRONON'
let s:d[0x1D08E]='BYZANTINE MUSICAL SYMBOL LEIMMA IMISEOS CHRONOU'
let s:d[0x1D08F]='BYZANTINE MUSICAL SYMBOL GORGON NEO ANO'
let s:d[0x1D090]='BYZANTINE MUSICAL SYMBOL GORGON PARESTIGMENON ARISTERA'
let s:d[0x1D091]='BYZANTINE MUSICAL SYMBOL GORGON PARESTIGMENON DEXIA'
let s:d[0x1D092]='BYZANTINE MUSICAL SYMBOL DIGORGON'
let s:d[0x1D093]='BYZANTINE MUSICAL SYMBOL DIGORGON PARESTIGMENON ARISTERA KATO'
let s:d[0x1D094]='BYZANTINE MUSICAL SYMBOL DIGORGON PARESTIGMENON ARISTERA ANO'
let s:d[0x1D095]='BYZANTINE MUSICAL SYMBOL DIGORGON PARESTIGMENON DEXIA'
let s:d[0x1D096]='BYZANTINE MUSICAL SYMBOL TRIGORGON'
let s:d[0x1D097]='BYZANTINE MUSICAL SYMBOL ARGON'
let s:d[0x1D098]='BYZANTINE MUSICAL SYMBOL IMIDIARGON'
let s:d[0x1D099]='BYZANTINE MUSICAL SYMBOL DIARGON'
let s:d[0x1D09A]='BYZANTINE MUSICAL SYMBOL AGOGI POLI ARGI'
let s:d[0x1D09B]='BYZANTINE MUSICAL SYMBOL AGOGI ARGOTERI'
let s:d[0x1D09C]='BYZANTINE MUSICAL SYMBOL AGOGI ARGI'
let s:d[0x1D09D]='BYZANTINE MUSICAL SYMBOL AGOGI METRIA'
let s:d[0x1D09E]='BYZANTINE MUSICAL SYMBOL AGOGI MESI'
let s:d[0x1D09F]='BYZANTINE MUSICAL SYMBOL AGOGI GORGI'
let s:d[0x1D0A0]='BYZANTINE MUSICAL SYMBOL AGOGI GORGOTERI'
let s:d[0x1D0A1]='BYZANTINE MUSICAL SYMBOL AGOGI POLI GORGI'
let s:d[0x1D0A2]='BYZANTINE MUSICAL SYMBOL MARTYRIA PROTOS ICHOS'
let s:d[0x1D0A3]='BYZANTINE MUSICAL SYMBOL MARTYRIA ALLI PROTOS ICHOS'
let s:d[0x1D0A4]='BYZANTINE MUSICAL SYMBOL MARTYRIA DEYTEROS ICHOS'
let s:d[0x1D0A5]='BYZANTINE MUSICAL SYMBOL MARTYRIA ALLI DEYTEROS ICHOS'
let s:d[0x1D0A6]='BYZANTINE MUSICAL SYMBOL MARTYRIA TRITOS ICHOS'
let s:d[0x1D0A7]='BYZANTINE MUSICAL SYMBOL MARTYRIA TRIFONIAS'
let s:d[0x1D0A8]='BYZANTINE MUSICAL SYMBOL MARTYRIA TETARTOS ICHOS'
let s:d[0x1D0A9]='BYZANTINE MUSICAL SYMBOL MARTYRIA TETARTOS LEGETOS ICHOS'
let s:d[0x1D0AA]='BYZANTINE MUSICAL SYMBOL MARTYRIA LEGETOS ICHOS'
let s:d[0x1D0AB]='BYZANTINE MUSICAL SYMBOL MARTYRIA PLAGIOS ICHOS'
let s:d[0x1D0AC]='BYZANTINE MUSICAL SYMBOL ISAKIA TELOUS ICHIMATOS'
let s:d[0x1D0AD]='BYZANTINE MUSICAL SYMBOL APOSTROFOI TELOUS ICHIMATOS'
let s:d[0x1D0AE]='BYZANTINE MUSICAL SYMBOL FANEROSIS TETRAFONIAS'
let s:d[0x1D0AF]='BYZANTINE MUSICAL SYMBOL FANEROSIS MONOFONIAS'
let s:d[0x1D0B0]='BYZANTINE MUSICAL SYMBOL FANEROSIS DIFONIAS'
let s:d[0x1D0B1]='BYZANTINE MUSICAL SYMBOL MARTYRIA VARYS ICHOS'
let s:d[0x1D0B2]='BYZANTINE MUSICAL SYMBOL MARTYRIA PROTOVARYS ICHOS'
let s:d[0x1D0B3]='BYZANTINE MUSICAL SYMBOL MARTYRIA PLAGIOS TETARTOS ICHOS'
let s:d[0x1D0B4]='BYZANTINE MUSICAL SYMBOL GORTHMIKON N APLOUN'
let s:d[0x1D0B5]='BYZANTINE MUSICAL SYMBOL GORTHMIKON N DIPLOUN'
let s:d[0x1D0B6]='BYZANTINE MUSICAL SYMBOL ENARXIS KAI FTHORA VOU'
let s:d[0x1D0B7]='BYZANTINE MUSICAL SYMBOL IMIFONON'
let s:d[0x1D0B8]='BYZANTINE MUSICAL SYMBOL IMIFTHORON'
let s:d[0x1D0B9]='BYZANTINE MUSICAL SYMBOL FTHORA ARCHAION DEYTEROU ICHOU'
let s:d[0x1D0BA]='BYZANTINE MUSICAL SYMBOL FTHORA DIATONIKI PA'
let s:d[0x1D0BB]='BYZANTINE MUSICAL SYMBOL FTHORA DIATONIKI NANA'
let s:d[0x1D0BC]='BYZANTINE MUSICAL SYMBOL FTHORA NAOS ICHOS'
let s:d[0x1D0BD]='BYZANTINE MUSICAL SYMBOL FTHORA DIATONIKI DI'
let s:d[0x1D0BE]='BYZANTINE MUSICAL SYMBOL FTHORA SKLIRON DIATONON DI'
let s:d[0x1D0BF]='BYZANTINE MUSICAL SYMBOL FTHORA DIATONIKI KE'
let s:d[0x1D0C0]='BYZANTINE MUSICAL SYMBOL FTHORA DIATONIKI ZO'
let s:d[0x1D0C1]='BYZANTINE MUSICAL SYMBOL FTHORA DIATONIKI NI KATO'
let s:d[0x1D0C2]='BYZANTINE MUSICAL SYMBOL FTHORA DIATONIKI NI ANO'
let s:d[0x1D0C3]='BYZANTINE MUSICAL SYMBOL FTHORA MALAKON CHROMA DIFONIAS'
let s:d[0x1D0C4]='BYZANTINE MUSICAL SYMBOL FTHORA MALAKON CHROMA MONOFONIAS'
let s:d[0x1D0C5]='BYZANTINE MUSICAL SYMBOL FHTORA SKLIRON CHROMA VASIS'
let s:d[0x1D0C6]='BYZANTINE MUSICAL SYMBOL FTHORA SKLIRON CHROMA SYNAFI'
let s:d[0x1D0C7]='BYZANTINE MUSICAL SYMBOL FTHORA NENANO'
let s:d[0x1D0C8]='BYZANTINE MUSICAL SYMBOL CHROA ZYGOS'
let s:d[0x1D0C9]='BYZANTINE MUSICAL SYMBOL CHROA KLITON'
let s:d[0x1D0CA]='BYZANTINE MUSICAL SYMBOL CHROA SPATHI'
let s:d[0x1D0CB]='BYZANTINE MUSICAL SYMBOL FTHORA I YFESIS TETARTIMORION'
let s:d[0x1D0CC]='BYZANTINE MUSICAL SYMBOL FTHORA ENARMONIOS ANTIFONIA'
let s:d[0x1D0CD]='BYZANTINE MUSICAL SYMBOL YFESIS TRITIMORION'
let s:d[0x1D0CE]='BYZANTINE MUSICAL SYMBOL DIESIS TRITIMORION'
let s:d[0x1D0CF]='BYZANTINE MUSICAL SYMBOL DIESIS TETARTIMORION'
let s:d[0x1D0D0]='BYZANTINE MUSICAL SYMBOL DIESIS APLI DYO DODEKATA'
let s:d[0x1D0D1]='BYZANTINE MUSICAL SYMBOL DIESIS MONOGRAMMOS TESSERA DODEKATA'
let s:d[0x1D0D2]='BYZANTINE MUSICAL SYMBOL DIESIS DIGRAMMOS EX DODEKATA'
let s:d[0x1D0D3]='BYZANTINE MUSICAL SYMBOL DIESIS TRIGRAMMOS OKTO DODEKATA'
let s:d[0x1D0D4]='BYZANTINE MUSICAL SYMBOL YFESIS APLI DYO DODEKATA'
let s:d[0x1D0D5]='BYZANTINE MUSICAL SYMBOL YFESIS MONOGRAMMOS TESSERA DODEKATA'
let s:d[0x1D0D6]='BYZANTINE MUSICAL SYMBOL YFESIS DIGRAMMOS EX DODEKATA'
let s:d[0x1D0D7]='BYZANTINE MUSICAL SYMBOL YFESIS TRIGRAMMOS OKTO DODEKATA'
let s:d[0x1D0D8]='BYZANTINE MUSICAL SYMBOL GENIKI DIESIS'
let s:d[0x1D0D9]='BYZANTINE MUSICAL SYMBOL GENIKI YFESIS'
let s:d[0x1D0DA]='BYZANTINE MUSICAL SYMBOL DIASTOLI APLI MIKRI'
let s:d[0x1D0DB]='BYZANTINE MUSICAL SYMBOL DIASTOLI APLI MEGALI'
let s:d[0x1D0DC]='BYZANTINE MUSICAL SYMBOL DIASTOLI DIPLI'
let s:d[0x1D0DD]='BYZANTINE MUSICAL SYMBOL DIASTOLI THESEOS'
let s:d[0x1D0DE]='BYZANTINE MUSICAL SYMBOL SIMANSIS THESEOS'
let s:d[0x1D0DF]='BYZANTINE MUSICAL SYMBOL SIMANSIS THESEOS DISIMOU'
let s:d[0x1D0E0]='BYZANTINE MUSICAL SYMBOL SIMANSIS THESEOS TRISIMOU'
let s:d[0x1D0E1]='BYZANTINE MUSICAL SYMBOL SIMANSIS THESEOS TETRASIMOU'
let s:d[0x1D0E2]='BYZANTINE MUSICAL SYMBOL SIMANSIS ARSEOS'
let s:d[0x1D0E3]='BYZANTINE MUSICAL SYMBOL SIMANSIS ARSEOS DISIMOU'
let s:d[0x1D0E4]='BYZANTINE MUSICAL SYMBOL SIMANSIS ARSEOS TRISIMOU'
let s:d[0x1D0E5]='BYZANTINE MUSICAL SYMBOL SIMANSIS ARSEOS TETRASIMOU'
let s:d[0x1D0E6]='BYZANTINE MUSICAL SYMBOL DIGRAMMA GG'
let s:d[0x1D0E7]='BYZANTINE MUSICAL SYMBOL DIFTOGGOS OU'
let s:d[0x1D0E8]='BYZANTINE MUSICAL SYMBOL STIGMA'
let s:d[0x1D0E9]='BYZANTINE MUSICAL SYMBOL ARKTIKO PA'
let s:d[0x1D0EA]='BYZANTINE MUSICAL SYMBOL ARKTIKO VOU'
let s:d[0x1D0EB]='BYZANTINE MUSICAL SYMBOL ARKTIKO GA'
let s:d[0x1D0EC]='BYZANTINE MUSICAL SYMBOL ARKTIKO DI'
let s:d[0x1D0ED]='BYZANTINE MUSICAL SYMBOL ARKTIKO KE'
let s:d[0x1D0EE]='BYZANTINE MUSICAL SYMBOL ARKTIKO ZO'
let s:d[0x1D0EF]='BYZANTINE MUSICAL SYMBOL ARKTIKO NI'
let s:d[0x1D0F0]='BYZANTINE MUSICAL SYMBOL KENTIMATA NEO MESO'
let s:d[0x1D0F1]='BYZANTINE MUSICAL SYMBOL KENTIMA NEO MESO'
let s:d[0x1D0F2]='BYZANTINE MUSICAL SYMBOL KENTIMATA NEO KATO'
let s:d[0x1D0F3]='BYZANTINE MUSICAL SYMBOL KENTIMA NEO KATO'
let s:d[0x1D0F4]='BYZANTINE MUSICAL SYMBOL KLASMA KATO'
let s:d[0x1D0F5]='BYZANTINE MUSICAL SYMBOL GORGON NEO KATO'
let s:d[0x1D100]='MUSICAL SYMBOL SINGLE BARLINE'
let s:d[0x1D101]='MUSICAL SYMBOL DOUBLE BARLINE'
let s:d[0x1D102]='MUSICAL SYMBOL FINAL BARLINE'
let s:d[0x1D103]='MUSICAL SYMBOL REVERSE FINAL BARLINE'
let s:d[0x1D104]='MUSICAL SYMBOL DASHED BARLINE'
let s:d[0x1D105]='MUSICAL SYMBOL SHORT BARLINE'
let s:d[0x1D106]='MUSICAL SYMBOL LEFT REPEAT SIGN'
let s:d[0x1D107]='MUSICAL SYMBOL RIGHT REPEAT SIGN'
let s:d[0x1D108]='MUSICAL SYMBOL REPEAT DOTS'
let s:d[0x1D109]='MUSICAL SYMBOL DAL SEGNO'
let s:d[0x1D10A]='MUSICAL SYMBOL DA CAPO'
let s:d[0x1D10B]='MUSICAL SYMBOL SEGNO'
let s:d[0x1D10C]='MUSICAL SYMBOL CODA'
let s:d[0x1D10D]='MUSICAL SYMBOL REPEATED FIGURE-1'
let s:d[0x1D10E]='MUSICAL SYMBOL REPEATED FIGURE-2'
let s:d[0x1D10F]='MUSICAL SYMBOL REPEATED FIGURE-3'
let s:d[0x1D110]='MUSICAL SYMBOL FERMATA'
let s:d[0x1D111]='MUSICAL SYMBOL FERMATA BELOW'
let s:d[0x1D112]='MUSICAL SYMBOL BREATH MARK'
let s:d[0x1D113]='MUSICAL SYMBOL CAESURA'
let s:d[0x1D114]='MUSICAL SYMBOL BRACE'
let s:d[0x1D115]='MUSICAL SYMBOL BRACKET'
let s:d[0x1D116]='MUSICAL SYMBOL ONE-LINE STAFF'
let s:d[0x1D117]='MUSICAL SYMBOL TWO-LINE STAFF'
let s:d[0x1D118]='MUSICAL SYMBOL THREE-LINE STAFF'
let s:d[0x1D119]='MUSICAL SYMBOL FOUR-LINE STAFF'
let s:d[0x1D11A]='MUSICAL SYMBOL FIVE-LINE STAFF'
let s:d[0x1D11B]='MUSICAL SYMBOL SIX-LINE STAFF'
let s:d[0x1D11C]='MUSICAL SYMBOL SIX-STRING FRETBOARD'
let s:d[0x1D11D]='MUSICAL SYMBOL FOUR-STRING FRETBOARD'
let s:d[0x1D11E]='MUSICAL SYMBOL G CLEF'
let s:d[0x1D11F]='MUSICAL SYMBOL G CLEF OTTAVA ALTA'
let s:d[0x1D120]='MUSICAL SYMBOL G CLEF OTTAVA BASSA'
let s:d[0x1D121]='MUSICAL SYMBOL C CLEF'
let s:d[0x1D122]='MUSICAL SYMBOL F CLEF'
let s:d[0x1D123]='MUSICAL SYMBOL F CLEF OTTAVA ALTA'
let s:d[0x1D124]='MUSICAL SYMBOL F CLEF OTTAVA BASSA'
let s:d[0x1D125]='MUSICAL SYMBOL DRUM CLEF-1'
let s:d[0x1D126]='MUSICAL SYMBOL DRUM CLEF-2'
let s:d[0x1D129]='MUSICAL SYMBOL MULTIPLE MEASURE REST'
let s:d[0x1D12A]='MUSICAL SYMBOL DOUBLE SHARP'
let s:d[0x1D12B]='MUSICAL SYMBOL DOUBLE FLAT'
let s:d[0x1D12C]='MUSICAL SYMBOL FLAT UP'
let s:d[0x1D12D]='MUSICAL SYMBOL FLAT DOWN'
let s:d[0x1D12E]='MUSICAL SYMBOL NATURAL UP'
let s:d[0x1D12F]='MUSICAL SYMBOL NATURAL DOWN'
let s:d[0x1D130]='MUSICAL SYMBOL SHARP UP'
let s:d[0x1D131]='MUSICAL SYMBOL SHARP DOWN'
let s:d[0x1D132]='MUSICAL SYMBOL QUARTER TONE SHARP'
let s:d[0x1D133]='MUSICAL SYMBOL QUARTER TONE FLAT'
let s:d[0x1D134]='MUSICAL SYMBOL COMMON TIME'
let s:d[0x1D135]='MUSICAL SYMBOL CUT TIME'
let s:d[0x1D136]='MUSICAL SYMBOL OTTAVA ALTA'
let s:d[0x1D137]='MUSICAL SYMBOL OTTAVA BASSA'
let s:d[0x1D138]='MUSICAL SYMBOL QUINDICESIMA ALTA'
let s:d[0x1D139]='MUSICAL SYMBOL QUINDICESIMA BASSA'
let s:d[0x1D13A]='MUSICAL SYMBOL MULTI REST'
let s:d[0x1D13B]='MUSICAL SYMBOL WHOLE REST'
let s:d[0x1D13C]='MUSICAL SYMBOL HALF REST'
let s:d[0x1D13D]='MUSICAL SYMBOL QUARTER REST'
let s:d[0x1D13E]='MUSICAL SYMBOL EIGHTH REST'
let s:d[0x1D13F]='MUSICAL SYMBOL SIXTEENTH REST'
let s:d[0x1D140]='MUSICAL SYMBOL THIRTY-SECOND REST'
let s:d[0x1D141]='MUSICAL SYMBOL SIXTY-FOURTH REST'
let s:d[0x1D142]='MUSICAL SYMBOL ONE HUNDRED TWENTY-EIGHTH REST'
let s:d[0x1D143]='MUSICAL SYMBOL X NOTEHEAD'
let s:d[0x1D144]='MUSICAL SYMBOL PLUS NOTEHEAD'
let s:d[0x1D145]='MUSICAL SYMBOL CIRCLE X NOTEHEAD'
let s:d[0x1D146]='MUSICAL SYMBOL SQUARE NOTEHEAD WHITE'
let s:d[0x1D147]='MUSICAL SYMBOL SQUARE NOTEHEAD BLACK'
let s:d[0x1D148]='MUSICAL SYMBOL TRIANGLE NOTEHEAD UP WHITE'
let s:d[0x1D149]='MUSICAL SYMBOL TRIANGLE NOTEHEAD UP BLACK'
let s:d[0x1D14A]='MUSICAL SYMBOL TRIANGLE NOTEHEAD LEFT WHITE'
let s:d[0x1D14B]='MUSICAL SYMBOL TRIANGLE NOTEHEAD LEFT BLACK'
let s:d[0x1D14C]='MUSICAL SYMBOL TRIANGLE NOTEHEAD RIGHT WHITE'
let s:d[0x1D14D]='MUSICAL SYMBOL TRIANGLE NOTEHEAD RIGHT BLACK'
let s:d[0x1D14E]='MUSICAL SYMBOL TRIANGLE NOTEHEAD DOWN WHITE'
let s:d[0x1D14F]='MUSICAL SYMBOL TRIANGLE NOTEHEAD DOWN BLACK'
let s:d[0x1D150]='MUSICAL SYMBOL TRIANGLE NOTEHEAD UP RIGHT WHITE'
let s:d[0x1D151]='MUSICAL SYMBOL TRIANGLE NOTEHEAD UP RIGHT BLACK'
let s:d[0x1D152]='MUSICAL SYMBOL MOON NOTEHEAD WHITE'
let s:d[0x1D153]='MUSICAL SYMBOL MOON NOTEHEAD BLACK'
let s:d[0x1D154]='MUSICAL SYMBOL TRIANGLE-ROUND NOTEHEAD DOWN WHITE'
let s:d[0x1D155]='MUSICAL SYMBOL TRIANGLE-ROUND NOTEHEAD DOWN BLACK'
let s:d[0x1D156]='MUSICAL SYMBOL PARENTHESIS NOTEHEAD'
let s:d[0x1D157]='MUSICAL SYMBOL VOID NOTEHEAD'
let s:d[0x1D158]='MUSICAL SYMBOL NOTEHEAD BLACK'
let s:d[0x1D159]='MUSICAL SYMBOL NULL NOTEHEAD'
let s:d[0x1D15A]='MUSICAL SYMBOL CLUSTER NOTEHEAD WHITE'
let s:d[0x1D15B]='MUSICAL SYMBOL CLUSTER NOTEHEAD BLACK'
let s:d[0x1D15C]='MUSICAL SYMBOL BREVE'
let s:d[0x1D15D]='MUSICAL SYMBOL WHOLE NOTE'
let s:d[0x1D15E]='MUSICAL SYMBOL HALF NOTE'
let s:d[0x1D15F]='MUSICAL SYMBOL QUARTER NOTE'
let s:d[0x1D160]='MUSICAL SYMBOL EIGHTH NOTE'
let s:d[0x1D161]='MUSICAL SYMBOL SIXTEENTH NOTE'
let s:d[0x1D162]='MUSICAL SYMBOL THIRTY-SECOND NOTE'
let s:d[0x1D163]='MUSICAL SYMBOL SIXTY-FOURTH NOTE'
let s:d[0x1D164]='MUSICAL SYMBOL ONE HUNDRED TWENTY-EIGHTH NOTE'
let s:d[0x1D165]='MUSICAL SYMBOL COMBINING STEM'
let s:d[0x1D166]='MUSICAL SYMBOL COMBINING SPRECHGESANG STEM'
let s:d[0x1D167]='MUSICAL SYMBOL COMBINING TREMOLO-1'
let s:d[0x1D168]='MUSICAL SYMBOL COMBINING TREMOLO-2'
let s:d[0x1D169]='MUSICAL SYMBOL COMBINING TREMOLO-3'
let s:d[0x1D16A]='MUSICAL SYMBOL FINGERED TREMOLO-1'
let s:d[0x1D16B]='MUSICAL SYMBOL FINGERED TREMOLO-2'
let s:d[0x1D16C]='MUSICAL SYMBOL FINGERED TREMOLO-3'
let s:d[0x1D16D]='MUSICAL SYMBOL COMBINING AUGMENTATION DOT'
let s:d[0x1D16E]='MUSICAL SYMBOL COMBINING FLAG-1'
let s:d[0x1D16F]='MUSICAL SYMBOL COMBINING FLAG-2'
let s:d[0x1D170]='MUSICAL SYMBOL COMBINING FLAG-3'
let s:d[0x1D171]='MUSICAL SYMBOL COMBINING FLAG-4'
let s:d[0x1D172]='MUSICAL SYMBOL COMBINING FLAG-5'
let s:d[0x1D173]='MUSICAL SYMBOL BEGIN BEAM'
let s:d[0x1D174]='MUSICAL SYMBOL END BEAM'
let s:d[0x1D175]='MUSICAL SYMBOL BEGIN TIE'
let s:d[0x1D176]='MUSICAL SYMBOL END TIE'
let s:d[0x1D177]='MUSICAL SYMBOL BEGIN SLUR'
let s:d[0x1D178]='MUSICAL SYMBOL END SLUR'
let s:d[0x1D179]='MUSICAL SYMBOL BEGIN PHRASE'
let s:d[0x1D17A]='MUSICAL SYMBOL END PHRASE'
let s:d[0x1D17B]='MUSICAL SYMBOL COMBINING ACCENT'
let s:d[0x1D17C]='MUSICAL SYMBOL COMBINING STACCATO'
let s:d[0x1D17D]='MUSICAL SYMBOL COMBINING TENUTO'
let s:d[0x1D17E]='MUSICAL SYMBOL COMBINING STACCATISSIMO'
let s:d[0x1D17F]='MUSICAL SYMBOL COMBINING MARCATO'
let s:d[0x1D180]='MUSICAL SYMBOL COMBINING MARCATO-STACCATO'
let s:d[0x1D181]='MUSICAL SYMBOL COMBINING ACCENT-STACCATO'
let s:d[0x1D182]='MUSICAL SYMBOL COMBINING LOURE'
let s:d[0x1D183]='MUSICAL SYMBOL ARPEGGIATO UP'
let s:d[0x1D184]='MUSICAL SYMBOL ARPEGGIATO DOWN'
let s:d[0x1D185]='MUSICAL SYMBOL COMBINING DOIT'
let s:d[0x1D186]='MUSICAL SYMBOL COMBINING RIP'
let s:d[0x1D187]='MUSICAL SYMBOL COMBINING FLIP'
let s:d[0x1D188]='MUSICAL SYMBOL COMBINING SMEAR'
let s:d[0x1D189]='MUSICAL SYMBOL COMBINING BEND'
let s:d[0x1D18A]='MUSICAL SYMBOL COMBINING DOUBLE TONGUE'
let s:d[0x1D18B]='MUSICAL SYMBOL COMBINING TRIPLE TONGUE'
let s:d[0x1D18C]='MUSICAL SYMBOL RINFORZANDO'
let s:d[0x1D18D]='MUSICAL SYMBOL SUBITO'
let s:d[0x1D18E]='MUSICAL SYMBOL Z'
let s:d[0x1D18F]='MUSICAL SYMBOL PIANO'
let s:d[0x1D190]='MUSICAL SYMBOL MEZZO'
let s:d[0x1D191]='MUSICAL SYMBOL FORTE'
let s:d[0x1D192]='MUSICAL SYMBOL CRESCENDO'
let s:d[0x1D193]='MUSICAL SYMBOL DECRESCENDO'
let s:d[0x1D194]='MUSICAL SYMBOL GRACE NOTE SLASH'
let s:d[0x1D195]='MUSICAL SYMBOL GRACE NOTE NO SLASH'
let s:d[0x1D196]='MUSICAL SYMBOL TR'
let s:d[0x1D197]='MUSICAL SYMBOL TURN'
let s:d[0x1D198]='MUSICAL SYMBOL INVERTED TURN'
let s:d[0x1D199]='MUSICAL SYMBOL TURN SLASH'
let s:d[0x1D19A]='MUSICAL SYMBOL TURN UP'
let s:d[0x1D19B]='MUSICAL SYMBOL ORNAMENT STROKE-1'
let s:d[0x1D19C]='MUSICAL SYMBOL ORNAMENT STROKE-2'
let s:d[0x1D19D]='MUSICAL SYMBOL ORNAMENT STROKE-3'
let s:d[0x1D19E]='MUSICAL SYMBOL ORNAMENT STROKE-4'
let s:d[0x1D19F]='MUSICAL SYMBOL ORNAMENT STROKE-5'
let s:d[0x1D1A0]='MUSICAL SYMBOL ORNAMENT STROKE-6'
let s:d[0x1D1A1]='MUSICAL SYMBOL ORNAMENT STROKE-7'
let s:d[0x1D1A2]='MUSICAL SYMBOL ORNAMENT STROKE-8'
let s:d[0x1D1A3]='MUSICAL SYMBOL ORNAMENT STROKE-9'
let s:d[0x1D1A4]='MUSICAL SYMBOL ORNAMENT STROKE-10'
let s:d[0x1D1A5]='MUSICAL SYMBOL ORNAMENT STROKE-11'
let s:d[0x1D1A6]='MUSICAL SYMBOL HAUPTSTIMME'
let s:d[0x1D1A7]='MUSICAL SYMBOL NEBENSTIMME'
let s:d[0x1D1A8]='MUSICAL SYMBOL END OF STIMME'
let s:d[0x1D1A9]='MUSICAL SYMBOL DEGREE SLASH'
let s:d[0x1D1AA]='MUSICAL SYMBOL COMBINING DOWN BOW'
let s:d[0x1D1AB]='MUSICAL SYMBOL COMBINING UP BOW'
let s:d[0x1D1AC]='MUSICAL SYMBOL COMBINING HARMONIC'
let s:d[0x1D1AD]='MUSICAL SYMBOL COMBINING SNAP PIZZICATO'
let s:d[0x1D1AE]='MUSICAL SYMBOL PEDAL MARK'
let s:d[0x1D1AF]='MUSICAL SYMBOL PEDAL UP MARK'
let s:d[0x1D1B0]='MUSICAL SYMBOL HALF PEDAL MARK'
let s:d[0x1D1B1]='MUSICAL SYMBOL GLISSANDO UP'
let s:d[0x1D1B2]='MUSICAL SYMBOL GLISSANDO DOWN'
let s:d[0x1D1B3]='MUSICAL SYMBOL WITH FINGERNAILS'
let s:d[0x1D1B4]='MUSICAL SYMBOL DAMP'
let s:d[0x1D1B5]='MUSICAL SYMBOL DAMP ALL'
let s:d[0x1D1B6]='MUSICAL SYMBOL MAXIMA'
let s:d[0x1D1B7]='MUSICAL SYMBOL LONGA'
let s:d[0x1D1B8]='MUSICAL SYMBOL BREVIS'
let s:d[0x1D1B9]='MUSICAL SYMBOL SEMIBREVIS WHITE'
let s:d[0x1D1BA]='MUSICAL SYMBOL SEMIBREVIS BLACK'
let s:d[0x1D1BB]='MUSICAL SYMBOL MINIMA'
let s:d[0x1D1BC]='MUSICAL SYMBOL MINIMA BLACK'
let s:d[0x1D1BD]='MUSICAL SYMBOL SEMIMINIMA WHITE'
let s:d[0x1D1BE]='MUSICAL SYMBOL SEMIMINIMA BLACK'
let s:d[0x1D1BF]='MUSICAL SYMBOL FUSA WHITE'
let s:d[0x1D1C0]='MUSICAL SYMBOL FUSA BLACK'
let s:d[0x1D1C1]='MUSICAL SYMBOL LONGA PERFECTA REST'
let s:d[0x1D1C2]='MUSICAL SYMBOL LONGA IMPERFECTA REST'
let s:d[0x1D1C3]='MUSICAL SYMBOL BREVIS REST'
let s:d[0x1D1C4]='MUSICAL SYMBOL SEMIBREVIS REST'
let s:d[0x1D1C5]='MUSICAL SYMBOL MINIMA REST'
let s:d[0x1D1C6]='MUSICAL SYMBOL SEMIMINIMA REST'
let s:d[0x1D1C7]='MUSICAL SYMBOL TEMPUS PERFECTUM CUM PROLATIONE PERFECTA'
let s:d[0x1D1C8]='MUSICAL SYMBOL TEMPUS PERFECTUM CUM PROLATIONE IMPERFECTA'
let s:d[0x1D1C9]='MUSICAL SYMBOL TEMPUS PERFECTUM CUM PROLATIONE PERFECTA DIMINUTION-1'
let s:d[0x1D1CA]='MUSICAL SYMBOL TEMPUS IMPERFECTUM CUM PROLATIONE PERFECTA'
let s:d[0x1D1CB]='MUSICAL SYMBOL TEMPUS IMPERFECTUM CUM PROLATIONE IMPERFECTA'
let s:d[0x1D1CC]='MUSICAL SYMBOL TEMPUS IMPERFECTUM CUM PROLATIONE IMPERFECTA DIMINUTION-1'
let s:d[0x1D1CD]='MUSICAL SYMBOL TEMPUS IMPERFECTUM CUM PROLATIONE IMPERFECTA DIMINUTION-2'
let s:d[0x1D1CE]='MUSICAL SYMBOL TEMPUS IMPERFECTUM CUM PROLATIONE IMPERFECTA DIMINUTION-3'
let s:d[0x1D1CF]='MUSICAL SYMBOL CROIX'
let s:d[0x1D1D0]='MUSICAL SYMBOL GREGORIAN C CLEF'
let s:d[0x1D1D1]='MUSICAL SYMBOL GREGORIAN F CLEF'
let s:d[0x1D1D2]='MUSICAL SYMBOL SQUARE B'
let s:d[0x1D1D3]='MUSICAL SYMBOL VIRGA'
let s:d[0x1D1D4]='MUSICAL SYMBOL PODATUS'
let s:d[0x1D1D5]='MUSICAL SYMBOL CLIVIS'
let s:d[0x1D1D6]='MUSICAL SYMBOL SCANDICUS'
let s:d[0x1D1D7]='MUSICAL SYMBOL CLIMACUS'
let s:d[0x1D1D8]='MUSICAL SYMBOL TORCULUS'
let s:d[0x1D1D9]='MUSICAL SYMBOL PORRECTUS'
let s:d[0x1D1DA]='MUSICAL SYMBOL PORRECTUS FLEXUS'
let s:d[0x1D1DB]='MUSICAL SYMBOL SCANDICUS FLEXUS'
let s:d[0x1D1DC]='MUSICAL SYMBOL TORCULUS RESUPINUS'
let s:d[0x1D1DD]='MUSICAL SYMBOL PES SUBPUNCTIS'
let s:d[0x1D200]='GREEK VOCAL NOTATION SYMBOL-1'
let s:d[0x1D201]='GREEK VOCAL NOTATION SYMBOL-2'
let s:d[0x1D202]='GREEK VOCAL NOTATION SYMBOL-3'
let s:d[0x1D203]='GREEK VOCAL NOTATION SYMBOL-4'
let s:d[0x1D204]='GREEK VOCAL NOTATION SYMBOL-5'
let s:d[0x1D205]='GREEK VOCAL NOTATION SYMBOL-6'
let s:d[0x1D206]='GREEK VOCAL NOTATION SYMBOL-7'
let s:d[0x1D207]='GREEK VOCAL NOTATION SYMBOL-8'
let s:d[0x1D208]='GREEK VOCAL NOTATION SYMBOL-9'
let s:d[0x1D209]='GREEK VOCAL NOTATION SYMBOL-10'
let s:d[0x1D20A]='GREEK VOCAL NOTATION SYMBOL-11'
let s:d[0x1D20B]='GREEK VOCAL NOTATION SYMBOL-12'
let s:d[0x1D20C]='GREEK VOCAL NOTATION SYMBOL-13'
let s:d[0x1D20D]='GREEK VOCAL NOTATION SYMBOL-14'
let s:d[0x1D20E]='GREEK VOCAL NOTATION SYMBOL-15'
let s:d[0x1D20F]='GREEK VOCAL NOTATION SYMBOL-16'
let s:d[0x1D210]='GREEK VOCAL NOTATION SYMBOL-17'
let s:d[0x1D211]='GREEK VOCAL NOTATION SYMBOL-18'
let s:d[0x1D212]='GREEK VOCAL NOTATION SYMBOL-19'
let s:d[0x1D213]='GREEK VOCAL NOTATION SYMBOL-20'
let s:d[0x1D214]='GREEK VOCAL NOTATION SYMBOL-21'
let s:d[0x1D215]='GREEK VOCAL NOTATION SYMBOL-22'
let s:d[0x1D216]='GREEK VOCAL NOTATION SYMBOL-23'
let s:d[0x1D217]='GREEK VOCAL NOTATION SYMBOL-24'
let s:d[0x1D218]='GREEK VOCAL NOTATION SYMBOL-50'
let s:d[0x1D219]='GREEK VOCAL NOTATION SYMBOL-51'
let s:d[0x1D21A]='GREEK VOCAL NOTATION SYMBOL-52'
let s:d[0x1D21B]='GREEK VOCAL NOTATION SYMBOL-53'
let s:d[0x1D21C]='GREEK VOCAL NOTATION SYMBOL-54'
let s:d[0x1D21D]='GREEK INSTRUMENTAL NOTATION SYMBOL-1'
let s:d[0x1D21E]='GREEK INSTRUMENTAL NOTATION SYMBOL-2'
let s:d[0x1D21F]='GREEK INSTRUMENTAL NOTATION SYMBOL-4'
let s:d[0x1D220]='GREEK INSTRUMENTAL NOTATION SYMBOL-5'
let s:d[0x1D221]='GREEK INSTRUMENTAL NOTATION SYMBOL-7'
let s:d[0x1D222]='GREEK INSTRUMENTAL NOTATION SYMBOL-8'
let s:d[0x1D223]='GREEK INSTRUMENTAL NOTATION SYMBOL-11'
let s:d[0x1D224]='GREEK INSTRUMENTAL NOTATION SYMBOL-12'
let s:d[0x1D225]='GREEK INSTRUMENTAL NOTATION SYMBOL-13'
let s:d[0x1D226]='GREEK INSTRUMENTAL NOTATION SYMBOL-14'
let s:d[0x1D227]='GREEK INSTRUMENTAL NOTATION SYMBOL-17'
let s:d[0x1D228]='GREEK INSTRUMENTAL NOTATION SYMBOL-18'
let s:d[0x1D229]='GREEK INSTRUMENTAL NOTATION SYMBOL-19'
let s:d[0x1D22A]='GREEK INSTRUMENTAL NOTATION SYMBOL-23'
let s:d[0x1D22B]='GREEK INSTRUMENTAL NOTATION SYMBOL-24'
let s:d[0x1D22C]='GREEK INSTRUMENTAL NOTATION SYMBOL-25'
let s:d[0x1D22D]='GREEK INSTRUMENTAL NOTATION SYMBOL-26'
let s:d[0x1D22E]='GREEK INSTRUMENTAL NOTATION SYMBOL-27'
let s:d[0x1D22F]='GREEK INSTRUMENTAL NOTATION SYMBOL-29'
let s:d[0x1D230]='GREEK INSTRUMENTAL NOTATION SYMBOL-30'
let s:d[0x1D231]='GREEK INSTRUMENTAL NOTATION SYMBOL-32'
let s:d[0x1D232]='GREEK INSTRUMENTAL NOTATION SYMBOL-36'
let s:d[0x1D233]='GREEK INSTRUMENTAL NOTATION SYMBOL-37'
let s:d[0x1D234]='GREEK INSTRUMENTAL NOTATION SYMBOL-38'
let s:d[0x1D235]='GREEK INSTRUMENTAL NOTATION SYMBOL-39'
let s:d[0x1D236]='GREEK INSTRUMENTAL NOTATION SYMBOL-40'
let s:d[0x1D237]='GREEK INSTRUMENTAL NOTATION SYMBOL-42'
let s:d[0x1D238]='GREEK INSTRUMENTAL NOTATION SYMBOL-43'
let s:d[0x1D239]='GREEK INSTRUMENTAL NOTATION SYMBOL-45'
let s:d[0x1D23A]='GREEK INSTRUMENTAL NOTATION SYMBOL-47'
let s:d[0x1D23B]='GREEK INSTRUMENTAL NOTATION SYMBOL-48'
let s:d[0x1D23C]='GREEK INSTRUMENTAL NOTATION SYMBOL-49'
let s:d[0x1D23D]='GREEK INSTRUMENTAL NOTATION SYMBOL-50'
let s:d[0x1D23E]='GREEK INSTRUMENTAL NOTATION SYMBOL-51'
let s:d[0x1D23F]='GREEK INSTRUMENTAL NOTATION SYMBOL-52'
let s:d[0x1D240]='GREEK INSTRUMENTAL NOTATION SYMBOL-53'
let s:d[0x1D241]='GREEK INSTRUMENTAL NOTATION SYMBOL-54'
let s:d[0x1D242]='COMBINING GREEK MUSICAL TRISEME'
let s:d[0x1D243]='COMBINING GREEK MUSICAL TETRASEME'
let s:d[0x1D244]='COMBINING GREEK MUSICAL PENTASEME'
let s:d[0x1D245]='GREEK MUSICAL LEIMMA'
let s:d[0x1D300]='MONOGRAM FOR EARTH'
let s:d[0x1D301]='DIGRAM FOR HEAVENLY EARTH'
let s:d[0x1D302]='DIGRAM FOR HUMAN EARTH'
let s:d[0x1D303]='DIGRAM FOR EARTHLY HEAVEN'
let s:d[0x1D304]='DIGRAM FOR EARTHLY HUMAN'
let s:d[0x1D305]='DIGRAM FOR EARTH'
let s:d[0x1D306]='TETRAGRAM FOR CENTRE'
let s:d[0x1D307]='TETRAGRAM FOR FULL CIRCLE'
let s:d[0x1D308]='TETRAGRAM FOR MIRED'
let s:d[0x1D309]='TETRAGRAM FOR BARRIER'
let s:d[0x1D30A]='TETRAGRAM FOR KEEPING SMALL'
let s:d[0x1D30B]='TETRAGRAM FOR CONTRARIETY'
let s:d[0x1D30C]='TETRAGRAM FOR ASCENT'
let s:d[0x1D30D]='TETRAGRAM FOR OPPOSITION'
let s:d[0x1D30E]='TETRAGRAM FOR BRANCHING OUT'
let s:d[0x1D30F]='TETRAGRAM FOR DEFECTIVENESS OR DISTORTION'
let s:d[0x1D310]='TETRAGRAM FOR DIVERGENCE'
let s:d[0x1D311]='TETRAGRAM FOR YOUTHFULNESS'
let s:d[0x1D312]='TETRAGRAM FOR INCREASE'
let s:d[0x1D313]='TETRAGRAM FOR PENETRATION'
let s:d[0x1D314]='TETRAGRAM FOR REACH'
let s:d[0x1D315]='TETRAGRAM FOR CONTACT'
let s:d[0x1D316]='TETRAGRAM FOR HOLDING BACK'
let s:d[0x1D317]='TETRAGRAM FOR WAITING'
let s:d[0x1D318]='TETRAGRAM FOR FOLLOWING'
let s:d[0x1D319]='TETRAGRAM FOR ADVANCE'
let s:d[0x1D31A]='TETRAGRAM FOR RELEASE'
let s:d[0x1D31B]='TETRAGRAM FOR RESISTANCE'
let s:d[0x1D31C]='TETRAGRAM FOR EASE'
let s:d[0x1D31D]='TETRAGRAM FOR JOY'
let s:d[0x1D31E]='TETRAGRAM FOR CONTENTION'
let s:d[0x1D31F]='TETRAGRAM FOR ENDEAVOUR'
let s:d[0x1D320]='TETRAGRAM FOR DUTIES'
let s:d[0x1D321]='TETRAGRAM FOR CHANGE'
let s:d[0x1D322]='TETRAGRAM FOR DECISIVENESS'
let s:d[0x1D323]='TETRAGRAM FOR BOLD RESOLUTION'
let s:d[0x1D324]='TETRAGRAM FOR PACKING'
let s:d[0x1D325]='TETRAGRAM FOR LEGION'
let s:d[0x1D326]='TETRAGRAM FOR CLOSENESS'
let s:d[0x1D327]='TETRAGRAM FOR KINSHIP'
let s:d[0x1D328]='TETRAGRAM FOR GATHERING'
let s:d[0x1D329]='TETRAGRAM FOR STRENGTH'
let s:d[0x1D32A]='TETRAGRAM FOR PURITY'
let s:d[0x1D32B]='TETRAGRAM FOR FULLNESS'
let s:d[0x1D32C]='TETRAGRAM FOR RESIDENCE'
let s:d[0x1D32D]='TETRAGRAM FOR LAW OR MODEL'
let s:d[0x1D32E]='TETRAGRAM FOR RESPONSE'
let s:d[0x1D32F]='TETRAGRAM FOR GOING TO MEET'
let s:d[0x1D330]='TETRAGRAM FOR ENCOUNTERS'
let s:d[0x1D331]='TETRAGRAM FOR STOVE'
let s:d[0x1D332]='TETRAGRAM FOR GREATNESS'
let s:d[0x1D333]='TETRAGRAM FOR ENLARGEMENT'
let s:d[0x1D334]='TETRAGRAM FOR PATTERN'
let s:d[0x1D335]='TETRAGRAM FOR RITUAL'
let s:d[0x1D336]='TETRAGRAM FOR FLIGHT'
let s:d[0x1D337]='TETRAGRAM FOR VASTNESS OR WASTING'
let s:d[0x1D338]='TETRAGRAM FOR CONSTANCY'
let s:d[0x1D339]='TETRAGRAM FOR MEASURE'
let s:d[0x1D33A]='TETRAGRAM FOR ETERNITY'
let s:d[0x1D33B]='TETRAGRAM FOR UNITY'
let s:d[0x1D33C]='TETRAGRAM FOR DIMINISHMENT'
let s:d[0x1D33D]='TETRAGRAM FOR CLOSED MOUTH'
let s:d[0x1D33E]='TETRAGRAM FOR GUARDEDNESS'
let s:d[0x1D33F]='TETRAGRAM FOR GATHERING IN'
let s:d[0x1D340]='TETRAGRAM FOR MASSING'
let s:d[0x1D341]='TETRAGRAM FOR ACCUMULATION'
let s:d[0x1D342]='TETRAGRAM FOR EMBELLISHMENT'
let s:d[0x1D343]='TETRAGRAM FOR DOUBT'
let s:d[0x1D344]='TETRAGRAM FOR WATCH'
let s:d[0x1D345]='TETRAGRAM FOR SINKING'
let s:d[0x1D346]='TETRAGRAM FOR INNER'
let s:d[0x1D347]='TETRAGRAM FOR DEPARTURE'
let s:d[0x1D348]='TETRAGRAM FOR DARKENING'
let s:d[0x1D349]='TETRAGRAM FOR DIMMING'
let s:d[0x1D34A]='TETRAGRAM FOR EXHAUSTION'
let s:d[0x1D34B]='TETRAGRAM FOR SEVERANCE'
let s:d[0x1D34C]='TETRAGRAM FOR STOPPAGE'
let s:d[0x1D34D]='TETRAGRAM FOR HARDNESS'
let s:d[0x1D34E]='TETRAGRAM FOR COMPLETION'
let s:d[0x1D34F]='TETRAGRAM FOR CLOSURE'
let s:d[0x1D350]='TETRAGRAM FOR FAILURE'
let s:d[0x1D351]='TETRAGRAM FOR AGGRAVATION'
let s:d[0x1D352]='TETRAGRAM FOR COMPLIANCE'
let s:d[0x1D353]='TETRAGRAM FOR ON THE VERGE'
let s:d[0x1D354]='TETRAGRAM FOR DIFFICULTIES'
let s:d[0x1D355]='TETRAGRAM FOR LABOURING'
let s:d[0x1D356]='TETRAGRAM FOR FOSTERING'
let s:d[0x1D360]='COUNTING ROD UNIT DIGIT ONE'
let s:d[0x1D361]='COUNTING ROD UNIT DIGIT TWO'
let s:d[0x1D362]='COUNTING ROD UNIT DIGIT THREE'
let s:d[0x1D363]='COUNTING ROD UNIT DIGIT FOUR'
let s:d[0x1D364]='COUNTING ROD UNIT DIGIT FIVE'
let s:d[0x1D365]='COUNTING ROD UNIT DIGIT SIX'
let s:d[0x1D366]='COUNTING ROD UNIT DIGIT SEVEN'
let s:d[0x1D367]='COUNTING ROD UNIT DIGIT EIGHT'
let s:d[0x1D368]='COUNTING ROD UNIT DIGIT NINE'
let s:d[0x1D369]='COUNTING ROD TENS DIGIT ONE'
let s:d[0x1D36A]='COUNTING ROD TENS DIGIT TWO'
let s:d[0x1D36B]='COUNTING ROD TENS DIGIT THREE'
let s:d[0x1D36C]='COUNTING ROD TENS DIGIT FOUR'
let s:d[0x1D36D]='COUNTING ROD TENS DIGIT FIVE'
let s:d[0x1D36E]='COUNTING ROD TENS DIGIT SIX'
let s:d[0x1D36F]='COUNTING ROD TENS DIGIT SEVEN'
let s:d[0x1D370]='COUNTING ROD TENS DIGIT EIGHT'
let s:d[0x1D371]='COUNTING ROD TENS DIGIT NINE'
let s:d[0x1D400]='MATHEMATICAL BOLD CAPITAL A'
let s:d[0x1D401]='MATHEMATICAL BOLD CAPITAL B'
let s:d[0x1D402]='MATHEMATICAL BOLD CAPITAL C'
let s:d[0x1D403]='MATHEMATICAL BOLD CAPITAL D'
let s:d[0x1D404]='MATHEMATICAL BOLD CAPITAL E'
let s:d[0x1D405]='MATHEMATICAL BOLD CAPITAL F'
let s:d[0x1D406]='MATHEMATICAL BOLD CAPITAL G'
let s:d[0x1D407]='MATHEMATICAL BOLD CAPITAL H'
let s:d[0x1D408]='MATHEMATICAL BOLD CAPITAL I'
let s:d[0x1D409]='MATHEMATICAL BOLD CAPITAL J'
let s:d[0x1D40A]='MATHEMATICAL BOLD CAPITAL K'
let s:d[0x1D40B]='MATHEMATICAL BOLD CAPITAL L'
let s:d[0x1D40C]='MATHEMATICAL BOLD CAPITAL M'
let s:d[0x1D40D]='MATHEMATICAL BOLD CAPITAL N'
let s:d[0x1D40E]='MATHEMATICAL BOLD CAPITAL O'
let s:d[0x1D40F]='MATHEMATICAL BOLD CAPITAL P'
let s:d[0x1D410]='MATHEMATICAL BOLD CAPITAL Q'
let s:d[0x1D411]='MATHEMATICAL BOLD CAPITAL R'
let s:d[0x1D412]='MATHEMATICAL BOLD CAPITAL S'
let s:d[0x1D413]='MATHEMATICAL BOLD CAPITAL T'
let s:d[0x1D414]='MATHEMATICAL BOLD CAPITAL U'
let s:d[0x1D415]='MATHEMATICAL BOLD CAPITAL V'
let s:d[0x1D416]='MATHEMATICAL BOLD CAPITAL W'
let s:d[0x1D417]='MATHEMATICAL BOLD CAPITAL X'
let s:d[0x1D418]='MATHEMATICAL BOLD CAPITAL Y'
let s:d[0x1D419]='MATHEMATICAL BOLD CAPITAL Z'
let s:d[0x1D41A]='MATHEMATICAL BOLD SMALL A'
let s:d[0x1D41B]='MATHEMATICAL BOLD SMALL B'
let s:d[0x1D41C]='MATHEMATICAL BOLD SMALL C'
let s:d[0x1D41D]='MATHEMATICAL BOLD SMALL D'
let s:d[0x1D41E]='MATHEMATICAL BOLD SMALL E'
let s:d[0x1D41F]='MATHEMATICAL BOLD SMALL F'
let s:d[0x1D420]='MATHEMATICAL BOLD SMALL G'
let s:d[0x1D421]='MATHEMATICAL BOLD SMALL H'
let s:d[0x1D422]='MATHEMATICAL BOLD SMALL I'
let s:d[0x1D423]='MATHEMATICAL BOLD SMALL J'
let s:d[0x1D424]='MATHEMATICAL BOLD SMALL K'
let s:d[0x1D425]='MATHEMATICAL BOLD SMALL L'
let s:d[0x1D426]='MATHEMATICAL BOLD SMALL M'
let s:d[0x1D427]='MATHEMATICAL BOLD SMALL N'
let s:d[0x1D428]='MATHEMATICAL BOLD SMALL O'
let s:d[0x1D429]='MATHEMATICAL BOLD SMALL P'
let s:d[0x1D42A]='MATHEMATICAL BOLD SMALL Q'
let s:d[0x1D42B]='MATHEMATICAL BOLD SMALL R'
let s:d[0x1D42C]='MATHEMATICAL BOLD SMALL S'
let s:d[0x1D42D]='MATHEMATICAL BOLD SMALL T'
let s:d[0x1D42E]='MATHEMATICAL BOLD SMALL U'
let s:d[0x1D42F]='MATHEMATICAL BOLD SMALL V'
let s:d[0x1D430]='MATHEMATICAL BOLD SMALL W'
let s:d[0x1D431]='MATHEMATICAL BOLD SMALL X'
let s:d[0x1D432]='MATHEMATICAL BOLD SMALL Y'
let s:d[0x1D433]='MATHEMATICAL BOLD SMALL Z'
let s:d[0x1D434]='MATHEMATICAL ITALIC CAPITAL A'
let s:d[0x1D435]='MATHEMATICAL ITALIC CAPITAL B'
let s:d[0x1D436]='MATHEMATICAL ITALIC CAPITAL C'
let s:d[0x1D437]='MATHEMATICAL ITALIC CAPITAL D'
let s:d[0x1D438]='MATHEMATICAL ITALIC CAPITAL E'
let s:d[0x1D439]='MATHEMATICAL ITALIC CAPITAL F'
let s:d[0x1D43A]='MATHEMATICAL ITALIC CAPITAL G'
let s:d[0x1D43B]='MATHEMATICAL ITALIC CAPITAL H'
let s:d[0x1D43C]='MATHEMATICAL ITALIC CAPITAL I'
let s:d[0x1D43D]='MATHEMATICAL ITALIC CAPITAL J'
let s:d[0x1D43E]='MATHEMATICAL ITALIC CAPITAL K'
let s:d[0x1D43F]='MATHEMATICAL ITALIC CAPITAL L'
let s:d[0x1D440]='MATHEMATICAL ITALIC CAPITAL M'
let s:d[0x1D441]='MATHEMATICAL ITALIC CAPITAL N'
let s:d[0x1D442]='MATHEMATICAL ITALIC CAPITAL O'
let s:d[0x1D443]='MATHEMATICAL ITALIC CAPITAL P'
let s:d[0x1D444]='MATHEMATICAL ITALIC CAPITAL Q'
let s:d[0x1D445]='MATHEMATICAL ITALIC CAPITAL R'
let s:d[0x1D446]='MATHEMATICAL ITALIC CAPITAL S'
let s:d[0x1D447]='MATHEMATICAL ITALIC CAPITAL T'
let s:d[0x1D448]='MATHEMATICAL ITALIC CAPITAL U'
let s:d[0x1D449]='MATHEMATICAL ITALIC CAPITAL V'
let s:d[0x1D44A]='MATHEMATICAL ITALIC CAPITAL W'
let s:d[0x1D44B]='MATHEMATICAL ITALIC CAPITAL X'
let s:d[0x1D44C]='MATHEMATICAL ITALIC CAPITAL Y'
let s:d[0x1D44D]='MATHEMATICAL ITALIC CAPITAL Z'
let s:d[0x1D44E]='MATHEMATICAL ITALIC SMALL A'
let s:d[0x1D44F]='MATHEMATICAL ITALIC SMALL B'
let s:d[0x1D450]='MATHEMATICAL ITALIC SMALL C'
let s:d[0x1D451]='MATHEMATICAL ITALIC SMALL D'
let s:d[0x1D452]='MATHEMATICAL ITALIC SMALL E'
let s:d[0x1D453]='MATHEMATICAL ITALIC SMALL F'
let s:d[0x1D454]='MATHEMATICAL ITALIC SMALL G'
let s:d[0x1D455]='<reserved>'
let s:d[0x1D456]='MATHEMATICAL ITALIC SMALL I'
let s:d[0x1D457]='MATHEMATICAL ITALIC SMALL J'
let s:d[0x1D458]='MATHEMATICAL ITALIC SMALL K'
let s:d[0x1D459]='MATHEMATICAL ITALIC SMALL L'
let s:d[0x1D45A]='MATHEMATICAL ITALIC SMALL M'
let s:d[0x1D45B]='MATHEMATICAL ITALIC SMALL N'
let s:d[0x1D45C]='MATHEMATICAL ITALIC SMALL O'
let s:d[0x1D45D]='MATHEMATICAL ITALIC SMALL P'
let s:d[0x1D45E]='MATHEMATICAL ITALIC SMALL Q'
let s:d[0x1D45F]='MATHEMATICAL ITALIC SMALL R'
let s:d[0x1D460]='MATHEMATICAL ITALIC SMALL S'
let s:d[0x1D461]='MATHEMATICAL ITALIC SMALL T'
let s:d[0x1D462]='MATHEMATICAL ITALIC SMALL U'
let s:d[0x1D463]='MATHEMATICAL ITALIC SMALL V'
let s:d[0x1D464]='MATHEMATICAL ITALIC SMALL W'
let s:d[0x1D465]='MATHEMATICAL ITALIC SMALL X'
let s:d[0x1D466]='MATHEMATICAL ITALIC SMALL Y'
let s:d[0x1D467]='MATHEMATICAL ITALIC SMALL Z'
let s:d[0x1D468]='MATHEMATICAL BOLD ITALIC CAPITAL A'
let s:d[0x1D469]='MATHEMATICAL BOLD ITALIC CAPITAL B'
let s:d[0x1D46A]='MATHEMATICAL BOLD ITALIC CAPITAL C'
let s:d[0x1D46B]='MATHEMATICAL BOLD ITALIC CAPITAL D'
let s:d[0x1D46C]='MATHEMATICAL BOLD ITALIC CAPITAL E'
let s:d[0x1D46D]='MATHEMATICAL BOLD ITALIC CAPITAL F'
let s:d[0x1D46E]='MATHEMATICAL BOLD ITALIC CAPITAL G'
let s:d[0x1D46F]='MATHEMATICAL BOLD ITALIC CAPITAL H'
let s:d[0x1D470]='MATHEMATICAL BOLD ITALIC CAPITAL I'
let s:d[0x1D471]='MATHEMATICAL BOLD ITALIC CAPITAL J'
let s:d[0x1D472]='MATHEMATICAL BOLD ITALIC CAPITAL K'
let s:d[0x1D473]='MATHEMATICAL BOLD ITALIC CAPITAL L'
let s:d[0x1D474]='MATHEMATICAL BOLD ITALIC CAPITAL M'
let s:d[0x1D475]='MATHEMATICAL BOLD ITALIC CAPITAL N'
let s:d[0x1D476]='MATHEMATICAL BOLD ITALIC CAPITAL O'
let s:d[0x1D477]='MATHEMATICAL BOLD ITALIC CAPITAL P'
let s:d[0x1D478]='MATHEMATICAL BOLD ITALIC CAPITAL Q'
let s:d[0x1D479]='MATHEMATICAL BOLD ITALIC CAPITAL R'
let s:d[0x1D47A]='MATHEMATICAL BOLD ITALIC CAPITAL S'
let s:d[0x1D47B]='MATHEMATICAL BOLD ITALIC CAPITAL T'
let s:d[0x1D47C]='MATHEMATICAL BOLD ITALIC CAPITAL U'
let s:d[0x1D47D]='MATHEMATICAL BOLD ITALIC CAPITAL V'
let s:d[0x1D47E]='MATHEMATICAL BOLD ITALIC CAPITAL W'
let s:d[0x1D47F]='MATHEMATICAL BOLD ITALIC CAPITAL X'
let s:d[0x1D480]='MATHEMATICAL BOLD ITALIC CAPITAL Y'
let s:d[0x1D481]='MATHEMATICAL BOLD ITALIC CAPITAL Z'
let s:d[0x1D482]='MATHEMATICAL BOLD ITALIC SMALL A'
let s:d[0x1D483]='MATHEMATICAL BOLD ITALIC SMALL B'
let s:d[0x1D484]='MATHEMATICAL BOLD ITALIC SMALL C'
let s:d[0x1D485]='MATHEMATICAL BOLD ITALIC SMALL D'
let s:d[0x1D486]='MATHEMATICAL BOLD ITALIC SMALL E'
let s:d[0x1D487]='MATHEMATICAL BOLD ITALIC SMALL F'
let s:d[0x1D488]='MATHEMATICAL BOLD ITALIC SMALL G'
let s:d[0x1D489]='MATHEMATICAL BOLD ITALIC SMALL H'
let s:d[0x1D48A]='MATHEMATICAL BOLD ITALIC SMALL I'
let s:d[0x1D48B]='MATHEMATICAL BOLD ITALIC SMALL J'
let s:d[0x1D48C]='MATHEMATICAL BOLD ITALIC SMALL K'
let s:d[0x1D48D]='MATHEMATICAL BOLD ITALIC SMALL L'
let s:d[0x1D48E]='MATHEMATICAL BOLD ITALIC SMALL M'
let s:d[0x1D48F]='MATHEMATICAL BOLD ITALIC SMALL N'
let s:d[0x1D490]='MATHEMATICAL BOLD ITALIC SMALL O'
let s:d[0x1D491]='MATHEMATICAL BOLD ITALIC SMALL P'
let s:d[0x1D492]='MATHEMATICAL BOLD ITALIC SMALL Q'
let s:d[0x1D493]='MATHEMATICAL BOLD ITALIC SMALL R'
let s:d[0x1D494]='MATHEMATICAL BOLD ITALIC SMALL S'
let s:d[0x1D495]='MATHEMATICAL BOLD ITALIC SMALL T'
let s:d[0x1D496]='MATHEMATICAL BOLD ITALIC SMALL U'
let s:d[0x1D497]='MATHEMATICAL BOLD ITALIC SMALL V'
let s:d[0x1D498]='MATHEMATICAL BOLD ITALIC SMALL W'
let s:d[0x1D499]='MATHEMATICAL BOLD ITALIC SMALL X'
let s:d[0x1D49A]='MATHEMATICAL BOLD ITALIC SMALL Y'
let s:d[0x1D49B]='MATHEMATICAL BOLD ITALIC SMALL Z'
let s:d[0x1D49C]='MATHEMATICAL SCRIPT CAPITAL A'
let s:d[0x1D49D]='<reserved>'
let s:d[0x1D49E]='MATHEMATICAL SCRIPT CAPITAL C'
let s:d[0x1D49F]='MATHEMATICAL SCRIPT CAPITAL D'
let s:d[0x1D4A0]='<reserved>'
let s:d[0x1D4A1]='<reserved>'
let s:d[0x1D4A2]='MATHEMATICAL SCRIPT CAPITAL G'
let s:d[0x1D4A3]='<reserved>'
let s:d[0x1D4A4]='<reserved>'
let s:d[0x1D4A5]='MATHEMATICAL SCRIPT CAPITAL J'
let s:d[0x1D4A6]='MATHEMATICAL SCRIPT CAPITAL K'
let s:d[0x1D4A7]='<reserved>'
let s:d[0x1D4A8]='<reserved>'
let s:d[0x1D4A9]='MATHEMATICAL SCRIPT CAPITAL N'
let s:d[0x1D4AA]='MATHEMATICAL SCRIPT CAPITAL O'
let s:d[0x1D4AB]='MATHEMATICAL SCRIPT CAPITAL P'
let s:d[0x1D4AC]='MATHEMATICAL SCRIPT CAPITAL Q'
let s:d[0x1D4AD]='<reserved>'
let s:d[0x1D4AE]='MATHEMATICAL SCRIPT CAPITAL S'
let s:d[0x1D4AF]='MATHEMATICAL SCRIPT CAPITAL T'
let s:d[0x1D4B0]='MATHEMATICAL SCRIPT CAPITAL U'
let s:d[0x1D4B1]='MATHEMATICAL SCRIPT CAPITAL V'
let s:d[0x1D4B2]='MATHEMATICAL SCRIPT CAPITAL W'
let s:d[0x1D4B3]='MATHEMATICAL SCRIPT CAPITAL X'
let s:d[0x1D4B4]='MATHEMATICAL SCRIPT CAPITAL Y'
let s:d[0x1D4B5]='MATHEMATICAL SCRIPT CAPITAL Z'
let s:d[0x1D4B6]='MATHEMATICAL SCRIPT SMALL A'
let s:d[0x1D4B7]='MATHEMATICAL SCRIPT SMALL B'
let s:d[0x1D4B8]='MATHEMATICAL SCRIPT SMALL C'
let s:d[0x1D4B9]='MATHEMATICAL SCRIPT SMALL D'
let s:d[0x1D4BA]='<reserved>'
let s:d[0x1D4BB]='MATHEMATICAL SCRIPT SMALL F'
let s:d[0x1D4BC]='<reserved>'
let s:d[0x1D4BD]='MATHEMATICAL SCRIPT SMALL H'
let s:d[0x1D4BE]='MATHEMATICAL SCRIPT SMALL I'
let s:d[0x1D4BF]='MATHEMATICAL SCRIPT SMALL J'
let s:d[0x1D4C0]='MATHEMATICAL SCRIPT SMALL K'
let s:d[0x1D4C1]='MATHEMATICAL SCRIPT SMALL L'
let s:d[0x1D4C2]='MATHEMATICAL SCRIPT SMALL M'
let s:d[0x1D4C3]='MATHEMATICAL SCRIPT SMALL N'
let s:d[0x1D4C4]='<reserved>'
let s:d[0x1D4C5]='MATHEMATICAL SCRIPT SMALL P'
let s:d[0x1D4C6]='MATHEMATICAL SCRIPT SMALL Q'
let s:d[0x1D4C7]='MATHEMATICAL SCRIPT SMALL R'
let s:d[0x1D4C8]='MATHEMATICAL SCRIPT SMALL S'
let s:d[0x1D4C9]='MATHEMATICAL SCRIPT SMALL T'
let s:d[0x1D4CA]='MATHEMATICAL SCRIPT SMALL U'
let s:d[0x1D4CB]='MATHEMATICAL SCRIPT SMALL V'
let s:d[0x1D4CC]='MATHEMATICAL SCRIPT SMALL W'
let s:d[0x1D4CD]='MATHEMATICAL SCRIPT SMALL X'
let s:d[0x1D4CE]='MATHEMATICAL SCRIPT SMALL Y'
let s:d[0x1D4CF]='MATHEMATICAL SCRIPT SMALL Z'
let s:d[0x1D4D0]='MATHEMATICAL BOLD SCRIPT CAPITAL A'
let s:d[0x1D4D1]='MATHEMATICAL BOLD SCRIPT CAPITAL B'
let s:d[0x1D4D2]='MATHEMATICAL BOLD SCRIPT CAPITAL C'
let s:d[0x1D4D3]='MATHEMATICAL BOLD SCRIPT CAPITAL D'
let s:d[0x1D4D4]='MATHEMATICAL BOLD SCRIPT CAPITAL E'
let s:d[0x1D4D5]='MATHEMATICAL BOLD SCRIPT CAPITAL F'
let s:d[0x1D4D6]='MATHEMATICAL BOLD SCRIPT CAPITAL G'
let s:d[0x1D4D7]='MATHEMATICAL BOLD SCRIPT CAPITAL H'
let s:d[0x1D4D8]='MATHEMATICAL BOLD SCRIPT CAPITAL I'
let s:d[0x1D4D9]='MATHEMATICAL BOLD SCRIPT CAPITAL J'
let s:d[0x1D4DA]='MATHEMATICAL BOLD SCRIPT CAPITAL K'
let s:d[0x1D4DB]='MATHEMATICAL BOLD SCRIPT CAPITAL L'
let s:d[0x1D4DC]='MATHEMATICAL BOLD SCRIPT CAPITAL M'
let s:d[0x1D4DD]='MATHEMATICAL BOLD SCRIPT CAPITAL N'
let s:d[0x1D4DE]='MATHEMATICAL BOLD SCRIPT CAPITAL O'
let s:d[0x1D4DF]='MATHEMATICAL BOLD SCRIPT CAPITAL P'
let s:d[0x1D4E0]='MATHEMATICAL BOLD SCRIPT CAPITAL Q'
let s:d[0x1D4E1]='MATHEMATICAL BOLD SCRIPT CAPITAL R'
let s:d[0x1D4E2]='MATHEMATICAL BOLD SCRIPT CAPITAL S'
let s:d[0x1D4E3]='MATHEMATICAL BOLD SCRIPT CAPITAL T'
let s:d[0x1D4E4]='MATHEMATICAL BOLD SCRIPT CAPITAL U'
let s:d[0x1D4E5]='MATHEMATICAL BOLD SCRIPT CAPITAL V'
let s:d[0x1D4E6]='MATHEMATICAL BOLD SCRIPT CAPITAL W'
let s:d[0x1D4E7]='MATHEMATICAL BOLD SCRIPT CAPITAL X'
let s:d[0x1D4E8]='MATHEMATICAL BOLD SCRIPT CAPITAL Y'
let s:d[0x1D4E9]='MATHEMATICAL BOLD SCRIPT CAPITAL Z'
let s:d[0x1D4EA]='MATHEMATICAL BOLD SCRIPT SMALL A'
let s:d[0x1D4EB]='MATHEMATICAL BOLD SCRIPT SMALL B'
let s:d[0x1D4EC]='MATHEMATICAL BOLD SCRIPT SMALL C'
let s:d[0x1D4ED]='MATHEMATICAL BOLD SCRIPT SMALL D'
let s:d[0x1D4EE]='MATHEMATICAL BOLD SCRIPT SMALL E'
let s:d[0x1D4EF]='MATHEMATICAL BOLD SCRIPT SMALL F'
let s:d[0x1D4F0]='MATHEMATICAL BOLD SCRIPT SMALL G'
let s:d[0x1D4F1]='MATHEMATICAL BOLD SCRIPT SMALL H'
let s:d[0x1D4F2]='MATHEMATICAL BOLD SCRIPT SMALL I'
let s:d[0x1D4F3]='MATHEMATICAL BOLD SCRIPT SMALL J'
let s:d[0x1D4F4]='MATHEMATICAL BOLD SCRIPT SMALL K'
let s:d[0x1D4F5]='MATHEMATICAL BOLD SCRIPT SMALL L'
let s:d[0x1D4F6]='MATHEMATICAL BOLD SCRIPT SMALL M'
let s:d[0x1D4F7]='MATHEMATICAL BOLD SCRIPT SMALL N'
let s:d[0x1D4F8]='MATHEMATICAL BOLD SCRIPT SMALL O'
let s:d[0x1D4F9]='MATHEMATICAL BOLD SCRIPT SMALL P'
let s:d[0x1D4FA]='MATHEMATICAL BOLD SCRIPT SMALL Q'
let s:d[0x1D4FB]='MATHEMATICAL BOLD SCRIPT SMALL R'
let s:d[0x1D4FC]='MATHEMATICAL BOLD SCRIPT SMALL S'
let s:d[0x1D4FD]='MATHEMATICAL BOLD SCRIPT SMALL T'
let s:d[0x1D4FE]='MATHEMATICAL BOLD SCRIPT SMALL U'
let s:d[0x1D4FF]='MATHEMATICAL BOLD SCRIPT SMALL V'
let s:d[0x1D500]='MATHEMATICAL BOLD SCRIPT SMALL W'
let s:d[0x1D501]='MATHEMATICAL BOLD SCRIPT SMALL X'
let s:d[0x1D502]='MATHEMATICAL BOLD SCRIPT SMALL Y'
let s:d[0x1D503]='MATHEMATICAL BOLD SCRIPT SMALL Z'
let s:d[0x1D504]='MATHEMATICAL FRAKTUR CAPITAL A'
let s:d[0x1D505]='MATHEMATICAL FRAKTUR CAPITAL B'
let s:d[0x1D506]='<reserved>'
let s:d[0x1D507]='MATHEMATICAL FRAKTUR CAPITAL D'
let s:d[0x1D508]='MATHEMATICAL FRAKTUR CAPITAL E'
let s:d[0x1D509]='MATHEMATICAL FRAKTUR CAPITAL F'
let s:d[0x1D50A]='MATHEMATICAL FRAKTUR CAPITAL G'
let s:d[0x1D50B]='<reserved>'
let s:d[0x1D50C]='<reserved>'
let s:d[0x1D50D]='MATHEMATICAL FRAKTUR CAPITAL J'
let s:d[0x1D50E]='MATHEMATICAL FRAKTUR CAPITAL K'
let s:d[0x1D50F]='MATHEMATICAL FRAKTUR CAPITAL L'
let s:d[0x1D510]='MATHEMATICAL FRAKTUR CAPITAL M'
let s:d[0x1D511]='MATHEMATICAL FRAKTUR CAPITAL N'
let s:d[0x1D512]='MATHEMATICAL FRAKTUR CAPITAL O'
let s:d[0x1D513]='MATHEMATICAL FRAKTUR CAPITAL P'
let s:d[0x1D514]='MATHEMATICAL FRAKTUR CAPITAL Q'
let s:d[0x1D515]='<reserved>'
let s:d[0x1D516]='MATHEMATICAL FRAKTUR CAPITAL S'
let s:d[0x1D517]='MATHEMATICAL FRAKTUR CAPITAL T'
let s:d[0x1D518]='MATHEMATICAL FRAKTUR CAPITAL U'
let s:d[0x1D519]='MATHEMATICAL FRAKTUR CAPITAL V'
let s:d[0x1D51A]='MATHEMATICAL FRAKTUR CAPITAL W'
let s:d[0x1D51B]='MATHEMATICAL FRAKTUR CAPITAL X'
let s:d[0x1D51C]='MATHEMATICAL FRAKTUR CAPITAL Y'
let s:d[0x1D51D]='<reserved>'
let s:d[0x1D51E]='MATHEMATICAL FRAKTUR SMALL A'
let s:d[0x1D51F]='MATHEMATICAL FRAKTUR SMALL B'
let s:d[0x1D520]='MATHEMATICAL FRAKTUR SMALL C'
let s:d[0x1D521]='MATHEMATICAL FRAKTUR SMALL D'
let s:d[0x1D522]='MATHEMATICAL FRAKTUR SMALL E'
let s:d[0x1D523]='MATHEMATICAL FRAKTUR SMALL F'
let s:d[0x1D524]='MATHEMATICAL FRAKTUR SMALL G'
let s:d[0x1D525]='MATHEMATICAL FRAKTUR SMALL H'
let s:d[0x1D526]='MATHEMATICAL FRAKTUR SMALL I'
let s:d[0x1D527]='MATHEMATICAL FRAKTUR SMALL J'
let s:d[0x1D528]='MATHEMATICAL FRAKTUR SMALL K'
let s:d[0x1D529]='MATHEMATICAL FRAKTUR SMALL L'
let s:d[0x1D52A]='MATHEMATICAL FRAKTUR SMALL M'
let s:d[0x1D52B]='MATHEMATICAL FRAKTUR SMALL N'
let s:d[0x1D52C]='MATHEMATICAL FRAKTUR SMALL O'
let s:d[0x1D52D]='MATHEMATICAL FRAKTUR SMALL P'
let s:d[0x1D52E]='MATHEMATICAL FRAKTUR SMALL Q'
let s:d[0x1D52F]='MATHEMATICAL FRAKTUR SMALL R'
let s:d[0x1D530]='MATHEMATICAL FRAKTUR SMALL S'
let s:d[0x1D531]='MATHEMATICAL FRAKTUR SMALL T'
let s:d[0x1D532]='MATHEMATICAL FRAKTUR SMALL U'
let s:d[0x1D533]='MATHEMATICAL FRAKTUR SMALL V'
let s:d[0x1D534]='MATHEMATICAL FRAKTUR SMALL W'
let s:d[0x1D535]='MATHEMATICAL FRAKTUR SMALL X'
let s:d[0x1D536]='MATHEMATICAL FRAKTUR SMALL Y'
let s:d[0x1D537]='MATHEMATICAL FRAKTUR SMALL Z'
let s:d[0x1D538]='MATHEMATICAL DOUBLE-STRUCK CAPITAL A'
let s:d[0x1D539]='MATHEMATICAL DOUBLE-STRUCK CAPITAL B'
let s:d[0x1D53A]='<reserved>'
let s:d[0x1D53B]='MATHEMATICAL DOUBLE-STRUCK CAPITAL D'
let s:d[0x1D53C]='MATHEMATICAL DOUBLE-STRUCK CAPITAL E'
let s:d[0x1D53D]='MATHEMATICAL DOUBLE-STRUCK CAPITAL F'
let s:d[0x1D53E]='MATHEMATICAL DOUBLE-STRUCK CAPITAL G'
let s:d[0x1D53F]='<reserved>'
let s:d[0x1D540]='MATHEMATICAL DOUBLE-STRUCK CAPITAL I'
let s:d[0x1D541]='MATHEMATICAL DOUBLE-STRUCK CAPITAL J'
let s:d[0x1D542]='MATHEMATICAL DOUBLE-STRUCK CAPITAL K'
let s:d[0x1D543]='MATHEMATICAL DOUBLE-STRUCK CAPITAL L'
let s:d[0x1D544]='MATHEMATICAL DOUBLE-STRUCK CAPITAL M'
let s:d[0x1D545]='<reserved>'
let s:d[0x1D546]='MATHEMATICAL DOUBLE-STRUCK CAPITAL O'
let s:d[0x1D547]='<reserved>'
let s:d[0x1D548]='<reserved>'
let s:d[0x1D549]='<reserved>'
let s:d[0x1D54A]='MATHEMATICAL DOUBLE-STRUCK CAPITAL S'
let s:d[0x1D54B]='MATHEMATICAL DOUBLE-STRUCK CAPITAL T'
let s:d[0x1D54C]='MATHEMATICAL DOUBLE-STRUCK CAPITAL U'
let s:d[0x1D54D]='MATHEMATICAL DOUBLE-STRUCK CAPITAL V'
let s:d[0x1D54E]='MATHEMATICAL DOUBLE-STRUCK CAPITAL W'
let s:d[0x1D54F]='MATHEMATICAL DOUBLE-STRUCK CAPITAL X'
let s:d[0x1D550]='MATHEMATICAL DOUBLE-STRUCK CAPITAL Y'
let s:d[0x1D551]='<reserved>'
let s:d[0x1D552]='MATHEMATICAL DOUBLE-STRUCK SMALL A'
let s:d[0x1D553]='MATHEMATICAL DOUBLE-STRUCK SMALL B'
let s:d[0x1D554]='MATHEMATICAL DOUBLE-STRUCK SMALL C'
let s:d[0x1D555]='MATHEMATICAL DOUBLE-STRUCK SMALL D'
let s:d[0x1D556]='MATHEMATICAL DOUBLE-STRUCK SMALL E'
let s:d[0x1D557]='MATHEMATICAL DOUBLE-STRUCK SMALL F'
let s:d[0x1D558]='MATHEMATICAL DOUBLE-STRUCK SMALL G'
let s:d[0x1D559]='MATHEMATICAL DOUBLE-STRUCK SMALL H'
let s:d[0x1D55A]='MATHEMATICAL DOUBLE-STRUCK SMALL I'
let s:d[0x1D55B]='MATHEMATICAL DOUBLE-STRUCK SMALL J'
let s:d[0x1D55C]='MATHEMATICAL DOUBLE-STRUCK SMALL K'
let s:d[0x1D55D]='MATHEMATICAL DOUBLE-STRUCK SMALL L'
let s:d[0x1D55E]='MATHEMATICAL DOUBLE-STRUCK SMALL M'
let s:d[0x1D55F]='MATHEMATICAL DOUBLE-STRUCK SMALL N'
let s:d[0x1D560]='MATHEMATICAL DOUBLE-STRUCK SMALL O'
let s:d[0x1D561]='MATHEMATICAL DOUBLE-STRUCK SMALL P'
let s:d[0x1D562]='MATHEMATICAL DOUBLE-STRUCK SMALL Q'
let s:d[0x1D563]='MATHEMATICAL DOUBLE-STRUCK SMALL R'
let s:d[0x1D564]='MATHEMATICAL DOUBLE-STRUCK SMALL S'
let s:d[0x1D565]='MATHEMATICAL DOUBLE-STRUCK SMALL T'
let s:d[0x1D566]='MATHEMATICAL DOUBLE-STRUCK SMALL U'
let s:d[0x1D567]='MATHEMATICAL DOUBLE-STRUCK SMALL V'
let s:d[0x1D568]='MATHEMATICAL DOUBLE-STRUCK SMALL W'
let s:d[0x1D569]='MATHEMATICAL DOUBLE-STRUCK SMALL X'
let s:d[0x1D56A]='MATHEMATICAL DOUBLE-STRUCK SMALL Y'
let s:d[0x1D56B]='MATHEMATICAL DOUBLE-STRUCK SMALL Z'
let s:d[0x1D56C]='MATHEMATICAL BOLD FRAKTUR CAPITAL A'
let s:d[0x1D56D]='MATHEMATICAL BOLD FRAKTUR CAPITAL B'
let s:d[0x1D56E]='MATHEMATICAL BOLD FRAKTUR CAPITAL C'
let s:d[0x1D56F]='MATHEMATICAL BOLD FRAKTUR CAPITAL D'
let s:d[0x1D570]='MATHEMATICAL BOLD FRAKTUR CAPITAL E'
let s:d[0x1D571]='MATHEMATICAL BOLD FRAKTUR CAPITAL F'
let s:d[0x1D572]='MATHEMATICAL BOLD FRAKTUR CAPITAL G'
let s:d[0x1D573]='MATHEMATICAL BOLD FRAKTUR CAPITAL H'
let s:d[0x1D574]='MATHEMATICAL BOLD FRAKTUR CAPITAL I'
let s:d[0x1D575]='MATHEMATICAL BOLD FRAKTUR CAPITAL J'
let s:d[0x1D576]='MATHEMATICAL BOLD FRAKTUR CAPITAL K'
let s:d[0x1D577]='MATHEMATICAL BOLD FRAKTUR CAPITAL L'
let s:d[0x1D578]='MATHEMATICAL BOLD FRAKTUR CAPITAL M'
let s:d[0x1D579]='MATHEMATICAL BOLD FRAKTUR CAPITAL N'
let s:d[0x1D57A]='MATHEMATICAL BOLD FRAKTUR CAPITAL O'
let s:d[0x1D57B]='MATHEMATICAL BOLD FRAKTUR CAPITAL P'
let s:d[0x1D57C]='MATHEMATICAL BOLD FRAKTUR CAPITAL Q'
let s:d[0x1D57D]='MATHEMATICAL BOLD FRAKTUR CAPITAL R'
let s:d[0x1D57E]='MATHEMATICAL BOLD FRAKTUR CAPITAL S'
let s:d[0x1D57F]='MATHEMATICAL BOLD FRAKTUR CAPITAL T'
let s:d[0x1D580]='MATHEMATICAL BOLD FRAKTUR CAPITAL U'
let s:d[0x1D581]='MATHEMATICAL BOLD FRAKTUR CAPITAL V'
let s:d[0x1D582]='MATHEMATICAL BOLD FRAKTUR CAPITAL W'
let s:d[0x1D583]='MATHEMATICAL BOLD FRAKTUR CAPITAL X'
let s:d[0x1D584]='MATHEMATICAL BOLD FRAKTUR CAPITAL Y'
let s:d[0x1D585]='MATHEMATICAL BOLD FRAKTUR CAPITAL Z'
let s:d[0x1D586]='MATHEMATICAL BOLD FRAKTUR SMALL A'
let s:d[0x1D587]='MATHEMATICAL BOLD FRAKTUR SMALL B'
let s:d[0x1D588]='MATHEMATICAL BOLD FRAKTUR SMALL C'
let s:d[0x1D589]='MATHEMATICAL BOLD FRAKTUR SMALL D'
let s:d[0x1D58A]='MATHEMATICAL BOLD FRAKTUR SMALL E'
let s:d[0x1D58B]='MATHEMATICAL BOLD FRAKTUR SMALL F'
let s:d[0x1D58C]='MATHEMATICAL BOLD FRAKTUR SMALL G'
let s:d[0x1D58D]='MATHEMATICAL BOLD FRAKTUR SMALL H'
let s:d[0x1D58E]='MATHEMATICAL BOLD FRAKTUR SMALL I'
let s:d[0x1D58F]='MATHEMATICAL BOLD FRAKTUR SMALL J'
let s:d[0x1D590]='MATHEMATICAL BOLD FRAKTUR SMALL K'
let s:d[0x1D591]='MATHEMATICAL BOLD FRAKTUR SMALL L'
let s:d[0x1D592]='MATHEMATICAL BOLD FRAKTUR SMALL M'
let s:d[0x1D593]='MATHEMATICAL BOLD FRAKTUR SMALL N'
let s:d[0x1D594]='MATHEMATICAL BOLD FRAKTUR SMALL O'
let s:d[0x1D595]='MATHEMATICAL BOLD FRAKTUR SMALL P'
let s:d[0x1D596]='MATHEMATICAL BOLD FRAKTUR SMALL Q'
let s:d[0x1D597]='MATHEMATICAL BOLD FRAKTUR SMALL R'
let s:d[0x1D598]='MATHEMATICAL BOLD FRAKTUR SMALL S'
let s:d[0x1D599]='MATHEMATICAL BOLD FRAKTUR SMALL T'
let s:d[0x1D59A]='MATHEMATICAL BOLD FRAKTUR SMALL U'
let s:d[0x1D59B]='MATHEMATICAL BOLD FRAKTUR SMALL V'
let s:d[0x1D59C]='MATHEMATICAL BOLD FRAKTUR SMALL W'
let s:d[0x1D59D]='MATHEMATICAL BOLD FRAKTUR SMALL X'
let s:d[0x1D59E]='MATHEMATICAL BOLD FRAKTUR SMALL Y'
let s:d[0x1D59F]='MATHEMATICAL BOLD FRAKTUR SMALL Z'
let s:d[0x1D5A0]='MATHEMATICAL SANS-SERIF CAPITAL A'
let s:d[0x1D5A1]='MATHEMATICAL SANS-SERIF CAPITAL B'
let s:d[0x1D5A2]='MATHEMATICAL SANS-SERIF CAPITAL C'
let s:d[0x1D5A3]='MATHEMATICAL SANS-SERIF CAPITAL D'
let s:d[0x1D5A4]='MATHEMATICAL SANS-SERIF CAPITAL E'
let s:d[0x1D5A5]='MATHEMATICAL SANS-SERIF CAPITAL F'
let s:d[0x1D5A6]='MATHEMATICAL SANS-SERIF CAPITAL G'
let s:d[0x1D5A7]='MATHEMATICAL SANS-SERIF CAPITAL H'
let s:d[0x1D5A8]='MATHEMATICAL SANS-SERIF CAPITAL I'
let s:d[0x1D5A9]='MATHEMATICAL SANS-SERIF CAPITAL J'
let s:d[0x1D5AA]='MATHEMATICAL SANS-SERIF CAPITAL K'
let s:d[0x1D5AB]='MATHEMATICAL SANS-SERIF CAPITAL L'
let s:d[0x1D5AC]='MATHEMATICAL SANS-SERIF CAPITAL M'
let s:d[0x1D5AD]='MATHEMATICAL SANS-SERIF CAPITAL N'
let s:d[0x1D5AE]='MATHEMATICAL SANS-SERIF CAPITAL O'
let s:d[0x1D5AF]='MATHEMATICAL SANS-SERIF CAPITAL P'
let s:d[0x1D5B0]='MATHEMATICAL SANS-SERIF CAPITAL Q'
let s:d[0x1D5B1]='MATHEMATICAL SANS-SERIF CAPITAL R'
let s:d[0x1D5B2]='MATHEMATICAL SANS-SERIF CAPITAL S'
let s:d[0x1D5B3]='MATHEMATICAL SANS-SERIF CAPITAL T'
let s:d[0x1D5B4]='MATHEMATICAL SANS-SERIF CAPITAL U'
let s:d[0x1D5B5]='MATHEMATICAL SANS-SERIF CAPITAL V'
let s:d[0x1D5B6]='MATHEMATICAL SANS-SERIF CAPITAL W'
let s:d[0x1D5B7]='MATHEMATICAL SANS-SERIF CAPITAL X'
let s:d[0x1D5B8]='MATHEMATICAL SANS-SERIF CAPITAL Y'
let s:d[0x1D5B9]='MATHEMATICAL SANS-SERIF CAPITAL Z'
let s:d[0x1D5BA]='MATHEMATICAL SANS-SERIF SMALL A'
let s:d[0x1D5BB]='MATHEMATICAL SANS-SERIF SMALL B'
let s:d[0x1D5BC]='MATHEMATICAL SANS-SERIF SMALL C'
let s:d[0x1D5BD]='MATHEMATICAL SANS-SERIF SMALL D'
let s:d[0x1D5BE]='MATHEMATICAL SANS-SERIF SMALL E'
let s:d[0x1D5BF]='MATHEMATICAL SANS-SERIF SMALL F'
let s:d[0x1D5C0]='MATHEMATICAL SANS-SERIF SMALL G'
let s:d[0x1D5C1]='MATHEMATICAL SANS-SERIF SMALL H'
let s:d[0x1D5C2]='MATHEMATICAL SANS-SERIF SMALL I'
let s:d[0x1D5C3]='MATHEMATICAL SANS-SERIF SMALL J'
let s:d[0x1D5C4]='MATHEMATICAL SANS-SERIF SMALL K'
let s:d[0x1D5C5]='MATHEMATICAL SANS-SERIF SMALL L'
let s:d[0x1D5C6]='MATHEMATICAL SANS-SERIF SMALL M'
let s:d[0x1D5C7]='MATHEMATICAL SANS-SERIF SMALL N'
let s:d[0x1D5C8]='MATHEMATICAL SANS-SERIF SMALL O'
let s:d[0x1D5C9]='MATHEMATICAL SANS-SERIF SMALL P'
let s:d[0x1D5CA]='MATHEMATICAL SANS-SERIF SMALL Q'
let s:d[0x1D5CB]='MATHEMATICAL SANS-SERIF SMALL R'
let s:d[0x1D5CC]='MATHEMATICAL SANS-SERIF SMALL S'
let s:d[0x1D5CD]='MATHEMATICAL SANS-SERIF SMALL T'
let s:d[0x1D5CE]='MATHEMATICAL SANS-SERIF SMALL U'
let s:d[0x1D5CF]='MATHEMATICAL SANS-SERIF SMALL V'
let s:d[0x1D5D0]='MATHEMATICAL SANS-SERIF SMALL W'
let s:d[0x1D5D1]='MATHEMATICAL SANS-SERIF SMALL X'
let s:d[0x1D5D2]='MATHEMATICAL SANS-SERIF SMALL Y'
let s:d[0x1D5D3]='MATHEMATICAL SANS-SERIF SMALL Z'
let s:d[0x1D5D4]='MATHEMATICAL SANS-SERIF BOLD CAPITAL A'
let s:d[0x1D5D5]='MATHEMATICAL SANS-SERIF BOLD CAPITAL B'
let s:d[0x1D5D6]='MATHEMATICAL SANS-SERIF BOLD CAPITAL C'
let s:d[0x1D5D7]='MATHEMATICAL SANS-SERIF BOLD CAPITAL D'
let s:d[0x1D5D8]='MATHEMATICAL SANS-SERIF BOLD CAPITAL E'
let s:d[0x1D5D9]='MATHEMATICAL SANS-SERIF BOLD CAPITAL F'
let s:d[0x1D5DA]='MATHEMATICAL SANS-SERIF BOLD CAPITAL G'
let s:d[0x1D5DB]='MATHEMATICAL SANS-SERIF BOLD CAPITAL H'
let s:d[0x1D5DC]='MATHEMATICAL SANS-SERIF BOLD CAPITAL I'
let s:d[0x1D5DD]='MATHEMATICAL SANS-SERIF BOLD CAPITAL J'
let s:d[0x1D5DE]='MATHEMATICAL SANS-SERIF BOLD CAPITAL K'
let s:d[0x1D5DF]='MATHEMATICAL SANS-SERIF BOLD CAPITAL L'
let s:d[0x1D5E0]='MATHEMATICAL SANS-SERIF BOLD CAPITAL M'
let s:d[0x1D5E1]='MATHEMATICAL SANS-SERIF BOLD CAPITAL N'
let s:d[0x1D5E2]='MATHEMATICAL SANS-SERIF BOLD CAPITAL O'
let s:d[0x1D5E3]='MATHEMATICAL SANS-SERIF BOLD CAPITAL P'
let s:d[0x1D5E4]='MATHEMATICAL SANS-SERIF BOLD CAPITAL Q'
let s:d[0x1D5E5]='MATHEMATICAL SANS-SERIF BOLD CAPITAL R'
let s:d[0x1D5E6]='MATHEMATICAL SANS-SERIF BOLD CAPITAL S'
let s:d[0x1D5E7]='MATHEMATICAL SANS-SERIF BOLD CAPITAL T'
let s:d[0x1D5E8]='MATHEMATICAL SANS-SERIF BOLD CAPITAL U'
let s:d[0x1D5E9]='MATHEMATICAL SANS-SERIF BOLD CAPITAL V'
let s:d[0x1D5EA]='MATHEMATICAL SANS-SERIF BOLD CAPITAL W'
let s:d[0x1D5EB]='MATHEMATICAL SANS-SERIF BOLD CAPITAL X'
let s:d[0x1D5EC]='MATHEMATICAL SANS-SERIF BOLD CAPITAL Y'
let s:d[0x1D5ED]='MATHEMATICAL SANS-SERIF BOLD CAPITAL Z'
let s:d[0x1D5EE]='MATHEMATICAL SANS-SERIF BOLD SMALL A'
let s:d[0x1D5EF]='MATHEMATICAL SANS-SERIF BOLD SMALL B'
let s:d[0x1D5F0]='MATHEMATICAL SANS-SERIF BOLD SMALL C'
let s:d[0x1D5F1]='MATHEMATICAL SANS-SERIF BOLD SMALL D'
let s:d[0x1D5F2]='MATHEMATICAL SANS-SERIF BOLD SMALL E'
let s:d[0x1D5F3]='MATHEMATICAL SANS-SERIF BOLD SMALL F'
let s:d[0x1D5F4]='MATHEMATICAL SANS-SERIF BOLD SMALL G'
let s:d[0x1D5F5]='MATHEMATICAL SANS-SERIF BOLD SMALL H'
let s:d[0x1D5F6]='MATHEMATICAL SANS-SERIF BOLD SMALL I'
let s:d[0x1D5F7]='MATHEMATICAL SANS-SERIF BOLD SMALL J'
let s:d[0x1D5F8]='MATHEMATICAL SANS-SERIF BOLD SMALL K'
let s:d[0x1D5F9]='MATHEMATICAL SANS-SERIF BOLD SMALL L'
let s:d[0x1D5FA]='MATHEMATICAL SANS-SERIF BOLD SMALL M'
let s:d[0x1D5FB]='MATHEMATICAL SANS-SERIF BOLD SMALL N'
let s:d[0x1D5FC]='MATHEMATICAL SANS-SERIF BOLD SMALL O'
let s:d[0x1D5FD]='MATHEMATICAL SANS-SERIF BOLD SMALL P'
let s:d[0x1D5FE]='MATHEMATICAL SANS-SERIF BOLD SMALL Q'
let s:d[0x1D5FF]='MATHEMATICAL SANS-SERIF BOLD SMALL R'
let s:d[0x1D600]='MATHEMATICAL SANS-SERIF BOLD SMALL S'
let s:d[0x1D601]='MATHEMATICAL SANS-SERIF BOLD SMALL T'
let s:d[0x1D602]='MATHEMATICAL SANS-SERIF BOLD SMALL U'
let s:d[0x1D603]='MATHEMATICAL SANS-SERIF BOLD SMALL V'
let s:d[0x1D604]='MATHEMATICAL SANS-SERIF BOLD SMALL W'
let s:d[0x1D605]='MATHEMATICAL SANS-SERIF BOLD SMALL X'
let s:d[0x1D606]='MATHEMATICAL SANS-SERIF BOLD SMALL Y'
let s:d[0x1D607]='MATHEMATICAL SANS-SERIF BOLD SMALL Z'
let s:d[0x1D608]='MATHEMATICAL SANS-SERIF ITALIC CAPITAL A'
let s:d[0x1D609]='MATHEMATICAL SANS-SERIF ITALIC CAPITAL B'
let s:d[0x1D60A]='MATHEMATICAL SANS-SERIF ITALIC CAPITAL C'
let s:d[0x1D60B]='MATHEMATICAL SANS-SERIF ITALIC CAPITAL D'
let s:d[0x1D60C]='MATHEMATICAL SANS-SERIF ITALIC CAPITAL E'
let s:d[0x1D60D]='MATHEMATICAL SANS-SERIF ITALIC CAPITAL F'
let s:d[0x1D60E]='MATHEMATICAL SANS-SERIF ITALIC CAPITAL G'
let s:d[0x1D60F]='MATHEMATICAL SANS-SERIF ITALIC CAPITAL H'
let s:d[0x1D610]='MATHEMATICAL SANS-SERIF ITALIC CAPITAL I'
let s:d[0x1D611]='MATHEMATICAL SANS-SERIF ITALIC CAPITAL J'
let s:d[0x1D612]='MATHEMATICAL SANS-SERIF ITALIC CAPITAL K'
let s:d[0x1D613]='MATHEMATICAL SANS-SERIF ITALIC CAPITAL L'
let s:d[0x1D614]='MATHEMATICAL SANS-SERIF ITALIC CAPITAL M'
let s:d[0x1D615]='MATHEMATICAL SANS-SERIF ITALIC CAPITAL N'
let s:d[0x1D616]='MATHEMATICAL SANS-SERIF ITALIC CAPITAL O'
let s:d[0x1D617]='MATHEMATICAL SANS-SERIF ITALIC CAPITAL P'
let s:d[0x1D618]='MATHEMATICAL SANS-SERIF ITALIC CAPITAL Q'
let s:d[0x1D619]='MATHEMATICAL SANS-SERIF ITALIC CAPITAL R'
let s:d[0x1D61A]='MATHEMATICAL SANS-SERIF ITALIC CAPITAL S'
let s:d[0x1D61B]='MATHEMATICAL SANS-SERIF ITALIC CAPITAL T'
let s:d[0x1D61C]='MATHEMATICAL SANS-SERIF ITALIC CAPITAL U'
let s:d[0x1D61D]='MATHEMATICAL SANS-SERIF ITALIC CAPITAL V'
let s:d[0x1D61E]='MATHEMATICAL SANS-SERIF ITALIC CAPITAL W'
let s:d[0x1D61F]='MATHEMATICAL SANS-SERIF ITALIC CAPITAL X'
let s:d[0x1D620]='MATHEMATICAL SANS-SERIF ITALIC CAPITAL Y'
let s:d[0x1D621]='MATHEMATICAL SANS-SERIF ITALIC CAPITAL Z'
let s:d[0x1D622]='MATHEMATICAL SANS-SERIF ITALIC SMALL A'
let s:d[0x1D623]='MATHEMATICAL SANS-SERIF ITALIC SMALL B'
let s:d[0x1D624]='MATHEMATICAL SANS-SERIF ITALIC SMALL C'
let s:d[0x1D625]='MATHEMATICAL SANS-SERIF ITALIC SMALL D'
let s:d[0x1D626]='MATHEMATICAL SANS-SERIF ITALIC SMALL E'
let s:d[0x1D627]='MATHEMATICAL SANS-SERIF ITALIC SMALL F'
let s:d[0x1D628]='MATHEMATICAL SANS-SERIF ITALIC SMALL G'
let s:d[0x1D629]='MATHEMATICAL SANS-SERIF ITALIC SMALL H'
let s:d[0x1D62A]='MATHEMATICAL SANS-SERIF ITALIC SMALL I'
let s:d[0x1D62B]='MATHEMATICAL SANS-SERIF ITALIC SMALL J'
let s:d[0x1D62C]='MATHEMATICAL SANS-SERIF ITALIC SMALL K'
let s:d[0x1D62D]='MATHEMATICAL SANS-SERIF ITALIC SMALL L'
let s:d[0x1D62E]='MATHEMATICAL SANS-SERIF ITALIC SMALL M'
let s:d[0x1D62F]='MATHEMATICAL SANS-SERIF ITALIC SMALL N'
let s:d[0x1D630]='MATHEMATICAL SANS-SERIF ITALIC SMALL O'
let s:d[0x1D631]='MATHEMATICAL SANS-SERIF ITALIC SMALL P'
let s:d[0x1D632]='MATHEMATICAL SANS-SERIF ITALIC SMALL Q'
let s:d[0x1D633]='MATHEMATICAL SANS-SERIF ITALIC SMALL R'
let s:d[0x1D634]='MATHEMATICAL SANS-SERIF ITALIC SMALL S'
let s:d[0x1D635]='MATHEMATICAL SANS-SERIF ITALIC SMALL T'
let s:d[0x1D636]='MATHEMATICAL SANS-SERIF ITALIC SMALL U'
let s:d[0x1D637]='MATHEMATICAL SANS-SERIF ITALIC SMALL V'
let s:d[0x1D638]='MATHEMATICAL SANS-SERIF ITALIC SMALL W'
let s:d[0x1D639]='MATHEMATICAL SANS-SERIF ITALIC SMALL X'
let s:d[0x1D63A]='MATHEMATICAL SANS-SERIF ITALIC SMALL Y'
let s:d[0x1D63B]='MATHEMATICAL SANS-SERIF ITALIC SMALL Z'
let s:d[0x1D63C]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL A'
let s:d[0x1D63D]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL B'
let s:d[0x1D63E]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL C'
let s:d[0x1D63F]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL D'
let s:d[0x1D640]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL E'
let s:d[0x1D641]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL F'
let s:d[0x1D642]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL G'
let s:d[0x1D643]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL H'
let s:d[0x1D644]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL I'
let s:d[0x1D645]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL J'
let s:d[0x1D646]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL K'
let s:d[0x1D647]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL L'
let s:d[0x1D648]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL M'
let s:d[0x1D649]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL N'
let s:d[0x1D64A]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL O'
let s:d[0x1D64B]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL P'
let s:d[0x1D64C]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL Q'
let s:d[0x1D64D]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL R'
let s:d[0x1D64E]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL S'
let s:d[0x1D64F]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL T'
let s:d[0x1D650]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL U'
let s:d[0x1D651]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL V'
let s:d[0x1D652]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL W'
let s:d[0x1D653]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL X'
let s:d[0x1D654]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL Y'
let s:d[0x1D655]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL Z'
let s:d[0x1D656]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL A'
let s:d[0x1D657]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL B'
let s:d[0x1D658]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL C'
let s:d[0x1D659]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL D'
let s:d[0x1D65A]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL E'
let s:d[0x1D65B]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL F'
let s:d[0x1D65C]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL G'
let s:d[0x1D65D]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL H'
let s:d[0x1D65E]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL I'
let s:d[0x1D65F]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL J'
let s:d[0x1D660]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL K'
let s:d[0x1D661]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL L'
let s:d[0x1D662]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL M'
let s:d[0x1D663]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL N'
let s:d[0x1D664]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL O'
let s:d[0x1D665]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL P'
let s:d[0x1D666]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL Q'
let s:d[0x1D667]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL R'
let s:d[0x1D668]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL S'
let s:d[0x1D669]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL T'
let s:d[0x1D66A]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL U'
let s:d[0x1D66B]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL V'
let s:d[0x1D66C]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL W'
let s:d[0x1D66D]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL X'
let s:d[0x1D66E]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL Y'
let s:d[0x1D66F]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL Z'
let s:d[0x1D670]='MATHEMATICAL MONOSPACE CAPITAL A'
let s:d[0x1D671]='MATHEMATICAL MONOSPACE CAPITAL B'
let s:d[0x1D672]='MATHEMATICAL MONOSPACE CAPITAL C'
let s:d[0x1D673]='MATHEMATICAL MONOSPACE CAPITAL D'
let s:d[0x1D674]='MATHEMATICAL MONOSPACE CAPITAL E'
let s:d[0x1D675]='MATHEMATICAL MONOSPACE CAPITAL F'
let s:d[0x1D676]='MATHEMATICAL MONOSPACE CAPITAL G'
let s:d[0x1D677]='MATHEMATICAL MONOSPACE CAPITAL H'
let s:d[0x1D678]='MATHEMATICAL MONOSPACE CAPITAL I'
let s:d[0x1D679]='MATHEMATICAL MONOSPACE CAPITAL J'
let s:d[0x1D67A]='MATHEMATICAL MONOSPACE CAPITAL K'
let s:d[0x1D67B]='MATHEMATICAL MONOSPACE CAPITAL L'
let s:d[0x1D67C]='MATHEMATICAL MONOSPACE CAPITAL M'
let s:d[0x1D67D]='MATHEMATICAL MONOSPACE CAPITAL N'
let s:d[0x1D67E]='MATHEMATICAL MONOSPACE CAPITAL O'
let s:d[0x1D67F]='MATHEMATICAL MONOSPACE CAPITAL P'
let s:d[0x1D680]='MATHEMATICAL MONOSPACE CAPITAL Q'
let s:d[0x1D681]='MATHEMATICAL MONOSPACE CAPITAL R'
let s:d[0x1D682]='MATHEMATICAL MONOSPACE CAPITAL S'
let s:d[0x1D683]='MATHEMATICAL MONOSPACE CAPITAL T'
let s:d[0x1D684]='MATHEMATICAL MONOSPACE CAPITAL U'
let s:d[0x1D685]='MATHEMATICAL MONOSPACE CAPITAL V'
let s:d[0x1D686]='MATHEMATICAL MONOSPACE CAPITAL W'
let s:d[0x1D687]='MATHEMATICAL MONOSPACE CAPITAL X'
let s:d[0x1D688]='MATHEMATICAL MONOSPACE CAPITAL Y'
let s:d[0x1D689]='MATHEMATICAL MONOSPACE CAPITAL Z'
let s:d[0x1D68A]='MATHEMATICAL MONOSPACE SMALL A'
let s:d[0x1D68B]='MATHEMATICAL MONOSPACE SMALL B'
let s:d[0x1D68C]='MATHEMATICAL MONOSPACE SMALL C'
let s:d[0x1D68D]='MATHEMATICAL MONOSPACE SMALL D'
let s:d[0x1D68E]='MATHEMATICAL MONOSPACE SMALL E'
let s:d[0x1D68F]='MATHEMATICAL MONOSPACE SMALL F'
let s:d[0x1D690]='MATHEMATICAL MONOSPACE SMALL G'
let s:d[0x1D691]='MATHEMATICAL MONOSPACE SMALL H'
let s:d[0x1D692]='MATHEMATICAL MONOSPACE SMALL I'
let s:d[0x1D693]='MATHEMATICAL MONOSPACE SMALL J'
let s:d[0x1D694]='MATHEMATICAL MONOSPACE SMALL K'
let s:d[0x1D695]='MATHEMATICAL MONOSPACE SMALL L'
let s:d[0x1D696]='MATHEMATICAL MONOSPACE SMALL M'
let s:d[0x1D697]='MATHEMATICAL MONOSPACE SMALL N'
let s:d[0x1D698]='MATHEMATICAL MONOSPACE SMALL O'
let s:d[0x1D699]='MATHEMATICAL MONOSPACE SMALL P'
let s:d[0x1D69A]='MATHEMATICAL MONOSPACE SMALL Q'
let s:d[0x1D69B]='MATHEMATICAL MONOSPACE SMALL R'
let s:d[0x1D69C]='MATHEMATICAL MONOSPACE SMALL S'
let s:d[0x1D69D]='MATHEMATICAL MONOSPACE SMALL T'
let s:d[0x1D69E]='MATHEMATICAL MONOSPACE SMALL U'
let s:d[0x1D69F]='MATHEMATICAL MONOSPACE SMALL V'
let s:d[0x1D6A0]='MATHEMATICAL MONOSPACE SMALL W'
let s:d[0x1D6A1]='MATHEMATICAL MONOSPACE SMALL X'
let s:d[0x1D6A2]='MATHEMATICAL MONOSPACE SMALL Y'
let s:d[0x1D6A3]='MATHEMATICAL MONOSPACE SMALL Z'
let s:d[0x1D6A4]='MATHEMATICAL ITALIC SMALL DOTLESS I'
let s:d[0x1D6A5]='MATHEMATICAL ITALIC SMALL DOTLESS J'
let s:d[0x1D6A8]='MATHEMATICAL BOLD CAPITAL ALPHA'
let s:d[0x1D6A9]='MATHEMATICAL BOLD CAPITAL BETA'
let s:d[0x1D6AA]='MATHEMATICAL BOLD CAPITAL GAMMA'
let s:d[0x1D6AB]='MATHEMATICAL BOLD CAPITAL DELTA'
let s:d[0x1D6AC]='MATHEMATICAL BOLD CAPITAL EPSILON'
let s:d[0x1D6AD]='MATHEMATICAL BOLD CAPITAL ZETA'
let s:d[0x1D6AE]='MATHEMATICAL BOLD CAPITAL ETA'
let s:d[0x1D6AF]='MATHEMATICAL BOLD CAPITAL THETA'
let s:d[0x1D6B0]='MATHEMATICAL BOLD CAPITAL IOTA'
let s:d[0x1D6B1]='MATHEMATICAL BOLD CAPITAL KAPPA'
let s:d[0x1D6B2]='MATHEMATICAL BOLD CAPITAL LAMDA'
let s:d[0x1D6B3]='MATHEMATICAL BOLD CAPITAL MU'
let s:d[0x1D6B4]='MATHEMATICAL BOLD CAPITAL NU'
let s:d[0x1D6B5]='MATHEMATICAL BOLD CAPITAL XI'
let s:d[0x1D6B6]='MATHEMATICAL BOLD CAPITAL OMICRON'
let s:d[0x1D6B7]='MATHEMATICAL BOLD CAPITAL PI'
let s:d[0x1D6B8]='MATHEMATICAL BOLD CAPITAL RHO'
let s:d[0x1D6B9]='MATHEMATICAL BOLD CAPITAL THETA SYMBOL'
let s:d[0x1D6BA]='MATHEMATICAL BOLD CAPITAL SIGMA'
let s:d[0x1D6BB]='MATHEMATICAL BOLD CAPITAL TAU'
let s:d[0x1D6BC]='MATHEMATICAL BOLD CAPITAL UPSILON'
let s:d[0x1D6BD]='MATHEMATICAL BOLD CAPITAL PHI'
let s:d[0x1D6BE]='MATHEMATICAL BOLD CAPITAL CHI'
let s:d[0x1D6BF]='MATHEMATICAL BOLD CAPITAL PSI'
let s:d[0x1D6C0]='MATHEMATICAL BOLD CAPITAL OMEGA'
let s:d[0x1D6C1]='MATHEMATICAL BOLD NABLA'
let s:d[0x1D6C2]='MATHEMATICAL BOLD SMALL ALPHA'
let s:d[0x1D6C3]='MATHEMATICAL BOLD SMALL BETA'
let s:d[0x1D6C4]='MATHEMATICAL BOLD SMALL GAMMA'
let s:d[0x1D6C5]='MATHEMATICAL BOLD SMALL DELTA'
let s:d[0x1D6C6]='MATHEMATICAL BOLD SMALL EPSILON'
let s:d[0x1D6C7]='MATHEMATICAL BOLD SMALL ZETA'
let s:d[0x1D6C8]='MATHEMATICAL BOLD SMALL ETA'
let s:d[0x1D6C9]='MATHEMATICAL BOLD SMALL THETA'
let s:d[0x1D6CA]='MATHEMATICAL BOLD SMALL IOTA'
let s:d[0x1D6CB]='MATHEMATICAL BOLD SMALL KAPPA'
let s:d[0x1D6CC]='MATHEMATICAL BOLD SMALL LAMDA'
let s:d[0x1D6CD]='MATHEMATICAL BOLD SMALL MU'
let s:d[0x1D6CE]='MATHEMATICAL BOLD SMALL NU'
let s:d[0x1D6CF]='MATHEMATICAL BOLD SMALL XI'
let s:d[0x1D6D0]='MATHEMATICAL BOLD SMALL OMICRON'
let s:d[0x1D6D1]='MATHEMATICAL BOLD SMALL PI'
let s:d[0x1D6D2]='MATHEMATICAL BOLD SMALL RHO'
let s:d[0x1D6D3]='MATHEMATICAL BOLD SMALL FINAL SIGMA'
let s:d[0x1D6D4]='MATHEMATICAL BOLD SMALL SIGMA'
let s:d[0x1D6D5]='MATHEMATICAL BOLD SMALL TAU'
let s:d[0x1D6D6]='MATHEMATICAL BOLD SMALL UPSILON'
let s:d[0x1D6D7]='MATHEMATICAL BOLD SMALL PHI'
let s:d[0x1D6D8]='MATHEMATICAL BOLD SMALL CHI'
let s:d[0x1D6D9]='MATHEMATICAL BOLD SMALL PSI'
let s:d[0x1D6DA]='MATHEMATICAL BOLD SMALL OMEGA'
let s:d[0x1D6DB]='MATHEMATICAL BOLD PARTIAL DIFFERENTIAL'
let s:d[0x1D6DC]='MATHEMATICAL BOLD EPSILON SYMBOL'
let s:d[0x1D6DD]='MATHEMATICAL BOLD THETA SYMBOL'
let s:d[0x1D6DE]='MATHEMATICAL BOLD KAPPA SYMBOL'
let s:d[0x1D6DF]='MATHEMATICAL BOLD PHI SYMBOL'
let s:d[0x1D6E0]='MATHEMATICAL BOLD RHO SYMBOL'
let s:d[0x1D6E1]='MATHEMATICAL BOLD PI SYMBOL'
let s:d[0x1D6E2]='MATHEMATICAL ITALIC CAPITAL ALPHA'
let s:d[0x1D6E3]='MATHEMATICAL ITALIC CAPITAL BETA'
let s:d[0x1D6E4]='MATHEMATICAL ITALIC CAPITAL GAMMA'
let s:d[0x1D6E5]='MATHEMATICAL ITALIC CAPITAL DELTA'
let s:d[0x1D6E6]='MATHEMATICAL ITALIC CAPITAL EPSILON'
let s:d[0x1D6E7]='MATHEMATICAL ITALIC CAPITAL ZETA'
let s:d[0x1D6E8]='MATHEMATICAL ITALIC CAPITAL ETA'
let s:d[0x1D6E9]='MATHEMATICAL ITALIC CAPITAL THETA'
let s:d[0x1D6EA]='MATHEMATICAL ITALIC CAPITAL IOTA'
let s:d[0x1D6EB]='MATHEMATICAL ITALIC CAPITAL KAPPA'
let s:d[0x1D6EC]='MATHEMATICAL ITALIC CAPITAL LAMDA'
let s:d[0x1D6ED]='MATHEMATICAL ITALIC CAPITAL MU'
let s:d[0x1D6EE]='MATHEMATICAL ITALIC CAPITAL NU'
let s:d[0x1D6EF]='MATHEMATICAL ITALIC CAPITAL XI'
let s:d[0x1D6F0]='MATHEMATICAL ITALIC CAPITAL OMICRON'
let s:d[0x1D6F1]='MATHEMATICAL ITALIC CAPITAL PI'
let s:d[0x1D6F2]='MATHEMATICAL ITALIC CAPITAL RHO'
let s:d[0x1D6F3]='MATHEMATICAL ITALIC CAPITAL THETA SYMBOL'
let s:d[0x1D6F4]='MATHEMATICAL ITALIC CAPITAL SIGMA'
let s:d[0x1D6F5]='MATHEMATICAL ITALIC CAPITAL TAU'
let s:d[0x1D6F6]='MATHEMATICAL ITALIC CAPITAL UPSILON'
let s:d[0x1D6F7]='MATHEMATICAL ITALIC CAPITAL PHI'
let s:d[0x1D6F8]='MATHEMATICAL ITALIC CAPITAL CHI'
let s:d[0x1D6F9]='MATHEMATICAL ITALIC CAPITAL PSI'
let s:d[0x1D6FA]='MATHEMATICAL ITALIC CAPITAL OMEGA'
let s:d[0x1D6FB]='MATHEMATICAL ITALIC NABLA'
let s:d[0x1D6FC]='MATHEMATICAL ITALIC SMALL ALPHA'
let s:d[0x1D6FD]='MATHEMATICAL ITALIC SMALL BETA'
let s:d[0x1D6FE]='MATHEMATICAL ITALIC SMALL GAMMA'
let s:d[0x1D6FF]='MATHEMATICAL ITALIC SMALL DELTA'
let s:d[0x1D700]='MATHEMATICAL ITALIC SMALL EPSILON'
let s:d[0x1D701]='MATHEMATICAL ITALIC SMALL ZETA'
let s:d[0x1D702]='MATHEMATICAL ITALIC SMALL ETA'
let s:d[0x1D703]='MATHEMATICAL ITALIC SMALL THETA'
let s:d[0x1D704]='MATHEMATICAL ITALIC SMALL IOTA'
let s:d[0x1D705]='MATHEMATICAL ITALIC SMALL KAPPA'
let s:d[0x1D706]='MATHEMATICAL ITALIC SMALL LAMDA'
let s:d[0x1D707]='MATHEMATICAL ITALIC SMALL MU'
let s:d[0x1D708]='MATHEMATICAL ITALIC SMALL NU'
let s:d[0x1D709]='MATHEMATICAL ITALIC SMALL XI'
let s:d[0x1D70A]='MATHEMATICAL ITALIC SMALL OMICRON'
let s:d[0x1D70B]='MATHEMATICAL ITALIC SMALL PI'
let s:d[0x1D70C]='MATHEMATICAL ITALIC SMALL RHO'
let s:d[0x1D70D]='MATHEMATICAL ITALIC SMALL FINAL SIGMA'
let s:d[0x1D70E]='MATHEMATICAL ITALIC SMALL SIGMA'
let s:d[0x1D70F]='MATHEMATICAL ITALIC SMALL TAU'
let s:d[0x1D710]='MATHEMATICAL ITALIC SMALL UPSILON'
let s:d[0x1D711]='MATHEMATICAL ITALIC SMALL PHI'
let s:d[0x1D712]='MATHEMATICAL ITALIC SMALL CHI'
let s:d[0x1D713]='MATHEMATICAL ITALIC SMALL PSI'
let s:d[0x1D714]='MATHEMATICAL ITALIC SMALL OMEGA'
let s:d[0x1D715]='MATHEMATICAL ITALIC PARTIAL DIFFERENTIAL'
let s:d[0x1D716]='MATHEMATICAL ITALIC EPSILON SYMBOL'
let s:d[0x1D717]='MATHEMATICAL ITALIC THETA SYMBOL'
let s:d[0x1D718]='MATHEMATICAL ITALIC KAPPA SYMBOL'
let s:d[0x1D719]='MATHEMATICAL ITALIC PHI SYMBOL'
let s:d[0x1D71A]='MATHEMATICAL ITALIC RHO SYMBOL'
let s:d[0x1D71B]='MATHEMATICAL ITALIC PI SYMBOL'
let s:d[0x1D71C]='MATHEMATICAL BOLD ITALIC CAPITAL ALPHA'
let s:d[0x1D71D]='MATHEMATICAL BOLD ITALIC CAPITAL BETA'
let s:d[0x1D71E]='MATHEMATICAL BOLD ITALIC CAPITAL GAMMA'
let s:d[0x1D71F]='MATHEMATICAL BOLD ITALIC CAPITAL DELTA'
let s:d[0x1D720]='MATHEMATICAL BOLD ITALIC CAPITAL EPSILON'
let s:d[0x1D721]='MATHEMATICAL BOLD ITALIC CAPITAL ZETA'
let s:d[0x1D722]='MATHEMATICAL BOLD ITALIC CAPITAL ETA'
let s:d[0x1D723]='MATHEMATICAL BOLD ITALIC CAPITAL THETA'
let s:d[0x1D724]='MATHEMATICAL BOLD ITALIC CAPITAL IOTA'
let s:d[0x1D725]='MATHEMATICAL BOLD ITALIC CAPITAL KAPPA'
let s:d[0x1D726]='MATHEMATICAL BOLD ITALIC CAPITAL LAMDA'
let s:d[0x1D727]='MATHEMATICAL BOLD ITALIC CAPITAL MU'
let s:d[0x1D728]='MATHEMATICAL BOLD ITALIC CAPITAL NU'
let s:d[0x1D729]='MATHEMATICAL BOLD ITALIC CAPITAL XI'
let s:d[0x1D72A]='MATHEMATICAL BOLD ITALIC CAPITAL OMICRON'
let s:d[0x1D72B]='MATHEMATICAL BOLD ITALIC CAPITAL PI'
let s:d[0x1D72C]='MATHEMATICAL BOLD ITALIC CAPITAL RHO'
let s:d[0x1D72D]='MATHEMATICAL BOLD ITALIC CAPITAL THETA SYMBOL'
let s:d[0x1D72E]='MATHEMATICAL BOLD ITALIC CAPITAL SIGMA'
let s:d[0x1D72F]='MATHEMATICAL BOLD ITALIC CAPITAL TAU'
let s:d[0x1D730]='MATHEMATICAL BOLD ITALIC CAPITAL UPSILON'
let s:d[0x1D731]='MATHEMATICAL BOLD ITALIC CAPITAL PHI'
let s:d[0x1D732]='MATHEMATICAL BOLD ITALIC CAPITAL CHI'
let s:d[0x1D733]='MATHEMATICAL BOLD ITALIC CAPITAL PSI'
let s:d[0x1D734]='MATHEMATICAL BOLD ITALIC CAPITAL OMEGA'
let s:d[0x1D735]='MATHEMATICAL BOLD ITALIC NABLA'
let s:d[0x1D736]='MATHEMATICAL BOLD ITALIC SMALL ALPHA'
let s:d[0x1D737]='MATHEMATICAL BOLD ITALIC SMALL BETA'
let s:d[0x1D738]='MATHEMATICAL BOLD ITALIC SMALL GAMMA'
let s:d[0x1D739]='MATHEMATICAL BOLD ITALIC SMALL DELTA'
let s:d[0x1D73A]='MATHEMATICAL BOLD ITALIC SMALL EPSILON'
let s:d[0x1D73B]='MATHEMATICAL BOLD ITALIC SMALL ZETA'
let s:d[0x1D73C]='MATHEMATICAL BOLD ITALIC SMALL ETA'
let s:d[0x1D73D]='MATHEMATICAL BOLD ITALIC SMALL THETA'
let s:d[0x1D73E]='MATHEMATICAL BOLD ITALIC SMALL IOTA'
let s:d[0x1D73F]='MATHEMATICAL BOLD ITALIC SMALL KAPPA'
let s:d[0x1D740]='MATHEMATICAL BOLD ITALIC SMALL LAMDA'
let s:d[0x1D741]='MATHEMATICAL BOLD ITALIC SMALL MU'
let s:d[0x1D742]='MATHEMATICAL BOLD ITALIC SMALL NU'
let s:d[0x1D743]='MATHEMATICAL BOLD ITALIC SMALL XI'
let s:d[0x1D744]='MATHEMATICAL BOLD ITALIC SMALL OMICRON'
let s:d[0x1D745]='MATHEMATICAL BOLD ITALIC SMALL PI'
let s:d[0x1D746]='MATHEMATICAL BOLD ITALIC SMALL RHO'
let s:d[0x1D747]='MATHEMATICAL BOLD ITALIC SMALL FINAL SIGMA'
let s:d[0x1D748]='MATHEMATICAL BOLD ITALIC SMALL SIGMA'
let s:d[0x1D749]='MATHEMATICAL BOLD ITALIC SMALL TAU'
let s:d[0x1D74A]='MATHEMATICAL BOLD ITALIC SMALL UPSILON'
let s:d[0x1D74B]='MATHEMATICAL BOLD ITALIC SMALL PHI'
let s:d[0x1D74C]='MATHEMATICAL BOLD ITALIC SMALL CHI'
let s:d[0x1D74D]='MATHEMATICAL BOLD ITALIC SMALL PSI'
let s:d[0x1D74E]='MATHEMATICAL BOLD ITALIC SMALL OMEGA'
let s:d[0x1D74F]='MATHEMATICAL BOLD ITALIC PARTIAL DIFFERENTIAL'
let s:d[0x1D750]='MATHEMATICAL BOLD ITALIC EPSILON SYMBOL'
let s:d[0x1D751]='MATHEMATICAL BOLD ITALIC THETA SYMBOL'
let s:d[0x1D752]='MATHEMATICAL BOLD ITALIC KAPPA SYMBOL'
let s:d[0x1D753]='MATHEMATICAL BOLD ITALIC PHI SYMBOL'
let s:d[0x1D754]='MATHEMATICAL BOLD ITALIC RHO SYMBOL'
let s:d[0x1D755]='MATHEMATICAL BOLD ITALIC PI SYMBOL'
let s:d[0x1D756]='MATHEMATICAL SANS-SERIF BOLD CAPITAL ALPHA'
let s:d[0x1D757]='MATHEMATICAL SANS-SERIF BOLD CAPITAL BETA'
let s:d[0x1D758]='MATHEMATICAL SANS-SERIF BOLD CAPITAL GAMMA'
let s:d[0x1D759]='MATHEMATICAL SANS-SERIF BOLD CAPITAL DELTA'
let s:d[0x1D75A]='MATHEMATICAL SANS-SERIF BOLD CAPITAL EPSILON'
let s:d[0x1D75B]='MATHEMATICAL SANS-SERIF BOLD CAPITAL ZETA'
let s:d[0x1D75C]='MATHEMATICAL SANS-SERIF BOLD CAPITAL ETA'
let s:d[0x1D75D]='MATHEMATICAL SANS-SERIF BOLD CAPITAL THETA'
let s:d[0x1D75E]='MATHEMATICAL SANS-SERIF BOLD CAPITAL IOTA'
let s:d[0x1D75F]='MATHEMATICAL SANS-SERIF BOLD CAPITAL KAPPA'
let s:d[0x1D760]='MATHEMATICAL SANS-SERIF BOLD CAPITAL LAMDA'
let s:d[0x1D761]='MATHEMATICAL SANS-SERIF BOLD CAPITAL MU'
let s:d[0x1D762]='MATHEMATICAL SANS-SERIF BOLD CAPITAL NU'
let s:d[0x1D763]='MATHEMATICAL SANS-SERIF BOLD CAPITAL XI'
let s:d[0x1D764]='MATHEMATICAL SANS-SERIF BOLD CAPITAL OMICRON'
let s:d[0x1D765]='MATHEMATICAL SANS-SERIF BOLD CAPITAL PI'
let s:d[0x1D766]='MATHEMATICAL SANS-SERIF BOLD CAPITAL RHO'
let s:d[0x1D767]='MATHEMATICAL SANS-SERIF BOLD CAPITAL THETA SYMBOL'
let s:d[0x1D768]='MATHEMATICAL SANS-SERIF BOLD CAPITAL SIGMA'
let s:d[0x1D769]='MATHEMATICAL SANS-SERIF BOLD CAPITAL TAU'
let s:d[0x1D76A]='MATHEMATICAL SANS-SERIF BOLD CAPITAL UPSILON'
let s:d[0x1D76B]='MATHEMATICAL SANS-SERIF BOLD CAPITAL PHI'
let s:d[0x1D76C]='MATHEMATICAL SANS-SERIF BOLD CAPITAL CHI'
let s:d[0x1D76D]='MATHEMATICAL SANS-SERIF BOLD CAPITAL PSI'
let s:d[0x1D76E]='MATHEMATICAL SANS-SERIF BOLD CAPITAL OMEGA'
let s:d[0x1D76F]='MATHEMATICAL SANS-SERIF BOLD NABLA'
let s:d[0x1D770]='MATHEMATICAL SANS-SERIF BOLD SMALL ALPHA'
let s:d[0x1D771]='MATHEMATICAL SANS-SERIF BOLD SMALL BETA'
let s:d[0x1D772]='MATHEMATICAL SANS-SERIF BOLD SMALL GAMMA'
let s:d[0x1D773]='MATHEMATICAL SANS-SERIF BOLD SMALL DELTA'
let s:d[0x1D774]='MATHEMATICAL SANS-SERIF BOLD SMALL EPSILON'
let s:d[0x1D775]='MATHEMATICAL SANS-SERIF BOLD SMALL ZETA'
let s:d[0x1D776]='MATHEMATICAL SANS-SERIF BOLD SMALL ETA'
let s:d[0x1D777]='MATHEMATICAL SANS-SERIF BOLD SMALL THETA'
let s:d[0x1D778]='MATHEMATICAL SANS-SERIF BOLD SMALL IOTA'
let s:d[0x1D779]='MATHEMATICAL SANS-SERIF BOLD SMALL KAPPA'
let s:d[0x1D77A]='MATHEMATICAL SANS-SERIF BOLD SMALL LAMDA'
let s:d[0x1D77B]='MATHEMATICAL SANS-SERIF BOLD SMALL MU'
let s:d[0x1D77C]='MATHEMATICAL SANS-SERIF BOLD SMALL NU'
let s:d[0x1D77D]='MATHEMATICAL SANS-SERIF BOLD SMALL XI'
let s:d[0x1D77E]='MATHEMATICAL SANS-SERIF BOLD SMALL OMICRON'
let s:d[0x1D77F]='MATHEMATICAL SANS-SERIF BOLD SMALL PI'
let s:d[0x1D780]='MATHEMATICAL SANS-SERIF BOLD SMALL RHO'
let s:d[0x1D781]='MATHEMATICAL SANS-SERIF BOLD SMALL FINAL SIGMA'
let s:d[0x1D782]='MATHEMATICAL SANS-SERIF BOLD SMALL SIGMA'
let s:d[0x1D783]='MATHEMATICAL SANS-SERIF BOLD SMALL TAU'
let s:d[0x1D784]='MATHEMATICAL SANS-SERIF BOLD SMALL UPSILON'
let s:d[0x1D785]='MATHEMATICAL SANS-SERIF BOLD SMALL PHI'
let s:d[0x1D786]='MATHEMATICAL SANS-SERIF BOLD SMALL CHI'
let s:d[0x1D787]='MATHEMATICAL SANS-SERIF BOLD SMALL PSI'
let s:d[0x1D788]='MATHEMATICAL SANS-SERIF BOLD SMALL OMEGA'
let s:d[0x1D789]='MATHEMATICAL SANS-SERIF BOLD PARTIAL DIFFERENTIAL'
let s:d[0x1D78A]='MATHEMATICAL SANS-SERIF BOLD EPSILON SYMBOL'
let s:d[0x1D78B]='MATHEMATICAL SANS-SERIF BOLD THETA SYMBOL'
let s:d[0x1D78C]='MATHEMATICAL SANS-SERIF BOLD KAPPA SYMBOL'
let s:d[0x1D78D]='MATHEMATICAL SANS-SERIF BOLD PHI SYMBOL'
let s:d[0x1D78E]='MATHEMATICAL SANS-SERIF BOLD RHO SYMBOL'
let s:d[0x1D78F]='MATHEMATICAL SANS-SERIF BOLD PI SYMBOL'
let s:d[0x1D790]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL ALPHA'
let s:d[0x1D791]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL BETA'
let s:d[0x1D792]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL GAMMA'
let s:d[0x1D793]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL DELTA'
let s:d[0x1D794]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL EPSILON'
let s:d[0x1D795]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL ZETA'
let s:d[0x1D796]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL ETA'
let s:d[0x1D797]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL THETA'
let s:d[0x1D798]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL IOTA'
let s:d[0x1D799]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL KAPPA'
let s:d[0x1D79A]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL LAMDA'
let s:d[0x1D79B]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL MU'
let s:d[0x1D79C]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL NU'
let s:d[0x1D79D]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL XI'
let s:d[0x1D79E]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL OMICRON'
let s:d[0x1D79F]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL PI'
let s:d[0x1D7A0]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL RHO'
let s:d[0x1D7A1]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL THETA SYMBOL'
let s:d[0x1D7A2]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL SIGMA'
let s:d[0x1D7A3]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL TAU'
let s:d[0x1D7A4]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL UPSILON'
let s:d[0x1D7A5]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL PHI'
let s:d[0x1D7A6]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL CHI'
let s:d[0x1D7A7]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL PSI'
let s:d[0x1D7A8]='MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL OMEGA'
let s:d[0x1D7A9]='MATHEMATICAL SANS-SERIF BOLD ITALIC NABLA'
let s:d[0x1D7AA]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL ALPHA'
let s:d[0x1D7AB]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL BETA'
let s:d[0x1D7AC]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL GAMMA'
let s:d[0x1D7AD]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL DELTA'
let s:d[0x1D7AE]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL EPSILON'
let s:d[0x1D7AF]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL ZETA'
let s:d[0x1D7B0]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL ETA'
let s:d[0x1D7B1]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL THETA'
let s:d[0x1D7B2]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL IOTA'
let s:d[0x1D7B3]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL KAPPA'
let s:d[0x1D7B4]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL LAMDA'
let s:d[0x1D7B5]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL MU'
let s:d[0x1D7B6]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL NU'
let s:d[0x1D7B7]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL XI'
let s:d[0x1D7B8]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL OMICRON'
let s:d[0x1D7B9]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL PI'
let s:d[0x1D7BA]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL RHO'
let s:d[0x1D7BB]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL FINAL SIGMA'
let s:d[0x1D7BC]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL SIGMA'
let s:d[0x1D7BD]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL TAU'
let s:d[0x1D7BE]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL UPSILON'
let s:d[0x1D7BF]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL PHI'
let s:d[0x1D7C0]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL CHI'
let s:d[0x1D7C1]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL PSI'
let s:d[0x1D7C2]='MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL OMEGA'
let s:d[0x1D7C3]='MATHEMATICAL SANS-SERIF BOLD ITALIC PARTIAL DIFFERENTIAL'
let s:d[0x1D7C4]='MATHEMATICAL SANS-SERIF BOLD ITALIC EPSILON SYMBOL'
let s:d[0x1D7C5]='MATHEMATICAL SANS-SERIF BOLD ITALIC THETA SYMBOL'
let s:d[0x1D7C6]='MATHEMATICAL SANS-SERIF BOLD ITALIC KAPPA SYMBOL'
let s:d[0x1D7C7]='MATHEMATICAL SANS-SERIF BOLD ITALIC PHI SYMBOL'
let s:d[0x1D7C8]='MATHEMATICAL SANS-SERIF BOLD ITALIC RHO SYMBOL'
let s:d[0x1D7C9]='MATHEMATICAL SANS-SERIF BOLD ITALIC PI SYMBOL'
let s:d[0x1D7CA]='MATHEMATICAL BOLD CAPITAL DIGAMMA'
let s:d[0x1D7CB]='MATHEMATICAL BOLD SMALL DIGAMMA'
let s:d[0x1D7CE]='MATHEMATICAL BOLD DIGIT ZERO'
let s:d[0x1D7CF]='MATHEMATICAL BOLD DIGIT ONE'
let s:d[0x1D7D0]='MATHEMATICAL BOLD DIGIT TWO'
let s:d[0x1D7D1]='MATHEMATICAL BOLD DIGIT THREE'
let s:d[0x1D7D2]='MATHEMATICAL BOLD DIGIT FOUR'
let s:d[0x1D7D3]='MATHEMATICAL BOLD DIGIT FIVE'
let s:d[0x1D7D4]='MATHEMATICAL BOLD DIGIT SIX'
let s:d[0x1D7D5]='MATHEMATICAL BOLD DIGIT SEVEN'
let s:d[0x1D7D6]='MATHEMATICAL BOLD DIGIT EIGHT'
let s:d[0x1D7D7]='MATHEMATICAL BOLD DIGIT NINE'
let s:d[0x1D7D8]='MATHEMATICAL DOUBLE-STRUCK DIGIT ZERO'
let s:d[0x1D7D9]='MATHEMATICAL DOUBLE-STRUCK DIGIT ONE'
let s:d[0x1D7DA]='MATHEMATICAL DOUBLE-STRUCK DIGIT TWO'
let s:d[0x1D7DB]='MATHEMATICAL DOUBLE-STRUCK DIGIT THREE'
let s:d[0x1D7DC]='MATHEMATICAL DOUBLE-STRUCK DIGIT FOUR'
let s:d[0x1D7DD]='MATHEMATICAL DOUBLE-STRUCK DIGIT FIVE'
let s:d[0x1D7DE]='MATHEMATICAL DOUBLE-STRUCK DIGIT SIX'
let s:d[0x1D7DF]='MATHEMATICAL DOUBLE-STRUCK DIGIT SEVEN'
let s:d[0x1D7E0]='MATHEMATICAL DOUBLE-STRUCK DIGIT EIGHT'
let s:d[0x1D7E1]='MATHEMATICAL DOUBLE-STRUCK DIGIT NINE'
let s:d[0x1D7E2]='MATHEMATICAL SANS-SERIF DIGIT ZERO'
let s:d[0x1D7E3]='MATHEMATICAL SANS-SERIF DIGIT ONE'
let s:d[0x1D7E4]='MATHEMATICAL SANS-SERIF DIGIT TWO'
let s:d[0x1D7E5]='MATHEMATICAL SANS-SERIF DIGIT THREE'
let s:d[0x1D7E6]='MATHEMATICAL SANS-SERIF DIGIT FOUR'
let s:d[0x1D7E7]='MATHEMATICAL SANS-SERIF DIGIT FIVE'
let s:d[0x1D7E8]='MATHEMATICAL SANS-SERIF DIGIT SIX'
let s:d[0x1D7E9]='MATHEMATICAL SANS-SERIF DIGIT SEVEN'
let s:d[0x1D7EA]='MATHEMATICAL SANS-SERIF DIGIT EIGHT'
let s:d[0x1D7EB]='MATHEMATICAL SANS-SERIF DIGIT NINE'
let s:d[0x1D7EC]='MATHEMATICAL SANS-SERIF BOLD DIGIT ZERO'
let s:d[0x1D7ED]='MATHEMATICAL SANS-SERIF BOLD DIGIT ONE'
let s:d[0x1D7EE]='MATHEMATICAL SANS-SERIF BOLD DIGIT TWO'
let s:d[0x1D7EF]='MATHEMATICAL SANS-SERIF BOLD DIGIT THREE'
let s:d[0x1D7F0]='MATHEMATICAL SANS-SERIF BOLD DIGIT FOUR'
let s:d[0x1D7F1]='MATHEMATICAL SANS-SERIF BOLD DIGIT FIVE'
let s:d[0x1D7F2]='MATHEMATICAL SANS-SERIF BOLD DIGIT SIX'
let s:d[0x1D7F3]='MATHEMATICAL SANS-SERIF BOLD DIGIT SEVEN'
let s:d[0x1D7F4]='MATHEMATICAL SANS-SERIF BOLD DIGIT EIGHT'
let s:d[0x1D7F5]='MATHEMATICAL SANS-SERIF BOLD DIGIT NINE'
let s:d[0x1D7F6]='MATHEMATICAL MONOSPACE DIGIT ZERO'
let s:d[0x1D7F7]='MATHEMATICAL MONOSPACE DIGIT ONE'
let s:d[0x1D7F8]='MATHEMATICAL MONOSPACE DIGIT TWO'
let s:d[0x1D7F9]='MATHEMATICAL MONOSPACE DIGIT THREE'
let s:d[0x1D7FA]='MATHEMATICAL MONOSPACE DIGIT FOUR'
let s:d[0x1D7FB]='MATHEMATICAL MONOSPACE DIGIT FIVE'
let s:d[0x1D7FC]='MATHEMATICAL MONOSPACE DIGIT SIX'
let s:d[0x1D7FD]='MATHEMATICAL MONOSPACE DIGIT SEVEN'
let s:d[0x1D7FE]='MATHEMATICAL MONOSPACE DIGIT EIGHT'
let s:d[0x1D7FF]='MATHEMATICAL MONOSPACE DIGIT NINE'
let s:d[0x1EE00]='ARABIC MATHEMATICAL ALEF'
let s:d[0x1EE01]='ARABIC MATHEMATICAL BEH'
let s:d[0x1EE02]='ARABIC MATHEMATICAL JEEM'
let s:d[0x1EE03]='ARABIC MATHEMATICAL DAL'
let s:d[0x1EE05]='ARABIC MATHEMATICAL WAW'
let s:d[0x1EE06]='ARABIC MATHEMATICAL ZAIN'
let s:d[0x1EE07]='ARABIC MATHEMATICAL HAH'
let s:d[0x1EE08]='ARABIC MATHEMATICAL TAH'
let s:d[0x1EE09]='ARABIC MATHEMATICAL YEH'
let s:d[0x1EE0A]='ARABIC MATHEMATICAL KAF'
let s:d[0x1EE0B]='ARABIC MATHEMATICAL LAM'
let s:d[0x1EE0C]='ARABIC MATHEMATICAL MEEM'
let s:d[0x1EE0D]='ARABIC MATHEMATICAL NOON'
let s:d[0x1EE0E]='ARABIC MATHEMATICAL SEEN'
let s:d[0x1EE0F]='ARABIC MATHEMATICAL AIN'
let s:d[0x1EE10]='ARABIC MATHEMATICAL FEH'
let s:d[0x1EE11]='ARABIC MATHEMATICAL SAD'
let s:d[0x1EE12]='ARABIC MATHEMATICAL QAF'
let s:d[0x1EE13]='ARABIC MATHEMATICAL REH'
let s:d[0x1EE14]='ARABIC MATHEMATICAL SHEEN'
let s:d[0x1EE15]='ARABIC MATHEMATICAL TEH'
let s:d[0x1EE16]='ARABIC MATHEMATICAL THEH'
let s:d[0x1EE17]='ARABIC MATHEMATICAL KHAH'
let s:d[0x1EE18]='ARABIC MATHEMATICAL THAL'
let s:d[0x1EE19]='ARABIC MATHEMATICAL DAD'
let s:d[0x1EE1A]='ARABIC MATHEMATICAL ZAH'
let s:d[0x1EE1B]='ARABIC MATHEMATICAL GHAIN'
let s:d[0x1EE1C]='ARABIC MATHEMATICAL DOTLESS BEH'
let s:d[0x1EE1D]='ARABIC MATHEMATICAL DOTLESS NOON'
let s:d[0x1EE1E]='ARABIC MATHEMATICAL DOTLESS FEH'
let s:d[0x1EE1F]='ARABIC MATHEMATICAL DOTLESS QAF'
let s:d[0x1EE21]='ARABIC MATHEMATICAL INITIAL BEH'
let s:d[0x1EE22]='ARABIC MATHEMATICAL INITIAL JEEM'
let s:d[0x1EE24]='ARABIC MATHEMATICAL INITIAL HEH'
let s:d[0x1EE27]='ARABIC MATHEMATICAL INITIAL HAH'
let s:d[0x1EE29]='ARABIC MATHEMATICAL INITIAL YEH'
let s:d[0x1EE2A]='ARABIC MATHEMATICAL INITIAL KAF'
let s:d[0x1EE2B]='ARABIC MATHEMATICAL INITIAL LAM'
let s:d[0x1EE2C]='ARABIC MATHEMATICAL INITIAL MEEM'
let s:d[0x1EE2D]='ARABIC MATHEMATICAL INITIAL NOON'
let s:d[0x1EE2E]='ARABIC MATHEMATICAL INITIAL SEEN'
let s:d[0x1EE2F]='ARABIC MATHEMATICAL INITIAL AIN'
let s:d[0x1EE30]='ARABIC MATHEMATICAL INITIAL FEH'
let s:d[0x1EE31]='ARABIC MATHEMATICAL INITIAL SAD'
let s:d[0x1EE32]='ARABIC MATHEMATICAL INITIAL QAF'
let s:d[0x1EE34]='ARABIC MATHEMATICAL INITIAL SHEEN'
let s:d[0x1EE35]='ARABIC MATHEMATICAL INITIAL TEH'
let s:d[0x1EE36]='ARABIC MATHEMATICAL INITIAL THEH'
let s:d[0x1EE37]='ARABIC MATHEMATICAL INITIAL KHAH'
let s:d[0x1EE39]='ARABIC MATHEMATICAL INITIAL DAD'
let s:d[0x1EE3B]='ARABIC MATHEMATICAL INITIAL GHAIN'
let s:d[0x1EE42]='ARABIC MATHEMATICAL TAILED JEEM'
let s:d[0x1EE47]='ARABIC MATHEMATICAL TAILED HAH'
let s:d[0x1EE49]='ARABIC MATHEMATICAL TAILED YEH'
let s:d[0x1EE4B]='ARABIC MATHEMATICAL TAILED LAM'
let s:d[0x1EE4D]='ARABIC MATHEMATICAL TAILED NOON'
let s:d[0x1EE4E]='ARABIC MATHEMATICAL TAILED SEEN'
let s:d[0x1EE4F]='ARABIC MATHEMATICAL TAILED AIN'
let s:d[0x1EE51]='ARABIC MATHEMATICAL TAILED SAD'
let s:d[0x1EE52]='ARABIC MATHEMATICAL TAILED QAF'
let s:d[0x1EE54]='ARABIC MATHEMATICAL TAILED SHEEN'
let s:d[0x1EE57]='ARABIC MATHEMATICAL TAILED KHAH'
let s:d[0x1EE59]='ARABIC MATHEMATICAL TAILED DAD'
let s:d[0x1EE5B]='ARABIC MATHEMATICAL TAILED GHAIN'
let s:d[0x1EE5D]='ARABIC MATHEMATICAL TAILED DOTLESS NOON'
let s:d[0x1EE5F]='ARABIC MATHEMATICAL TAILED DOTLESS QAF'
let s:d[0x1EE61]='ARABIC MATHEMATICAL STRETCHED BEH'
let s:d[0x1EE62]='ARABIC MATHEMATICAL STRETCHED JEEM'
let s:d[0x1EE64]='ARABIC MATHEMATICAL STRETCHED HEH'
let s:d[0x1EE67]='ARABIC MATHEMATICAL STRETCHED HAH'
let s:d[0x1EE68]='ARABIC MATHEMATICAL STRETCHED TAH'
let s:d[0x1EE69]='ARABIC MATHEMATICAL STRETCHED YEH'
let s:d[0x1EE6A]='ARABIC MATHEMATICAL STRETCHED KAF'
let s:d[0x1EE6C]='ARABIC MATHEMATICAL STRETCHED MEEM'
let s:d[0x1EE6D]='ARABIC MATHEMATICAL STRETCHED NOON'
let s:d[0x1EE6E]='ARABIC MATHEMATICAL STRETCHED SEEN'
let s:d[0x1EE6F]='ARABIC MATHEMATICAL STRETCHED AIN'
let s:d[0x1EE70]='ARABIC MATHEMATICAL STRETCHED FEH'
let s:d[0x1EE71]='ARABIC MATHEMATICAL STRETCHED SAD'
let s:d[0x1EE72]='ARABIC MATHEMATICAL STRETCHED QAF'
let s:d[0x1EE74]='ARABIC MATHEMATICAL STRETCHED SHEEN'
let s:d[0x1EE75]='ARABIC MATHEMATICAL STRETCHED TEH'
let s:d[0x1EE76]='ARABIC MATHEMATICAL STRETCHED THEH'
let s:d[0x1EE77]='ARABIC MATHEMATICAL STRETCHED KHAH'
let s:d[0x1EE79]='ARABIC MATHEMATICAL STRETCHED DAD'
let s:d[0x1EE7A]='ARABIC MATHEMATICAL STRETCHED ZAH'
let s:d[0x1EE7B]='ARABIC MATHEMATICAL STRETCHED GHAIN'
let s:d[0x1EE7C]='ARABIC MATHEMATICAL STRETCHED DOTLESS BEH'
let s:d[0x1EE7E]='ARABIC MATHEMATICAL STRETCHED DOTLESS FEH'
let s:d[0x1EE80]='ARABIC MATHEMATICAL LOOPED ALEF'
let s:d[0x1EE81]='ARABIC MATHEMATICAL LOOPED BEH'
let s:d[0x1EE82]='ARABIC MATHEMATICAL LOOPED JEEM'
let s:d[0x1EE83]='ARABIC MATHEMATICAL LOOPED DAL'
let s:d[0x1EE84]='ARABIC MATHEMATICAL LOOPED HEH'
let s:d[0x1EE85]='ARABIC MATHEMATICAL LOOPED WAW'
let s:d[0x1EE86]='ARABIC MATHEMATICAL LOOPED ZAIN'
let s:d[0x1EE87]='ARABIC MATHEMATICAL LOOPED HAH'
let s:d[0x1EE88]='ARABIC MATHEMATICAL LOOPED TAH'
let s:d[0x1EE89]='ARABIC MATHEMATICAL LOOPED YEH'
let s:d[0x1EE8B]='ARABIC MATHEMATICAL LOOPED LAM'
let s:d[0x1EE8C]='ARABIC MATHEMATICAL LOOPED MEEM'
let s:d[0x1EE8D]='ARABIC MATHEMATICAL LOOPED NOON'
let s:d[0x1EE8E]='ARABIC MATHEMATICAL LOOPED SEEN'
let s:d[0x1EE8F]='ARABIC MATHEMATICAL LOOPED AIN'
let s:d[0x1EE90]='ARABIC MATHEMATICAL LOOPED FEH'
let s:d[0x1EE91]='ARABIC MATHEMATICAL LOOPED SAD'
let s:d[0x1EE92]='ARABIC MATHEMATICAL LOOPED QAF'
let s:d[0x1EE93]='ARABIC MATHEMATICAL LOOPED REH'
let s:d[0x1EE94]='ARABIC MATHEMATICAL LOOPED SHEEN'
let s:d[0x1EE95]='ARABIC MATHEMATICAL LOOPED TEH'
let s:d[0x1EE96]='ARABIC MATHEMATICAL LOOPED THEH'
let s:d[0x1EE97]='ARABIC MATHEMATICAL LOOPED KHAH'
let s:d[0x1EE98]='ARABIC MATHEMATICAL LOOPED THAL'
let s:d[0x1EE99]='ARABIC MATHEMATICAL LOOPED DAD'
let s:d[0x1EE9A]='ARABIC MATHEMATICAL LOOPED ZAH'
let s:d[0x1EE9B]='ARABIC MATHEMATICAL LOOPED GHAIN'
let s:d[0x1EEA1]='ARABIC MATHEMATICAL DOUBLE-STRUCK BEH'
let s:d[0x1EEA2]='ARABIC MATHEMATICAL DOUBLE-STRUCK JEEM'
let s:d[0x1EEA3]='ARABIC MATHEMATICAL DOUBLE-STRUCK DAL'
let s:d[0x1EEA5]='ARABIC MATHEMATICAL DOUBLE-STRUCK WAW'
let s:d[0x1EEA6]='ARABIC MATHEMATICAL DOUBLE-STRUCK ZAIN'
let s:d[0x1EEA7]='ARABIC MATHEMATICAL DOUBLE-STRUCK HAH'
let s:d[0x1EEA8]='ARABIC MATHEMATICAL DOUBLE-STRUCK TAH'
let s:d[0x1EEA9]='ARABIC MATHEMATICAL DOUBLE-STRUCK YEH'
let s:d[0x1EEAB]='ARABIC MATHEMATICAL DOUBLE-STRUCK LAM'
let s:d[0x1EEAC]='ARABIC MATHEMATICAL DOUBLE-STRUCK MEEM'
let s:d[0x1EEAD]='ARABIC MATHEMATICAL DOUBLE-STRUCK NOON'
let s:d[0x1EEAE]='ARABIC MATHEMATICAL DOUBLE-STRUCK SEEN'
let s:d[0x1EEAF]='ARABIC MATHEMATICAL DOUBLE-STRUCK AIN'
let s:d[0x1EEB0]='ARABIC MATHEMATICAL DOUBLE-STRUCK FEH'
let s:d[0x1EEB1]='ARABIC MATHEMATICAL DOUBLE-STRUCK SAD'
let s:d[0x1EEB2]='ARABIC MATHEMATICAL DOUBLE-STRUCK QAF'
let s:d[0x1EEB3]='ARABIC MATHEMATICAL DOUBLE-STRUCK REH'
let s:d[0x1EEB4]='ARABIC MATHEMATICAL DOUBLE-STRUCK SHEEN'
let s:d[0x1EEB5]='ARABIC MATHEMATICAL DOUBLE-STRUCK TEH'
let s:d[0x1EEB6]='ARABIC MATHEMATICAL DOUBLE-STRUCK THEH'
let s:d[0x1EEB7]='ARABIC MATHEMATICAL DOUBLE-STRUCK KHAH'
let s:d[0x1EEB8]='ARABIC MATHEMATICAL DOUBLE-STRUCK THAL'
let s:d[0x1EEB9]='ARABIC MATHEMATICAL DOUBLE-STRUCK DAD'
let s:d[0x1EEBA]='ARABIC MATHEMATICAL DOUBLE-STRUCK ZAH'
let s:d[0x1EEBB]='ARABIC MATHEMATICAL DOUBLE-STRUCK GHAIN'
let s:d[0x1EEF0]='ARABIC MATHEMATICAL OPERATOR MEEM WITH HAH WITH TATWEEL'
let s:d[0x1EEF1]='ARABIC MATHEMATICAL OPERATOR HAH WITH DAL'
let s:d[0x1F000]='MAHJONG TILE EAST WIND'
let s:d[0x1F001]='MAHJONG TILE SOUTH WIND'
let s:d[0x1F002]='MAHJONG TILE WEST WIND'
let s:d[0x1F003]='MAHJONG TILE NORTH WIND'
let s:d[0x1F004]='MAHJONG TILE RED DRAGON'
let s:d[0x1F005]='MAHJONG TILE GREEN DRAGON'
let s:d[0x1F006]='MAHJONG TILE WHITE DRAGON'
let s:d[0x1F007]='MAHJONG TILE ONE OF CHARACTERS'
let s:d[0x1F008]='MAHJONG TILE TWO OF CHARACTERS'
let s:d[0x1F009]='MAHJONG TILE THREE OF CHARACTERS'
let s:d[0x1F00A]='MAHJONG TILE FOUR OF CHARACTERS'
let s:d[0x1F00B]='MAHJONG TILE FIVE OF CHARACTERS'
let s:d[0x1F00C]='MAHJONG TILE SIX OF CHARACTERS'
let s:d[0x1F00D]='MAHJONG TILE SEVEN OF CHARACTERS'
let s:d[0x1F00E]='MAHJONG TILE EIGHT OF CHARACTERS'
let s:d[0x1F00F]='MAHJONG TILE NINE OF CHARACTERS'
let s:d[0x1F010]='MAHJONG TILE ONE OF BAMBOOS'
let s:d[0x1F011]='MAHJONG TILE TWO OF BAMBOOS'
let s:d[0x1F012]='MAHJONG TILE THREE OF BAMBOOS'
let s:d[0x1F013]='MAHJONG TILE FOUR OF BAMBOOS'
let s:d[0x1F014]='MAHJONG TILE FIVE OF BAMBOOS'
let s:d[0x1F015]='MAHJONG TILE SIX OF BAMBOOS'
let s:d[0x1F016]='MAHJONG TILE SEVEN OF BAMBOOS'
let s:d[0x1F017]='MAHJONG TILE EIGHT OF BAMBOOS'
let s:d[0x1F018]='MAHJONG TILE NINE OF BAMBOOS'
let s:d[0x1F019]='MAHJONG TILE ONE OF CIRCLES'
let s:d[0x1F01A]='MAHJONG TILE TWO OF CIRCLES'
let s:d[0x1F01B]='MAHJONG TILE THREE OF CIRCLES'
let s:d[0x1F01C]='MAHJONG TILE FOUR OF CIRCLES'
let s:d[0x1F01D]='MAHJONG TILE FIVE OF CIRCLES'
let s:d[0x1F01E]='MAHJONG TILE SIX OF CIRCLES'
let s:d[0x1F01F]='MAHJONG TILE SEVEN OF CIRCLES'
let s:d[0x1F020]='MAHJONG TILE EIGHT OF CIRCLES'
let s:d[0x1F021]='MAHJONG TILE NINE OF CIRCLES'
let s:d[0x1F022]='MAHJONG TILE PLUM'
let s:d[0x1F023]='MAHJONG TILE ORCHID'
let s:d[0x1F024]='MAHJONG TILE BAMBOO'
let s:d[0x1F025]='MAHJONG TILE CHRYSANTHEMUM'
let s:d[0x1F026]='MAHJONG TILE SPRING'
let s:d[0x1F027]='MAHJONG TILE SUMMER'
let s:d[0x1F028]='MAHJONG TILE AUTUMN'
let s:d[0x1F029]='MAHJONG TILE WINTER'
let s:d[0x1F02A]='MAHJONG TILE JOKER'
let s:d[0x1F02B]='MAHJONG TILE BACK'
let s:d[0x1F030]='DOMINO TILE HORIZONTAL BACK'
let s:d[0x1F031]='DOMINO TILE HORIZONTAL-00-00'
let s:d[0x1F032]='DOMINO TILE HORIZONTAL-00-01'
let s:d[0x1F033]='DOMINO TILE HORIZONTAL-00-02'
let s:d[0x1F034]='DOMINO TILE HORIZONTAL-00-03'
let s:d[0x1F035]='DOMINO TILE HORIZONTAL-00-04'
let s:d[0x1F036]='DOMINO TILE HORIZONTAL-00-05'
let s:d[0x1F037]='DOMINO TILE HORIZONTAL-00-06'
let s:d[0x1F038]='DOMINO TILE HORIZONTAL-01-00'
let s:d[0x1F039]='DOMINO TILE HORIZONTAL-01-01'
let s:d[0x1F03A]='DOMINO TILE HORIZONTAL-01-02'
let s:d[0x1F03B]='DOMINO TILE HORIZONTAL-01-03'
let s:d[0x1F03C]='DOMINO TILE HORIZONTAL-01-04'
let s:d[0x1F03D]='DOMINO TILE HORIZONTAL-01-05'
let s:d[0x1F03E]='DOMINO TILE HORIZONTAL-01-06'
let s:d[0x1F03F]='DOMINO TILE HORIZONTAL-02-00'
let s:d[0x1F040]='DOMINO TILE HORIZONTAL-02-01'
let s:d[0x1F041]='DOMINO TILE HORIZONTAL-02-02'
let s:d[0x1F042]='DOMINO TILE HORIZONTAL-02-03'
let s:d[0x1F043]='DOMINO TILE HORIZONTAL-02-04'
let s:d[0x1F044]='DOMINO TILE HORIZONTAL-02-05'
let s:d[0x1F045]='DOMINO TILE HORIZONTAL-02-06'
let s:d[0x1F046]='DOMINO TILE HORIZONTAL-03-00'
let s:d[0x1F047]='DOMINO TILE HORIZONTAL-03-01'
let s:d[0x1F048]='DOMINO TILE HORIZONTAL-03-02'
let s:d[0x1F049]='DOMINO TILE HORIZONTAL-03-03'
let s:d[0x1F04A]='DOMINO TILE HORIZONTAL-03-04'
let s:d[0x1F04B]='DOMINO TILE HORIZONTAL-03-05'
let s:d[0x1F04C]='DOMINO TILE HORIZONTAL-03-06'
let s:d[0x1F04D]='DOMINO TILE HORIZONTAL-04-00'
let s:d[0x1F04E]='DOMINO TILE HORIZONTAL-04-01'
let s:d[0x1F04F]='DOMINO TILE HORIZONTAL-04-02'
let s:d[0x1F050]='DOMINO TILE HORIZONTAL-04-03'
let s:d[0x1F051]='DOMINO TILE HORIZONTAL-04-04'
let s:d[0x1F052]='DOMINO TILE HORIZONTAL-04-05'
let s:d[0x1F053]='DOMINO TILE HORIZONTAL-04-06'
let s:d[0x1F054]='DOMINO TILE HORIZONTAL-05-00'
let s:d[0x1F055]='DOMINO TILE HORIZONTAL-05-01'
let s:d[0x1F056]='DOMINO TILE HORIZONTAL-05-02'
let s:d[0x1F057]='DOMINO TILE HORIZONTAL-05-03'
let s:d[0x1F058]='DOMINO TILE HORIZONTAL-05-04'
let s:d[0x1F059]='DOMINO TILE HORIZONTAL-05-05'
let s:d[0x1F05A]='DOMINO TILE HORIZONTAL-05-06'
let s:d[0x1F05B]='DOMINO TILE HORIZONTAL-06-00'
let s:d[0x1F05C]='DOMINO TILE HORIZONTAL-06-01'
let s:d[0x1F05D]='DOMINO TILE HORIZONTAL-06-02'
let s:d[0x1F05E]='DOMINO TILE HORIZONTAL-06-03'
let s:d[0x1F05F]='DOMINO TILE HORIZONTAL-06-04'
let s:d[0x1F060]='DOMINO TILE HORIZONTAL-06-05'
let s:d[0x1F061]='DOMINO TILE HORIZONTAL-06-06'
let s:d[0x1F062]='DOMINO TILE VERTICAL BACK'
let s:d[0x1F063]='DOMINO TILE VERTICAL-00-00'
let s:d[0x1F064]='DOMINO TILE VERTICAL-00-01'
let s:d[0x1F065]='DOMINO TILE VERTICAL-00-02'
let s:d[0x1F066]='DOMINO TILE VERTICAL-00-03'
let s:d[0x1F067]='DOMINO TILE VERTICAL-00-04'
let s:d[0x1F068]='DOMINO TILE VERTICAL-00-05'
let s:d[0x1F069]='DOMINO TILE VERTICAL-00-06'
let s:d[0x1F06A]='DOMINO TILE VERTICAL-01-00'
let s:d[0x1F06B]='DOMINO TILE VERTICAL-01-01'
let s:d[0x1F06C]='DOMINO TILE VERTICAL-01-02'
let s:d[0x1F06D]='DOMINO TILE VERTICAL-01-03'
let s:d[0x1F06E]='DOMINO TILE VERTICAL-01-04'
let s:d[0x1F06F]='DOMINO TILE VERTICAL-01-05'
let s:d[0x1F070]='DOMINO TILE VERTICAL-01-06'
let s:d[0x1F071]='DOMINO TILE VERTICAL-02-00'
let s:d[0x1F072]='DOMINO TILE VERTICAL-02-01'
let s:d[0x1F073]='DOMINO TILE VERTICAL-02-02'
let s:d[0x1F074]='DOMINO TILE VERTICAL-02-03'
let s:d[0x1F075]='DOMINO TILE VERTICAL-02-04'
let s:d[0x1F076]='DOMINO TILE VERTICAL-02-05'
let s:d[0x1F077]='DOMINO TILE VERTICAL-02-06'
let s:d[0x1F078]='DOMINO TILE VERTICAL-03-00'
let s:d[0x1F079]='DOMINO TILE VERTICAL-03-01'
let s:d[0x1F07A]='DOMINO TILE VERTICAL-03-02'
let s:d[0x1F07B]='DOMINO TILE VERTICAL-03-03'
let s:d[0x1F07C]='DOMINO TILE VERTICAL-03-04'
let s:d[0x1F07D]='DOMINO TILE VERTICAL-03-05'
let s:d[0x1F07E]='DOMINO TILE VERTICAL-03-06'
let s:d[0x1F07F]='DOMINO TILE VERTICAL-04-00'
let s:d[0x1F080]='DOMINO TILE VERTICAL-04-01'
let s:d[0x1F081]='DOMINO TILE VERTICAL-04-02'
let s:d[0x1F082]='DOMINO TILE VERTICAL-04-03'
let s:d[0x1F083]='DOMINO TILE VERTICAL-04-04'
let s:d[0x1F084]='DOMINO TILE VERTICAL-04-05'
let s:d[0x1F085]='DOMINO TILE VERTICAL-04-06'
let s:d[0x1F086]='DOMINO TILE VERTICAL-05-00'
let s:d[0x1F087]='DOMINO TILE VERTICAL-05-01'
let s:d[0x1F088]='DOMINO TILE VERTICAL-05-02'
let s:d[0x1F089]='DOMINO TILE VERTICAL-05-03'
let s:d[0x1F08A]='DOMINO TILE VERTICAL-05-04'
let s:d[0x1F08B]='DOMINO TILE VERTICAL-05-05'
let s:d[0x1F08C]='DOMINO TILE VERTICAL-05-06'
let s:d[0x1F08D]='DOMINO TILE VERTICAL-06-00'
let s:d[0x1F08E]='DOMINO TILE VERTICAL-06-01'
let s:d[0x1F08F]='DOMINO TILE VERTICAL-06-02'
let s:d[0x1F090]='DOMINO TILE VERTICAL-06-03'
let s:d[0x1F091]='DOMINO TILE VERTICAL-06-04'
let s:d[0x1F092]='DOMINO TILE VERTICAL-06-05'
let s:d[0x1F093]='DOMINO TILE VERTICAL-06-06'
let s:d[0x1F0A0]='PLAYING CARD BACK'
let s:d[0x1F0A1]='PLAYING CARD ACE OF SPADES'
let s:d[0x1F0A2]='PLAYING CARD TWO OF SPADES'
let s:d[0x1F0A3]='PLAYING CARD THREE OF SPADES'
let s:d[0x1F0A4]='PLAYING CARD FOUR OF SPADES'
let s:d[0x1F0A5]='PLAYING CARD FIVE OF SPADES'
let s:d[0x1F0A6]='PLAYING CARD SIX OF SPADES'
let s:d[0x1F0A7]='PLAYING CARD SEVEN OF SPADES'
let s:d[0x1F0A8]='PLAYING CARD EIGHT OF SPADES'
let s:d[0x1F0A9]='PLAYING CARD NINE OF SPADES'
let s:d[0x1F0AA]='PLAYING CARD TEN OF SPADES'
let s:d[0x1F0AB]='PLAYING CARD JACK OF SPADES'
let s:d[0x1F0AC]='PLAYING CARD KNIGHT OF SPADES'
let s:d[0x1F0AD]='PLAYING CARD QUEEN OF SPADES'
let s:d[0x1F0AE]='PLAYING CARD KING OF SPADES'
let s:d[0x1F0B1]='PLAYING CARD ACE OF HEARTS'
let s:d[0x1F0B2]='PLAYING CARD TWO OF HEARTS'
let s:d[0x1F0B3]='PLAYING CARD THREE OF HEARTS'
let s:d[0x1F0B4]='PLAYING CARD FOUR OF HEARTS'
let s:d[0x1F0B5]='PLAYING CARD FIVE OF HEARTS'
let s:d[0x1F0B6]='PLAYING CARD SIX OF HEARTS'
let s:d[0x1F0B7]='PLAYING CARD SEVEN OF HEARTS'
let s:d[0x1F0B8]='PLAYING CARD EIGHT OF HEARTS'
let s:d[0x1F0B9]='PLAYING CARD NINE OF HEARTS'
let s:d[0x1F0BA]='PLAYING CARD TEN OF HEARTS'
let s:d[0x1F0BB]='PLAYING CARD JACK OF HEARTS'
let s:d[0x1F0BC]='PLAYING CARD KNIGHT OF HEARTS'
let s:d[0x1F0BD]='PLAYING CARD QUEEN OF HEARTS'
let s:d[0x1F0BE]='PLAYING CARD KING OF HEARTS'
let s:d[0x1F0C1]='PLAYING CARD ACE OF DIAMONDS'
let s:d[0x1F0C2]='PLAYING CARD TWO OF DIAMONDS'
let s:d[0x1F0C3]='PLAYING CARD THREE OF DIAMONDS'
let s:d[0x1F0C4]='PLAYING CARD FOUR OF DIAMONDS'
let s:d[0x1F0C5]='PLAYING CARD FIVE OF DIAMONDS'
let s:d[0x1F0C6]='PLAYING CARD SIX OF DIAMONDS'
let s:d[0x1F0C7]='PLAYING CARD SEVEN OF DIAMONDS'
let s:d[0x1F0C8]='PLAYING CARD EIGHT OF DIAMONDS'
let s:d[0x1F0C9]='PLAYING CARD NINE OF DIAMONDS'
let s:d[0x1F0CA]='PLAYING CARD TEN OF DIAMONDS'
let s:d[0x1F0CB]='PLAYING CARD JACK OF DIAMONDS'
let s:d[0x1F0CC]='PLAYING CARD KNIGHT OF DIAMONDS'
let s:d[0x1F0CD]='PLAYING CARD QUEEN OF DIAMONDS'
let s:d[0x1F0CE]='PLAYING CARD KING OF DIAMONDS'
let s:d[0x1F0CF]='PLAYING CARD BLACK JOKER'
let s:d[0x1F0D1]='PLAYING CARD ACE OF CLUBS'
let s:d[0x1F0D2]='PLAYING CARD TWO OF CLUBS'
let s:d[0x1F0D3]='PLAYING CARD THREE OF CLUBS'
let s:d[0x1F0D4]='PLAYING CARD FOUR OF CLUBS'
let s:d[0x1F0D5]='PLAYING CARD FIVE OF CLUBS'
let s:d[0x1F0D6]='PLAYING CARD SIX OF CLUBS'
let s:d[0x1F0D7]='PLAYING CARD SEVEN OF CLUBS'
let s:d[0x1F0D8]='PLAYING CARD EIGHT OF CLUBS'
let s:d[0x1F0D9]='PLAYING CARD NINE OF CLUBS'
let s:d[0x1F0DA]='PLAYING CARD TEN OF CLUBS'
let s:d[0x1F0DB]='PLAYING CARD JACK OF CLUBS'
let s:d[0x1F0DC]='PLAYING CARD KNIGHT OF CLUBS'
let s:d[0x1F0DD]='PLAYING CARD QUEEN OF CLUBS'
let s:d[0x1F0DE]='PLAYING CARD KING OF CLUBS'
let s:d[0x1F0DF]='PLAYING CARD WHITE JOKER'
let s:d[0x1F100]='DIGIT ZERO FULL STOP'
let s:d[0x1F101]='DIGIT ZERO COMMA'
let s:d[0x1F102]='DIGIT ONE COMMA'
let s:d[0x1F103]='DIGIT TWO COMMA'
let s:d[0x1F104]='DIGIT THREE COMMA'
let s:d[0x1F105]='DIGIT FOUR COMMA'
let s:d[0x1F106]='DIGIT FIVE COMMA'
let s:d[0x1F107]='DIGIT SIX COMMA'
let s:d[0x1F108]='DIGIT SEVEN COMMA'
let s:d[0x1F109]='DIGIT EIGHT COMMA'
let s:d[0x1F10A]='DIGIT NINE COMMA'
let s:d[0x1F110]='PARENTHESIZED LATIN CAPITAL LETTER A'
let s:d[0x1F111]='PARENTHESIZED LATIN CAPITAL LETTER B'
let s:d[0x1F112]='PARENTHESIZED LATIN CAPITAL LETTER C'
let s:d[0x1F113]='PARENTHESIZED LATIN CAPITAL LETTER D'
let s:d[0x1F114]='PARENTHESIZED LATIN CAPITAL LETTER E'
let s:d[0x1F115]='PARENTHESIZED LATIN CAPITAL LETTER F'
let s:d[0x1F116]='PARENTHESIZED LATIN CAPITAL LETTER G'
let s:d[0x1F117]='PARENTHESIZED LATIN CAPITAL LETTER H'
let s:d[0x1F118]='PARENTHESIZED LATIN CAPITAL LETTER I'
let s:d[0x1F119]='PARENTHESIZED LATIN CAPITAL LETTER J'
let s:d[0x1F11A]='PARENTHESIZED LATIN CAPITAL LETTER K'
let s:d[0x1F11B]='PARENTHESIZED LATIN CAPITAL LETTER L'
let s:d[0x1F11C]='PARENTHESIZED LATIN CAPITAL LETTER M'
let s:d[0x1F11D]='PARENTHESIZED LATIN CAPITAL LETTER N'
let s:d[0x1F11E]='PARENTHESIZED LATIN CAPITAL LETTER O'
let s:d[0x1F11F]='PARENTHESIZED LATIN CAPITAL LETTER P'
let s:d[0x1F120]='PARENTHESIZED LATIN CAPITAL LETTER Q'
let s:d[0x1F121]='PARENTHESIZED LATIN CAPITAL LETTER R'
let s:d[0x1F122]='PARENTHESIZED LATIN CAPITAL LETTER S'
let s:d[0x1F123]='PARENTHESIZED LATIN CAPITAL LETTER T'
let s:d[0x1F124]='PARENTHESIZED LATIN CAPITAL LETTER U'
let s:d[0x1F125]='PARENTHESIZED LATIN CAPITAL LETTER V'
let s:d[0x1F126]='PARENTHESIZED LATIN CAPITAL LETTER W'
let s:d[0x1F127]='PARENTHESIZED LATIN CAPITAL LETTER X'
let s:d[0x1F128]='PARENTHESIZED LATIN CAPITAL LETTER Y'
let s:d[0x1F129]='PARENTHESIZED LATIN CAPITAL LETTER Z'
let s:d[0x1F12A]='TORTOISE SHELL BRACKETED LATIN CAPITAL LETTER S'
let s:d[0x1F12B]='CIRCLED ITALIC LATIN CAPITAL LETTER C'
let s:d[0x1F12C]='CIRCLED ITALIC LATIN CAPITAL LETTER R'
let s:d[0x1F12D]='CIRCLED CD'
let s:d[0x1F12E]='CIRCLED WZ'
let s:d[0x1F130]='SQUARED LATIN CAPITAL LETTER A'
let s:d[0x1F131]='SQUARED LATIN CAPITAL LETTER B'
let s:d[0x1F132]='SQUARED LATIN CAPITAL LETTER C'
let s:d[0x1F133]='SQUARED LATIN CAPITAL LETTER D'
let s:d[0x1F134]='SQUARED LATIN CAPITAL LETTER E'
let s:d[0x1F135]='SQUARED LATIN CAPITAL LETTER F'
let s:d[0x1F136]='SQUARED LATIN CAPITAL LETTER G'
let s:d[0x1F137]='SQUARED LATIN CAPITAL LETTER H'
let s:d[0x1F138]='SQUARED LATIN CAPITAL LETTER I'
let s:d[0x1F139]='SQUARED LATIN CAPITAL LETTER J'
let s:d[0x1F13A]='SQUARED LATIN CAPITAL LETTER K'
let s:d[0x1F13B]='SQUARED LATIN CAPITAL LETTER L'
let s:d[0x1F13C]='SQUARED LATIN CAPITAL LETTER M'
let s:d[0x1F13D]='SQUARED LATIN CAPITAL LETTER N'
let s:d[0x1F13E]='SQUARED LATIN CAPITAL LETTER O'
let s:d[0x1F13F]='SQUARED LATIN CAPITAL LETTER P'
let s:d[0x1F140]='SQUARED LATIN CAPITAL LETTER Q'
let s:d[0x1F141]='SQUARED LATIN CAPITAL LETTER R'
let s:d[0x1F142]='SQUARED LATIN CAPITAL LETTER S'
let s:d[0x1F143]='SQUARED LATIN CAPITAL LETTER T'
let s:d[0x1F144]='SQUARED LATIN CAPITAL LETTER U'
let s:d[0x1F145]='SQUARED LATIN CAPITAL LETTER V'
let s:d[0x1F146]='SQUARED LATIN CAPITAL LETTER W'
let s:d[0x1F147]='SQUARED LATIN CAPITAL LETTER X'
let s:d[0x1F148]='SQUARED LATIN CAPITAL LETTER Y'
let s:d[0x1F149]='SQUARED LATIN CAPITAL LETTER Z'
let s:d[0x1F14A]='SQUARED HV'
let s:d[0x1F14B]='SQUARED MV'
let s:d[0x1F14C]='SQUARED SD'
let s:d[0x1F14D]='SQUARED SS'
let s:d[0x1F14E]='SQUARED PPV'
let s:d[0x1F14F]='SQUARED WC'
let s:d[0x1F150]='NEGATIVE CIRCLED LATIN CAPITAL LETTER A'
let s:d[0x1F151]='NEGATIVE CIRCLED LATIN CAPITAL LETTER B'
let s:d[0x1F152]='NEGATIVE CIRCLED LATIN CAPITAL LETTER C'
let s:d[0x1F153]='NEGATIVE CIRCLED LATIN CAPITAL LETTER D'
let s:d[0x1F154]='NEGATIVE CIRCLED LATIN CAPITAL LETTER E'
let s:d[0x1F155]='NEGATIVE CIRCLED LATIN CAPITAL LETTER F'
let s:d[0x1F156]='NEGATIVE CIRCLED LATIN CAPITAL LETTER G'
let s:d[0x1F157]='NEGATIVE CIRCLED LATIN CAPITAL LETTER H'
let s:d[0x1F158]='NEGATIVE CIRCLED LATIN CAPITAL LETTER I'
let s:d[0x1F159]='NEGATIVE CIRCLED LATIN CAPITAL LETTER J'
let s:d[0x1F15A]='NEGATIVE CIRCLED LATIN CAPITAL LETTER K'
let s:d[0x1F15B]='NEGATIVE CIRCLED LATIN CAPITAL LETTER L'
let s:d[0x1F15C]='NEGATIVE CIRCLED LATIN CAPITAL LETTER M'
let s:d[0x1F15D]='NEGATIVE CIRCLED LATIN CAPITAL LETTER N'
let s:d[0x1F15E]='NEGATIVE CIRCLED LATIN CAPITAL LETTER O'
let s:d[0x1F15F]='NEGATIVE CIRCLED LATIN CAPITAL LETTER P'
let s:d[0x1F160]='NEGATIVE CIRCLED LATIN CAPITAL LETTER Q'
let s:d[0x1F161]='NEGATIVE CIRCLED LATIN CAPITAL LETTER R'
let s:d[0x1F162]='NEGATIVE CIRCLED LATIN CAPITAL LETTER S'
let s:d[0x1F163]='NEGATIVE CIRCLED LATIN CAPITAL LETTER T'
let s:d[0x1F164]='NEGATIVE CIRCLED LATIN CAPITAL LETTER U'
let s:d[0x1F165]='NEGATIVE CIRCLED LATIN CAPITAL LETTER V'
let s:d[0x1F166]='NEGATIVE CIRCLED LATIN CAPITAL LETTER W'
let s:d[0x1F167]='NEGATIVE CIRCLED LATIN CAPITAL LETTER X'
let s:d[0x1F168]='NEGATIVE CIRCLED LATIN CAPITAL LETTER Y'
let s:d[0x1F169]='NEGATIVE CIRCLED LATIN CAPITAL LETTER Z'
let s:d[0x1F16A]='RAISED MC SIGN'
let s:d[0x1F16B]='RAISED MD SIGN'
let s:d[0x1F170]='NEGATIVE SQUARED LATIN CAPITAL LETTER A'
let s:d[0x1F171]='NEGATIVE SQUARED LATIN CAPITAL LETTER B'
let s:d[0x1F172]='NEGATIVE SQUARED LATIN CAPITAL LETTER C'
let s:d[0x1F173]='NEGATIVE SQUARED LATIN CAPITAL LETTER D'
let s:d[0x1F174]='NEGATIVE SQUARED LATIN CAPITAL LETTER E'
let s:d[0x1F175]='NEGATIVE SQUARED LATIN CAPITAL LETTER F'
let s:d[0x1F176]='NEGATIVE SQUARED LATIN CAPITAL LETTER G'
let s:d[0x1F177]='NEGATIVE SQUARED LATIN CAPITAL LETTER H'
let s:d[0x1F178]='NEGATIVE SQUARED LATIN CAPITAL LETTER I'
let s:d[0x1F179]='NEGATIVE SQUARED LATIN CAPITAL LETTER J'
let s:d[0x1F17A]='NEGATIVE SQUARED LATIN CAPITAL LETTER K'
let s:d[0x1F17B]='NEGATIVE SQUARED LATIN CAPITAL LETTER L'
let s:d[0x1F17C]='NEGATIVE SQUARED LATIN CAPITAL LETTER M'
let s:d[0x1F17D]='NEGATIVE SQUARED LATIN CAPITAL LETTER N'
let s:d[0x1F17E]='NEGATIVE SQUARED LATIN CAPITAL LETTER O'
let s:d[0x1F17F]='NEGATIVE SQUARED LATIN CAPITAL LETTER P'
let s:d[0x1F180]='NEGATIVE SQUARED LATIN CAPITAL LETTER Q'
let s:d[0x1F181]='NEGATIVE SQUARED LATIN CAPITAL LETTER R'
let s:d[0x1F182]='NEGATIVE SQUARED LATIN CAPITAL LETTER S'
let s:d[0x1F183]='NEGATIVE SQUARED LATIN CAPITAL LETTER T'
let s:d[0x1F184]='NEGATIVE SQUARED LATIN CAPITAL LETTER U'
let s:d[0x1F185]='NEGATIVE SQUARED LATIN CAPITAL LETTER V'
let s:d[0x1F186]='NEGATIVE SQUARED LATIN CAPITAL LETTER W'
let s:d[0x1F187]='NEGATIVE SQUARED LATIN CAPITAL LETTER X'
let s:d[0x1F188]='NEGATIVE SQUARED LATIN CAPITAL LETTER Y'
let s:d[0x1F189]='NEGATIVE SQUARED LATIN CAPITAL LETTER Z'
let s:d[0x1F18A]='CROSSED NEGATIVE SQUARED LATIN CAPITAL LETTER P'
let s:d[0x1F18B]='NEGATIVE SQUARED IC'
let s:d[0x1F18C]='NEGATIVE SQUARED PA'
let s:d[0x1F18D]='NEGATIVE SQUARED SA'
let s:d[0x1F18E]='NEGATIVE SQUARED AB'
let s:d[0x1F18F]='NEGATIVE SQUARED WC'
let s:d[0x1F190]='SQUARE DJ'
let s:d[0x1F191]='SQUARED CL'
let s:d[0x1F192]='SQUARED COOL'
let s:d[0x1F193]='SQUARED FREE'
let s:d[0x1F194]='SQUARED ID'
let s:d[0x1F195]='SQUARED NEW'
let s:d[0x1F196]='SQUARED NG'
let s:d[0x1F197]='SQUARED OK'
let s:d[0x1F198]='SQUARED SOS'
let s:d[0x1F199]='SQUARED UP WITH EXCLAMATION MARK'
let s:d[0x1F19A]='SQUARED VS'
let s:d[0x1F1E6]='REGIONAL INDICATOR SYMBOL LETTER A'
let s:d[0x1F1E7]='REGIONAL INDICATOR SYMBOL LETTER B'
let s:d[0x1F1E8]='REGIONAL INDICATOR SYMBOL LETTER C'
let s:d[0x1F1E9]='REGIONAL INDICATOR SYMBOL LETTER D'
let s:d[0x1F1EA]='REGIONAL INDICATOR SYMBOL LETTER E'
let s:d[0x1F1EB]='REGIONAL INDICATOR SYMBOL LETTER F'
let s:d[0x1F1EC]='REGIONAL INDICATOR SYMBOL LETTER G'
let s:d[0x1F1ED]='REGIONAL INDICATOR SYMBOL LETTER H'
let s:d[0x1F1EE]='REGIONAL INDICATOR SYMBOL LETTER I'
let s:d[0x1F1EF]='REGIONAL INDICATOR SYMBOL LETTER J'
let s:d[0x1F1F0]='REGIONAL INDICATOR SYMBOL LETTER K'
let s:d[0x1F1F1]='REGIONAL INDICATOR SYMBOL LETTER L'
let s:d[0x1F1F2]='REGIONAL INDICATOR SYMBOL LETTER M'
let s:d[0x1F1F3]='REGIONAL INDICATOR SYMBOL LETTER N'
let s:d[0x1F1F4]='REGIONAL INDICATOR SYMBOL LETTER O'
let s:d[0x1F1F5]='REGIONAL INDICATOR SYMBOL LETTER P'
let s:d[0x1F1F6]='REGIONAL INDICATOR SYMBOL LETTER Q'
let s:d[0x1F1F7]='REGIONAL INDICATOR SYMBOL LETTER R'
let s:d[0x1F1F8]='REGIONAL INDICATOR SYMBOL LETTER S'
let s:d[0x1F1F9]='REGIONAL INDICATOR SYMBOL LETTER T'
let s:d[0x1F1FA]='REGIONAL INDICATOR SYMBOL LETTER U'
let s:d[0x1F1FB]='REGIONAL INDICATOR SYMBOL LETTER V'
let s:d[0x1F1FC]='REGIONAL INDICATOR SYMBOL LETTER W'
let s:d[0x1F1FD]='REGIONAL INDICATOR SYMBOL LETTER X'
let s:d[0x1F1FE]='REGIONAL INDICATOR SYMBOL LETTER Y'
let s:d[0x1F1FF]='REGIONAL INDICATOR SYMBOL LETTER Z'
let s:d[0x1F200]='SQUARE HIRAGANA HOKA'
let s:d[0x1F201]='SQUARED KATAKANA KOKO'
let s:d[0x1F202]='SQUARED KATAKANA SA'
let s:d[0x1F210]='SQUARED CJK UNIFIED IDEOGRAPH-624B'
let s:d[0x1F211]='SQUARED CJK UNIFIED IDEOGRAPH-5B57'
let s:d[0x1F212]='SQUARED CJK UNIFIED IDEOGRAPH-53CC'
let s:d[0x1F213]='SQUARED KATAKANA DE'
let s:d[0x1F214]='SQUARED CJK UNIFIED IDEOGRAPH-4E8C'
let s:d[0x1F215]='SQUARED CJK UNIFIED IDEOGRAPH-591A'
let s:d[0x1F216]='SQUARED CJK UNIFIED IDEOGRAPH-89E3'
let s:d[0x1F217]='SQUARED CJK UNIFIED IDEOGRAPH-5929'
let s:d[0x1F218]='SQUARED CJK UNIFIED IDEOGRAPH-4EA4'
let s:d[0x1F219]='SQUARED CJK UNIFIED IDEOGRAPH-6620'
let s:d[0x1F21A]='SQUARED CJK UNIFIED IDEOGRAPH-7121'
let s:d[0x1F21B]='SQUARED CJK UNIFIED IDEOGRAPH-6599'
let s:d[0x1F21C]='SQUARED CJK UNIFIED IDEOGRAPH-524D'
let s:d[0x1F21D]='SQUARED CJK UNIFIED IDEOGRAPH-5F8C'
let s:d[0x1F21E]='SQUARED CJK UNIFIED IDEOGRAPH-518D'
let s:d[0x1F21F]='SQUARED CJK UNIFIED IDEOGRAPH-65B0'
let s:d[0x1F220]='SQUARED CJK UNIFIED IDEOGRAPH-521D'
let s:d[0x1F221]='SQUARED CJK UNIFIED IDEOGRAPH-7D42'
let s:d[0x1F222]='SQUARED CJK UNIFIED IDEOGRAPH-751F'
let s:d[0x1F223]='SQUARED CJK UNIFIED IDEOGRAPH-8CA9'
let s:d[0x1F224]='SQUARED CJK UNIFIED IDEOGRAPH-58F0'
let s:d[0x1F225]='SQUARED CJK UNIFIED IDEOGRAPH-5439'
let s:d[0x1F226]='SQUARED CJK UNIFIED IDEOGRAPH-6F14'
let s:d[0x1F227]='SQUARED CJK UNIFIED IDEOGRAPH-6295'
let s:d[0x1F228]='SQUARED CJK UNIFIED IDEOGRAPH-6355'
let s:d[0x1F229]='SQUARED CJK UNIFIED IDEOGRAPH-4E00'
let s:d[0x1F22A]='SQUARED CJK UNIFIED IDEOGRAPH-4E09'
let s:d[0x1F22B]='SQUARED CJK UNIFIED IDEOGRAPH-904A'
let s:d[0x1F22C]='SQUARED CJK UNIFIED IDEOGRAPH-5DE6'
let s:d[0x1F22D]='SQUARED CJK UNIFIED IDEOGRAPH-4E2D'
let s:d[0x1F22E]='SQUARED CJK UNIFIED IDEOGRAPH-53F3'
let s:d[0x1F22F]='SQUARED CJK UNIFIED IDEOGRAPH-6307'
let s:d[0x1F230]='SQUARED CJK UNIFIED IDEOGRAPH-8D70'
let s:d[0x1F231]='SQUARED CJK UNIFIED IDEOGRAPH-6253'
let s:d[0x1F232]='SQUARED CJK UNIFIED IDEOGRAPH-7981'
let s:d[0x1F233]='SQUARED CJK UNIFIED IDEOGRAPH-7A7A'
let s:d[0x1F234]='SQUARED CJK UNIFIED IDEOGRAPH-5408'
let s:d[0x1F235]='SQUARED CJK UNIFIED IDEOGRAPH-6E80'
let s:d[0x1F236]='SQUARED CJK UNIFIED IDEOGRAPH-6709'
let s:d[0x1F237]='SQUARED CJK UNIFIED IDEOGRAPH-6708'
let s:d[0x1F238]='SQUARED CJK UNIFIED IDEOGRAPH-7533'
let s:d[0x1F239]='SQUARED CJK UNIFIED IDEOGRAPH-5272'
let s:d[0x1F23A]='SQUARED CJK UNIFIED IDEOGRAPH-55B6'
let s:d[0x1F240]='TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-672C'
let s:d[0x1F241]='TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-4E09'
let s:d[0x1F242]='TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-4E8C'
let s:d[0x1F243]='TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-5B89'
let s:d[0x1F244]='TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-70B9'
let s:d[0x1F245]='TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-6253'
let s:d[0x1F246]='TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-76D7'
let s:d[0x1F247]='TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-52DD'
let s:d[0x1F248]='TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-6557'
let s:d[0x1F250]='CIRCLED IDEOGRAPH ADVANTAGE'
let s:d[0x1F251]='CIRCLED IDEOGRAPH ACCEPT'
let s:d[0x1F300]='CYCLONE'
let s:d[0x1F301]='FOGGY'
let s:d[0x1F302]='CLOSED UMBRELLA'
let s:d[0x1F303]='NIGHT WITH STARS'
let s:d[0x1F304]='SUNRISE OVER MOUNTAINS'
let s:d[0x1F305]='SUNRISE'
let s:d[0x1F306]='CITYSCAPE AT DUSK'
let s:d[0x1F307]='SUNSET OVER BUILDINGS'
let s:d[0x1F308]='RAINBOW'
let s:d[0x1F309]='BRIDGE AT NIGHT'
let s:d[0x1F30A]='WATER WAVE'
let s:d[0x1F30B]='VOLCANO'
let s:d[0x1F30C]='MILKY WAY'
let s:d[0x1F30D]='EARTH GLOBE EUROPE-AFRICA'
let s:d[0x1F30E]='EARTH GLOBE AMERICAS'
let s:d[0x1F30F]='EARTH GLOBE ASIA-AUSTRALIA'
let s:d[0x1F310]='GLOBE WITH MERIDIANS'
let s:d[0x1F311]='NEW MOON SYMBOL'
let s:d[0x1F312]='WAXING CRESCENT MOON SYMBOL'
let s:d[0x1F313]='FIRST QUARTER MOON SYMBOL'
let s:d[0x1F314]='WAXING GIBBOUS MOON SYMBOL'
let s:d[0x1F315]='FULL MOON SYMBOL'
let s:d[0x1F316]='WANING GIBBOUS MOON SYMBOL'
let s:d[0x1F317]='LAST QUARTER MOON SYMBOL'
let s:d[0x1F318]='WANING CRESCENT MOON SYMBOL'
let s:d[0x1F319]='CRESCENT MOON'
let s:d[0x1F31A]='NEW MOON WITH FACE'
let s:d[0x1F31B]='FIRST QUARTER MOON WITH FACE'
let s:d[0x1F31C]='LAST QUARTER MOON WITH FACE'
let s:d[0x1F31D]='FULL MOON WITH FACE'
let s:d[0x1F31E]='SUN WITH FACE'
let s:d[0x1F31F]='GLOWING STAR'
let s:d[0x1F320]='SHOOTING STAR'
let s:d[0x1F330]='CHESTNUT'
let s:d[0x1F331]='SEEDLING'
let s:d[0x1F332]='EVERGREEN TREE'
let s:d[0x1F333]='DECIDUOUS TREE'
let s:d[0x1F334]='PALM TREE'
let s:d[0x1F335]='CACTUS'
let s:d[0x1F337]='TULIP'
let s:d[0x1F338]='CHERRY BLOSSOM'
let s:d[0x1F339]='ROSE'
let s:d[0x1F33A]='HIBISCUS'
let s:d[0x1F33B]='SUNFLOWER'
let s:d[0x1F33C]='BLOSSOM'
let s:d[0x1F33D]='EAR OF MAIZE'
let s:d[0x1F33E]='EAR OF RICE'
let s:d[0x1F33F]='HERB'
let s:d[0x1F340]='FOUR LEAF CLOVER'
let s:d[0x1F341]='MAPLE LEAF'
let s:d[0x1F342]='FALLEN LEAF'
let s:d[0x1F343]='LEAF FLUTTERING IN WIND'
let s:d[0x1F344]='MUSHROOM'
let s:d[0x1F345]='TOMATO'
let s:d[0x1F346]='AUBERGINE'
let s:d[0x1F347]='GRAPES'
let s:d[0x1F348]='MELON'
let s:d[0x1F349]='WATERMELON'
let s:d[0x1F34A]='TANGERINE'
let s:d[0x1F34B]='LEMON'
let s:d[0x1F34C]='BANANA'
let s:d[0x1F34D]='PINEAPPLE'
let s:d[0x1F34E]='RED APPLE'
let s:d[0x1F34F]='GREEN APPLE'
let s:d[0x1F350]='PEAR'
let s:d[0x1F351]='PEACH'
let s:d[0x1F352]='CHERRIES'
let s:d[0x1F353]='STRAWBERRY'
let s:d[0x1F354]='HAMBURGER'
let s:d[0x1F355]='SLICE OF PIZZA'
let s:d[0x1F356]='MEAT ON BONE'
let s:d[0x1F357]='POULTRY LEG'
let s:d[0x1F358]='RICE CRACKER'
let s:d[0x1F359]='RICE BALL'
let s:d[0x1F35A]='COOKED RICE'
let s:d[0x1F35B]='CURRY AND RICE'
let s:d[0x1F35C]='STEAMING BOWL'
let s:d[0x1F35D]='SPAGHETTI'
let s:d[0x1F35E]='BREAD'
let s:d[0x1F35F]='FRENCH FRIES'
let s:d[0x1F360]='ROASTED SWEET POTATO'
let s:d[0x1F361]='DANGO'
let s:d[0x1F362]='ODEN'
let s:d[0x1F363]='SUSHI'
let s:d[0x1F364]='FRIED SHRIMP'
let s:d[0x1F365]='FISH CAKE WITH SWIRL DESIGN'
let s:d[0x1F366]='SOFT ICE CREAM'
let s:d[0x1F367]='SHAVED ICE'
let s:d[0x1F368]='ICE CREAM'
let s:d[0x1F369]='DOUGHNUT'
let s:d[0x1F36A]='COOKIE'
let s:d[0x1F36B]='CHOCOLATE BAR'
let s:d[0x1F36C]='CANDY'
let s:d[0x1F36D]='LOLLIPOP'
let s:d[0x1F36E]='CUSTARD'
let s:d[0x1F36F]='HONEY POT'
let s:d[0x1F370]='SHORTCAKE'
let s:d[0x1F371]='BENTO BOX'
let s:d[0x1F372]='POT OF FOOD'
let s:d[0x1F373]='COOKING'
let s:d[0x1F374]='FORK AND KNIFE'
let s:d[0x1F375]='TEACUP WITHOUT HANDLE'
let s:d[0x1F376]='SAKE BOTTLE AND CUP'
let s:d[0x1F377]='WINE GLASS'
let s:d[0x1F378]='COCKTAIL GLASS'
let s:d[0x1F379]='TROPICAL DRINK'
let s:d[0x1F37A]='BEER MUG'
let s:d[0x1F37B]='CLINKING BEER MUGS'
let s:d[0x1F37C]='BABY BOTTLE'
let s:d[0x1F380]='RIBBON'
let s:d[0x1F381]='WRAPPED PRESENT'
let s:d[0x1F382]='BIRTHDAY CAKE'
let s:d[0x1F383]='JACK-O-LANTERN'
let s:d[0x1F384]='CHRISTMAS TREE'
let s:d[0x1F385]='FATHER CHRISTMAS'
let s:d[0x1F386]='FIREWORKS'
let s:d[0x1F387]='FIREWORK SPARKLER'
let s:d[0x1F388]='BALLOON'
let s:d[0x1F389]='PARTY POPPER'
let s:d[0x1F38A]='CONFETTI BALL'
let s:d[0x1F38B]='TANABATA TREE'
let s:d[0x1F38C]='CROSSED FLAGS'
let s:d[0x1F38D]='PINE DECORATION'
let s:d[0x1F38E]='JAPANESE DOLLS'
let s:d[0x1F38F]='CARP STREAMER'
let s:d[0x1F390]='WIND CHIME'
let s:d[0x1F391]='MOON VIEWING CEREMONY'
let s:d[0x1F392]='SCHOOL SATCHEL'
let s:d[0x1F393]='GRADUATION CAP'
let s:d[0x1F3A0]='CAROUSEL HORSE'
let s:d[0x1F3A1]='FERRIS WHEEL'
let s:d[0x1F3A2]='ROLLER COASTER'
let s:d[0x1F3A3]='FISHING POLE AND FISH'
let s:d[0x1F3A4]='MICROPHONE'
let s:d[0x1F3A5]='MOVIE CAMERA'
let s:d[0x1F3A6]='CINEMA'
let s:d[0x1F3A7]='HEADPHONE'
let s:d[0x1F3A8]='ARTIST PALETTE'
let s:d[0x1F3A9]='TOP HAT'
let s:d[0x1F3AA]='CIRCUS TENT'
let s:d[0x1F3AB]='TICKET'
let s:d[0x1F3AC]='CLAPPER BOARD'
let s:d[0x1F3AD]='PERFORMING ARTS'
let s:d[0x1F3AE]='VIDEO GAME'
let s:d[0x1F3AF]='DIRECT HIT'
let s:d[0x1F3B0]='SLOT MACHINE'
let s:d[0x1F3B1]='BILLIARDS'
let s:d[0x1F3B2]='GAME DIE'
let s:d[0x1F3B3]='BOWLING'
let s:d[0x1F3B4]='FLOWER PLAYING CARDS'
let s:d[0x1F3B5]='MUSICAL NOTE'
let s:d[0x1F3B6]='MULTIPLE MUSICAL NOTES'
let s:d[0x1F3B7]='SAXOPHONE'
let s:d[0x1F3B8]='GUITAR'
let s:d[0x1F3B9]='MUSICAL KEYBOARD'
let s:d[0x1F3BA]='TRUMPET'
let s:d[0x1F3BB]='VIOLIN'
let s:d[0x1F3BC]='MUSICAL SCORE'
let s:d[0x1F3BD]='RUNNING SHIRT WITH SASH'
let s:d[0x1F3BE]='TENNIS RACQUET AND BALL'
let s:d[0x1F3BF]='SKI AND SKI BOOT'
let s:d[0x1F3C0]='BASKETBALL AND HOOP'
let s:d[0x1F3C1]='CHEQUERED FLAG'
let s:d[0x1F3C2]='SNOWBOARDER'
let s:d[0x1F3C3]='RUNNER'
let s:d[0x1F3C4]='SURFER'
let s:d[0x1F3C6]='TROPHY'
let s:d[0x1F3C7]='HORSE RACING'
let s:d[0x1F3C8]='AMERICAN FOOTBALL'
let s:d[0x1F3C9]='RUGBY FOOTBALL'
let s:d[0x1F3CA]='SWIMMER'
let s:d[0x1F3E0]='HOUSE BUILDING'
let s:d[0x1F3E1]='HOUSE WITH GARDEN'
let s:d[0x1F3E2]='OFFICE BUILDING'
let s:d[0x1F3E3]='JAPANESE POST OFFICE'
let s:d[0x1F3E4]='EUROPEAN POST OFFICE'
let s:d[0x1F3E5]='HOSPITAL'
let s:d[0x1F3E6]='BANK'
let s:d[0x1F3E7]='AUTOMATED TELLER MACHINE'
let s:d[0x1F3E8]='HOTEL'
let s:d[0x1F3E9]='LOVE HOTEL'
let s:d[0x1F3EA]='CONVENIENCE STORE'
let s:d[0x1F3EB]='SCHOOL'
let s:d[0x1F3EC]='DEPARTMENT STORE'
let s:d[0x1F3ED]='FACTORY'
let s:d[0x1F3EE]='IZAKAYA LANTERN'
let s:d[0x1F3EF]='JAPANESE CASTLE'
let s:d[0x1F3F0]='EUROPEAN CASTLE'
let s:d[0x1F400]='RAT'
let s:d[0x1F401]='MOUSE'
let s:d[0x1F402]='OX'
let s:d[0x1F403]='WATER BUFFALO'
let s:d[0x1F404]='COW'
let s:d[0x1F405]='TIGER'
let s:d[0x1F406]='LEOPARD'
let s:d[0x1F407]='RABBIT'
let s:d[0x1F408]='CAT'
let s:d[0x1F409]='DRAGON'
let s:d[0x1F40A]='CROCODILE'
let s:d[0x1F40B]='WHALE'
let s:d[0x1F40C]='SNAIL'
let s:d[0x1F40D]='SNAKE'
let s:d[0x1F40E]='HORSE'
let s:d[0x1F40F]='RAM'
let s:d[0x1F410]='GOAT'
let s:d[0x1F411]='SHEEP'
let s:d[0x1F412]='MONKEY'
let s:d[0x1F413]='ROOSTER'
let s:d[0x1F414]='CHICKEN'
let s:d[0x1F415]='DOG'
let s:d[0x1F416]='PIG'
let s:d[0x1F417]='BOAR'
let s:d[0x1F418]='ELEPHANT'
let s:d[0x1F419]='OCTOPUS'
let s:d[0x1F41A]='SPIRAL SHELL'
let s:d[0x1F41B]='BUG'
let s:d[0x1F41C]='ANT'
let s:d[0x1F41D]='HONEYBEE'
let s:d[0x1F41E]='LADY BEETLE'
let s:d[0x1F41F]='FISH'
let s:d[0x1F420]='TROPICAL FISH'
let s:d[0x1F421]='BLOWFISH'
let s:d[0x1F422]='TURTLE'
let s:d[0x1F423]='HATCHING CHICK'
let s:d[0x1F424]='BABY CHICK'
let s:d[0x1F425]='FRONT-FACING BABY CHICK'
let s:d[0x1F426]='BIRD'
let s:d[0x1F427]='PENGUIN'
let s:d[0x1F428]='KOALA'
let s:d[0x1F429]='POODLE'
let s:d[0x1F42A]='DROMEDARY CAMEL'
let s:d[0x1F42B]='BACTRIAN CAMEL'
let s:d[0x1F42C]='DOLPHIN'
let s:d[0x1F42D]='MOUSE FACE'
let s:d[0x1F42E]='COW FACE'
let s:d[0x1F42F]='TIGER FACE'
let s:d[0x1F430]='RABBIT FACE'
let s:d[0x1F431]='CAT FACE'
let s:d[0x1F432]='DRAGON FACE'
let s:d[0x1F433]='SPOUTING WHALE'
let s:d[0x1F434]='HORSE FACE'
let s:d[0x1F435]='MONKEY FACE'
let s:d[0x1F436]='DOG FACE'
let s:d[0x1F437]='PIG FACE'
let s:d[0x1F438]='FROG FACE'
let s:d[0x1F439]='HAMSTER FACE'
let s:d[0x1F43A]='WOLF FACE'
let s:d[0x1F43B]='BEAR FACE'
let s:d[0x1F43C]='PANDA FACE'
let s:d[0x1F43D]='PIG NOSE'
let s:d[0x1F43E]='PAW PRINTS'
let s:d[0x1F440]='EYES'
let s:d[0x1F442]='EAR'
let s:d[0x1F443]='NOSE'
let s:d[0x1F444]='MOUTH'
let s:d[0x1F445]='TONGUE'
let s:d[0x1F446]='WHITE UP POINTING BACKHAND INDEX'
let s:d[0x1F447]='WHITE DOWN POINTING BACKHAND INDEX'
let s:d[0x1F448]='WHITE LEFT POINTING BACKHAND INDEX'
let s:d[0x1F449]='WHITE RIGHT POINTING BACKHAND INDEX'
let s:d[0x1F44A]='FISTED HAND SIGN'
let s:d[0x1F44B]='WAVING HAND SIGN'
let s:d[0x1F44C]='OK HAND SIGN'
let s:d[0x1F44D]='THUMBS UP SIGN'
let s:d[0x1F44E]='THUMBS DOWN SIGN'
let s:d[0x1F44F]='CLAPPING HANDS SIGN'
let s:d[0x1F450]='OPEN HANDS SIGN'
let s:d[0x1F451]='CROWN'
let s:d[0x1F452]='WOMANS HAT'
let s:d[0x1F453]='EYEGLASSES'
let s:d[0x1F454]='NECKTIE'
let s:d[0x1F455]='T-SHIRT'
let s:d[0x1F456]='JEANS'
let s:d[0x1F457]='DRESS'
let s:d[0x1F458]='KIMONO'
let s:d[0x1F459]='BIKINI'
let s:d[0x1F45A]='WOMANS CLOTHES'
let s:d[0x1F45B]='PURSE'
let s:d[0x1F45C]='HANDBAG'
let s:d[0x1F45D]='POUCH'
let s:d[0x1F45E]='MANS SHOE'
let s:d[0x1F45F]='ATHLETIC SHOE'
let s:d[0x1F460]='HIGH-HEELED SHOE'
let s:d[0x1F461]='WOMANS SANDAL'
let s:d[0x1F462]='WOMANS BOOTS'
let s:d[0x1F463]='FOOTPRINTS'
let s:d[0x1F464]='BUST IN SILHOUETTE'
let s:d[0x1F465]='BUSTS IN SILHOUETTE'
let s:d[0x1F466]='BOY'
let s:d[0x1F467]='GIRL'
let s:d[0x1F468]='MAN'
let s:d[0x1F469]='WOMAN'
let s:d[0x1F46A]='FAMILY'
let s:d[0x1F46B]='MAN AND WOMAN HOLDING HANDS'
let s:d[0x1F46C]='TWO MEN HOLDING HANDS'
let s:d[0x1F46D]='TWO WOMEN HOLDING HANDS'
let s:d[0x1F46E]='POLICE OFFICER'
let s:d[0x1F46F]='WOMAN WITH BUNNY EARS'
let s:d[0x1F470]='BRIDE WITH VEIL'
let s:d[0x1F471]='PERSON WITH BLOND HAIR'
let s:d[0x1F472]='MAN WITH GUA PI MAO'
let s:d[0x1F473]='MAN WITH TURBAN'
let s:d[0x1F474]='OLDER MAN'
let s:d[0x1F475]='OLDER WOMAN'
let s:d[0x1F476]='BABY'
let s:d[0x1F477]='CONSTRUCTION WORKER'
let s:d[0x1F478]='PRINCESS'
let s:d[0x1F479]='JAPANESE OGRE'
let s:d[0x1F47A]='JAPANESE GOBLIN'
let s:d[0x1F47B]='GHOST'
let s:d[0x1F47C]='BABY ANGEL'
let s:d[0x1F47D]='EXTRATERRESTRIAL ALIEN'
let s:d[0x1F47E]='ALIEN MONSTER'
let s:d[0x1F47F]='IMP'
let s:d[0x1F480]='SKULL'
let s:d[0x1F481]='INFORMATION DESK PERSON'
let s:d[0x1F482]='GUARDSMAN'
let s:d[0x1F483]='DANCER'
let s:d[0x1F484]='LIPSTICK'
let s:d[0x1F485]='NAIL POLISH'
let s:d[0x1F486]='FACE MASSAGE'
let s:d[0x1F487]='HAIRCUT'
let s:d[0x1F488]='BARBER POLE'
let s:d[0x1F489]='SYRINGE'
let s:d[0x1F48A]='PILL'
let s:d[0x1F48B]='KISS MARK'
let s:d[0x1F48C]='LOVE LETTER'
let s:d[0x1F48D]='RING'
let s:d[0x1F48E]='GEM STONE'
let s:d[0x1F48F]='KISS'
let s:d[0x1F490]='BOUQUET'
let s:d[0x1F491]='COUPLE WITH HEART'
let s:d[0x1F492]='WEDDING'
let s:d[0x1F493]='BEATING HEART'
let s:d[0x1F494]='BROKEN HEART'
let s:d[0x1F495]='TWO HEARTS'
let s:d[0x1F496]='SPARKLING HEART'
let s:d[0x1F497]='GROWING HEART'
let s:d[0x1F498]='HEART WITH ARROW'
let s:d[0x1F499]='BLUE HEART'
let s:d[0x1F49A]='GREEN HEART'
let s:d[0x1F49B]='YELLOW HEART'
let s:d[0x1F49C]='PURPLE HEART'
let s:d[0x1F49D]='HEART WITH RIBBON'
let s:d[0x1F49E]='REVOLVING HEARTS'
let s:d[0x1F49F]='HEART DECORATION'
let s:d[0x1F4A0]='DIAMOND SHAPE WITH A DOT INSIDE'
let s:d[0x1F4A1]='ELECTRIC LIGHT BULB'
let s:d[0x1F4A2]='ANGER SYMBOL'
let s:d[0x1F4A3]='BOMB'
let s:d[0x1F4A4]='SLEEPING SYMBOL'
let s:d[0x1F4A5]='COLLISION SYMBOL'
let s:d[0x1F4A6]='SPLASHING SWEAT SYMBOL'
let s:d[0x1F4A7]='DROPLET'
let s:d[0x1F4A8]='DASH SYMBOL'
let s:d[0x1F4A9]='PILE OF POO'
let s:d[0x1F4AA]='FLEXED BICEPS'
let s:d[0x1F4AB]='DIZZY SYMBOL'
let s:d[0x1F4AC]='SPEECH BALLOON'
let s:d[0x1F4AD]='THOUGHT BALLOON'
let s:d[0x1F4AE]='WHITE FLOWER'
let s:d[0x1F4AF]='HUNDRED POINTS SYMBOL'
let s:d[0x1F4B0]='MONEY BAG'
let s:d[0x1F4B1]='CURRENCY EXCHANGE'
let s:d[0x1F4B2]='HEAVY DOLLAR SIGN'
let s:d[0x1F4B3]='CREDIT CARD'
let s:d[0x1F4B4]='BANKNOTE WITH YEN SIGN'
let s:d[0x1F4B5]='BANKNOTE WITH DOLLAR SIGN'
let s:d[0x1F4B6]='BANKNOTE WITH EURO SIGN'
let s:d[0x1F4B7]='BANKNOTE WITH POUND SIGN'
let s:d[0x1F4B8]='MONEY WITH WINGS'
let s:d[0x1F4B9]='CHART WITH UPWARDS TREND AND YEN SIGN'
let s:d[0x1F4BA]='SEAT'
let s:d[0x1F4BB]='PERSONAL COMPUTER'
let s:d[0x1F4BC]='BRIEFCASE'
let s:d[0x1F4BD]='MINIDISC'
let s:d[0x1F4BE]='FLOPPY DISK'
let s:d[0x1F4BF]='OPTICAL DISC'
let s:d[0x1F4C0]='DVD'
let s:d[0x1F4C1]='FILE FOLDER'
let s:d[0x1F4C2]='OPEN FILE FOLDER'
let s:d[0x1F4C3]='PAGE WITH CURL'
let s:d[0x1F4C4]='PAGE FACING UP'
let s:d[0x1F4C5]='CALENDAR'
let s:d[0x1F4C6]='TEAR-OFF CALENDAR'
let s:d[0x1F4C7]='CARD INDEX'
let s:d[0x1F4C8]='CHART WITH UPWARDS TREND'
let s:d[0x1F4C9]='CHART WITH DOWNWARDS TREND'
let s:d[0x1F4CA]='BAR CHART'
let s:d[0x1F4CB]='CLIPBOARD'
let s:d[0x1F4CC]='PUSHPIN'
let s:d[0x1F4CD]='ROUND PUSHPIN'
let s:d[0x1F4CE]='PAPERCLIP'
let s:d[0x1F4CF]='STRAIGHT RULER'
let s:d[0x1F4D0]='TRIANGULAR RULER'
let s:d[0x1F4D1]='BOOKMARK TABS'
let s:d[0x1F4D2]='LEDGER'
let s:d[0x1F4D3]='NOTEBOOK'
let s:d[0x1F4D4]='NOTEBOOK WITH DECORATIVE COVER'
let s:d[0x1F4D5]='CLOSED BOOK'
let s:d[0x1F4D6]='OPEN BOOK'
let s:d[0x1F4D7]='GREEN BOOK'
let s:d[0x1F4D8]='BLUE BOOK'
let s:d[0x1F4D9]='ORANGE BOOK'
let s:d[0x1F4DA]='BOOKS'
let s:d[0x1F4DB]='NAME BADGE'
let s:d[0x1F4DC]='SCROLL'
let s:d[0x1F4DD]='MEMO'
let s:d[0x1F4DE]='TELEPHONE RECEIVER'
let s:d[0x1F4DF]='PAGER'
let s:d[0x1F4E0]='FAX MACHINE'
let s:d[0x1F4E1]='SATELLITE ANTENNA'
let s:d[0x1F4E2]='PUBLIC ADDRESS LOUDSPEAKER'
let s:d[0x1F4E3]='CHEERING MEGAPHONE'
let s:d[0x1F4E4]='OUTBOX TRAY'
let s:d[0x1F4E5]='INBOX TRAY'
let s:d[0x1F4E6]='PACKAGE'
let s:d[0x1F4E7]='E-MAIL SYMBOL'
let s:d[0x1F4E8]='INCOMING ENVELOPE'
let s:d[0x1F4E9]='ENVELOPE WITH DOWNWARDS ARROW ABOVE'
let s:d[0x1F4EA]='CLOSED MAILBOX WITH LOWERED FLAG'
let s:d[0x1F4EB]='CLOSED MAILBOX WITH RAISED FLAG'
let s:d[0x1F4EC]='OPEN MAILBOX WITH RAISED FLAG'
let s:d[0x1F4ED]='OPEN MAILBOX WITH LOWERED FLAG'
let s:d[0x1F4EE]='POSTBOX'
let s:d[0x1F4EF]='POSTAL HORN'
let s:d[0x1F4F0]='NEWSPAPER'
let s:d[0x1F4F1]='MOBILE PHONE'
let s:d[0x1F4F2]='MOBILE PHONE WITH RIGHTWARDS ARROW AT LEFT'
let s:d[0x1F4F3]='VIBRATION MODE'
let s:d[0x1F4F4]='MOBILE PHONE OFF'
let s:d[0x1F4F5]='NO MOBILE PHONES'
let s:d[0x1F4F6]='ANTENNA WITH BARS'
let s:d[0x1F4F7]='CAMERA'
let s:d[0x1F4F9]='VIDEO CAMERA'
let s:d[0x1F4FA]='TELEVISION'
let s:d[0x1F4FB]='RADIO'
let s:d[0x1F4FC]='VIDEOCASSETTE'
let s:d[0x1F500]='TWISTED RIGHTWARDS ARROWS'
let s:d[0x1F501]='CLOCKWISE RIGHTWARDS AND LEFTWARDS OPEN CIRCLE ARROWS'
let s:d[0x1F502]='CLOCKWISE RIGHTWARDS AND LEFTWARDS OPEN CIRCLE ARROWS WITH CIRCLED ONE OVERLAY'
let s:d[0x1F503]='CLOCKWISE DOWNWARDS AND UPWARDS OPEN CIRCLE ARROWS'
let s:d[0x1F504]='ANTICLOCKWISE DOWNWARDS AND UPWARDS OPEN CIRCLE ARROWS'
let s:d[0x1F505]='LOW BRIGHTNESS SYMBOL'
let s:d[0x1F506]='HIGH BRIGHTNESS SYMBOL'
let s:d[0x1F507]='SPEAKER WITH CANCELLATION STROKE'
let s:d[0x1F508]='SPEAKER'
let s:d[0x1F509]='SPEAKER WITH ONE SOUND WAVE'
let s:d[0x1F50A]='SPEAKER WITH THREE SOUND WAVES'
let s:d[0x1F50B]='BATTERY'
let s:d[0x1F50C]='ELECTRIC PLUG'
let s:d[0x1F50D]='LEFT-POINTING MAGNIFYING GLASS'
let s:d[0x1F50E]='RIGHT-POINTING MAGNIFYING GLASS'
let s:d[0x1F50F]='LOCK WITH INK PEN'
let s:d[0x1F510]='CLOSED LOCK WITH KEY'
let s:d[0x1F511]='KEY'
let s:d[0x1F512]='LOCK'
let s:d[0x1F513]='OPEN LOCK'
let s:d[0x1F514]='BELL'
let s:d[0x1F515]='BELL WITH CANCELLATION STROKE'
let s:d[0x1F516]='BOOKMARK'
let s:d[0x1F517]='LINK SYMBOL'
let s:d[0x1F518]='RADIO BUTTON'
let s:d[0x1F519]='BACK WITH LEFTWARDS ARROW ABOVE'
let s:d[0x1F51A]='END WITH LEFTWARDS ARROW ABOVE'
let s:d[0x1F51B]='ON WITH EXCLAMATION MARK WITH LEFT RIGHT ARROW ABOVE'
let s:d[0x1F51C]='SOON WITH RIGHTWARDS ARROW ABOVE'
let s:d[0x1F51D]='TOP WITH UPWARDS ARROW ABOVE'
let s:d[0x1F51E]='NO ONE UNDER EIGHTEEN SYMBOL'
let s:d[0x1F51F]='KEYCAP TEN'
let s:d[0x1F520]='INPUT SYMBOL FOR LATIN CAPITAL LETTERS'
let s:d[0x1F521]='INPUT SYMBOL FOR LATIN SMALL LETTERS'
let s:d[0x1F522]='INPUT SYMBOL FOR NUMBERS'
let s:d[0x1F523]='INPUT SYMBOL FOR SYMBOLS'
let s:d[0x1F524]='INPUT SYMBOL FOR LATIN LETTERS'
let s:d[0x1F525]='FIRE'
let s:d[0x1F526]='ELECTRIC TORCH'
let s:d[0x1F527]='WRENCH'
let s:d[0x1F528]='HAMMER'
let s:d[0x1F529]='NUT AND BOLT'
let s:d[0x1F52A]='HOCHO'
let s:d[0x1F52B]='PISTOL'
let s:d[0x1F52C]='MICROSCOPE'
let s:d[0x1F52D]='TELESCOPE'
let s:d[0x1F52E]='CRYSTAL BALL'
let s:d[0x1F52F]='SIX POINTED STAR WITH MIDDLE DOT'
let s:d[0x1F530]='JAPANESE SYMBOL FOR BEGINNER'
let s:d[0x1F531]='TRIDENT EMBLEM'
let s:d[0x1F532]='BLACK SQUARE BUTTON'
let s:d[0x1F533]='WHITE SQUARE BUTTON'
let s:d[0x1F534]='LARGE RED CIRCLE'
let s:d[0x1F535]='LARGE BLUE CIRCLE'
let s:d[0x1F536]='LARGE ORANGE DIAMOND'
let s:d[0x1F537]='LARGE BLUE DIAMOND'
let s:d[0x1F538]='SMALL ORANGE DIAMOND'
let s:d[0x1F539]='SMALL BLUE DIAMOND'
let s:d[0x1F53A]='UP-POINTING RED TRIANGLE'
let s:d[0x1F53B]='DOWN-POINTING RED TRIANGLE'
let s:d[0x1F53C]='UP-POINTING SMALL RED TRIANGLE'
let s:d[0x1F53D]='DOWN-POINTING SMALL RED TRIANGLE'
let s:d[0x1F540]='CIRCLED CROSS POMMEE'
let s:d[0x1F541]='CROSS POMMEE WITH HALF-CIRCLE BELOW'
let s:d[0x1F542]='CROSS POMMEE'
let s:d[0x1F543]='NOTCHED LEFT SEMICIRCLE WITH THREE DOTS'
let s:d[0x1F550]='CLOCK FACE ONE OCLOCK'
let s:d[0x1F551]='CLOCK FACE TWO OCLOCK'
let s:d[0x1F552]='CLOCK FACE THREE OCLOCK'
let s:d[0x1F553]='CLOCK FACE FOUR OCLOCK'
let s:d[0x1F554]='CLOCK FACE FIVE OCLOCK'
let s:d[0x1F555]='CLOCK FACE SIX OCLOCK'
let s:d[0x1F556]='CLOCK FACE SEVEN OCLOCK'
let s:d[0x1F557]='CLOCK FACE EIGHT OCLOCK'
let s:d[0x1F558]='CLOCK FACE NINE OCLOCK'
let s:d[0x1F559]='CLOCK FACE TEN OCLOCK'
let s:d[0x1F55A]='CLOCK FACE ELEVEN OCLOCK'
let s:d[0x1F55B]='CLOCK FACE TWELVE OCLOCK'
let s:d[0x1F55C]='CLOCK FACE ONE-THIRTY'
let s:d[0x1F55D]='CLOCK FACE TWO-THIRTY'
let s:d[0x1F55E]='CLOCK FACE THREE-THIRTY'
let s:d[0x1F55F]='CLOCK FACE FOUR-THIRTY'
let s:d[0x1F560]='CLOCK FACE FIVE-THIRTY'
let s:d[0x1F561]='CLOCK FACE SIX-THIRTY'
let s:d[0x1F562]='CLOCK FACE SEVEN-THIRTY'
let s:d[0x1F563]='CLOCK FACE EIGHT-THIRTY'
let s:d[0x1F564]='CLOCK FACE NINE-THIRTY'
let s:d[0x1F565]='CLOCK FACE TEN-THIRTY'
let s:d[0x1F566]='CLOCK FACE ELEVEN-THIRTY'
let s:d[0x1F567]='CLOCK FACE TWELVE-THIRTY'
let s:d[0x1F5FB]='MOUNT FUJI'
let s:d[0x1F5FC]='TOKYO TOWER'
let s:d[0x1F5FD]='STATUE OF LIBERTY'
let s:d[0x1F5FE]='SILHOUETTE OF JAPAN'
let s:d[0x1F5FF]='MOYAI'
let s:d[0x1F600]='GRINNING FACE'
let s:d[0x1F601]='GRINNING FACE WITH SMILING EYES'
let s:d[0x1F602]='FACE WITH TEARS OF JOY'
let s:d[0x1F603]='SMILING FACE WITH OPEN MOUTH'
let s:d[0x1F604]='SMILING FACE WITH OPEN MOUTH AND SMILING EYES'
let s:d[0x1F605]='SMILING FACE WITH OPEN MOUTH AND COLD SWEAT'
let s:d[0x1F606]='SMILING FACE WITH OPEN MOUTH AND TIGHTLY-CLOSED EYES'
let s:d[0x1F607]='SMILING FACE WITH HALO'
let s:d[0x1F608]='SMILING FACE WITH HORNS'
let s:d[0x1F609]='WINKING FACE'
let s:d[0x1F60A]='SMILING FACE WITH SMILING EYES'
let s:d[0x1F60B]='FACE SAVOURING DELICIOUS FOOD'
let s:d[0x1F60C]='RELIEVED FACE'
let s:d[0x1F60D]='SMILING FACE WITH HEART-SHAPED EYES'
let s:d[0x1F60E]='SMILING FACE WITH SUNGLASSES'
let s:d[0x1F60F]='SMIRKING FACE'
let s:d[0x1F610]='NEUTRAL FACE'
let s:d[0x1F611]='EXPRESSIONLESS FACE'
let s:d[0x1F612]='UNAMUSED FACE'
let s:d[0x1F613]='FACE WITH COLD SWEAT'
let s:d[0x1F614]='PENSIVE FACE'
let s:d[0x1F615]='CONFUSED FACE'
let s:d[0x1F616]='CONFOUNDED FACE'
let s:d[0x1F617]='KISSING FACE'
let s:d[0x1F618]='FACE THROWING A KISS'
let s:d[0x1F619]='KISSING FACE WITH SMILING EYES'
let s:d[0x1F61A]='KISSING FACE WITH CLOSED EYES'
let s:d[0x1F61B]='FACE WITH STUCK-OUT TONGUE'
let s:d[0x1F61C]='FACE WITH STUCK-OUT TONGUE AND WINKING EYE'
let s:d[0x1F61D]='FACE WITH STUCK-OUT TONGUE AND TIGHTLY-CLOSED EYES'
let s:d[0x1F61E]='DISAPPOINTED FACE'
let s:d[0x1F61F]='WORRIED FACE'
let s:d[0x1F620]='ANGRY FACE'
let s:d[0x1F621]='POUTING FACE'
let s:d[0x1F622]='CRYING FACE'
let s:d[0x1F623]='PERSEVERING FACE'
let s:d[0x1F624]='FACE WITH LOOK OF TRIUMPH'
let s:d[0x1F625]='DISAPPOINTED BUT RELIEVED FACE'
let s:d[0x1F626]='FROWNING FACE WITH OPEN MOUTH'
let s:d[0x1F627]='ANGUISHED FACE'
let s:d[0x1F628]='FEARFUL FACE'
let s:d[0x1F629]='WEARY FACE'
let s:d[0x1F62A]='SLEEPY FACE'
let s:d[0x1F62B]='TIRED FACE'
let s:d[0x1F62C]='GRIMACING FACE'
let s:d[0x1F62D]='LOUDLY CRYING FACE'
let s:d[0x1F62E]='FACE WITH OPEN MOUTH'
let s:d[0x1F62F]='HUSHED FACE'
let s:d[0x1F630]='FACE WITH OPEN MOUTH AND COLD SWEAT'
let s:d[0x1F631]='FACE SCREAMING IN FEAR'
let s:d[0x1F632]='ASTONISHED FACE'
let s:d[0x1F633]='FLUSHED FACE'
let s:d[0x1F634]='SLEEPING FACE'
let s:d[0x1F635]='DIZZY FACE'
let s:d[0x1F636]='FACE WITHOUT MOUTH'
let s:d[0x1F637]='FACE WITH MEDICAL MASK'
let s:d[0x1F638]='GRINNING CAT FACE WITH SMILING EYES'
let s:d[0x1F639]='CAT FACE WITH TEARS OF JOY'
let s:d[0x1F63A]='SMILING CAT FACE WITH OPEN MOUTH'
let s:d[0x1F63B]='SMILING CAT FACE WITH HEART-SHAPED EYES'
let s:d[0x1F63C]='CAT FACE WITH WRY SMILE'
let s:d[0x1F63D]='KISSING CAT FACE WITH CLOSED EYES'
let s:d[0x1F63E]='POUTING CAT FACE'
let s:d[0x1F63F]='CRYING CAT FACE'
let s:d[0x1F640]='WEARY CAT FACE'
let s:d[0x1F645]='FACE WITH NO GOOD GESTURE'
let s:d[0x1F646]='FACE WITH OK GESTURE'
let s:d[0x1F647]='PERSON BOWING DEEPLY'
let s:d[0x1F648]='SEE-NO-EVIL MONKEY'
let s:d[0x1F649]='HEAR-NO-EVIL MONKEY'
let s:d[0x1F64A]='SPEAK-NO-EVIL MONKEY'
let s:d[0x1F64B]='HAPPY PERSON RAISING ONE HAND'
let s:d[0x1F64C]='PERSON RAISING BOTH HANDS IN CELEBRATION'
let s:d[0x1F64D]='PERSON FROWNING'
let s:d[0x1F64E]='PERSON WITH POUTING FACE'
let s:d[0x1F64F]='PERSON WITH FOLDED HANDS'
let s:d[0x1F680]='ROCKET'
let s:d[0x1F681]='HELICOPTER'
let s:d[0x1F682]='STEAM LOCOMOTIVE'
let s:d[0x1F683]='RAILWAY CAR'
let s:d[0x1F684]='HIGH-SPEED TRAIN'
let s:d[0x1F685]='HIGH-SPEED TRAIN WITH BULLET NOSE'
let s:d[0x1F686]='TRAIN'
let s:d[0x1F687]='METRO'
let s:d[0x1F688]='LIGHT RAIL'
let s:d[0x1F689]='STATION'
let s:d[0x1F68A]='TRAM'
let s:d[0x1F68B]='TRAM CAR'
let s:d[0x1F68C]='BUS'
let s:d[0x1F68D]='ONCOMING BUS'
let s:d[0x1F68E]='TROLLEYBUS'
let s:d[0x1F68F]='BUS STOP'
let s:d[0x1F690]='MINIBUS'
let s:d[0x1F691]='AMBULANCE'
let s:d[0x1F692]='FIRE ENGINE'
let s:d[0x1F693]='POLICE CAR'
let s:d[0x1F694]='ONCOMING POLICE CAR'
let s:d[0x1F695]='TAXI'
let s:d[0x1F696]='ONCOMING TAXI'
let s:d[0x1F697]='AUTOMOBILE'
let s:d[0x1F698]='ONCOMING AUTOMOBILE'
let s:d[0x1F699]='RECREATIONAL VEHICLE'
let s:d[0x1F69A]='DELIVERY TRUCK'
let s:d[0x1F69B]='ARTICULATED LORRY'
let s:d[0x1F69C]='TRACTOR'
let s:d[0x1F69D]='MONORAIL'
let s:d[0x1F69E]='MOUNTAIN RAILWAY'
let s:d[0x1F69F]='SUSPENSION RAILWAY'
let s:d[0x1F6A0]='MOUNTAIN CABLEWAY'
let s:d[0x1F6A1]='AERIAL TRAMWAY'
let s:d[0x1F6A2]='SHIP'
let s:d[0x1F6A3]='ROWBOAT'
let s:d[0x1F6A4]='SPEEDBOAT'
let s:d[0x1F6A5]='HORIZONTAL TRAFFIC LIGHT'
let s:d[0x1F6A6]='VERTICAL TRAFFIC LIGHT'
let s:d[0x1F6A7]='CONSTRUCTION SIGN'
let s:d[0x1F6A8]='POLICE CARS REVOLVING LIGHT'
let s:d[0x1F6A9]='TRIANGULAR FLAG ON POST'
let s:d[0x1F6AA]='DOOR'
let s:d[0x1F6AB]='NO ENTRY SIGN'
let s:d[0x1F6AC]='SMOKING SYMBOL'
let s:d[0x1F6AD]='NO SMOKING SYMBOL'
let s:d[0x1F6AE]='PUT LITTER IN ITS PLACE SYMBOL'
let s:d[0x1F6AF]='DO NOT LITTER SYMBOL'
let s:d[0x1F6B0]='POTABLE WATER SYMBOL'
let s:d[0x1F6B1]='NON-POTABLE WATER SYMBOL'
let s:d[0x1F6B2]='BICYCLE'
let s:d[0x1F6B3]='NO BICYCLES'
let s:d[0x1F6B4]='BICYCLIST'
let s:d[0x1F6B5]='MOUNTAIN BICYCLIST'
let s:d[0x1F6B6]='PEDESTRIAN'
let s:d[0x1F6B7]='NO PEDESTRIANS'
let s:d[0x1F6B8]='CHILDREN CROSSING'
let s:d[0x1F6B9]='MENS SYMBOL'
let s:d[0x1F6BA]='WOMENS SYMBOL'
let s:d[0x1F6BB]='RESTROOM'
let s:d[0x1F6BC]='BABY SYMBOL'
let s:d[0x1F6BD]='TOILET'
let s:d[0x1F6BE]='WATER CLOSET'
let s:d[0x1F6BF]='SHOWER'
let s:d[0x1F6C0]='BATH'
let s:d[0x1F6C1]='BATHTUB'
let s:d[0x1F6C2]='PASSPORT CONTROL'
let s:d[0x1F6C3]='CUSTOMS'
let s:d[0x1F6C4]='BAGGAGE CLAIM'
let s:d[0x1F6C5]='LEFT LUGGAGE'
let s:d[0x1F700]='ALCHEMICAL SYMBOL FOR QUINTESSENCE'
let s:d[0x1F701]='ALCHEMICAL SYMBOL FOR AIR'
let s:d[0x1F702]='ALCHEMICAL SYMBOL FOR FIRE'
let s:d[0x1F703]='ALCHEMICAL SYMBOL FOR EARTH'
let s:d[0x1F704]='ALCHEMICAL SYMBOL FOR WATER'
let s:d[0x1F705]='ALCHEMICAL SYMBOL FOR AQUAFORTIS'
let s:d[0x1F706]='ALCHEMICAL SYMBOL FOR AQUA REGIA'
let s:d[0x1F707]='ALCHEMICAL SYMBOL FOR AQUA REGIA-2'
let s:d[0x1F708]='ALCHEMICAL SYMBOL FOR AQUA VITAE'
let s:d[0x1F709]='ALCHEMICAL SYMBOL FOR AQUA VITAE-2'
let s:d[0x1F70A]='ALCHEMICAL SYMBOL FOR VINEGAR'
let s:d[0x1F70B]='ALCHEMICAL SYMBOL FOR VINEGAR-2'
let s:d[0x1F70C]='ALCHEMICAL SYMBOL FOR VINEGAR-3'
let s:d[0x1F70D]='ALCHEMICAL SYMBOL FOR SULFUR'
let s:d[0x1F70E]='ALCHEMICAL SYMBOL FOR PHILOSOPHERS SULFUR'
let s:d[0x1F70F]='ALCHEMICAL SYMBOL FOR BLACK SULFUR'
let s:d[0x1F710]='ALCHEMICAL SYMBOL FOR MERCURY SUBLIMATE'
let s:d[0x1F711]='ALCHEMICAL SYMBOL FOR MERCURY SUBLIMATE-2'
let s:d[0x1F712]='ALCHEMICAL SYMBOL FOR MERCURY SUBLIMATE-3'
let s:d[0x1F713]='ALCHEMICAL SYMBOL FOR CINNABAR'
let s:d[0x1F714]='ALCHEMICAL SYMBOL FOR SALT'
let s:d[0x1F715]='ALCHEMICAL SYMBOL FOR NITRE'
let s:d[0x1F716]='ALCHEMICAL SYMBOL FOR VITRIOL'
let s:d[0x1F717]='ALCHEMICAL SYMBOL FOR VITRIOL-2'
let s:d[0x1F718]='ALCHEMICAL SYMBOL FOR ROCK SALT'
let s:d[0x1F719]='ALCHEMICAL SYMBOL FOR ROCK SALT-2'
let s:d[0x1F71A]='ALCHEMICAL SYMBOL FOR GOLD'
let s:d[0x1F71B]='ALCHEMICAL SYMBOL FOR SILVER'
let s:d[0x1F71C]='ALCHEMICAL SYMBOL FOR IRON ORE'
let s:d[0x1F71D]='ALCHEMICAL SYMBOL FOR IRON ORE-2'
let s:d[0x1F71E]='ALCHEMICAL SYMBOL FOR CROCUS OF IRON'
let s:d[0x1F71F]='ALCHEMICAL SYMBOL FOR REGULUS OF IRON'
let s:d[0x1F720]='ALCHEMICAL SYMBOL FOR COPPER ORE'
let s:d[0x1F721]='ALCHEMICAL SYMBOL FOR IRON-COPPER ORE'
let s:d[0x1F722]='ALCHEMICAL SYMBOL FOR SUBLIMATE OF COPPER'
let s:d[0x1F723]='ALCHEMICAL SYMBOL FOR CROCUS OF COPPER'
let s:d[0x1F724]='ALCHEMICAL SYMBOL FOR CROCUS OF COPPER-2'
let s:d[0x1F725]='ALCHEMICAL SYMBOL FOR COPPER ANTIMONIATE'
let s:d[0x1F726]='ALCHEMICAL SYMBOL FOR SALT OF COPPER ANTIMONIATE'
let s:d[0x1F727]='ALCHEMICAL SYMBOL FOR SUBLIMATE OF SALT OF COPPER'
let s:d[0x1F728]='ALCHEMICAL SYMBOL FOR VERDIGRIS'
let s:d[0x1F729]='ALCHEMICAL SYMBOL FOR TIN ORE'
let s:d[0x1F72A]='ALCHEMICAL SYMBOL FOR LEAD ORE'
let s:d[0x1F72B]='ALCHEMICAL SYMBOL FOR ANTIMONY ORE'
let s:d[0x1F72C]='ALCHEMICAL SYMBOL FOR SUBLIMATE OF ANTIMONY'
let s:d[0x1F72D]='ALCHEMICAL SYMBOL FOR SALT OF ANTIMONY'
let s:d[0x1F72E]='ALCHEMICAL SYMBOL FOR SUBLIMATE OF SALT OF ANTIMONY'
let s:d[0x1F72F]='ALCHEMICAL SYMBOL FOR VINEGAR OF ANTIMONY'
let s:d[0x1F730]='ALCHEMICAL SYMBOL FOR REGULUS OF ANTIMONY'
let s:d[0x1F731]='ALCHEMICAL SYMBOL FOR REGULUS OF ANTIMONY-2'
let s:d[0x1F732]='ALCHEMICAL SYMBOL FOR REGULUS'
let s:d[0x1F733]='ALCHEMICAL SYMBOL FOR REGULUS-2'
let s:d[0x1F734]='ALCHEMICAL SYMBOL FOR REGULUS-3'
let s:d[0x1F735]='ALCHEMICAL SYMBOL FOR REGULUS-4'
let s:d[0x1F736]='ALCHEMICAL SYMBOL FOR ALKALI'
let s:d[0x1F737]='ALCHEMICAL SYMBOL FOR ALKALI-2'
let s:d[0x1F738]='ALCHEMICAL SYMBOL FOR MARCASITE'
let s:d[0x1F739]='ALCHEMICAL SYMBOL FOR SAL-AMMONIAC'
let s:d[0x1F73A]='ALCHEMICAL SYMBOL FOR ARSENIC'
let s:d[0x1F73B]='ALCHEMICAL SYMBOL FOR REALGAR'
let s:d[0x1F73C]='ALCHEMICAL SYMBOL FOR REALGAR-2'
let s:d[0x1F73D]='ALCHEMICAL SYMBOL FOR AURIPIGMENT'
let s:d[0x1F73E]='ALCHEMICAL SYMBOL FOR BISMUTH ORE'
let s:d[0x1F73F]='ALCHEMICAL SYMBOL FOR TARTAR'
let s:d[0x1F740]='ALCHEMICAL SYMBOL FOR TARTAR-2'
let s:d[0x1F741]='ALCHEMICAL SYMBOL FOR QUICK LIME'
let s:d[0x1F742]='ALCHEMICAL SYMBOL FOR BORAX'
let s:d[0x1F743]='ALCHEMICAL SYMBOL FOR BORAX-2'
let s:d[0x1F744]='ALCHEMICAL SYMBOL FOR BORAX-3'
let s:d[0x1F745]='ALCHEMICAL SYMBOL FOR ALUM'
let s:d[0x1F746]='ALCHEMICAL SYMBOL FOR OIL'
let s:d[0x1F747]='ALCHEMICAL SYMBOL FOR SPIRIT'
let s:d[0x1F748]='ALCHEMICAL SYMBOL FOR TINCTURE'
let s:d[0x1F749]='ALCHEMICAL SYMBOL FOR GUM'
let s:d[0x1F74A]='ALCHEMICAL SYMBOL FOR WAX'
let s:d[0x1F74B]='ALCHEMICAL SYMBOL FOR POWDER'
let s:d[0x1F74C]='ALCHEMICAL SYMBOL FOR CALX'
let s:d[0x1F74D]='ALCHEMICAL SYMBOL FOR TUTTY'
let s:d[0x1F74E]='ALCHEMICAL SYMBOL FOR CAPUT MORTUUM'
let s:d[0x1F74F]='ALCHEMICAL SYMBOL FOR SCEPTER OF JOVE'
let s:d[0x1F750]='ALCHEMICAL SYMBOL FOR CADUCEUS'
let s:d[0x1F751]='ALCHEMICAL SYMBOL FOR TRIDENT'
let s:d[0x1F752]='ALCHEMICAL SYMBOL FOR STARRED TRIDENT'
let s:d[0x1F753]='ALCHEMICAL SYMBOL FOR LODESTONE'
let s:d[0x1F754]='ALCHEMICAL SYMBOL FOR SOAP'
let s:d[0x1F755]='ALCHEMICAL SYMBOL FOR URINE'
let s:d[0x1F756]='ALCHEMICAL SYMBOL FOR HORSE DUNG'
let s:d[0x1F757]='ALCHEMICAL SYMBOL FOR ASHES'
let s:d[0x1F758]='ALCHEMICAL SYMBOL FOR POT ASHES'
let s:d[0x1F759]='ALCHEMICAL SYMBOL FOR BRICK'
let s:d[0x1F75A]='ALCHEMICAL SYMBOL FOR POWDERED BRICK'
let s:d[0x1F75B]='ALCHEMICAL SYMBOL FOR AMALGAM'
let s:d[0x1F75C]='ALCHEMICAL SYMBOL FOR STRATUM SUPER STRATUM'
let s:d[0x1F75D]='ALCHEMICAL SYMBOL FOR STRATUM SUPER STRATUM-2'
let s:d[0x1F75E]='ALCHEMICAL SYMBOL FOR SUBLIMATION'
let s:d[0x1F75F]='ALCHEMICAL SYMBOL FOR PRECIPITATE'
let s:d[0x1F760]='ALCHEMICAL SYMBOL FOR DISTILL'
let s:d[0x1F761]='ALCHEMICAL SYMBOL FOR DISSOLVE'
let s:d[0x1F762]='ALCHEMICAL SYMBOL FOR DISSOLVE-2'
let s:d[0x1F763]='ALCHEMICAL SYMBOL FOR PURIFY'
let s:d[0x1F764]='ALCHEMICAL SYMBOL FOR PUTREFACTION'
let s:d[0x1F765]='ALCHEMICAL SYMBOL FOR CRUCIBLE'
let s:d[0x1F766]='ALCHEMICAL SYMBOL FOR CRUCIBLE-2'
let s:d[0x1F767]='ALCHEMICAL SYMBOL FOR CRUCIBLE-3'
let s:d[0x1F768]='ALCHEMICAL SYMBOL FOR CRUCIBLE-4'
let s:d[0x1F769]='ALCHEMICAL SYMBOL FOR CRUCIBLE-5'
let s:d[0x1F76A]='ALCHEMICAL SYMBOL FOR ALEMBIC'
let s:d[0x1F76B]='ALCHEMICAL SYMBOL FOR BATH OF MARY'
let s:d[0x1F76C]='ALCHEMICAL SYMBOL FOR BATH OF VAPOURS'
let s:d[0x1F76D]='ALCHEMICAL SYMBOL FOR RETORT'
let s:d[0x1F76E]='ALCHEMICAL SYMBOL FOR HOUR'
let s:d[0x1F76F]='ALCHEMICAL SYMBOL FOR NIGHT'
let s:d[0x1F770]='ALCHEMICAL SYMBOL FOR DAY-NIGHT'
let s:d[0x1F771]='ALCHEMICAL SYMBOL FOR MONTH'
let s:d[0x1F772]='ALCHEMICAL SYMBOL FOR HALF DRAM'
let s:d[0x1F773]='ALCHEMICAL SYMBOL FOR HALF OUNCE'
let s:d[0x1FFFE]='<not a character>'
let s:d[0x1FFFF]='<not a character>'
let s:d[0x2F800]='CJK COMPATIBILITY IDEOGRAPH-2F800'
let s:d[0x2F801]='CJK COMPATIBILITY IDEOGRAPH-2F801'
let s:d[0x2F802]='CJK COMPATIBILITY IDEOGRAPH-2F802'
let s:d[0x2F803]='CJK COMPATIBILITY IDEOGRAPH-2F803'
let s:d[0x2F804]='CJK COMPATIBILITY IDEOGRAPH-2F804'
let s:d[0x2F805]='CJK COMPATIBILITY IDEOGRAPH-2F805'
let s:d[0x2F806]='CJK COMPATIBILITY IDEOGRAPH-2F806'
let s:d[0x2F807]='CJK COMPATIBILITY IDEOGRAPH-2F807'
let s:d[0x2F808]='CJK COMPATIBILITY IDEOGRAPH-2F808'
let s:d[0x2F809]='CJK COMPATIBILITY IDEOGRAPH-2F809'
let s:d[0x2F80A]='CJK COMPATIBILITY IDEOGRAPH-2F80A'
let s:d[0x2F80B]='CJK COMPATIBILITY IDEOGRAPH-2F80B'
let s:d[0x2F80C]='CJK COMPATIBILITY IDEOGRAPH-2F80C'
let s:d[0x2F80D]='CJK COMPATIBILITY IDEOGRAPH-2F80D'
let s:d[0x2F80E]='CJK COMPATIBILITY IDEOGRAPH-2F80E'
let s:d[0x2F80F]='CJK COMPATIBILITY IDEOGRAPH-2F80F'
let s:d[0x2F810]='CJK COMPATIBILITY IDEOGRAPH-2F810'
let s:d[0x2F811]='CJK COMPATIBILITY IDEOGRAPH-2F811'
let s:d[0x2F812]='CJK COMPATIBILITY IDEOGRAPH-2F812'
let s:d[0x2F813]='CJK COMPATIBILITY IDEOGRAPH-2F813'
let s:d[0x2F814]='CJK COMPATIBILITY IDEOGRAPH-2F814'
let s:d[0x2F815]='CJK COMPATIBILITY IDEOGRAPH-2F815'
let s:d[0x2F816]='CJK COMPATIBILITY IDEOGRAPH-2F816'
let s:d[0x2F817]='CJK COMPATIBILITY IDEOGRAPH-2F817'
let s:d[0x2F818]='CJK COMPATIBILITY IDEOGRAPH-2F818'
let s:d[0x2F819]='CJK COMPATIBILITY IDEOGRAPH-2F819'
let s:d[0x2F81A]='CJK COMPATIBILITY IDEOGRAPH-2F81A'
let s:d[0x2F81B]='CJK COMPATIBILITY IDEOGRAPH-2F81B'
let s:d[0x2F81C]='CJK COMPATIBILITY IDEOGRAPH-2F81C'
let s:d[0x2F81D]='CJK COMPATIBILITY IDEOGRAPH-2F81D'
let s:d[0x2F81E]='CJK COMPATIBILITY IDEOGRAPH-2F81E'
let s:d[0x2F81F]='CJK COMPATIBILITY IDEOGRAPH-2F81F'
let s:d[0x2F820]='CJK COMPATIBILITY IDEOGRAPH-2F820'
let s:d[0x2F821]='CJK COMPATIBILITY IDEOGRAPH-2F821'
let s:d[0x2F822]='CJK COMPATIBILITY IDEOGRAPH-2F822'
let s:d[0x2F823]='CJK COMPATIBILITY IDEOGRAPH-2F823'
let s:d[0x2F824]='CJK COMPATIBILITY IDEOGRAPH-2F824'
let s:d[0x2F825]='CJK COMPATIBILITY IDEOGRAPH-2F825'
let s:d[0x2F826]='CJK COMPATIBILITY IDEOGRAPH-2F826'
let s:d[0x2F827]='CJK COMPATIBILITY IDEOGRAPH-2F827'
let s:d[0x2F828]='CJK COMPATIBILITY IDEOGRAPH-2F828'
let s:d[0x2F829]='CJK COMPATIBILITY IDEOGRAPH-2F829'
let s:d[0x2F82A]='CJK COMPATIBILITY IDEOGRAPH-2F82A'
let s:d[0x2F82B]='CJK COMPATIBILITY IDEOGRAPH-2F82B'
let s:d[0x2F82C]='CJK COMPATIBILITY IDEOGRAPH-2F82C'
let s:d[0x2F82D]='CJK COMPATIBILITY IDEOGRAPH-2F82D'
let s:d[0x2F82E]='CJK COMPATIBILITY IDEOGRAPH-2F82E'
let s:d[0x2F82F]='CJK COMPATIBILITY IDEOGRAPH-2F82F'
let s:d[0x2F830]='CJK COMPATIBILITY IDEOGRAPH-2F830'
let s:d[0x2F831]='CJK COMPATIBILITY IDEOGRAPH-2F831'
let s:d[0x2F832]='CJK COMPATIBILITY IDEOGRAPH-2F832'
let s:d[0x2F833]='CJK COMPATIBILITY IDEOGRAPH-2F833'
let s:d[0x2F834]='CJK COMPATIBILITY IDEOGRAPH-2F834'
let s:d[0x2F835]='CJK COMPATIBILITY IDEOGRAPH-2F835'
let s:d[0x2F836]='CJK COMPATIBILITY IDEOGRAPH-2F836'
let s:d[0x2F837]='CJK COMPATIBILITY IDEOGRAPH-2F837'
let s:d[0x2F838]='CJK COMPATIBILITY IDEOGRAPH-2F838'
let s:d[0x2F839]='CJK COMPATIBILITY IDEOGRAPH-2F839'
let s:d[0x2F83A]='CJK COMPATIBILITY IDEOGRAPH-2F83A'
let s:d[0x2F83B]='CJK COMPATIBILITY IDEOGRAPH-2F83B'
let s:d[0x2F83C]='CJK COMPATIBILITY IDEOGRAPH-2F83C'
let s:d[0x2F83D]='CJK COMPATIBILITY IDEOGRAPH-2F83D'
let s:d[0x2F83E]='CJK COMPATIBILITY IDEOGRAPH-2F83E'
let s:d[0x2F83F]='CJK COMPATIBILITY IDEOGRAPH-2F83F'
let s:d[0x2F840]='CJK COMPATIBILITY IDEOGRAPH-2F840'
let s:d[0x2F841]='CJK COMPATIBILITY IDEOGRAPH-2F841'
let s:d[0x2F842]='CJK COMPATIBILITY IDEOGRAPH-2F842'
let s:d[0x2F843]='CJK COMPATIBILITY IDEOGRAPH-2F843'
let s:d[0x2F844]='CJK COMPATIBILITY IDEOGRAPH-2F844'
let s:d[0x2F845]='CJK COMPATIBILITY IDEOGRAPH-2F845'
let s:d[0x2F846]='CJK COMPATIBILITY IDEOGRAPH-2F846'
let s:d[0x2F847]='CJK COMPATIBILITY IDEOGRAPH-2F847'
let s:d[0x2F848]='CJK COMPATIBILITY IDEOGRAPH-2F848'
let s:d[0x2F849]='CJK COMPATIBILITY IDEOGRAPH-2F849'
let s:d[0x2F84A]='CJK COMPATIBILITY IDEOGRAPH-2F84A'
let s:d[0x2F84B]='CJK COMPATIBILITY IDEOGRAPH-2F84B'
let s:d[0x2F84C]='CJK COMPATIBILITY IDEOGRAPH-2F84C'
let s:d[0x2F84D]='CJK COMPATIBILITY IDEOGRAPH-2F84D'
let s:d[0x2F84E]='CJK COMPATIBILITY IDEOGRAPH-2F84E'
let s:d[0x2F84F]='CJK COMPATIBILITY IDEOGRAPH-2F84F'
let s:d[0x2F850]='CJK COMPATIBILITY IDEOGRAPH-2F850'
let s:d[0x2F851]='CJK COMPATIBILITY IDEOGRAPH-2F851'
let s:d[0x2F852]='CJK COMPATIBILITY IDEOGRAPH-2F852'
let s:d[0x2F853]='CJK COMPATIBILITY IDEOGRAPH-2F853'
let s:d[0x2F854]='CJK COMPATIBILITY IDEOGRAPH-2F854'
let s:d[0x2F855]='CJK COMPATIBILITY IDEOGRAPH-2F855'
let s:d[0x2F856]='CJK COMPATIBILITY IDEOGRAPH-2F856'
let s:d[0x2F857]='CJK COMPATIBILITY IDEOGRAPH-2F857'
let s:d[0x2F858]='CJK COMPATIBILITY IDEOGRAPH-2F858'
let s:d[0x2F859]='CJK COMPATIBILITY IDEOGRAPH-2F859'
let s:d[0x2F85A]='CJK COMPATIBILITY IDEOGRAPH-2F85A'
let s:d[0x2F85B]='CJK COMPATIBILITY IDEOGRAPH-2F85B'
let s:d[0x2F85C]='CJK COMPATIBILITY IDEOGRAPH-2F85C'
let s:d[0x2F85D]='CJK COMPATIBILITY IDEOGRAPH-2F85D'
let s:d[0x2F85E]='CJK COMPATIBILITY IDEOGRAPH-2F85E'
let s:d[0x2F85F]='CJK COMPATIBILITY IDEOGRAPH-2F85F'
let s:d[0x2F860]='CJK COMPATIBILITY IDEOGRAPH-2F860'
let s:d[0x2F861]='CJK COMPATIBILITY IDEOGRAPH-2F861'
let s:d[0x2F862]='CJK COMPATIBILITY IDEOGRAPH-2F862'
let s:d[0x2F863]='CJK COMPATIBILITY IDEOGRAPH-2F863'
let s:d[0x2F864]='CJK COMPATIBILITY IDEOGRAPH-2F864'
let s:d[0x2F865]='CJK COMPATIBILITY IDEOGRAPH-2F865'
let s:d[0x2F866]='CJK COMPATIBILITY IDEOGRAPH-2F866'
let s:d[0x2F867]='CJK COMPATIBILITY IDEOGRAPH-2F867'
let s:d[0x2F868]='CJK COMPATIBILITY IDEOGRAPH-2F868'
let s:d[0x2F869]='CJK COMPATIBILITY IDEOGRAPH-2F869'
let s:d[0x2F86A]='CJK COMPATIBILITY IDEOGRAPH-2F86A'
let s:d[0x2F86B]='CJK COMPATIBILITY IDEOGRAPH-2F86B'
let s:d[0x2F86C]='CJK COMPATIBILITY IDEOGRAPH-2F86C'
let s:d[0x2F86D]='CJK COMPATIBILITY IDEOGRAPH-2F86D'
let s:d[0x2F86E]='CJK COMPATIBILITY IDEOGRAPH-2F86E'
let s:d[0x2F86F]='CJK COMPATIBILITY IDEOGRAPH-2F86F'
let s:d[0x2F870]='CJK COMPATIBILITY IDEOGRAPH-2F870'
let s:d[0x2F871]='CJK COMPATIBILITY IDEOGRAPH-2F871'
let s:d[0x2F872]='CJK COMPATIBILITY IDEOGRAPH-2F872'
let s:d[0x2F873]='CJK COMPATIBILITY IDEOGRAPH-2F873'
let s:d[0x2F874]='CJK COMPATIBILITY IDEOGRAPH-2F874'
let s:d[0x2F875]='CJK COMPATIBILITY IDEOGRAPH-2F875'
let s:d[0x2F876]='CJK COMPATIBILITY IDEOGRAPH-2F876'
let s:d[0x2F877]='CJK COMPATIBILITY IDEOGRAPH-2F877'
let s:d[0x2F878]='CJK COMPATIBILITY IDEOGRAPH-2F878'
let s:d[0x2F879]='CJK COMPATIBILITY IDEOGRAPH-2F879'
let s:d[0x2F87A]='CJK COMPATIBILITY IDEOGRAPH-2F87A'
let s:d[0x2F87B]='CJK COMPATIBILITY IDEOGRAPH-2F87B'
let s:d[0x2F87C]='CJK COMPATIBILITY IDEOGRAPH-2F87C'
let s:d[0x2F87D]='CJK COMPATIBILITY IDEOGRAPH-2F87D'
let s:d[0x2F87E]='CJK COMPATIBILITY IDEOGRAPH-2F87E'
let s:d[0x2F87F]='CJK COMPATIBILITY IDEOGRAPH-2F87F'
let s:d[0x2F880]='CJK COMPATIBILITY IDEOGRAPH-2F880'
let s:d[0x2F881]='CJK COMPATIBILITY IDEOGRAPH-2F881'
let s:d[0x2F882]='CJK COMPATIBILITY IDEOGRAPH-2F882'
let s:d[0x2F883]='CJK COMPATIBILITY IDEOGRAPH-2F883'
let s:d[0x2F884]='CJK COMPATIBILITY IDEOGRAPH-2F884'
let s:d[0x2F885]='CJK COMPATIBILITY IDEOGRAPH-2F885'
let s:d[0x2F886]='CJK COMPATIBILITY IDEOGRAPH-2F886'
let s:d[0x2F887]='CJK COMPATIBILITY IDEOGRAPH-2F887'
let s:d[0x2F888]='CJK COMPATIBILITY IDEOGRAPH-2F888'
let s:d[0x2F889]='CJK COMPATIBILITY IDEOGRAPH-2F889'
let s:d[0x2F88A]='CJK COMPATIBILITY IDEOGRAPH-2F88A'
let s:d[0x2F88B]='CJK COMPATIBILITY IDEOGRAPH-2F88B'
let s:d[0x2F88C]='CJK COMPATIBILITY IDEOGRAPH-2F88C'
let s:d[0x2F88D]='CJK COMPATIBILITY IDEOGRAPH-2F88D'
let s:d[0x2F88E]='CJK COMPATIBILITY IDEOGRAPH-2F88E'
let s:d[0x2F88F]='CJK COMPATIBILITY IDEOGRAPH-2F88F'
let s:d[0x2F890]='CJK COMPATIBILITY IDEOGRAPH-2F890'
let s:d[0x2F891]='CJK COMPATIBILITY IDEOGRAPH-2F891'
let s:d[0x2F892]='CJK COMPATIBILITY IDEOGRAPH-2F892'
let s:d[0x2F893]='CJK COMPATIBILITY IDEOGRAPH-2F893'
let s:d[0x2F894]='CJK COMPATIBILITY IDEOGRAPH-2F894'
let s:d[0x2F895]='CJK COMPATIBILITY IDEOGRAPH-2F895'
let s:d[0x2F896]='CJK COMPATIBILITY IDEOGRAPH-2F896'
let s:d[0x2F897]='CJK COMPATIBILITY IDEOGRAPH-2F897'
let s:d[0x2F898]='CJK COMPATIBILITY IDEOGRAPH-2F898'
let s:d[0x2F899]='CJK COMPATIBILITY IDEOGRAPH-2F899'
let s:d[0x2F89A]='CJK COMPATIBILITY IDEOGRAPH-2F89A'
let s:d[0x2F89B]='CJK COMPATIBILITY IDEOGRAPH-2F89B'
let s:d[0x2F89C]='CJK COMPATIBILITY IDEOGRAPH-2F89C'
let s:d[0x2F89D]='CJK COMPATIBILITY IDEOGRAPH-2F89D'
let s:d[0x2F89E]='CJK COMPATIBILITY IDEOGRAPH-2F89E'
let s:d[0x2F89F]='CJK COMPATIBILITY IDEOGRAPH-2F89F'
let s:d[0x2F8A0]='CJK COMPATIBILITY IDEOGRAPH-2F8A0'
let s:d[0x2F8A1]='CJK COMPATIBILITY IDEOGRAPH-2F8A1'
let s:d[0x2F8A2]='CJK COMPATIBILITY IDEOGRAPH-2F8A2'
let s:d[0x2F8A3]='CJK COMPATIBILITY IDEOGRAPH-2F8A3'
let s:d[0x2F8A4]='CJK COMPATIBILITY IDEOGRAPH-2F8A4'
let s:d[0x2F8A5]='CJK COMPATIBILITY IDEOGRAPH-2F8A5'
let s:d[0x2F8A6]='CJK COMPATIBILITY IDEOGRAPH-2F8A6'
let s:d[0x2F8A7]='CJK COMPATIBILITY IDEOGRAPH-2F8A7'
let s:d[0x2F8A8]='CJK COMPATIBILITY IDEOGRAPH-2F8A8'
let s:d[0x2F8A9]='CJK COMPATIBILITY IDEOGRAPH-2F8A9'
let s:d[0x2F8AA]='CJK COMPATIBILITY IDEOGRAPH-2F8AA'
let s:d[0x2F8AB]='CJK COMPATIBILITY IDEOGRAPH-2F8AB'
let s:d[0x2F8AC]='CJK COMPATIBILITY IDEOGRAPH-2F8AC'
let s:d[0x2F8AD]='CJK COMPATIBILITY IDEOGRAPH-2F8AD'
let s:d[0x2F8AE]='CJK COMPATIBILITY IDEOGRAPH-2F8AE'
let s:d[0x2F8AF]='CJK COMPATIBILITY IDEOGRAPH-2F8AF'
let s:d[0x2F8B0]='CJK COMPATIBILITY IDEOGRAPH-2F8B0'
let s:d[0x2F8B1]='CJK COMPATIBILITY IDEOGRAPH-2F8B1'
let s:d[0x2F8B2]='CJK COMPATIBILITY IDEOGRAPH-2F8B2'
let s:d[0x2F8B3]='CJK COMPATIBILITY IDEOGRAPH-2F8B3'
let s:d[0x2F8B4]='CJK COMPATIBILITY IDEOGRAPH-2F8B4'
let s:d[0x2F8B5]='CJK COMPATIBILITY IDEOGRAPH-2F8B5'
let s:d[0x2F8B6]='CJK COMPATIBILITY IDEOGRAPH-2F8B6'
let s:d[0x2F8B7]='CJK COMPATIBILITY IDEOGRAPH-2F8B7'
let s:d[0x2F8B8]='CJK COMPATIBILITY IDEOGRAPH-2F8B8'
let s:d[0x2F8B9]='CJK COMPATIBILITY IDEOGRAPH-2F8B9'
let s:d[0x2F8BA]='CJK COMPATIBILITY IDEOGRAPH-2F8BA'
let s:d[0x2F8BB]='CJK COMPATIBILITY IDEOGRAPH-2F8BB'
let s:d[0x2F8BC]='CJK COMPATIBILITY IDEOGRAPH-2F8BC'
let s:d[0x2F8BD]='CJK COMPATIBILITY IDEOGRAPH-2F8BD'
let s:d[0x2F8BE]='CJK COMPATIBILITY IDEOGRAPH-2F8BE'
let s:d[0x2F8BF]='CJK COMPATIBILITY IDEOGRAPH-2F8BF'
let s:d[0x2F8C0]='CJK COMPATIBILITY IDEOGRAPH-2F8C0'
let s:d[0x2F8C1]='CJK COMPATIBILITY IDEOGRAPH-2F8C1'
let s:d[0x2F8C2]='CJK COMPATIBILITY IDEOGRAPH-2F8C2'
let s:d[0x2F8C3]='CJK COMPATIBILITY IDEOGRAPH-2F8C3'
let s:d[0x2F8C4]='CJK COMPATIBILITY IDEOGRAPH-2F8C4'
let s:d[0x2F8C5]='CJK COMPATIBILITY IDEOGRAPH-2F8C5'
let s:d[0x2F8C6]='CJK COMPATIBILITY IDEOGRAPH-2F8C6'
let s:d[0x2F8C7]='CJK COMPATIBILITY IDEOGRAPH-2F8C7'
let s:d[0x2F8C8]='CJK COMPATIBILITY IDEOGRAPH-2F8C8'
let s:d[0x2F8C9]='CJK COMPATIBILITY IDEOGRAPH-2F8C9'
let s:d[0x2F8CA]='CJK COMPATIBILITY IDEOGRAPH-2F8CA'
let s:d[0x2F8CB]='CJK COMPATIBILITY IDEOGRAPH-2F8CB'
let s:d[0x2F8CC]='CJK COMPATIBILITY IDEOGRAPH-2F8CC'
let s:d[0x2F8CD]='CJK COMPATIBILITY IDEOGRAPH-2F8CD'
let s:d[0x2F8CE]='CJK COMPATIBILITY IDEOGRAPH-2F8CE'
let s:d[0x2F8CF]='CJK COMPATIBILITY IDEOGRAPH-2F8CF'
let s:d[0x2F8D0]='CJK COMPATIBILITY IDEOGRAPH-2F8D0'
let s:d[0x2F8D1]='CJK COMPATIBILITY IDEOGRAPH-2F8D1'
let s:d[0x2F8D2]='CJK COMPATIBILITY IDEOGRAPH-2F8D2'
let s:d[0x2F8D3]='CJK COMPATIBILITY IDEOGRAPH-2F8D3'
let s:d[0x2F8D4]='CJK COMPATIBILITY IDEOGRAPH-2F8D4'
let s:d[0x2F8D5]='CJK COMPATIBILITY IDEOGRAPH-2F8D5'
let s:d[0x2F8D6]='CJK COMPATIBILITY IDEOGRAPH-2F8D6'
let s:d[0x2F8D7]='CJK COMPATIBILITY IDEOGRAPH-2F8D7'
let s:d[0x2F8D8]='CJK COMPATIBILITY IDEOGRAPH-2F8D8'
let s:d[0x2F8D9]='CJK COMPATIBILITY IDEOGRAPH-2F8D9'
let s:d[0x2F8DA]='CJK COMPATIBILITY IDEOGRAPH-2F8DA'
let s:d[0x2F8DB]='CJK COMPATIBILITY IDEOGRAPH-2F8DB'
let s:d[0x2F8DC]='CJK COMPATIBILITY IDEOGRAPH-2F8DC'
let s:d[0x2F8DD]='CJK COMPATIBILITY IDEOGRAPH-2F8DD'
let s:d[0x2F8DE]='CJK COMPATIBILITY IDEOGRAPH-2F8DE'
let s:d[0x2F8DF]='CJK COMPATIBILITY IDEOGRAPH-2F8DF'
let s:d[0x2F8E0]='CJK COMPATIBILITY IDEOGRAPH-2F8E0'
let s:d[0x2F8E1]='CJK COMPATIBILITY IDEOGRAPH-2F8E1'
let s:d[0x2F8E2]='CJK COMPATIBILITY IDEOGRAPH-2F8E2'
let s:d[0x2F8E3]='CJK COMPATIBILITY IDEOGRAPH-2F8E3'
let s:d[0x2F8E4]='CJK COMPATIBILITY IDEOGRAPH-2F8E4'
let s:d[0x2F8E5]='CJK COMPATIBILITY IDEOGRAPH-2F8E5'
let s:d[0x2F8E6]='CJK COMPATIBILITY IDEOGRAPH-2F8E6'
let s:d[0x2F8E7]='CJK COMPATIBILITY IDEOGRAPH-2F8E7'
let s:d[0x2F8E8]='CJK COMPATIBILITY IDEOGRAPH-2F8E8'
let s:d[0x2F8E9]='CJK COMPATIBILITY IDEOGRAPH-2F8E9'
let s:d[0x2F8EA]='CJK COMPATIBILITY IDEOGRAPH-2F8EA'
let s:d[0x2F8EB]='CJK COMPATIBILITY IDEOGRAPH-2F8EB'
let s:d[0x2F8EC]='CJK COMPATIBILITY IDEOGRAPH-2F8EC'
let s:d[0x2F8ED]='CJK COMPATIBILITY IDEOGRAPH-2F8ED'
let s:d[0x2F8EE]='CJK COMPATIBILITY IDEOGRAPH-2F8EE'
let s:d[0x2F8EF]='CJK COMPATIBILITY IDEOGRAPH-2F8EF'
let s:d[0x2F8F0]='CJK COMPATIBILITY IDEOGRAPH-2F8F0'
let s:d[0x2F8F1]='CJK COMPATIBILITY IDEOGRAPH-2F8F1'
let s:d[0x2F8F2]='CJK COMPATIBILITY IDEOGRAPH-2F8F2'
let s:d[0x2F8F3]='CJK COMPATIBILITY IDEOGRAPH-2F8F3'
let s:d[0x2F8F4]='CJK COMPATIBILITY IDEOGRAPH-2F8F4'
let s:d[0x2F8F5]='CJK COMPATIBILITY IDEOGRAPH-2F8F5'
let s:d[0x2F8F6]='CJK COMPATIBILITY IDEOGRAPH-2F8F6'
let s:d[0x2F8F7]='CJK COMPATIBILITY IDEOGRAPH-2F8F7'
let s:d[0x2F8F8]='CJK COMPATIBILITY IDEOGRAPH-2F8F8'
let s:d[0x2F8F9]='CJK COMPATIBILITY IDEOGRAPH-2F8F9'
let s:d[0x2F8FA]='CJK COMPATIBILITY IDEOGRAPH-2F8FA'
let s:d[0x2F8FB]='CJK COMPATIBILITY IDEOGRAPH-2F8FB'
let s:d[0x2F8FC]='CJK COMPATIBILITY IDEOGRAPH-2F8FC'
let s:d[0x2F8FD]='CJK COMPATIBILITY IDEOGRAPH-2F8FD'
let s:d[0x2F8FE]='CJK COMPATIBILITY IDEOGRAPH-2F8FE'
let s:d[0x2F8FF]='CJK COMPATIBILITY IDEOGRAPH-2F8FF'
let s:d[0x2F900]='CJK COMPATIBILITY IDEOGRAPH-2F900'
let s:d[0x2F901]='CJK COMPATIBILITY IDEOGRAPH-2F901'
let s:d[0x2F902]='CJK COMPATIBILITY IDEOGRAPH-2F902'
let s:d[0x2F903]='CJK COMPATIBILITY IDEOGRAPH-2F903'
let s:d[0x2F904]='CJK COMPATIBILITY IDEOGRAPH-2F904'
let s:d[0x2F905]='CJK COMPATIBILITY IDEOGRAPH-2F905'
let s:d[0x2F906]='CJK COMPATIBILITY IDEOGRAPH-2F906'
let s:d[0x2F907]='CJK COMPATIBILITY IDEOGRAPH-2F907'
let s:d[0x2F908]='CJK COMPATIBILITY IDEOGRAPH-2F908'
let s:d[0x2F909]='CJK COMPATIBILITY IDEOGRAPH-2F909'
let s:d[0x2F90A]='CJK COMPATIBILITY IDEOGRAPH-2F90A'
let s:d[0x2F90B]='CJK COMPATIBILITY IDEOGRAPH-2F90B'
let s:d[0x2F90C]='CJK COMPATIBILITY IDEOGRAPH-2F90C'
let s:d[0x2F90D]='CJK COMPATIBILITY IDEOGRAPH-2F90D'
let s:d[0x2F90E]='CJK COMPATIBILITY IDEOGRAPH-2F90E'
let s:d[0x2F90F]='CJK COMPATIBILITY IDEOGRAPH-2F90F'
let s:d[0x2F910]='CJK COMPATIBILITY IDEOGRAPH-2F910'
let s:d[0x2F911]='CJK COMPATIBILITY IDEOGRAPH-2F911'
let s:d[0x2F912]='CJK COMPATIBILITY IDEOGRAPH-2F912'
let s:d[0x2F913]='CJK COMPATIBILITY IDEOGRAPH-2F913'
let s:d[0x2F914]='CJK COMPATIBILITY IDEOGRAPH-2F914'
let s:d[0x2F915]='CJK COMPATIBILITY IDEOGRAPH-2F915'
let s:d[0x2F916]='CJK COMPATIBILITY IDEOGRAPH-2F916'
let s:d[0x2F917]='CJK COMPATIBILITY IDEOGRAPH-2F917'
let s:d[0x2F918]='CJK COMPATIBILITY IDEOGRAPH-2F918'
let s:d[0x2F919]='CJK COMPATIBILITY IDEOGRAPH-2F919'
let s:d[0x2F91A]='CJK COMPATIBILITY IDEOGRAPH-2F91A'
let s:d[0x2F91B]='CJK COMPATIBILITY IDEOGRAPH-2F91B'
let s:d[0x2F91C]='CJK COMPATIBILITY IDEOGRAPH-2F91C'
let s:d[0x2F91D]='CJK COMPATIBILITY IDEOGRAPH-2F91D'
let s:d[0x2F91E]='CJK COMPATIBILITY IDEOGRAPH-2F91E'
let s:d[0x2F91F]='CJK COMPATIBILITY IDEOGRAPH-2F91F'
let s:d[0x2F920]='CJK COMPATIBILITY IDEOGRAPH-2F920'
let s:d[0x2F921]='CJK COMPATIBILITY IDEOGRAPH-2F921'
let s:d[0x2F922]='CJK COMPATIBILITY IDEOGRAPH-2F922'
let s:d[0x2F923]='CJK COMPATIBILITY IDEOGRAPH-2F923'
let s:d[0x2F924]='CJK COMPATIBILITY IDEOGRAPH-2F924'
let s:d[0x2F925]='CJK COMPATIBILITY IDEOGRAPH-2F925'
let s:d[0x2F926]='CJK COMPATIBILITY IDEOGRAPH-2F926'
let s:d[0x2F927]='CJK COMPATIBILITY IDEOGRAPH-2F927'
let s:d[0x2F928]='CJK COMPATIBILITY IDEOGRAPH-2F928'
let s:d[0x2F929]='CJK COMPATIBILITY IDEOGRAPH-2F929'
let s:d[0x2F92A]='CJK COMPATIBILITY IDEOGRAPH-2F92A'
let s:d[0x2F92B]='CJK COMPATIBILITY IDEOGRAPH-2F92B'
let s:d[0x2F92C]='CJK COMPATIBILITY IDEOGRAPH-2F92C'
let s:d[0x2F92D]='CJK COMPATIBILITY IDEOGRAPH-2F92D'
let s:d[0x2F92E]='CJK COMPATIBILITY IDEOGRAPH-2F92E'
let s:d[0x2F92F]='CJK COMPATIBILITY IDEOGRAPH-2F92F'
let s:d[0x2F930]='CJK COMPATIBILITY IDEOGRAPH-2F930'
let s:d[0x2F931]='CJK COMPATIBILITY IDEOGRAPH-2F931'
let s:d[0x2F932]='CJK COMPATIBILITY IDEOGRAPH-2F932'
let s:d[0x2F933]='CJK COMPATIBILITY IDEOGRAPH-2F933'
let s:d[0x2F934]='CJK COMPATIBILITY IDEOGRAPH-2F934'
let s:d[0x2F935]='CJK COMPATIBILITY IDEOGRAPH-2F935'
let s:d[0x2F936]='CJK COMPATIBILITY IDEOGRAPH-2F936'
let s:d[0x2F937]='CJK COMPATIBILITY IDEOGRAPH-2F937'
let s:d[0x2F938]='CJK COMPATIBILITY IDEOGRAPH-2F938'
let s:d[0x2F939]='CJK COMPATIBILITY IDEOGRAPH-2F939'
let s:d[0x2F93A]='CJK COMPATIBILITY IDEOGRAPH-2F93A'
let s:d[0x2F93B]='CJK COMPATIBILITY IDEOGRAPH-2F93B'
let s:d[0x2F93C]='CJK COMPATIBILITY IDEOGRAPH-2F93C'
let s:d[0x2F93D]='CJK COMPATIBILITY IDEOGRAPH-2F93D'
let s:d[0x2F93E]='CJK COMPATIBILITY IDEOGRAPH-2F93E'
let s:d[0x2F93F]='CJK COMPATIBILITY IDEOGRAPH-2F93F'
let s:d[0x2F940]='CJK COMPATIBILITY IDEOGRAPH-2F940'
let s:d[0x2F941]='CJK COMPATIBILITY IDEOGRAPH-2F941'
let s:d[0x2F942]='CJK COMPATIBILITY IDEOGRAPH-2F942'
let s:d[0x2F943]='CJK COMPATIBILITY IDEOGRAPH-2F943'
let s:d[0x2F944]='CJK COMPATIBILITY IDEOGRAPH-2F944'
let s:d[0x2F945]='CJK COMPATIBILITY IDEOGRAPH-2F945'
let s:d[0x2F946]='CJK COMPATIBILITY IDEOGRAPH-2F946'
let s:d[0x2F947]='CJK COMPATIBILITY IDEOGRAPH-2F947'
let s:d[0x2F948]='CJK COMPATIBILITY IDEOGRAPH-2F948'
let s:d[0x2F949]='CJK COMPATIBILITY IDEOGRAPH-2F949'
let s:d[0x2F94A]='CJK COMPATIBILITY IDEOGRAPH-2F94A'
let s:d[0x2F94B]='CJK COMPATIBILITY IDEOGRAPH-2F94B'
let s:d[0x2F94C]='CJK COMPATIBILITY IDEOGRAPH-2F94C'
let s:d[0x2F94D]='CJK COMPATIBILITY IDEOGRAPH-2F94D'
let s:d[0x2F94E]='CJK COMPATIBILITY IDEOGRAPH-2F94E'
let s:d[0x2F94F]='CJK COMPATIBILITY IDEOGRAPH-2F94F'
let s:d[0x2F950]='CJK COMPATIBILITY IDEOGRAPH-2F950'
let s:d[0x2F951]='CJK COMPATIBILITY IDEOGRAPH-2F951'
let s:d[0x2F952]='CJK COMPATIBILITY IDEOGRAPH-2F952'
let s:d[0x2F953]='CJK COMPATIBILITY IDEOGRAPH-2F953'
let s:d[0x2F954]='CJK COMPATIBILITY IDEOGRAPH-2F954'
let s:d[0x2F955]='CJK COMPATIBILITY IDEOGRAPH-2F955'
let s:d[0x2F956]='CJK COMPATIBILITY IDEOGRAPH-2F956'
let s:d[0x2F957]='CJK COMPATIBILITY IDEOGRAPH-2F957'
let s:d[0x2F958]='CJK COMPATIBILITY IDEOGRAPH-2F958'
let s:d[0x2F959]='CJK COMPATIBILITY IDEOGRAPH-2F959'
let s:d[0x2F95A]='CJK COMPATIBILITY IDEOGRAPH-2F95A'
let s:d[0x2F95B]='CJK COMPATIBILITY IDEOGRAPH-2F95B'
let s:d[0x2F95C]='CJK COMPATIBILITY IDEOGRAPH-2F95C'
let s:d[0x2F95D]='CJK COMPATIBILITY IDEOGRAPH-2F95D'
let s:d[0x2F95E]='CJK COMPATIBILITY IDEOGRAPH-2F95E'
let s:d[0x2F95F]='CJK COMPATIBILITY IDEOGRAPH-2F95F'
let s:d[0x2F960]='CJK COMPATIBILITY IDEOGRAPH-2F960'
let s:d[0x2F961]='CJK COMPATIBILITY IDEOGRAPH-2F961'
let s:d[0x2F962]='CJK COMPATIBILITY IDEOGRAPH-2F962'
let s:d[0x2F963]='CJK COMPATIBILITY IDEOGRAPH-2F963'
let s:d[0x2F964]='CJK COMPATIBILITY IDEOGRAPH-2F964'
let s:d[0x2F965]='CJK COMPATIBILITY IDEOGRAPH-2F965'
let s:d[0x2F966]='CJK COMPATIBILITY IDEOGRAPH-2F966'
let s:d[0x2F967]='CJK COMPATIBILITY IDEOGRAPH-2F967'
let s:d[0x2F968]='CJK COMPATIBILITY IDEOGRAPH-2F968'
let s:d[0x2F969]='CJK COMPATIBILITY IDEOGRAPH-2F969'
let s:d[0x2F96A]='CJK COMPATIBILITY IDEOGRAPH-2F96A'
let s:d[0x2F96B]='CJK COMPATIBILITY IDEOGRAPH-2F96B'
let s:d[0x2F96C]='CJK COMPATIBILITY IDEOGRAPH-2F96C'
let s:d[0x2F96D]='CJK COMPATIBILITY IDEOGRAPH-2F96D'
let s:d[0x2F96E]='CJK COMPATIBILITY IDEOGRAPH-2F96E'
let s:d[0x2F96F]='CJK COMPATIBILITY IDEOGRAPH-2F96F'
let s:d[0x2F970]='CJK COMPATIBILITY IDEOGRAPH-2F970'
let s:d[0x2F971]='CJK COMPATIBILITY IDEOGRAPH-2F971'
let s:d[0x2F972]='CJK COMPATIBILITY IDEOGRAPH-2F972'
let s:d[0x2F973]='CJK COMPATIBILITY IDEOGRAPH-2F973'
let s:d[0x2F974]='CJK COMPATIBILITY IDEOGRAPH-2F974'
let s:d[0x2F975]='CJK COMPATIBILITY IDEOGRAPH-2F975'
let s:d[0x2F976]='CJK COMPATIBILITY IDEOGRAPH-2F976'
let s:d[0x2F977]='CJK COMPATIBILITY IDEOGRAPH-2F977'
let s:d[0x2F978]='CJK COMPATIBILITY IDEOGRAPH-2F978'
let s:d[0x2F979]='CJK COMPATIBILITY IDEOGRAPH-2F979'
let s:d[0x2F97A]='CJK COMPATIBILITY IDEOGRAPH-2F97A'
let s:d[0x2F97B]='CJK COMPATIBILITY IDEOGRAPH-2F97B'
let s:d[0x2F97C]='CJK COMPATIBILITY IDEOGRAPH-2F97C'
let s:d[0x2F97D]='CJK COMPATIBILITY IDEOGRAPH-2F97D'
let s:d[0x2F97E]='CJK COMPATIBILITY IDEOGRAPH-2F97E'
let s:d[0x2F97F]='CJK COMPATIBILITY IDEOGRAPH-2F97F'
let s:d[0x2F980]='CJK COMPATIBILITY IDEOGRAPH-2F980'
let s:d[0x2F981]='CJK COMPATIBILITY IDEOGRAPH-2F981'
let s:d[0x2F982]='CJK COMPATIBILITY IDEOGRAPH-2F982'
let s:d[0x2F983]='CJK COMPATIBILITY IDEOGRAPH-2F983'
let s:d[0x2F984]='CJK COMPATIBILITY IDEOGRAPH-2F984'
let s:d[0x2F985]='CJK COMPATIBILITY IDEOGRAPH-2F985'
let s:d[0x2F986]='CJK COMPATIBILITY IDEOGRAPH-2F986'
let s:d[0x2F987]='CJK COMPATIBILITY IDEOGRAPH-2F987'
let s:d[0x2F988]='CJK COMPATIBILITY IDEOGRAPH-2F988'
let s:d[0x2F989]='CJK COMPATIBILITY IDEOGRAPH-2F989'
let s:d[0x2F98A]='CJK COMPATIBILITY IDEOGRAPH-2F98A'
let s:d[0x2F98B]='CJK COMPATIBILITY IDEOGRAPH-2F98B'
let s:d[0x2F98C]='CJK COMPATIBILITY IDEOGRAPH-2F98C'
let s:d[0x2F98D]='CJK COMPATIBILITY IDEOGRAPH-2F98D'
let s:d[0x2F98E]='CJK COMPATIBILITY IDEOGRAPH-2F98E'
let s:d[0x2F98F]='CJK COMPATIBILITY IDEOGRAPH-2F98F'
let s:d[0x2F990]='CJK COMPATIBILITY IDEOGRAPH-2F990'
let s:d[0x2F991]='CJK COMPATIBILITY IDEOGRAPH-2F991'
let s:d[0x2F992]='CJK COMPATIBILITY IDEOGRAPH-2F992'
let s:d[0x2F993]='CJK COMPATIBILITY IDEOGRAPH-2F993'
let s:d[0x2F994]='CJK COMPATIBILITY IDEOGRAPH-2F994'
let s:d[0x2F995]='CJK COMPATIBILITY IDEOGRAPH-2F995'
let s:d[0x2F996]='CJK COMPATIBILITY IDEOGRAPH-2F996'
let s:d[0x2F997]='CJK COMPATIBILITY IDEOGRAPH-2F997'
let s:d[0x2F998]='CJK COMPATIBILITY IDEOGRAPH-2F998'
let s:d[0x2F999]='CJK COMPATIBILITY IDEOGRAPH-2F999'
let s:d[0x2F99A]='CJK COMPATIBILITY IDEOGRAPH-2F99A'
let s:d[0x2F99B]='CJK COMPATIBILITY IDEOGRAPH-2F99B'
let s:d[0x2F99C]='CJK COMPATIBILITY IDEOGRAPH-2F99C'
let s:d[0x2F99D]='CJK COMPATIBILITY IDEOGRAPH-2F99D'
let s:d[0x2F99E]='CJK COMPATIBILITY IDEOGRAPH-2F99E'
let s:d[0x2F99F]='CJK COMPATIBILITY IDEOGRAPH-2F99F'
let s:d[0x2F9A0]='CJK COMPATIBILITY IDEOGRAPH-2F9A0'
let s:d[0x2F9A1]='CJK COMPATIBILITY IDEOGRAPH-2F9A1'
let s:d[0x2F9A2]='CJK COMPATIBILITY IDEOGRAPH-2F9A2'
let s:d[0x2F9A3]='CJK COMPATIBILITY IDEOGRAPH-2F9A3'
let s:d[0x2F9A4]='CJK COMPATIBILITY IDEOGRAPH-2F9A4'
let s:d[0x2F9A5]='CJK COMPATIBILITY IDEOGRAPH-2F9A5'
let s:d[0x2F9A6]='CJK COMPATIBILITY IDEOGRAPH-2F9A6'
let s:d[0x2F9A7]='CJK COMPATIBILITY IDEOGRAPH-2F9A7'
let s:d[0x2F9A8]='CJK COMPATIBILITY IDEOGRAPH-2F9A8'
let s:d[0x2F9A9]='CJK COMPATIBILITY IDEOGRAPH-2F9A9'
let s:d[0x2F9AA]='CJK COMPATIBILITY IDEOGRAPH-2F9AA'
let s:d[0x2F9AB]='CJK COMPATIBILITY IDEOGRAPH-2F9AB'
let s:d[0x2F9AC]='CJK COMPATIBILITY IDEOGRAPH-2F9AC'
let s:d[0x2F9AD]='CJK COMPATIBILITY IDEOGRAPH-2F9AD'
let s:d[0x2F9AE]='CJK COMPATIBILITY IDEOGRAPH-2F9AE'
let s:d[0x2F9AF]='CJK COMPATIBILITY IDEOGRAPH-2F9AF'
let s:d[0x2F9B0]='CJK COMPATIBILITY IDEOGRAPH-2F9B0'
let s:d[0x2F9B1]='CJK COMPATIBILITY IDEOGRAPH-2F9B1'
let s:d[0x2F9B2]='CJK COMPATIBILITY IDEOGRAPH-2F9B2'
let s:d[0x2F9B3]='CJK COMPATIBILITY IDEOGRAPH-2F9B3'
let s:d[0x2F9B4]='CJK COMPATIBILITY IDEOGRAPH-2F9B4'
let s:d[0x2F9B5]='CJK COMPATIBILITY IDEOGRAPH-2F9B5'
let s:d[0x2F9B6]='CJK COMPATIBILITY IDEOGRAPH-2F9B6'
let s:d[0x2F9B7]='CJK COMPATIBILITY IDEOGRAPH-2F9B7'
let s:d[0x2F9B8]='CJK COMPATIBILITY IDEOGRAPH-2F9B8'
let s:d[0x2F9B9]='CJK COMPATIBILITY IDEOGRAPH-2F9B9'
let s:d[0x2F9BA]='CJK COMPATIBILITY IDEOGRAPH-2F9BA'
let s:d[0x2F9BB]='CJK COMPATIBILITY IDEOGRAPH-2F9BB'
let s:d[0x2F9BC]='CJK COMPATIBILITY IDEOGRAPH-2F9BC'
let s:d[0x2F9BD]='CJK COMPATIBILITY IDEOGRAPH-2F9BD'
let s:d[0x2F9BE]='CJK COMPATIBILITY IDEOGRAPH-2F9BE'
let s:d[0x2F9BF]='CJK COMPATIBILITY IDEOGRAPH-2F9BF'
let s:d[0x2F9C0]='CJK COMPATIBILITY IDEOGRAPH-2F9C0'
let s:d[0x2F9C1]='CJK COMPATIBILITY IDEOGRAPH-2F9C1'
let s:d[0x2F9C2]='CJK COMPATIBILITY IDEOGRAPH-2F9C2'
let s:d[0x2F9C3]='CJK COMPATIBILITY IDEOGRAPH-2F9C3'
let s:d[0x2F9C4]='CJK COMPATIBILITY IDEOGRAPH-2F9C4'
let s:d[0x2F9C5]='CJK COMPATIBILITY IDEOGRAPH-2F9C5'
let s:d[0x2F9C6]='CJK COMPATIBILITY IDEOGRAPH-2F9C6'
let s:d[0x2F9C7]='CJK COMPATIBILITY IDEOGRAPH-2F9C7'
let s:d[0x2F9C8]='CJK COMPATIBILITY IDEOGRAPH-2F9C8'
let s:d[0x2F9C9]='CJK COMPATIBILITY IDEOGRAPH-2F9C9'
let s:d[0x2F9CA]='CJK COMPATIBILITY IDEOGRAPH-2F9CA'
let s:d[0x2F9CB]='CJK COMPATIBILITY IDEOGRAPH-2F9CB'
let s:d[0x2F9CC]='CJK COMPATIBILITY IDEOGRAPH-2F9CC'
let s:d[0x2F9CD]='CJK COMPATIBILITY IDEOGRAPH-2F9CD'
let s:d[0x2F9CE]='CJK COMPATIBILITY IDEOGRAPH-2F9CE'
let s:d[0x2F9CF]='CJK COMPATIBILITY IDEOGRAPH-2F9CF'
let s:d[0x2F9D0]='CJK COMPATIBILITY IDEOGRAPH-2F9D0'
let s:d[0x2F9D1]='CJK COMPATIBILITY IDEOGRAPH-2F9D1'
let s:d[0x2F9D2]='CJK COMPATIBILITY IDEOGRAPH-2F9D2'
let s:d[0x2F9D3]='CJK COMPATIBILITY IDEOGRAPH-2F9D3'
let s:d[0x2F9D4]='CJK COMPATIBILITY IDEOGRAPH-2F9D4'
let s:d[0x2F9D5]='CJK COMPATIBILITY IDEOGRAPH-2F9D5'
let s:d[0x2F9D6]='CJK COMPATIBILITY IDEOGRAPH-2F9D6'
let s:d[0x2F9D7]='CJK COMPATIBILITY IDEOGRAPH-2F9D7'
let s:d[0x2F9D8]='CJK COMPATIBILITY IDEOGRAPH-2F9D8'
let s:d[0x2F9D9]='CJK COMPATIBILITY IDEOGRAPH-2F9D9'
let s:d[0x2F9DA]='CJK COMPATIBILITY IDEOGRAPH-2F9DA'
let s:d[0x2F9DB]='CJK COMPATIBILITY IDEOGRAPH-2F9DB'
let s:d[0x2F9DC]='CJK COMPATIBILITY IDEOGRAPH-2F9DC'
let s:d[0x2F9DD]='CJK COMPATIBILITY IDEOGRAPH-2F9DD'
let s:d[0x2F9DE]='CJK COMPATIBILITY IDEOGRAPH-2F9DE'
let s:d[0x2F9DF]='CJK COMPATIBILITY IDEOGRAPH-2F9DF'
let s:d[0x2F9E0]='CJK COMPATIBILITY IDEOGRAPH-2F9E0'
let s:d[0x2F9E1]='CJK COMPATIBILITY IDEOGRAPH-2F9E1'
let s:d[0x2F9E2]='CJK COMPATIBILITY IDEOGRAPH-2F9E2'
let s:d[0x2F9E3]='CJK COMPATIBILITY IDEOGRAPH-2F9E3'
let s:d[0x2F9E4]='CJK COMPATIBILITY IDEOGRAPH-2F9E4'
let s:d[0x2F9E5]='CJK COMPATIBILITY IDEOGRAPH-2F9E5'
let s:d[0x2F9E6]='CJK COMPATIBILITY IDEOGRAPH-2F9E6'
let s:d[0x2F9E7]='CJK COMPATIBILITY IDEOGRAPH-2F9E7'
let s:d[0x2F9E8]='CJK COMPATIBILITY IDEOGRAPH-2F9E8'
let s:d[0x2F9E9]='CJK COMPATIBILITY IDEOGRAPH-2F9E9'
let s:d[0x2F9EA]='CJK COMPATIBILITY IDEOGRAPH-2F9EA'
let s:d[0x2F9EB]='CJK COMPATIBILITY IDEOGRAPH-2F9EB'
let s:d[0x2F9EC]='CJK COMPATIBILITY IDEOGRAPH-2F9EC'
let s:d[0x2F9ED]='CJK COMPATIBILITY IDEOGRAPH-2F9ED'
let s:d[0x2F9EE]='CJK COMPATIBILITY IDEOGRAPH-2F9EE'
let s:d[0x2F9EF]='CJK COMPATIBILITY IDEOGRAPH-2F9EF'
let s:d[0x2F9F0]='CJK COMPATIBILITY IDEOGRAPH-2F9F0'
let s:d[0x2F9F1]='CJK COMPATIBILITY IDEOGRAPH-2F9F1'
let s:d[0x2F9F2]='CJK COMPATIBILITY IDEOGRAPH-2F9F2'
let s:d[0x2F9F3]='CJK COMPATIBILITY IDEOGRAPH-2F9F3'
let s:d[0x2F9F4]='CJK COMPATIBILITY IDEOGRAPH-2F9F4'
let s:d[0x2F9F5]='CJK COMPATIBILITY IDEOGRAPH-2F9F5'
let s:d[0x2F9F6]='CJK COMPATIBILITY IDEOGRAPH-2F9F6'
let s:d[0x2F9F7]='CJK COMPATIBILITY IDEOGRAPH-2F9F7'
let s:d[0x2F9F8]='CJK COMPATIBILITY IDEOGRAPH-2F9F8'
let s:d[0x2F9F9]='CJK COMPATIBILITY IDEOGRAPH-2F9F9'
let s:d[0x2F9FA]='CJK COMPATIBILITY IDEOGRAPH-2F9FA'
let s:d[0x2F9FB]='CJK COMPATIBILITY IDEOGRAPH-2F9FB'
let s:d[0x2F9FC]='CJK COMPATIBILITY IDEOGRAPH-2F9FC'
let s:d[0x2F9FD]='CJK COMPATIBILITY IDEOGRAPH-2F9FD'
let s:d[0x2F9FE]='CJK COMPATIBILITY IDEOGRAPH-2F9FE'
let s:d[0x2F9FF]='CJK COMPATIBILITY IDEOGRAPH-2F9FF'
let s:d[0x2FA00]='CJK COMPATIBILITY IDEOGRAPH-2FA00'
let s:d[0x2FA01]='CJK COMPATIBILITY IDEOGRAPH-2FA01'
let s:d[0x2FA02]='CJK COMPATIBILITY IDEOGRAPH-2FA02'
let s:d[0x2FA03]='CJK COMPATIBILITY IDEOGRAPH-2FA03'
let s:d[0x2FA04]='CJK COMPATIBILITY IDEOGRAPH-2FA04'
let s:d[0x2FA05]='CJK COMPATIBILITY IDEOGRAPH-2FA05'
let s:d[0x2FA06]='CJK COMPATIBILITY IDEOGRAPH-2FA06'
let s:d[0x2FA07]='CJK COMPATIBILITY IDEOGRAPH-2FA07'
let s:d[0x2FA08]='CJK COMPATIBILITY IDEOGRAPH-2FA08'
let s:d[0x2FA09]='CJK COMPATIBILITY IDEOGRAPH-2FA09'
let s:d[0x2FA0A]='CJK COMPATIBILITY IDEOGRAPH-2FA0A'
let s:d[0x2FA0B]='CJK COMPATIBILITY IDEOGRAPH-2FA0B'
let s:d[0x2FA0C]='CJK COMPATIBILITY IDEOGRAPH-2FA0C'
let s:d[0x2FA0D]='CJK COMPATIBILITY IDEOGRAPH-2FA0D'
let s:d[0x2FA0E]='CJK COMPATIBILITY IDEOGRAPH-2FA0E'
let s:d[0x2FA0F]='CJK COMPATIBILITY IDEOGRAPH-2FA0F'
let s:d[0x2FA10]='CJK COMPATIBILITY IDEOGRAPH-2FA10'
let s:d[0x2FA11]='CJK COMPATIBILITY IDEOGRAPH-2FA11'
let s:d[0x2FA12]='CJK COMPATIBILITY IDEOGRAPH-2FA12'
let s:d[0x2FA13]='CJK COMPATIBILITY IDEOGRAPH-2FA13'
let s:d[0x2FA14]='CJK COMPATIBILITY IDEOGRAPH-2FA14'
let s:d[0x2FA15]='CJK COMPATIBILITY IDEOGRAPH-2FA15'
let s:d[0x2FA16]='CJK COMPATIBILITY IDEOGRAPH-2FA16'
let s:d[0x2FA17]='CJK COMPATIBILITY IDEOGRAPH-2FA17'
let s:d[0x2FA18]='CJK COMPATIBILITY IDEOGRAPH-2FA18'
let s:d[0x2FA19]='CJK COMPATIBILITY IDEOGRAPH-2FA19'
let s:d[0x2FA1A]='CJK COMPATIBILITY IDEOGRAPH-2FA1A'
let s:d[0x2FA1B]='CJK COMPATIBILITY IDEOGRAPH-2FA1B'
let s:d[0x2FA1C]='CJK COMPATIBILITY IDEOGRAPH-2FA1C'
let s:d[0x2FA1D]='CJK COMPATIBILITY IDEOGRAPH-2FA1D'
let s:d[0x2FFFE]='<not a character>'
let s:d[0x2FFFF]='<not a character>'
let s:d[0x3FFFE]='<not a character>'
let s:d[0x3FFFF]='<not a character>'
let s:d[0x4FFFE]='<not a character>'
let s:d[0x4FFFF]='<not a character>'
let s:d[0x5FFFE]='<not a character>'
let s:d[0x5FFFF]='<not a character>'
let s:d[0x6FFFE]='<not a character>'
let s:d[0x6FFFF]='<not a character>'
let s:d[0x7FFFE]='<not a character>'
let s:d[0x7FFFF]='<not a character>'
let s:d[0x8FFFE]='<not a character>'
let s:d[0x8FFFF]='<not a character>'
let s:d[0x9FFFE]='<not a character>'
let s:d[0x9FFFF]='<not a character>'
let s:d[0xAFFFE]='<not a character>'
let s:d[0xAFFFF]='<not a character>'
let s:d[0xBFFFE]='<not a character>'
let s:d[0xBFFFF]='<not a character>'
let s:d[0xCFFFE]='<not a character>'
let s:d[0xCFFFF]='<not a character>'
let s:d[0xDFFFE]='<not a character>'
let s:d[0xDFFFF]='<not a character>'
let s:d[0xE0001]='LANGUAGE TAG'
let s:d[0xE0020]='TAG SPACE'
let s:d[0xE0021]='TAG EXCLAMATION MARK'
let s:d[0xE0022]='TAG QUOTATION MARK'
let s:d[0xE0023]='TAG NUMBER SIGN'
let s:d[0xE0024]='TAG DOLLAR SIGN'
let s:d[0xE0025]='TAG PERCENT SIGN'
let s:d[0xE0026]='TAG AMPERSAND'
let s:d[0xE0027]='TAG APOSTROPHE'
let s:d[0xE0028]='TAG LEFT PARENTHESIS'
let s:d[0xE0029]='TAG RIGHT PARENTHESIS'
let s:d[0xE002A]='TAG ASTERISK'
let s:d[0xE002B]='TAG PLUS SIGN'
let s:d[0xE002C]='TAG COMMA'
let s:d[0xE002D]='TAG HYPHEN-MINUS'
let s:d[0xE002E]='TAG FULL STOP'
let s:d[0xE002F]='TAG SOLIDUS'
let s:d[0xE0030]='TAG DIGIT ZERO'
let s:d[0xE0031]='TAG DIGIT ONE'
let s:d[0xE0032]='TAG DIGIT TWO'
let s:d[0xE0033]='TAG DIGIT THREE'
let s:d[0xE0034]='TAG DIGIT FOUR'
let s:d[0xE0035]='TAG DIGIT FIVE'
let s:d[0xE0036]='TAG DIGIT SIX'
let s:d[0xE0037]='TAG DIGIT SEVEN'
let s:d[0xE0038]='TAG DIGIT EIGHT'
let s:d[0xE0039]='TAG DIGIT NINE'
let s:d[0xE003A]='TAG COLON'
let s:d[0xE003B]='TAG SEMICOLON'
let s:d[0xE003C]='TAG LESS-THAN SIGN'
let s:d[0xE003D]='TAG EQUALS SIGN'
let s:d[0xE003E]='TAG GREATER-THAN SIGN'
let s:d[0xE003F]='TAG QUESTION MARK'
let s:d[0xE0040]='TAG COMMERCIAL AT'
let s:d[0xE0041]='TAG LATIN CAPITAL LETTER A'
let s:d[0xE0042]='TAG LATIN CAPITAL LETTER B'
let s:d[0xE0043]='TAG LATIN CAPITAL LETTER C'
let s:d[0xE0044]='TAG LATIN CAPITAL LETTER D'
let s:d[0xE0045]='TAG LATIN CAPITAL LETTER E'
let s:d[0xE0046]='TAG LATIN CAPITAL LETTER F'
let s:d[0xE0047]='TAG LATIN CAPITAL LETTER G'
let s:d[0xE0048]='TAG LATIN CAPITAL LETTER H'
let s:d[0xE0049]='TAG LATIN CAPITAL LETTER I'
let s:d[0xE004A]='TAG LATIN CAPITAL LETTER J'
let s:d[0xE004B]='TAG LATIN CAPITAL LETTER K'
let s:d[0xE004C]='TAG LATIN CAPITAL LETTER L'
let s:d[0xE004D]='TAG LATIN CAPITAL LETTER M'
let s:d[0xE004E]='TAG LATIN CAPITAL LETTER N'
let s:d[0xE004F]='TAG LATIN CAPITAL LETTER O'
let s:d[0xE0050]='TAG LATIN CAPITAL LETTER P'
let s:d[0xE0051]='TAG LATIN CAPITAL LETTER Q'
let s:d[0xE0052]='TAG LATIN CAPITAL LETTER R'
let s:d[0xE0053]='TAG LATIN CAPITAL LETTER S'
let s:d[0xE0054]='TAG LATIN CAPITAL LETTER T'
let s:d[0xE0055]='TAG LATIN CAPITAL LETTER U'
let s:d[0xE0056]='TAG LATIN CAPITAL LETTER V'
let s:d[0xE0057]='TAG LATIN CAPITAL LETTER W'
let s:d[0xE0058]='TAG LATIN CAPITAL LETTER X'
let s:d[0xE0059]='TAG LATIN CAPITAL LETTER Y'
let s:d[0xE005A]='TAG LATIN CAPITAL LETTER Z'
let s:d[0xE005B]='TAG LEFT SQUARE BRACKET'
let s:d[0xE005C]='TAG REVERSE SOLIDUS'
let s:d[0xE005D]='TAG RIGHT SQUARE BRACKET'
let s:d[0xE005E]='TAG CIRCUMFLEX ACCENT'
let s:d[0xE005F]='TAG LOW LINE'
let s:d[0xE0060]='TAG GRAVE ACCENT'
let s:d[0xE0061]='TAG LATIN SMALL LETTER A'
let s:d[0xE0062]='TAG LATIN SMALL LETTER B'
let s:d[0xE0063]='TAG LATIN SMALL LETTER C'
let s:d[0xE0064]='TAG LATIN SMALL LETTER D'
let s:d[0xE0065]='TAG LATIN SMALL LETTER E'
let s:d[0xE0066]='TAG LATIN SMALL LETTER F'
let s:d[0xE0067]='TAG LATIN SMALL LETTER G'
let s:d[0xE0068]='TAG LATIN SMALL LETTER H'
let s:d[0xE0069]='TAG LATIN SMALL LETTER I'
let s:d[0xE006A]='TAG LATIN SMALL LETTER J'
let s:d[0xE006B]='TAG LATIN SMALL LETTER K'
let s:d[0xE006C]='TAG LATIN SMALL LETTER L'
let s:d[0xE006D]='TAG LATIN SMALL LETTER M'
let s:d[0xE006E]='TAG LATIN SMALL LETTER N'
let s:d[0xE006F]='TAG LATIN SMALL LETTER O'
let s:d[0xE0070]='TAG LATIN SMALL LETTER P'
let s:d[0xE0071]='TAG LATIN SMALL LETTER Q'
let s:d[0xE0072]='TAG LATIN SMALL LETTER R'
let s:d[0xE0073]='TAG LATIN SMALL LETTER S'
let s:d[0xE0074]='TAG LATIN SMALL LETTER T'
let s:d[0xE0075]='TAG LATIN SMALL LETTER U'
let s:d[0xE0076]='TAG LATIN SMALL LETTER V'
let s:d[0xE0077]='TAG LATIN SMALL LETTER W'
let s:d[0xE0078]='TAG LATIN SMALL LETTER X'
let s:d[0xE0079]='TAG LATIN SMALL LETTER Y'
let s:d[0xE007A]='TAG LATIN SMALL LETTER Z'
let s:d[0xE007B]='TAG LEFT CURLY BRACKET'
let s:d[0xE007C]='TAG VERTICAL LINE'
let s:d[0xE007D]='TAG RIGHT CURLY BRACKET'
let s:d[0xE007E]='TAG TILDE'
let s:d[0xE007F]='CANCEL TAG'
let s:d[0xE0100]='VARIATION SELECTOR-17'
let s:d[0xE0101]='VARIATION SELECTOR-18'
let s:d[0xE0102]='VARIATION SELECTOR-19'
let s:d[0xE0103]='VARIATION SELECTOR-20'
let s:d[0xE0104]='VARIATION SELECTOR-21'
let s:d[0xE0105]='VARIATION SELECTOR-22'
let s:d[0xE0106]='VARIATION SELECTOR-23'
let s:d[0xE0107]='VARIATION SELECTOR-24'
let s:d[0xE0108]='VARIATION SELECTOR-25'
let s:d[0xE0109]='VARIATION SELECTOR-26'
let s:d[0xE010A]='VARIATION SELECTOR-27'
let s:d[0xE010B]='VARIATION SELECTOR-28'
let s:d[0xE010C]='VARIATION SELECTOR-29'
let s:d[0xE010D]='VARIATION SELECTOR-30'
let s:d[0xE010E]='VARIATION SELECTOR-31'
let s:d[0xE010F]='VARIATION SELECTOR-32'
let s:d[0xE0110]='VARIATION SELECTOR-33'
let s:d[0xE0111]='VARIATION SELECTOR-34'
let s:d[0xE0112]='VARIATION SELECTOR-35'
let s:d[0xE0113]='VARIATION SELECTOR-36'
let s:d[0xE0114]='VARIATION SELECTOR-37'
let s:d[0xE0115]='VARIATION SELECTOR-38'
let s:d[0xE0116]='VARIATION SELECTOR-39'
let s:d[0xE0117]='VARIATION SELECTOR-40'
let s:d[0xE0118]='VARIATION SELECTOR-41'
let s:d[0xE0119]='VARIATION SELECTOR-42'
let s:d[0xE011A]='VARIATION SELECTOR-43'
let s:d[0xE011B]='VARIATION SELECTOR-44'
let s:d[0xE011C]='VARIATION SELECTOR-45'
let s:d[0xE011D]='VARIATION SELECTOR-46'
let s:d[0xE011E]='VARIATION SELECTOR-47'
let s:d[0xE011F]='VARIATION SELECTOR-48'
let s:d[0xE0120]='VARIATION SELECTOR-49'
let s:d[0xE0121]='VARIATION SELECTOR-50'
let s:d[0xE0122]='VARIATION SELECTOR-51'
let s:d[0xE0123]='VARIATION SELECTOR-52'
let s:d[0xE0124]='VARIATION SELECTOR-53'
let s:d[0xE0125]='VARIATION SELECTOR-54'
let s:d[0xE0126]='VARIATION SELECTOR-55'
let s:d[0xE0127]='VARIATION SELECTOR-56'
let s:d[0xE0128]='VARIATION SELECTOR-57'
let s:d[0xE0129]='VARIATION SELECTOR-58'
let s:d[0xE012A]='VARIATION SELECTOR-59'
let s:d[0xE012B]='VARIATION SELECTOR-60'
let s:d[0xE012C]='VARIATION SELECTOR-61'
let s:d[0xE012D]='VARIATION SELECTOR-62'
let s:d[0xE012E]='VARIATION SELECTOR-63'
let s:d[0xE012F]='VARIATION SELECTOR-64'
let s:d[0xE0130]='VARIATION SELECTOR-65'
let s:d[0xE0131]='VARIATION SELECTOR-66'
let s:d[0xE0132]='VARIATION SELECTOR-67'
let s:d[0xE0133]='VARIATION SELECTOR-68'
let s:d[0xE0134]='VARIATION SELECTOR-69'
let s:d[0xE0135]='VARIATION SELECTOR-70'
let s:d[0xE0136]='VARIATION SELECTOR-71'
let s:d[0xE0137]='VARIATION SELECTOR-72'
let s:d[0xE0138]='VARIATION SELECTOR-73'
let s:d[0xE0139]='VARIATION SELECTOR-74'
let s:d[0xE013A]='VARIATION SELECTOR-75'
let s:d[0xE013B]='VARIATION SELECTOR-76'
let s:d[0xE013C]='VARIATION SELECTOR-77'
let s:d[0xE013D]='VARIATION SELECTOR-78'
let s:d[0xE013E]='VARIATION SELECTOR-79'
let s:d[0xE013F]='VARIATION SELECTOR-80'
let s:d[0xE0140]='VARIATION SELECTOR-81'
let s:d[0xE0141]='VARIATION SELECTOR-82'
let s:d[0xE0142]='VARIATION SELECTOR-83'
let s:d[0xE0143]='VARIATION SELECTOR-84'
let s:d[0xE0144]='VARIATION SELECTOR-85'
let s:d[0xE0145]='VARIATION SELECTOR-86'
let s:d[0xE0146]='VARIATION SELECTOR-87'
let s:d[0xE0147]='VARIATION SELECTOR-88'
let s:d[0xE0148]='VARIATION SELECTOR-89'
let s:d[0xE0149]='VARIATION SELECTOR-90'
let s:d[0xE014A]='VARIATION SELECTOR-91'
let s:d[0xE014B]='VARIATION SELECTOR-92'
let s:d[0xE014C]='VARIATION SELECTOR-93'
let s:d[0xE014D]='VARIATION SELECTOR-94'
let s:d[0xE014E]='VARIATION SELECTOR-95'
let s:d[0xE014F]='VARIATION SELECTOR-96'
let s:d[0xE0150]='VARIATION SELECTOR-97'
let s:d[0xE0151]='VARIATION SELECTOR-98'
let s:d[0xE0152]='VARIATION SELECTOR-99'
let s:d[0xE0153]='VARIATION SELECTOR-100'
let s:d[0xE0154]='VARIATION SELECTOR-101'
let s:d[0xE0155]='VARIATION SELECTOR-102'
let s:d[0xE0156]='VARIATION SELECTOR-103'
let s:d[0xE0157]='VARIATION SELECTOR-104'
let s:d[0xE0158]='VARIATION SELECTOR-105'
let s:d[0xE0159]='VARIATION SELECTOR-106'
let s:d[0xE015A]='VARIATION SELECTOR-107'
let s:d[0xE015B]='VARIATION SELECTOR-108'
let s:d[0xE015C]='VARIATION SELECTOR-109'
let s:d[0xE015D]='VARIATION SELECTOR-110'
let s:d[0xE015E]='VARIATION SELECTOR-111'
let s:d[0xE015F]='VARIATION SELECTOR-112'
let s:d[0xE0160]='VARIATION SELECTOR-113'
let s:d[0xE0161]='VARIATION SELECTOR-114'
let s:d[0xE0162]='VARIATION SELECTOR-115'
let s:d[0xE0163]='VARIATION SELECTOR-116'
let s:d[0xE0164]='VARIATION SELECTOR-117'
let s:d[0xE0165]='VARIATION SELECTOR-118'
let s:d[0xE0166]='VARIATION SELECTOR-119'
let s:d[0xE0167]='VARIATION SELECTOR-120'
let s:d[0xE0168]='VARIATION SELECTOR-121'
let s:d[0xE0169]='VARIATION SELECTOR-122'
let s:d[0xE016A]='VARIATION SELECTOR-123'
let s:d[0xE016B]='VARIATION SELECTOR-124'
let s:d[0xE016C]='VARIATION SELECTOR-125'
let s:d[0xE016D]='VARIATION SELECTOR-126'
let s:d[0xE016E]='VARIATION SELECTOR-127'
let s:d[0xE016F]='VARIATION SELECTOR-128'
let s:d[0xE0170]='VARIATION SELECTOR-129'
let s:d[0xE0171]='VARIATION SELECTOR-130'
let s:d[0xE0172]='VARIATION SELECTOR-131'
let s:d[0xE0173]='VARIATION SELECTOR-132'
let s:d[0xE0174]='VARIATION SELECTOR-133'
let s:d[0xE0175]='VARIATION SELECTOR-134'
let s:d[0xE0176]='VARIATION SELECTOR-135'
let s:d[0xE0177]='VARIATION SELECTOR-136'
let s:d[0xE0178]='VARIATION SELECTOR-137'
let s:d[0xE0179]='VARIATION SELECTOR-138'
let s:d[0xE017A]='VARIATION SELECTOR-139'
let s:d[0xE017B]='VARIATION SELECTOR-140'
let s:d[0xE017C]='VARIATION SELECTOR-141'
let s:d[0xE017D]='VARIATION SELECTOR-142'
let s:d[0xE017E]='VARIATION SELECTOR-143'
let s:d[0xE017F]='VARIATION SELECTOR-144'
let s:d[0xE0180]='VARIATION SELECTOR-145'
let s:d[0xE0181]='VARIATION SELECTOR-146'
let s:d[0xE0182]='VARIATION SELECTOR-147'
let s:d[0xE0183]='VARIATION SELECTOR-148'
let s:d[0xE0184]='VARIATION SELECTOR-149'
let s:d[0xE0185]='VARIATION SELECTOR-150'
let s:d[0xE0186]='VARIATION SELECTOR-151'
let s:d[0xE0187]='VARIATION SELECTOR-152'
let s:d[0xE0188]='VARIATION SELECTOR-153'
let s:d[0xE0189]='VARIATION SELECTOR-154'
let s:d[0xE018A]='VARIATION SELECTOR-155'
let s:d[0xE018B]='VARIATION SELECTOR-156'
let s:d[0xE018C]='VARIATION SELECTOR-157'
let s:d[0xE018D]='VARIATION SELECTOR-158'
let s:d[0xE018E]='VARIATION SELECTOR-159'
let s:d[0xE018F]='VARIATION SELECTOR-160'
let s:d[0xE0190]='VARIATION SELECTOR-161'
let s:d[0xE0191]='VARIATION SELECTOR-162'
let s:d[0xE0192]='VARIATION SELECTOR-163'
let s:d[0xE0193]='VARIATION SELECTOR-164'
let s:d[0xE0194]='VARIATION SELECTOR-165'
let s:d[0xE0195]='VARIATION SELECTOR-166'
let s:d[0xE0196]='VARIATION SELECTOR-167'
let s:d[0xE0197]='VARIATION SELECTOR-168'
let s:d[0xE0198]='VARIATION SELECTOR-169'
let s:d[0xE0199]='VARIATION SELECTOR-170'
let s:d[0xE019A]='VARIATION SELECTOR-171'
let s:d[0xE019B]='VARIATION SELECTOR-172'
let s:d[0xE019C]='VARIATION SELECTOR-173'
let s:d[0xE019D]='VARIATION SELECTOR-174'
let s:d[0xE019E]='VARIATION SELECTOR-175'
let s:d[0xE019F]='VARIATION SELECTOR-176'
let s:d[0xE01A0]='VARIATION SELECTOR-177'
let s:d[0xE01A1]='VARIATION SELECTOR-178'
let s:d[0xE01A2]='VARIATION SELECTOR-179'
let s:d[0xE01A3]='VARIATION SELECTOR-180'
let s:d[0xE01A4]='VARIATION SELECTOR-181'
let s:d[0xE01A5]='VARIATION SELECTOR-182'
let s:d[0xE01A6]='VARIATION SELECTOR-183'
let s:d[0xE01A7]='VARIATION SELECTOR-184'
let s:d[0xE01A8]='VARIATION SELECTOR-185'
let s:d[0xE01A9]='VARIATION SELECTOR-186'
let s:d[0xE01AA]='VARIATION SELECTOR-187'
let s:d[0xE01AB]='VARIATION SELECTOR-188'
let s:d[0xE01AC]='VARIATION SELECTOR-189'
let s:d[0xE01AD]='VARIATION SELECTOR-190'
let s:d[0xE01AE]='VARIATION SELECTOR-191'
let s:d[0xE01AF]='VARIATION SELECTOR-192'
let s:d[0xE01B0]='VARIATION SELECTOR-193'
let s:d[0xE01B1]='VARIATION SELECTOR-194'
let s:d[0xE01B2]='VARIATION SELECTOR-195'
let s:d[0xE01B3]='VARIATION SELECTOR-196'
let s:d[0xE01B4]='VARIATION SELECTOR-197'
let s:d[0xE01B5]='VARIATION SELECTOR-198'
let s:d[0xE01B6]='VARIATION SELECTOR-199'
let s:d[0xE01B7]='VARIATION SELECTOR-200'
let s:d[0xE01B8]='VARIATION SELECTOR-201'
let s:d[0xE01B9]='VARIATION SELECTOR-202'
let s:d[0xE01BA]='VARIATION SELECTOR-203'
let s:d[0xE01BB]='VARIATION SELECTOR-204'
let s:d[0xE01BC]='VARIATION SELECTOR-205'
let s:d[0xE01BD]='VARIATION SELECTOR-206'
let s:d[0xE01BE]='VARIATION SELECTOR-207'
let s:d[0xE01BF]='VARIATION SELECTOR-208'
let s:d[0xE01C0]='VARIATION SELECTOR-209'
let s:d[0xE01C1]='VARIATION SELECTOR-210'
let s:d[0xE01C2]='VARIATION SELECTOR-211'
let s:d[0xE01C3]='VARIATION SELECTOR-212'
let s:d[0xE01C4]='VARIATION SELECTOR-213'
let s:d[0xE01C5]='VARIATION SELECTOR-214'
let s:d[0xE01C6]='VARIATION SELECTOR-215'
let s:d[0xE01C7]='VARIATION SELECTOR-216'
let s:d[0xE01C8]='VARIATION SELECTOR-217'
let s:d[0xE01C9]='VARIATION SELECTOR-218'
let s:d[0xE01CA]='VARIATION SELECTOR-219'
let s:d[0xE01CB]='VARIATION SELECTOR-220'
let s:d[0xE01CC]='VARIATION SELECTOR-221'
let s:d[0xE01CD]='VARIATION SELECTOR-222'
let s:d[0xE01CE]='VARIATION SELECTOR-223'
let s:d[0xE01CF]='VARIATION SELECTOR-224'
let s:d[0xE01D0]='VARIATION SELECTOR-225'
let s:d[0xE01D1]='VARIATION SELECTOR-226'
let s:d[0xE01D2]='VARIATION SELECTOR-227'
let s:d[0xE01D3]='VARIATION SELECTOR-228'
let s:d[0xE01D4]='VARIATION SELECTOR-229'
let s:d[0xE01D5]='VARIATION SELECTOR-230'
let s:d[0xE01D6]='VARIATION SELECTOR-231'
let s:d[0xE01D7]='VARIATION SELECTOR-232'
let s:d[0xE01D8]='VARIATION SELECTOR-233'
let s:d[0xE01D9]='VARIATION SELECTOR-234'
let s:d[0xE01DA]='VARIATION SELECTOR-235'
let s:d[0xE01DB]='VARIATION SELECTOR-236'
let s:d[0xE01DC]='VARIATION SELECTOR-237'
let s:d[0xE01DD]='VARIATION SELECTOR-238'
let s:d[0xE01DE]='VARIATION SELECTOR-239'
let s:d[0xE01DF]='VARIATION SELECTOR-240'
let s:d[0xE01E0]='VARIATION SELECTOR-241'
let s:d[0xE01E1]='VARIATION SELECTOR-242'
let s:d[0xE01E2]='VARIATION SELECTOR-243'
let s:d[0xE01E3]='VARIATION SELECTOR-244'
let s:d[0xE01E4]='VARIATION SELECTOR-245'
let s:d[0xE01E5]='VARIATION SELECTOR-246'
let s:d[0xE01E6]='VARIATION SELECTOR-247'
let s:d[0xE01E7]='VARIATION SELECTOR-248'
let s:d[0xE01E8]='VARIATION SELECTOR-249'
let s:d[0xE01E9]='VARIATION SELECTOR-250'
let s:d[0xE01EA]='VARIATION SELECTOR-251'
let s:d[0xE01EB]='VARIATION SELECTOR-252'
let s:d[0xE01EC]='VARIATION SELECTOR-253'
let s:d[0xE01ED]='VARIATION SELECTOR-254'
let s:d[0xE01EE]='VARIATION SELECTOR-255'
let s:d[0xE01EF]='VARIATION SELECTOR-256'
let s:d[0xEFFFE]='<not a character>'
let s:d[0xEFFFF]='<not a character>'
let s:d[0xFFFFE]='<not a character>'
let s:d[0xFFFFF]='<not a character>'
let s:d[0x10FFFE]='<not a character>'
let s:d[0x10FFFF]='<not a character>'
